/*****************************************************/
/**  Autogenerated cmu_us_slt spam accent params  */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_slt_spamf0_accent.h"

static const cst_cart_node cmu_us_slt_spamf0_accent_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0001, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0002, (cst_val *)&val_0002},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0005 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0008, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0011, (cst_val *)&val_0011},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0012, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0015, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0017, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0020, (cst_val *)&val_0019},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0021, (cst_val *)&val_0020},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0022, (cst_val *)&val_0021},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0023, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0027, (cst_val *)&val_0026},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0028, (cst_val *)&val_0006},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0029, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0028 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0032, (cst_val *)&val_0010},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0033, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0036, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0039, (cst_val *)&val_0034},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0040, (cst_val *)&val_0035},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0041, (cst_val *)&val_0036},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0042, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0045, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0041 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0047, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0050, (cst_val *)&val_0044},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0051, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0052, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0056, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0058, (cst_val *)&val_0003},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0059, (cst_val *)&val_0052},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0060, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0062, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0064, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0066, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0069, (cst_val *)&val_0006},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0070, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0072, (cst_val *)&val_0060},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0073, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0064 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0078, (cst_val *)&val_0021},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0079, (cst_val *)&val_0031},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0080, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0083, (cst_val *)&val_0022},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0084, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0087, (cst_val *)&val_0071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0090, (cst_val *)&val_0022},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0091, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0093, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0096, (cst_val *)&val_0079},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0097, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0101, (cst_val *)&val_0083},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0102, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0104, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0106, (cst_val *)&val_0086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0108, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0110, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0113, (cst_val *)&val_0092},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0114, (cst_val *)&val_0093},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0115, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0119, (cst_val *)&val_0006},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0120, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0123, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0101 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0126, (cst_val *)&val_0102},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0127, (cst_val *)&val_0103},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0128, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0130, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0133, (cst_val *)&val_0022},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0134, (cst_val *)&val_0107},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0135, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0138, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0141, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0144, (cst_val *)&val_0115},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0145, (cst_val *)&val_0022},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0146, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0149, (cst_val *)&val_0118},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0150, (cst_val *)&val_0022},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0151, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0154, (cst_val *)&val_0054},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0155, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0158, (cst_val *)&val_0060},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0159, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0162, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0165, (cst_val *)&val_0054},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0166, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0169, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0172, (cst_val *)&val_0102},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0173, (cst_val *)&val_0022},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0174, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0178, (cst_val *)&val_0136},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_accent_NO_0179, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_accent_NO_0182, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_spamf0_accent_feat_table[] = {
"lisp_cg_break",
"syllable_duration",
"pos_in_word",
"syl_numphones",
"ssyl_in",
"syl_in",
"syl_vowel",
"n.n.lisp_cg_break",
"n.accented",
"syl_out",
"p.accented",
"R:SylStructure.parent.gpos",
"R:SylStructure.parent.R:Word.n.gpos",
"n.stress",
"nn.stress",
"accented",
"p.stress",
"n.lisp_cg_break",
"ssyl_out",
"pp.stress",
NULL };

const cst_cart cmu_us_slt_spamf0_accent_cart = {
  cmu_us_slt_spamf0_accent_cart_nodes,
  cmu_us_slt_spamf0_accent_feat_table
};
