/*****************************************************/
/**  Autogenerated cmu_us_awb phrase carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_awb_spamf0_phrase.h"

static const cst_cart_node cmu_us_awb_spamf0_phrase_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0002, (cst_val *)&val_0002},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0003, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0004, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0005 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0008 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0009, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0011, (cst_val *)&val_0010},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0012, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0014 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0016, (cst_val *)&val_0015},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0017, (cst_val *)&val_0016},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0018, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0020, (cst_val *)&val_0019},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0021, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0025, (cst_val *)&val_0023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0026, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0029, (cst_val *)&val_0027},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0030, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0035, (cst_val *)&val_0002},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0036, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0035 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0039, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0042, (cst_val *)&val_0038},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0043, (cst_val *)&val_0039},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0044, (cst_val *)&val_0040},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0045, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0046, (cst_val *)&val_0042},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0047, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0049, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0052, (cst_val *)&val_0047},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0053, (cst_val *)&val_0048},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0054, (cst_val *)&val_0049},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0055, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0058, (cst_val *)&val_0053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0062, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0065, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0067, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0069, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0071, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0074, (cst_val *)&val_0041},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0075, (cst_val *)&val_0067},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0076, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0068 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0078, (cst_val *)&val_0069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0081, (cst_val *)&val_0072},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0082, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0084, (cst_val *)&val_0027},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0085, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0090, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0092, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0093, (cst_val *)&val_0081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0096, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0099, (cst_val *)&val_0050},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0100, (cst_val *)&val_0087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0088 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0102, (cst_val *)&val_0089},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0103, (cst_val *)&val_0090},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0104, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0107, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0093 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0109, (cst_val *)&val_0094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0113, (cst_val *)&val_0040},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0114, (cst_val *)&val_0098},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0115, (cst_val *)&val_0099},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0116, (cst_val *)&val_0100},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0117, (cst_val *)&val_0101},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0118, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0122, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0107 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0125, (cst_val *)&val_0108},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0126, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0129, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0132, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0135, (cst_val *)&val_0117},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0136, (cst_val *)&val_0069},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0137, (cst_val *)&val_0118},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0138, (cst_val *)&val_0087},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0139, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0142, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0122 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0144, (cst_val *)&val_0123},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0145, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0147, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0150, (cst_val *)&val_0127},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0151, (cst_val *)&val_0011},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0152, (cst_val *)&val_0128},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0153, (cst_val *)&val_0002},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0154, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0156, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0158, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0162, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0165, (cst_val *)&val_0138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0168, (cst_val *)&val_0141},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0169, (cst_val *)&val_0081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0173, (cst_val *)&val_0002},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0174, (cst_val *)&val_0100},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0175, (cst_val *)&val_0145},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0176, (cst_val *)&val_0146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0181, (cst_val *)&val_0151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0183, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0186, (cst_val *)&val_0156},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0187, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0190, (cst_val *)&val_0159},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0191, (cst_val *)&val_0160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0195, (cst_val *)&val_0164},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0196, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0198, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0201, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0169 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0204, (cst_val *)&val_0170},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0205, (cst_val *)&val_0171},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0206, (cst_val *)&val_0172},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0207, (cst_val *)&val_0173},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0208, (cst_val *)&val_0002},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0209, (cst_val *)&val_0174},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0210, (cst_val *)&val_0006},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0211, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0178 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0216, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0219, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0181 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0221, (cst_val *)&val_0182},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0183 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0223, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0226, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0228, (cst_val *)&val_0188},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0229, (cst_val *)&val_0189},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0230, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0232, (cst_val *)&val_0191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0193 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0235, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0196 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0238, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0241, (cst_val *)&val_0199},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0242, (cst_val *)&val_0200},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0243, (cst_val *)&val_0040},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0244, (cst_val *)&val_0069},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0245, (cst_val *)&val_0201},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0247, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0249, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0253, (cst_val *)&val_0098},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0254, (cst_val *)&val_0208},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0255, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0256, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0211 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0260, (cst_val *)&val_0027},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0261, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0263, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0265, (cst_val *)&val_0215},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0266, (cst_val *)&val_0216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0220 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0271, (cst_val *)&val_0002},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0272, (cst_val *)&val_0221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0276, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0225 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0278, (cst_val *)&val_0156},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0279, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0281, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0227 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0283, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0284, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0285, (cst_val *)&val_0229},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0286, (cst_val *)&val_0230},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0290, (cst_val *)&val_0234},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0237 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0294, (cst_val *)&val_0023},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0295, (cst_val *)&val_0186},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0296, (cst_val *)&val_0069},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0297, (cst_val *)&val_0238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0241 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0301, (cst_val *)&val_0242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0304, (cst_val *)&val_0245},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0305, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0248 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0309, (cst_val *)&val_0040},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0310, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0311, (cst_val *)&val_0249},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0312, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0314, (cst_val *)&val_0251},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0315, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0254 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0318, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0255 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0320, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0323, (cst_val *)&val_0259},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0324, (cst_val *)&val_0260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0326, (cst_val *)&val_0173},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0327, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0330, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0334, (cst_val *)&val_0268},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0335, (cst_val *)&val_0208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0270 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0338, (cst_val *)&val_0256},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0339, (cst_val *)&val_0271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0341, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0345, (cst_val *)&val_0064},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0346, (cst_val *)&val_0276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0348, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0279 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0350, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0353, (cst_val *)&val_0282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0355, (cst_val *)&val_0087},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0356, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0359, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0360, (cst_val *)&val_0286},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0361, (cst_val *)&val_0069},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0362, (cst_val *)&val_0287},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0363, (cst_val *)&val_0011},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0364, (cst_val *)&val_0288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0289 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0366, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0370, (cst_val *)&val_0293},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0294 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0372, (cst_val *)&val_0295},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0373, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0297 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0376, (cst_val *)&val_0141},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0377, (cst_val *)&val_0298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0300 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0380, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0385, (cst_val *)&val_0067},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0386, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0387, (cst_val *)&val_0306},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0388, (cst_val *)&val_0307},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0389, (cst_val *)&val_0069},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0390, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0394, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0314 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0398, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0315 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0400, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0402, (cst_val *)&val_0318},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0403, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0320 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0406, (cst_val *)&val_0081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0409, (cst_val *)&val_0323},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0410, (cst_val *)&val_0208},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0411, (cst_val *)&val_0324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0413, (cst_val *)&val_0326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0329 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0417, (cst_val *)&val_0330},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0418, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0421, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0422, (cst_val *)&val_0326},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0423, (cst_val *)&val_0333},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0335 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0426, (cst_val *)&val_0336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0337 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0428, (cst_val *)&val_0338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0339 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0431, (cst_val *)&val_0340},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0432, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0435, (cst_val *)&val_0041},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0436, (cst_val *)&val_0344},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0345 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0438, (cst_val *)&val_0346},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0439, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0350 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0444, (cst_val *)&val_0156},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0445, (cst_val *)&val_0156},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0446, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0449, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0354 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0452, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_phrase_NO_0454, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0358 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_spamf0_phrase_feat_table[] = {
"R:SylStructure.parent.R:Syllable.syl_break",
"R:SylStructure.parent.parent.R:Word.pos_in_phrase",
"R:SylStructure.parent.R:Syllable.position_type",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_syls_in_phrase",
"lisp_cg_content_words_in_phrase",
"R:SylStructure.parent.lisp_cg_syl_ratio",
"R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:SylStructure.parent.parent.gpos",
"R:SylStructure.parent.R:Syllable.n.n.lisp_cg_break",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_phrase_ratio",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_find_phrase_number",
"R:SylStructure.parent.R:Syllable.syl_in",
"R:SylStructure.parent.R:Syllable.syl_out",
"R:SylStructure.parent.R:Syllable.p.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_spamf0_phrase_cart = {
  cmu_us_awb_spamf0_phrase_cart_nodes,
  cmu_us_awb_spamf0_phrase_feat_table
};
