/*****************************************************/
/**  Autogenerated cmu_us_rms spam accent params  */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_rms_spamf0_accent.h"

static const cst_cart_node cmu_us_rms_spamf0_accent_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0002, (cst_val *)&val_0002},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0003, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0004, (cst_val *)&val_0004},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0005, (cst_val *)&val_0005},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0010, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0013, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0014 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0015, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0017, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0019, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0021 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0022, (cst_val *)&val_0013},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0023, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0026, (cst_val *)&val_0005},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0027, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0029, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0032, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0034, (cst_val *)&val_0002},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0035, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0039, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0040, (cst_val *)&val_0035},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0041, (cst_val *)&val_0005},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0042, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0045, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0047, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0042 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0050, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0051, (cst_val *)&val_0043},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0052, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0054, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0045 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0056, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0059, (cst_val *)&val_0005},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0060, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0063, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0066, (cst_val *)&val_0053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0068, (cst_val *)&val_0050},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0069, (cst_val *)&val_0055},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0070, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0072, (cst_val *)&val_0058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0076, (cst_val *)&val_0062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0064 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0079, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0081, (cst_val *)&val_0067},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0082, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0084, (cst_val *)&val_0050},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0085, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0089, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0091, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0092, (cst_val *)&val_0074},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0093, (cst_val *)&val_0075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0096, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0100, (cst_val *)&val_0013},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0101, (cst_val *)&val_0081},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0102, (cst_val *)&val_0002},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0103, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0105, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0108, (cst_val *)&val_0085},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0109, (cst_val *)&val_0086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0113, (cst_val *)&val_0090},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0114, (cst_val *)&val_0091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0118, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0119, (cst_val *)&val_0005},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0120, (cst_val *)&val_0095},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0121, (cst_val *)&val_0005},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0122, (cst_val *)&val_0011},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0123, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0124, (cst_val *)&val_0096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0127, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0128, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0131, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0135, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0137, (cst_val *)&val_0107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0140, (cst_val *)&val_0110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0143, (cst_val *)&val_0113},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0144, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0146, (cst_val *)&val_0002},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0147, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0150, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0152, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0155, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0157, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0160, (cst_val *)&val_0125},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0161, (cst_val *)&val_0126},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0162, (cst_val *)&val_0127},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0163, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0167, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0170, (cst_val *)&val_0002},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0171, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0172, (cst_val *)&val_0134},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0173, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0178, (cst_val *)&val_0019},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_accent_NO_0179, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0141 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0182, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0142 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_accent_NO_0184, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_spamf0_accent_feat_table[] = {
"syllable_duration",
"lisp_cg_break",
"stress",
"p.lisp_cg_break",
"R:SylStructure.parent.R:Word.p.gpos",
"syl_out",
"syl_in",
"n.lisp_cg_break",
"ssyl_in",
"syl_vowel",
"p.p.lisp_cg_break",
"p.stress",
"R:SylStructure.parent.gpos",
"p.accented",
"syl_numphones",
"pos_in_word",
"accented",
"n.n.lisp_cg_break",
"n.accented",
"pp.stress",
NULL };

const cst_cart cmu_us_rms_spamf0_accent_cart = {
  cmu_us_rms_spamf0_accent_cart_nodes,
  cmu_us_rms_spamf0_accent_feat_table
};
