DEF_STATIC_CONST_VAL_FLOAT(val_0000,0.517857);
DEF_STATIC_CONST_VAL_FLOAT(val_0001,3.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0002,1.000000);
DEF_STATIC_CONST_VAL_STRING(val_0003,"0");
DEF_STATIC_CONST_VAL_FLOAT(val_0004,0.775000);
DEF_STATIC_CONST_VAL_FLOAT(val_0005,5.132650);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0004 6
DEF_STATIC_CONST_VAL_FLOAT(val_0006,5.070250);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0006 8
DEF_STATIC_CONST_VAL_FLOAT(val_0007,0.134783);
DEF_STATIC_CONST_VAL_FLOAT(val_0008,0.076087);
DEF_STATIC_CONST_VAL_FLOAT(val_0009,5.095280);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0009 11
DEF_STATIC_CONST_VAL_FLOAT(val_0010,0.091346);
DEF_STATIC_CONST_VAL_FLOAT(val_0011,5.133550);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0011 13
DEF_STATIC_CONST_VAL_FLOAT(val_0012,5.113340);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0008 14
DEF_STATIC_CONST_VAL_FLOAT(val_0013,5.079500);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0003 15
DEF_STATIC_CONST_VAL_FLOAT(val_0014,0.300000);
DEF_STATIC_CONST_VAL_STRING(val_0015,"cc");
DEF_STATIC_CONST_VAL_FLOAT(val_0016,5.028440);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0016 18
DEF_STATIC_CONST_VAL_FLOAT(val_0017,7.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0018,10.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0019,5.115000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0020 22
DEF_STATIC_CONST_VAL_STRING(val_0020,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0021,3.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0022,5.059300);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0023 25
DEF_STATIC_CONST_VAL_FLOAT(val_0023,4.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0024,5.083780);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0025 27
DEF_STATIC_CONST_VAL_FLOAT(val_0025,5.064460);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0022 28
DEF_STATIC_CONST_VAL_STRING(val_0026,"det");
DEF_STATIC_CONST_VAL_FLOAT(val_0027,5.102740);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0028 30
DEF_STATIC_CONST_VAL_FLOAT(val_0028,5.091040);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0019 31
DEF_STATIC_CONST_VAL_FLOAT(val_0029,6.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0030,0.079426);
DEF_STATIC_CONST_VAL_FLOAT(val_0031,5.040590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0033 35
DEF_STATIC_CONST_VAL_FLOAT(val_0032,5.032130);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0032 36
DEF_STATIC_CONST_VAL_FLOAT(val_0033,5.070910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0031 37
DEF_STATIC_CONST_VAL_FLOAT(val_0034,5.086640);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0018 38
DEF_STATIC_CONST_VAL_FLOAT(val_0035,5.108300);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0015 39
DEF_STATIC_CONST_VAL_FLOAT(val_0036,0.225000);
DEF_STATIC_CONST_VAL_FLOAT(val_0037,5.121080);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0040 42
DEF_STATIC_CONST_VAL_FLOAT(val_0038,5.103110);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0039 43
DEF_STATIC_CONST_VAL_FLOAT(val_0039,5.068960);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0002 44
DEF_STATIC_CONST_VAL_FLOAT(val_0040,2.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0041,9.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0042,0.533333);
DEF_STATIC_CONST_VAL_FLOAT(val_0043,5.145470);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0050 52
DEF_STATIC_CONST_VAL_FLOAT(val_0044,5.171140);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0049 53
DEF_STATIC_CONST_VAL_FLOAT(val_0045,9.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0046,5.116800);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0053 55
DEF_STATIC_CONST_VAL_FLOAT(val_0047,5.144190);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0048 56
DEF_STATIC_CONST_VAL_FLOAT(val_0048,0.436364);
DEF_STATIC_CONST_VAL_STRING(val_0049,"single");
DEF_STATIC_CONST_VAL_FLOAT(val_0050,1.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0051,5.120600);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0059 61
DEF_STATIC_CONST_VAL_FLOAT(val_0052,5.090390);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0058 62
DEF_STATIC_CONST_VAL_FLOAT(val_0053,6.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0054,5.134760);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0063 65
DEF_STATIC_CONST_VAL_FLOAT(val_0055,5.151430);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0062 66
DEF_STATIC_CONST_VAL_FLOAT(val_0056,6.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0057,0.228788);
DEF_STATIC_CONST_VAL_FLOAT(val_0058,5.107310);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0067 69
DEF_STATIC_CONST_VAL_FLOAT(val_0059,5.124400);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0066 70
DEF_STATIC_CONST_VAL_FLOAT(val_0060,5.130590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0057 71
DEF_STATIC_CONST_VAL_FLOAT(val_0061,5.103510);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0071 73
DEF_STATIC_CONST_VAL_FLOAT(val_0062,2.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0063,0.227273);
DEF_STATIC_CONST_VAL_FLOAT(val_0064,5.145000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0074 76
DEF_STATIC_CONST_VAL_STRING(val_0065,"initial");
DEF_STATIC_CONST_VAL_FLOAT(val_0066,5.165950);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0076 78
DEF_STATIC_CONST_VAL_FLOAT(val_0067,5.178850);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0073 79
DEF_STATIC_CONST_VAL_FLOAT(val_0068,12.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0069,5.115360);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0079 81
DEF_STATIC_CONST_VAL_FLOAT(val_0070,5.154310);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0056 82
DEF_STATIC_CONST_VAL_FLOAT(val_0071,5.057030);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0082 84
DEF_STATIC_CONST_VAL_FLOAT(val_0072,5.103300);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0047 85
DEF_STATIC_CONST_VAL_FLOAT(val_0073,0.309091);
DEF_STATIC_CONST_VAL_FLOAT(val_0074,5.181770);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0086 88
DEF_STATIC_CONST_VAL_FLOAT(val_0075,5.163220);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0085 89
DEF_STATIC_CONST_VAL_FLOAT(val_0076,5.138910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0089 91
DEF_STATIC_CONST_VAL_FLOAT(val_0077,0.232168);
DEF_STATIC_CONST_VAL_FLOAT(val_0078,5.164230);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0092 94
DEF_STATIC_CONST_VAL_FLOAT(val_0079,5.160440);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0091 95
DEF_STATIC_CONST_VAL_FLOAT(val_0080,5.133000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0095 97
DEF_STATIC_CONST_VAL_FLOAT(val_0081,5.151540);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0046 98
DEF_STATIC_CONST_VAL_FLOAT(val_0082,1.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0083,7.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0084,0.145238);
DEF_STATIC_CONST_VAL_FLOAT(val_0085,5.140880);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0103 105
DEF_STATIC_CONST_VAL_FLOAT(val_0086,5.161630);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0102 106
DEF_STATIC_CONST_VAL_FLOAT(val_0087,5.183370);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0101 107
DEF_STATIC_CONST_VAL_FLOAT(val_0088,11.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0089,5.126800);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0108 110
DEF_STATIC_CONST_VAL_FLOAT(val_0090,5.081510);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0107 111
DEF_STATIC_CONST_VAL_FLOAT(val_0091,5.146810);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0100 112
DEF_STATIC_CONST_VAL_FLOAT(val_0092,13.000000);
DEF_STATIC_CONST_VAL_STRING(val_0093,"aux");
DEF_STATIC_CONST_VAL_FLOAT(val_0094,5.165490);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0113 115
DEF_STATIC_CONST_VAL_FLOAT(val_0095,5.193890);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0112 116
DEF_STATIC_CONST_VAL_FLOAT(val_0096,14.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0097,5.148060);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0116 118
DEF_STATIC_CONST_VAL_FLOAT(val_0098,5.169590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0099 119
DEF_STATIC_CONST_VAL_FLOAT(val_0099,20.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0100,17.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0101,13.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0102,5.152430);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0121 123
DEF_STATIC_CONST_VAL_FLOAT(val_0103,5.177400);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0124 126
DEF_STATIC_CONST_VAL_FLOAT(val_0104,5.197380);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0126 128
DEF_STATIC_CONST_VAL_FLOAT(val_0105,5.189140);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0123 129
DEF_STATIC_CONST_VAL_FLOAT(val_0106,5.172840);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0129 131
DEF_STATIC_CONST_VAL_FLOAT(val_0107,5.156490);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0120 132
DEF_STATIC_CONST_VAL_FLOAT(val_0108,5.164960);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0132 134
DEF_STATIC_CONST_VAL_FLOAT(val_0109,5.128280);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0119 135
DEF_STATIC_CONST_VAL_FLOAT(val_0110,5.195100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0098 136
DEF_STATIC_CONST_VAL_FLOAT(val_0111,5.144370);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0136 138
DEF_STATIC_CONST_VAL_FLOAT(val_0112,5.100360);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0045 139
DEF_STATIC_CONST_VAL_FLOAT(val_0113,0.308300);
DEF_STATIC_CONST_VAL_FLOAT(val_0114,5.161680);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0141 143
DEF_STATIC_CONST_VAL_FLOAT(val_0115,13.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0116,5.133670);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0143 145
DEF_STATIC_CONST_VAL_FLOAT(val_0117,5.119910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0140 146
DEF_STATIC_CONST_VAL_FLOAT(val_0118,10.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0119,0.366667);
DEF_STATIC_CONST_VAL_FLOAT(val_0120,5.082150);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0149 151
DEF_STATIC_CONST_VAL_FLOAT(val_0121,5.093750);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0148 152
DEF_STATIC_CONST_VAL_FLOAT(val_0122,0.371429);
DEF_STATIC_CONST_VAL_FLOAT(val_0123,5.145590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0152 154
DEF_STATIC_CONST_VAL_FLOAT(val_0124,5.115680);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0147 155
DEF_STATIC_CONST_VAL_FLOAT(val_0125,5.080490);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0155 157
DEF_STATIC_CONST_VAL_FLOAT(val_0126,5.102690);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0146 158
DEF_STATIC_CONST_VAL_FLOAT(val_0127,16.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0128,8.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0129,5.128610);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0159 161
DEF_STATIC_CONST_VAL_FLOAT(val_0130,5.154400);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0158 162
DEF_STATIC_CONST_VAL_FLOAT(val_0131,5.117000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0139 163
DEF_STATIC_CONST_VAL_FLOAT(val_0132,5.117070);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0163 165
DEF_STATIC_CONST_VAL_FLOAT(val_0133,11.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0134,0.450000);
DEF_STATIC_CONST_VAL_FLOAT(val_0135,5.093960);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0166 168
DEF_STATIC_CONST_VAL_FLOAT(val_0136,5.085910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0165 169
DEF_STATIC_CONST_VAL_FLOAT(val_0137,5.063340);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0044 170
DEF_STATIC_CONST_VAL_FLOAT(val_0138,4.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0139,5.054780);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0172 174
DEF_STATIC_CONST_VAL_FLOAT(val_0140,5.086340);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0171 175
DEF_STATIC_CONST_VAL_STRING(val_0141,"1");
DEF_STATIC_CONST_VAL_FLOAT(val_0142,3.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0143,5.106380);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0176 178
DEF_STATIC_CONST_VAL_FLOAT(val_0144,5.087260);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0175 179
DEF_STATIC_CONST_VAL_FLOAT(val_0145,0.423529);
DEF_STATIC_CONST_VAL_FLOAT(val_0146,5.079820);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0179 181
DEF_STATIC_CONST_VAL_FLOAT(val_0147,5.071380);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0170 182
DEF_STATIC_CONST_VAL_FLOAT(val_0148,5.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0149,5.053100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0182 184
DEF_STATIC_CONST_VAL_FLOAT(val_0150,5.067070);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0001 185
DEF_STATIC_CONST_VAL_FLOAT(val_0151,19.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0152,5.122050);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0188 190
DEF_STATIC_CONST_VAL_FLOAT(val_0153,5.111030);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0187 191
DEF_STATIC_CONST_VAL_FLOAT(val_0154,5.095050);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0186 192
DEF_STATIC_CONST_VAL_FLOAT(val_0155,5.076060);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0185 193
DEF_STATIC_CONST_VAL_FLOAT(val_0156,0.455556);
DEF_STATIC_CONST_VAL_FLOAT(val_0157,0.383838);
DEF_STATIC_CONST_VAL_FLOAT(val_0158,5.087800);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0195 197
DEF_STATIC_CONST_VAL_FLOAT(val_0159,0.419580);
DEF_STATIC_CONST_VAL_FLOAT(val_0160,5.066380);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0197 199
DEF_STATIC_CONST_VAL_FLOAT(val_0161,5.078330);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0194 200
DEF_STATIC_CONST_VAL_FLOAT(val_0162,7.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0163,5.038190);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0200 202
DEF_STATIC_CONST_VAL_FLOAT(val_0164,5.072210);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0202 204
DEF_STATIC_CONST_VAL_FLOAT(val_0165,5.040370);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0204 206
DEF_STATIC_CONST_VAL_FLOAT(val_0166,5.067310);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0193 207
DEF_STATIC_CONST_VAL_FLOAT(val_0167,5.110490);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0207 209
DEF_STATIC_CONST_VAL_FLOAT(val_0168,5.103090);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0209 211
DEF_STATIC_CONST_VAL_FLOAT(val_0169,5.077190);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0212 214
DEF_STATIC_CONST_VAL_FLOAT(val_0170,5.094700);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0211 215
DEF_STATIC_CONST_VAL_FLOAT(val_0171,5.067810);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0000 216
DEF_STATIC_CONST_VAL_STRING(val_0172,"4");
DEF_STATIC_CONST_VAL_FLOAT(val_0173,14.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0174,10.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0175,3.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0176,5.019060);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0221 223
DEF_STATIC_CONST_VAL_FLOAT(val_0177,4.990400);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0220 224
DEF_STATIC_CONST_VAL_FLOAT(val_0178,4.951700);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0225 227
DEF_STATIC_CONST_VAL_FLOAT(val_0179,4.977680);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0224 228
DEF_STATIC_CONST_VAL_FLOAT(val_0180,4.999180);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0219 229
DEF_STATIC_CONST_VAL_FLOAT(val_0181,5.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0182,4.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0183,0.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0184,4.987530);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0232 234
DEF_STATIC_CONST_VAL_FLOAT(val_0185,4.979200);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0231 235
DEF_STATIC_CONST_VAL_FLOAT(val_0186,4.966930);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0230 236
DEF_STATIC_CONST_VAL_FLOAT(val_0187,4.957000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0229 237
DEF_STATIC_CONST_VAL_FLOAT(val_0188,4.991000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0218 238
DEF_STATIC_CONST_VAL_FLOAT(val_0189,12.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0190,4.971730);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0239 241
DEF_STATIC_CONST_VAL_FLOAT(val_0191,4.981150);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0238 242
DEF_STATIC_CONST_VAL_FLOAT(val_0192,13.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0193,6.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0194,7.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0195,4.951530);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0244 246
DEF_STATIC_CONST_VAL_FLOAT(val_0196,5.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0197,4.962120);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0246 248
DEF_STATIC_CONST_VAL_FLOAT(val_0198,4.957960);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0243 249
DEF_STATIC_CONST_VAL_FLOAT(val_0199,4.942590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0242 250
DEF_STATIC_CONST_VAL_FLOAT(val_0200,4.972200);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0217 251
DEF_STATIC_CONST_VAL_FLOAT(val_0201,16.299999);
DEF_STATIC_CONST_VAL_FLOAT(val_0202,4.967920);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0252 254
DEF_STATIC_CONST_VAL_FLOAT(val_0203,4.951680);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0251 255
DEF_STATIC_CONST_VAL_FLOAT(val_0204,19.200001);
DEF_STATIC_CONST_VAL_FLOAT(val_0205,17.200001);
DEF_STATIC_CONST_VAL_FLOAT(val_0206,4.941430);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0256 258
DEF_STATIC_CONST_VAL_FLOAT(val_0207,4.931930);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0255 259
DEF_STATIC_CONST_VAL_FLOAT(val_0208,4.914000);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0216 260
DEF_STATIC_CONST_VAL_FLOAT(val_0209,0.550000);
DEF_STATIC_CONST_VAL_FLOAT(val_0210,0.863636);
DEF_STATIC_CONST_VAL_FLOAT(val_0211,0.763333);
DEF_STATIC_CONST_VAL_FLOAT(val_0212,4.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0213,5.150800);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0266 268
DEF_STATIC_CONST_VAL_FLOAT(val_0214,5.151900);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0265 269
DEF_STATIC_CONST_VAL_FLOAT(val_0215,5.135360);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0264 270
DEF_STATIC_CONST_VAL_FLOAT(val_0216,5.125430);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0263 271
DEF_STATIC_CONST_VAL_FLOAT(val_0217,5.115620);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0271 273
DEF_STATIC_CONST_VAL_FLOAT(val_0218,5.089110);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0262 274
DEF_STATIC_CONST_VAL_FLOAT(val_0219,5.070620);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0275 277
DEF_STATIC_CONST_VAL_FLOAT(val_0220,5.046150);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0274 278
DEF_STATIC_CONST_VAL_FLOAT(val_0221,5.016460);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0261 279
DEF_STATIC_CONST_VAL_FLOAT(val_0222,0.590909);
DEF_STATIC_CONST_VAL_FLOAT(val_0223,5.066120);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0281 283
DEF_STATIC_CONST_VAL_FLOAT(val_0224,5.083100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0280 284
DEF_STATIC_CONST_VAL_FLOAT(val_0225,4.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0226,5.041060);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0286 288
DEF_STATIC_CONST_VAL_FLOAT(val_0227,5.022520);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0285 289
DEF_STATIC_CONST_VAL_FLOAT(val_0228,5.062370);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0284 290
DEF_STATIC_CONST_VAL_FLOAT(val_0229,5.049880);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0290 292
DEF_STATIC_CONST_VAL_FLOAT(val_0230,5.069480);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0292 294
DEF_STATIC_CONST_VAL_FLOAT(val_0231,5.059080);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0279 295
DEF_STATIC_CONST_VAL_FLOAT(val_0232,2.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0233,5.100160);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0296 298
DEF_STATIC_CONST_VAL_FLOAT(val_0234,4.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0235,5.076070);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0300 302
DEF_STATIC_CONST_VAL_FLOAT(val_0236,5.090510);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0299 303
DEF_STATIC_CONST_VAL_FLOAT(val_0237,5.053900);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0303 305
DEF_STATIC_CONST_VAL_FLOAT(val_0238,5.078200);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0298 306
DEF_STATIC_CONST_VAL_FLOAT(val_0239,5.091380);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0295 307
DEF_STATIC_CONST_VAL_FLOAT(val_0240,5.078640);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0307 309
DEF_STATIC_CONST_VAL_FLOAT(val_0241,0.681818);
DEF_STATIC_CONST_VAL_FLOAT(val_0242,5.052290);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0310 312
DEF_STATIC_CONST_VAL_FLOAT(val_0243,5.044760);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0309 313
DEF_STATIC_CONST_VAL_FLOAT(val_0244,5.064670);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0260 314
DEF_STATIC_CONST_VAL_FLOAT(val_0245,0.856000);
DEF_STATIC_CONST_VAL_FLOAT(val_0246,5.128400);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0316 318
DEF_STATIC_CONST_VAL_FLOAT(val_0247,5.105760);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0315 319
DEF_STATIC_CONST_VAL_FLOAT(val_0248,0.586000);
DEF_STATIC_CONST_VAL_FLOAT(val_0249,15.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0250,5.095150);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0321 323
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0320 324
DEF_STATIC_CONST_VAL_FLOAT(val_0251,7.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0252,5.066740);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0326 328
DEF_STATIC_CONST_VAL_FLOAT(val_0253,13.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0254,5.057910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0328 330
DEF_STATIC_CONST_VAL_FLOAT(val_0255,5.045480);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0325 331
DEF_STATIC_CONST_VAL_FLOAT(val_0256,5.070210);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0324 332
DEF_STATIC_CONST_VAL_FLOAT(val_0257,0.543421);
DEF_STATIC_CONST_VAL_FLOAT(val_0258,5.093210);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0332 334
DEF_STATIC_CONST_VAL_FLOAT(val_0259,5.066270);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0319 335
DEF_STATIC_CONST_VAL_STRING(val_0260,"to");
DEF_STATIC_CONST_VAL_FLOAT(val_0261,5.103640);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0335 337
DEF_STATIC_CONST_VAL_FLOAT(val_0262,8.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0263,10.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0264,5.027220);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0342 344
DEF_STATIC_CONST_VAL_FLOAT(val_0265,5.003420);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0341 345
DEF_STATIC_CONST_VAL_FLOAT(val_0266,5.040160);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0346 348
DEF_STATIC_CONST_VAL_FLOAT(val_0267,5.048850);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0345 349
DEF_STATIC_CONST_VAL_FLOAT(val_0268,5.041560);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0349 351
DEF_STATIC_CONST_VAL_FLOAT(val_0269,0.717195);
DEF_STATIC_CONST_VAL_FLOAT(val_0270,5.044720);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0352 354
DEF_STATIC_CONST_VAL_FLOAT(val_0271,5.017210);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0351 355
DEF_STATIC_CONST_VAL_FLOAT(val_0272,5.016620);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0340 356
DEF_STATIC_CONST_VAL_FLOAT(val_0273,5.005600);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0339 357
DEF_STATIC_CONST_VAL_FLOAT(val_0274,5.047580);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0338 358
DEF_STATIC_CONST_VAL_FLOAT(val_0275,5.025320);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0360 362
DEF_STATIC_CONST_VAL_FLOAT(val_0276,5.040130);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0359 363
DEF_STATIC_CONST_VAL_FLOAT(val_0277,5.062290);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0363 365
DEF_STATIC_CONST_VAL_FLOAT(val_0278,5.039070);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0358 366
DEF_STATIC_CONST_VAL_FLOAT(val_0279,8.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0280,5.063420);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0367 369
DEF_STATIC_CONST_VAL_FLOAT(val_0281,9.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0282,0.784314);
DEF_STATIC_CONST_VAL_FLOAT(val_0283,5.055190);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0370 372
DEF_STATIC_CONST_VAL_FLOAT(val_0284,5.055590);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0369 373
DEF_STATIC_CONST_VAL_FLOAT(val_0285,5.047220);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0366 374
DEF_STATIC_CONST_VAL_FLOAT(val_0286,15.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0287,5.079540);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0374 376
DEF_STATIC_CONST_VAL_FLOAT(val_0288,5.056100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0337 377
DEF_STATIC_CONST_VAL_FLOAT(val_0289,0.692941);
DEF_STATIC_CONST_VAL_FLOAT(val_0290,5.088230);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0379 381
DEF_STATIC_CONST_VAL_FLOAT(val_0291,0.640271);
DEF_STATIC_CONST_VAL_FLOAT(val_0292,5.055020);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0382 384
DEF_STATIC_CONST_VAL_FLOAT(val_0293,5.074990);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0381 385
DEF_STATIC_CONST_VAL_FLOAT(val_0294,5.086430);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0378 386
DEF_STATIC_CONST_VAL_FLOAT(val_0295,5.043100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0386 388
DEF_STATIC_CONST_VAL_FLOAT(val_0296,0.655385);
DEF_STATIC_CONST_VAL_FLOAT(val_0297,5.078270);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0389 391
DEF_STATIC_CONST_VAL_FLOAT(val_0298,5.069550);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0388 392
DEF_STATIC_CONST_VAL_FLOAT(val_0299,5.047350);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0377 393
DEF_STATIC_CONST_VAL_FLOAT(val_0300,0.760000);
DEF_STATIC_CONST_VAL_FLOAT(val_0301,5.057940);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0395 397
DEF_STATIC_CONST_VAL_FLOAT(val_0302,5.075960);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0394 398
DEF_STATIC_CONST_VAL_FLOAT(val_0303,0.788261);
DEF_STATIC_CONST_VAL_FLOAT(val_0304,5.056090);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0398 400
DEF_STATIC_CONST_VAL_FLOAT(val_0305,5.038450);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0393 401
DEF_STATIC_CONST_VAL_FLOAT(val_0306,5.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0307,5.021070);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0401 403
DEF_STATIC_CONST_VAL_FLOAT(val_0308,18.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0309,7.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0310,11.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0311,5.050820);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0407 409
DEF_STATIC_CONST_VAL_FLOAT(val_0312,5.041850);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0406 410
DEF_STATIC_CONST_VAL_FLOAT(val_0313,5.073100);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0410 412
DEF_STATIC_CONST_VAL_FLOAT(val_0314,5.062460);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0412 414
DEF_STATIC_CONST_VAL_FLOAT(val_0315,5.044470);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0405 415
DEF_STATIC_CONST_VAL_FLOAT(val_0316,5.026910);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0415 417
DEF_STATIC_CONST_VAL_FLOAT(val_0317,5.051640);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0404 418
DEF_STATIC_CONST_VAL_FLOAT(val_0318,5.064720);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0403 419
DEF_STATIC_CONST_VAL_FLOAT(val_0319,5.036090);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0314 420
DEF_STATIC_CONST_VAL_FLOAT(val_0320,0.928571);
DEF_STATIC_CONST_VAL_FLOAT(val_0321,0.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0322,5.078760);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0421 423
DEF_STATIC_CONST_VAL_FLOAT(val_0323,14.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0324,5.051240);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0426 428
DEF_STATIC_CONST_VAL_FLOAT(val_0325,5.032290);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0425 429
DEF_STATIC_CONST_VAL_FLOAT(val_0326,5.058750);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0424 430
DEF_STATIC_CONST_VAL_FLOAT(val_0327,9.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0328,10.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0329,5.033180);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0433 435
DEF_STATIC_CONST_VAL_FLOAT(val_0330,5.027110);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0432 436
DEF_STATIC_CONST_VAL_FLOAT(val_0331,5.050940);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0431 437
DEF_STATIC_CONST_VAL_STRING(val_0332,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0333,5.030700);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0438 440
DEF_STATIC_CONST_VAL_FLOAT(val_0334,5.007250);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0437 441
DEF_STATIC_CONST_VAL_FLOAT(val_0335,5.034650);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0430 442
DEF_STATIC_CONST_VAL_FLOAT(val_0336,5.045990);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0423 443
DEF_STATIC_CONST_VAL_STRING(val_0337,"in");
DEF_STATIC_CONST_VAL_FLOAT(val_0338,5.041210);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0443 445
DEF_STATIC_CONST_VAL_FLOAT(val_0339,0.903297);
DEF_STATIC_CONST_VAL_FLOAT(val_0340,5.055820);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0445 447
DEF_STATIC_CONST_VAL_FLOAT(val_0341,5.070460);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0420 448
DEF_STATIC_CONST_VAL_FLOAT(val_0342,5.026660);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0449 451
DEF_STATIC_CONST_VAL_FLOAT(val_0343,4.982370);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0448 452
DEF_STATIC_CONST_VAL_FLOAT(val_0344,9.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0345,5.045580);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0453 455
DEF_STATIC_CONST_VAL_FLOAT(val_0346,5.021690);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0452 456
DEF_STATIC_CONST_VAL_FLOAT(val_0347,10.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0348,0.941667);
DEF_STATIC_CONST_VAL_FLOAT(val_0349,5.017530);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0457 459
DEF_STATIC_CONST_VAL_FLOAT(val_0350,5.001840);
#define CTNODE_cmu_us_slt_spamf0_phrase_NO_0456 460
DEF_STATIC_CONST_VAL_FLOAT(val_0351,5.034320);
