LIBRARY	"fliteDll"
EXPORTS 
	flite_init
	flite_voice_select
	flite_file_to_speech
	flite_text_to_speech
	flite_phones_to_speech
	flite_ssml_file_to_speech
	flite_ssml_text_to_speech
	flite_text_to_wave
	flite_synth_text
	flite_synth_phones
	flite_do_synth
	flite_process_output
	usenglish_init
	cmu_lex_init
	cmu_dari_lang_init
	cmu_dari_lex_init
	cmu_pashto_lang_init
	cmu_pashto_lex_init
	new_voice
	delete_voice
	flite_feat_set
	flite_feat_set_float
	flite_feat_set_int
	flite_feat_set_string
	flite_feat_remove
	flite_ffeature_string
	flite_get_param_val
	flite_get_param_float
	flite_get_param_int
	flite_get_param_string
	flite_voice_add_lex_addenda
	cg_synth
	cg_db_val
	clunits_synth
	clunit_db_val
	dur_stats_val
	cart_val
	uttfunc_val
	lexicon_val
	cst_strdup
	cst_sprintf
	audio_open
	audio_write
	audio_close
	audio_stream_chunk
	audio_streaming_info_val
	new_audio_streaming_info
	
	