/*******************************************************/
/**  generated lexicon entry file from cmu    */
/*******************************************************/

#include "cst_string.h"
#include "cst_lexicon.h"

const int cmu_lex_num_bytes = 
#include "cmu_lex_num_bytes.c"
;

const int cmu_lex_num_entries = 36963;

const char * const cmu_lex_phone_table[57] = 
{
    "_epsilon_",
    "ax0",
    "ey1",
    "l",
    "p",
    "ih1",
    "r",
    "t",
    "g",
    "er0",
    "b",
    "aa1",
    "n",
    "k",
    "th",
    "eh0",
    "s",
    "m",
    "ao1",
    "eh1",
    "d",
    "aa0",
    "ae1",
    "ow1",
    "ih0",
    "iy0",
    "ow0",
    "ey0",
    "uw1",
    "v",
    "iy1",
    "z",
    "uw0",
    "ng",
    "sh",
    "ae0",
    "ah1",
    "ao0",
    "f",
    "hh",
    "ay1",
    "jh",
    "aw1",
    "aw0",
    "ch",
    "zh",
    "y",
    "uh1",
    "dh",
    "w",
    "er1",
    "oy1",
    "ay0",
    "oy0",
    "uh0",
    "ah0",
    NULL
};

const char * const cmu_lex_phones_huff_table[257] = 
{
    NULL, /* reserved */
#include "cmu_lex_phones_huff_table.c"
    NULL
};

const char * const cmu_lex_entries_huff_table[257] = 
{
    NULL, /* reserved */
#include "cmu_lex_entries_huff_table.c"
    NULL
};

