#
# External Addenda lexicon
#
#  #Comment
#  Blank lines are ignored
#  "headword" [pos] : phone phone phone phone ...
#
#  phone *must* be in the phoneset for the lexicon, thus vowels must be
#  appended with 0 or 1 stress values (if you have them in your language)
#  head word should be quoted if it contains non-ascii or whitespace
#
sleekit j : s l iy1 k ih0 t
trochled : t r ao1 k ax0 l d
voldemort n :
   

