/*****************************************************/
/**  Autogenerated cmu_us_awb spam accent params  */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_awb_spamf0_accent.h"

static const cst_cart_node cmu_us_awb_spamf0_accent_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0002, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0003 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0004, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0005 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0008, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0011, (cst_val *)&val_0011},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0012, (cst_val *)&val_0012},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0013, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0014 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0015, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0020, (cst_val *)&val_0019},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0021, (cst_val *)&val_0011},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0022, (cst_val *)&val_0020},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0023, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0025, (cst_val *)&val_0023},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0026, (cst_val *)&val_0024},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0027, (cst_val *)&val_0010},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0028, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0031, (cst_val *)&val_0010},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0032, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0036, (cst_val *)&val_0008},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0037, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0040, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0043, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0040 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0046, (cst_val *)&val_0002},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0047, (cst_val *)&val_0041},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0048, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0050, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0045 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0053, (cst_val *)&val_0024},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0054, (cst_val *)&val_0046},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0055, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0057, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0060, (cst_val *)&val_0052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0062, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0063, (cst_val *)&val_0007},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0064, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0068, (cst_val *)&val_0057},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0069, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0073, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0075, (cst_val *)&val_0057},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0076, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0080, (cst_val *)&val_0011},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0081, (cst_val *)&val_0011},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0082, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0068 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0086, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0088, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0090, (cst_val *)&val_0024},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0091, (cst_val *)&val_0071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0093, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0097, (cst_val *)&val_0011},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0098, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0100, (cst_val *)&val_0077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0101, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0104, (cst_val *)&val_0080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0107, (cst_val *)&val_0083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0109, (cst_val *)&val_0085},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0110, (cst_val *)&val_0008},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0111, (cst_val *)&val_0086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0113, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0116, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0120, (cst_val *)&val_0032},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0121, (cst_val *)&val_0011},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0122, (cst_val *)&val_0011},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0123, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0126, (cst_val *)&val_0024},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0127, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0130, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0132, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0135, (cst_val *)&val_0024},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0136, (cst_val *)&val_0101},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0137, (cst_val *)&val_0102},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0138, (cst_val *)&val_0103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0141, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0107 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0144, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0145, (cst_val *)&val_0109},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0146, (cst_val *)&val_0110},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0147, (cst_val *)&val_0011},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0148, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0155, (cst_val *)&val_0117},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0156, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0159, (cst_val *)&val_0120},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0160, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0162, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0165, (cst_val *)&val_0124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0168, (cst_val *)&val_0008},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0169, (cst_val *)&val_0011},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0170, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0127 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0172, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0176, (cst_val *)&val_0023},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0177, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0180, (cst_val *)&val_0011},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0181, (cst_val *)&val_0133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_spamf0_accent_NO_0184, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_spamf0_accent_NO_0185, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_spamf0_accent_feat_table[] = {
"lisp_cg_break",
"syllable_duration",
"pos_in_word",
"syl_numphones",
"pp.stress",
"R:SylStructure.parent.R:Word.n.gpos",
"p.stress",
"accented",
"syl_vowel",
"R:SylStructure.parent.R:Word.p.gpos",
"syl_in",
"ssyl_in",
"ssyl_out",
"p.lisp_cg_break",
"R:SylStructure.parent.gpos",
"syl_out",
"p.p.lisp_cg_break",
"nn.stress",
"stress",
"syl_break",
"n.accented",
"n.n.lisp_cg_break",
"n.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_spamf0_accent_cart = {
  cmu_us_awb_spamf0_accent_cart_nodes,
  cmu_us_awb_spamf0_accent_feat_table
};
