DEF_STATIC_CONST_VAL_STRING(val_0000,"4");
DEF_STATIC_CONST_VAL_FLOAT(val_0001,9.600000);
DEF_STATIC_CONST_VAL_STRING(val_0002,"single");
DEF_STATIC_CONST_VAL_FLOAT(val_0003,8.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0004,4.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0005,4.396490);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0004 6
DEF_STATIC_CONST_VAL_FLOAT(val_0006,3.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0007,4.368390);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0006 8
DEF_STATIC_CONST_VAL_FLOAT(val_0008,4.383990);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0003 9
DEF_STATIC_CONST_VAL_FLOAT(val_0009,4.386140);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0009 11
DEF_STATIC_CONST_VAL_FLOAT(val_0010,11.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0011,7.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0012,4.413500);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0012 14
DEF_STATIC_CONST_VAL_FLOAT(val_0013,4.445100);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0011 15
DEF_STATIC_CONST_VAL_FLOAT(val_0014,4.398630);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0002 16
DEF_STATIC_CONST_VAL_FLOAT(val_0015,8.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0016,8.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0017,4.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0018,4.387750);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0018 20
DEF_STATIC_CONST_VAL_FLOAT(val_0019,7.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0020,4.357350);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0021 23
DEF_STATIC_CONST_VAL_FLOAT(val_0021,4.369500);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0020 24
DEF_STATIC_CONST_VAL_FLOAT(val_0022,4.338020);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0017 25
DEF_STATIC_CONST_VAL_FLOAT(val_0023,5.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0024,9.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0025,4.400890);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0026 28
DEF_STATIC_CONST_VAL_FLOAT(val_0026,4.410950);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0025 29
DEF_STATIC_CONST_VAL_FLOAT(val_0027,7.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0028,11.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0029,4.380760);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0030 32
DEF_STATIC_CONST_VAL_FLOAT(val_0030,4.324210);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0029 33
DEF_STATIC_CONST_VAL_FLOAT(val_0031,4.392250);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0016 34
DEF_STATIC_CONST_VAL_FLOAT(val_0032,4.343000);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0001 35
DEF_STATIC_CONST_VAL_FLOAT(val_0033,10.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0034,4.327330);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0036 38
DEF_STATIC_CONST_VAL_FLOAT(val_0035,4.368730);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0035 39
DEF_STATIC_CONST_VAL_FLOAT(val_0036,4.404690);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0039 41
DEF_STATIC_CONST_VAL_FLOAT(val_0037,4.363320);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0000 42
DEF_STATIC_CONST_VAL_FLOAT(val_0038,0.424000);
DEF_STATIC_CONST_VAL_FLOAT(val_0039,0.192421);
DEF_STATIC_CONST_VAL_STRING(val_0040,"0");
DEF_STATIC_CONST_VAL_STRING(val_0041,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0042,0.085143);
DEF_STATIC_CONST_VAL_FLOAT(val_0043,4.975580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0047 49
DEF_STATIC_CONST_VAL_FLOAT(val_0044,0.074667);
DEF_STATIC_CONST_VAL_FLOAT(val_0045,4.952480);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0049 51
DEF_STATIC_CONST_VAL_FLOAT(val_0046,4.931430);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0046 52
DEF_STATIC_CONST_VAL_FLOAT(val_0047,0.160606);
DEF_STATIC_CONST_VAL_FLOAT(val_0048,14.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0049,4.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0050,0.533333);
DEF_STATIC_CONST_VAL_FLOAT(val_0051,4.946270);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0055 57
DEF_STATIC_CONST_VAL_FLOAT(val_0052,4.927260);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0054 58
DEF_STATIC_CONST_VAL_FLOAT(val_0053,0.103497);
DEF_STATIC_CONST_VAL_FLOAT(val_0054,4.926360);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0058 60
DEF_STATIC_CONST_VAL_FLOAT(val_0055,4.891170);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0053 61
DEF_STATIC_CONST_VAL_FLOAT(val_0056,4.944260);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0052 62
DEF_STATIC_CONST_VAL_STRING(val_0057,"final");
DEF_STATIC_CONST_VAL_FLOAT(val_0058,4.863530);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0062 64
DEF_STATIC_CONST_VAL_FLOAT(val_0059,4.916650);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0045 65
DEF_STATIC_CONST_VAL_STRING(val_0060,"cc");
DEF_STATIC_CONST_VAL_FLOAT(val_0061,4.858380);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0065 67
DEF_STATIC_CONST_VAL_FLOAT(val_0062,4.931330);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0067 69
DEF_STATIC_CONST_VAL_FLOAT(val_0063,4.863620);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0069 71
DEF_STATIC_CONST_VAL_STRING(val_0064,"det");
DEF_STATIC_CONST_VAL_FLOAT(val_0065,4.911890);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0071 73
DEF_STATIC_CONST_VAL_FLOAT(val_0066,4.893900);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0044 74
DEF_STATIC_CONST_VAL_FLOAT(val_0067,5.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0068,4.878970);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0076 78
DEF_STATIC_CONST_VAL_FLOAT(val_0069,0.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0070,4.872520);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0078 80
DEF_STATIC_CONST_VAL_FLOAT(val_0071,4.834380);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0075 81
DEF_STATIC_CONST_VAL_FLOAT(val_0072,1.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0073,4.921980);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0082 84
DEF_STATIC_CONST_VAL_FLOAT(val_0074,11.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0075,4.876200);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0085 87
DEF_STATIC_CONST_VAL_FLOAT(val_0076,4.896750);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0084 88
DEF_STATIC_CONST_VAL_FLOAT(val_0077,4.903230);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0081 89
DEF_STATIC_CONST_VAL_FLOAT(val_0078,4.867620);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0074 90
DEF_STATIC_CONST_VAL_FLOAT(val_0079,10.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0080,4.811350);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0090 92
DEF_STATIC_CONST_VAL_FLOAT(val_0081,5.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0082,4.858900);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0093 95
DEF_STATIC_CONST_VAL_FLOAT(val_0083,4.874020);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0092 96
DEF_STATIC_CONST_VAL_FLOAT(val_0084,13.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0085,4.810470);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0096 98
DEF_STATIC_CONST_VAL_FLOAT(val_0086,4.864580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0043 99
DEF_STATIC_CONST_VAL_STRING(val_0087,"aux");
DEF_STATIC_CONST_VAL_FLOAT(val_0088,4.822310);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0100 102
DEF_STATIC_CONST_VAL_FLOAT(val_0089,8.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0090,0.265000);
DEF_STATIC_CONST_VAL_FLOAT(val_0091,4.907690);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0104 106
DEF_STATIC_CONST_VAL_FLOAT(val_0092,4.938080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0103 107
DEF_STATIC_CONST_VAL_FLOAT(val_0093,4.911980);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0107 109
DEF_STATIC_CONST_VAL_FLOAT(val_0094,0.338095);
DEF_STATIC_CONST_VAL_FLOAT(val_0095,4.891610);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0109 111
DEF_STATIC_CONST_VAL_FLOAT(val_0096,4.865080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0102 112
DEF_STATIC_CONST_VAL_FLOAT(val_0097,4.854450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0099 113
DEF_STATIC_CONST_VAL_FLOAT(val_0098,0.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0099,3.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0100,14.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0101,2.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0102,4.878540);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0118 120
DEF_STATIC_CONST_VAL_FLOAT(val_0103,4.902200);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0117 121
DEF_STATIC_CONST_VAL_FLOAT(val_0104,4.859010);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0116 122
DEF_STATIC_CONST_VAL_FLOAT(val_0105,0.225714);
DEF_STATIC_CONST_VAL_FLOAT(val_0106,4.914210);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0122 124
DEF_STATIC_CONST_VAL_FLOAT(val_0107,4.932340);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0115 125
DEF_STATIC_CONST_VAL_STRING(val_0108,"initial");
DEF_STATIC_CONST_VAL_FLOAT(val_0109,4.853500);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0126 128
DEF_STATIC_CONST_VAL_FLOAT(val_0110,4.810160);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0125 129
DEF_STATIC_CONST_VAL_FLOAT(val_0111,17.200001);
DEF_STATIC_CONST_VAL_FLOAT(val_0112,4.872180);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0129 131
DEF_STATIC_CONST_VAL_FLOAT(val_0113,4.886890);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0114 132
DEF_STATIC_CONST_VAL_FLOAT(val_0114,0.308333);
DEF_STATIC_CONST_VAL_FLOAT(val_0115,4.848950);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0132 134
DEF_STATIC_CONST_VAL_FLOAT(val_0116,4.800500);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0113 135
DEF_STATIC_CONST_VAL_FLOAT(val_0117,0.398947);
DEF_STATIC_CONST_VAL_FLOAT(val_0118,3.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0119,0.270000);
DEF_STATIC_CONST_VAL_FLOAT(val_0120,4.816340);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0139 141
DEF_STATIC_CONST_VAL_FLOAT(val_0121,4.797450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0138 142
DEF_STATIC_CONST_VAL_FLOAT(val_0122,4.876030);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0142 144
DEF_STATIC_CONST_VAL_FLOAT(val_0123,4.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0124,4.876100);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0145 147
DEF_STATIC_CONST_VAL_FLOAT(val_0125,4.830910);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0147 149
DEF_STATIC_CONST_VAL_FLOAT(val_0126,4.865910);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0144 150
DEF_STATIC_CONST_VAL_FLOAT(val_0127,0.322500);
DEF_STATIC_CONST_VAL_FLOAT(val_0128,10.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0129,4.822800);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0154 156
DEF_STATIC_CONST_VAL_FLOAT(val_0130,4.828160);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0156 158
DEF_STATIC_CONST_VAL_FLOAT(val_0131,12.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0132,4.875770);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0158 160
DEF_STATIC_CONST_VAL_FLOAT(val_0133,4.868800);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0153 161
DEF_STATIC_CONST_VAL_FLOAT(val_0134,4.886540);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0152 162
DEF_STATIC_CONST_VAL_FLOAT(val_0135,0.226667);
DEF_STATIC_CONST_VAL_FLOAT(val_0136,4.835410);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0162 164
DEF_STATIC_CONST_VAL_FLOAT(val_0137,4.812960);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0151 165
DEF_STATIC_CONST_VAL_FLOAT(val_0138,11.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0139,4.810450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0165 167
DEF_STATIC_CONST_VAL_FLOAT(val_0140,4.835830);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0150 168
DEF_STATIC_CONST_VAL_FLOAT(val_0141,6.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0142,4.814710);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0169 171
DEF_STATIC_CONST_VAL_FLOAT(val_0143,4.852440);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0168 172
DEF_STATIC_CONST_VAL_FLOAT(val_0144,4.788630);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0137 173
DEF_STATIC_CONST_VAL_FLOAT(val_0145,0.366667);
DEF_STATIC_CONST_VAL_FLOAT(val_0146,0.317460);
DEF_STATIC_CONST_VAL_FLOAT(val_0147,4.787950);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0176 178
DEF_STATIC_CONST_VAL_FLOAT(val_0148,4.816570);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0175 179
DEF_STATIC_CONST_VAL_FLOAT(val_0149,4.785480);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0174 180
DEF_STATIC_CONST_VAL_FLOAT(val_0150,4.825470);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0173 181
DEF_STATIC_CONST_VAL_FLOAT(val_0151,2.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0152,4.861570);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0181 183
DEF_STATIC_CONST_VAL_FLOAT(val_0153,18.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0154,4.814410);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0183 185
DEF_STATIC_CONST_VAL_FLOAT(val_0155,4.805800);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0136 186
DEF_STATIC_CONST_VAL_STRING(val_0156,"1");
DEF_STATIC_CONST_VAL_FLOAT(val_0157,4.801920);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0187 189
DEF_STATIC_CONST_VAL_FLOAT(val_0158,4.776860);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0186 190
DEF_STATIC_CONST_VAL_FLOAT(val_0159,0.273846);
DEF_STATIC_CONST_VAL_FLOAT(val_0160,0.207273);
DEF_STATIC_CONST_VAL_FLOAT(val_0161,4.797630);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0191 193
DEF_STATIC_CONST_VAL_FLOAT(val_0162,4.840820);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0190 194
DEF_STATIC_CONST_VAL_FLOAT(val_0163,4.793020);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0135 195
DEF_STATIC_CONST_VAL_FLOAT(val_0164,0.410526);
DEF_STATIC_CONST_VAL_FLOAT(val_0165,4.814260);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0196 198
DEF_STATIC_CONST_VAL_FLOAT(val_0166,4.772070);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0198 200
DEF_STATIC_CONST_VAL_FLOAT(val_0167,4.798090);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0195 201
DEF_STATIC_CONST_VAL_FLOAT(val_0168,4.742080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0201 203
DEF_STATIC_CONST_VAL_FLOAT(val_0169,4.799530);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0042 204
DEF_STATIC_CONST_VAL_FLOAT(val_0170,1.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0171,0.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0172,0.686508);
DEF_STATIC_CONST_VAL_FLOAT(val_0173,3.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0174,0.523810);
DEF_STATIC_CONST_VAL_FLOAT(val_0175,4.861440);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0211 213
DEF_STATIC_CONST_VAL_FLOAT(val_0176,4.890010);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0210 214
DEF_STATIC_CONST_VAL_FLOAT(val_0177,4.855110);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0209 215
DEF_STATIC_CONST_VAL_FLOAT(val_0178,4.850450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0208 216
DEF_STATIC_CONST_VAL_FLOAT(val_0179,4.899450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0216 218
DEF_STATIC_CONST_VAL_FLOAT(val_0180,4.875960);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0207 219
DEF_STATIC_CONST_VAL_FLOAT(val_0181,4.861250);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0219 221
DEF_STATIC_CONST_VAL_FLOAT(val_0182,0.547619);
DEF_STATIC_CONST_VAL_FLOAT(val_0183,4.791690);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0221 223
DEF_STATIC_CONST_VAL_FLOAT(val_0184,4.837420);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0223 225
DEF_STATIC_CONST_VAL_FLOAT(val_0185,4.811060);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0206 226
DEF_STATIC_CONST_VAL_STRING(val_0186,"mid");
DEF_STATIC_CONST_VAL_FLOAT(val_0187,4.836950);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0226 228
DEF_STATIC_CONST_VAL_FLOAT(val_0188,0.836923);
DEF_STATIC_CONST_VAL_FLOAT(val_0189,0.791026);
DEF_STATIC_CONST_VAL_FLOAT(val_0190,4.775300);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0230 232
DEF_STATIC_CONST_VAL_FLOAT(val_0191,8.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0192,4.819350);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0232 234
DEF_STATIC_CONST_VAL_FLOAT(val_0193,4.794590);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0229 235
DEF_STATIC_CONST_VAL_FLOAT(val_0194,3.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0195,4.853780);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0235 237
DEF_STATIC_CONST_VAL_FLOAT(val_0196,4.805130);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0228 238
DEF_STATIC_CONST_VAL_FLOAT(val_0197,4.746540);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0238 240
DEF_STATIC_CONST_VAL_FLOAT(val_0198,4.789490);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0205 241
DEF_STATIC_CONST_VAL_FLOAT(val_0199,2.300000);
DEF_STATIC_CONST_VAL_STRING(val_0200,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0201,4.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0202,4.814810);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0245 247
DEF_STATIC_CONST_VAL_FLOAT(val_0203,4.774960);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0247 249
DEF_STATIC_CONST_VAL_FLOAT(val_0204,9.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0205,4.813010);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0249 251
DEF_STATIC_CONST_VAL_FLOAT(val_0206,4.789450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0244 252
DEF_STATIC_CONST_VAL_FLOAT(val_0207,4.773200);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0243 253
DEF_STATIC_CONST_VAL_FLOAT(val_0208,6.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0209,4.750080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0256 258
DEF_STATIC_CONST_VAL_FLOAT(val_0210,4.798390);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0255 259
DEF_STATIC_CONST_VAL_FLOAT(val_0211,4.800260);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0254 260
DEF_STATIC_CONST_VAL_STRING(val_0212,"in");
DEF_STATIC_CONST_VAL_FLOAT(val_0213,4.774330);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0261 263
DEF_STATIC_CONST_VAL_FLOAT(val_0214,4.700450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0263 265
DEF_STATIC_CONST_VAL_FLOAT(val_0215,6.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0216,0.836257);
DEF_STATIC_CONST_VAL_FLOAT(val_0217,4.739070);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0266 268
DEF_STATIC_CONST_VAL_FLOAT(val_0218,4.763830);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0265 269
DEF_STATIC_CONST_VAL_FLOAT(val_0219,4.714560);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0260 270
DEF_STATIC_CONST_VAL_FLOAT(val_0220,4.764440);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0253 271
DEF_STATIC_CONST_VAL_FLOAT(val_0221,0.683333);
DEF_STATIC_CONST_VAL_FLOAT(val_0222,4.764450);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0272 274
DEF_STATIC_CONST_VAL_FLOAT(val_0223,4.722580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0271 275
DEF_STATIC_CONST_VAL_FLOAT(val_0224,4.696220);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0242 276
DEF_STATIC_CONST_VAL_FLOAT(val_0225,4.648490);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0276 278
DEF_STATIC_CONST_VAL_FLOAT(val_0226,4.760830);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0279 281
DEF_STATIC_CONST_VAL_FLOAT(val_0227,4.708580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0281 283
DEF_STATIC_CONST_VAL_FLOAT(val_0228,0.905333);
DEF_STATIC_CONST_VAL_FLOAT(val_0229,0.875556);
DEF_STATIC_CONST_VAL_FLOAT(val_0230,6.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0231,4.727900);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0286 288
DEF_STATIC_CONST_VAL_FLOAT(val_0232,4.734210);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0285 289
DEF_STATIC_CONST_VAL_FLOAT(val_0233,4.703550);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0284 290
DEF_STATIC_CONST_VAL_FLOAT(val_0234,0.924364);
DEF_STATIC_CONST_VAL_FLOAT(val_0235,4.758470);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0290 292
DEF_STATIC_CONST_VAL_FLOAT(val_0236,4.719230);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0283 293
DEF_STATIC_CONST_VAL_FLOAT(val_0237,4.712340);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0278 294
DEF_STATIC_CONST_VAL_FLOAT(val_0238,5.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0239,4.701960);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0297 299
DEF_STATIC_CONST_VAL_FLOAT(val_0240,4.680390);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0296 300
DEF_STATIC_CONST_VAL_FLOAT(val_0241,4.652970);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0295 301
DEF_STATIC_CONST_VAL_FLOAT(val_0242,0.838461);
DEF_STATIC_CONST_VAL_FLOAT(val_0243,4.695580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0301 303
DEF_STATIC_CONST_VAL_FLOAT(val_0244,4.708820);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0294 304
DEF_STATIC_CONST_VAL_FLOAT(val_0245,0.941667);
DEF_STATIC_CONST_VAL_FLOAT(val_0246,4.756950);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0305 307
DEF_STATIC_CONST_VAL_FLOAT(val_0247,4.721460);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0304 308
DEF_STATIC_CONST_VAL_FLOAT(val_0248,4.689650);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0241 309
DEF_STATIC_CONST_VAL_FLOAT(val_0249,0.607143);
DEF_STATIC_CONST_VAL_FLOAT(val_0250,4.792470);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0312 314
DEF_STATIC_CONST_VAL_FLOAT(val_0251,5.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0252,8.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0253,4.851350);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0315 317
DEF_STATIC_CONST_VAL_FLOAT(val_0254,4.851640);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0314 318
DEF_STATIC_CONST_VAL_FLOAT(val_0255,4.795740);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0318 320
DEF_STATIC_CONST_VAL_FLOAT(val_0256,7.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0257,4.857580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0320 322
DEF_STATIC_CONST_VAL_FLOAT(val_0258,4.807780);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0311 323
DEF_STATIC_CONST_VAL_FLOAT(val_0259,18.200001);
DEF_STATIC_CONST_VAL_FLOAT(val_0260,0.633333);
DEF_STATIC_CONST_VAL_FLOAT(val_0261,4.824330);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0324 326
DEF_STATIC_CONST_VAL_FLOAT(val_0262,4.780200);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0327 329
DEF_STATIC_CONST_VAL_FLOAT(val_0263,4.798640);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0326 330
DEF_STATIC_CONST_VAL_FLOAT(val_0264,7.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0265,4.777530);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0330 332
DEF_STATIC_CONST_VAL_FLOAT(val_0266,4.757310);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0323 333
DEF_STATIC_CONST_VAL_FLOAT(val_0267,4.816320);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0310 334
DEF_STATIC_CONST_VAL_FLOAT(val_0268,0.559091);
DEF_STATIC_CONST_VAL_FLOAT(val_0269,4.866600);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0335 337
DEF_STATIC_CONST_VAL_FLOAT(val_0270,4.851180);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0334 338
DEF_STATIC_CONST_VAL_FLOAT(val_0271,3.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0272,4.809280);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0339 341
DEF_STATIC_CONST_VAL_FLOAT(val_0273,4.825830);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0341 343
DEF_STATIC_CONST_VAL_FLOAT(val_0274,4.855460);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0338 344
DEF_STATIC_CONST_VAL_FLOAT(val_0275,4.802930);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0309 345
DEF_STATIC_CONST_VAL_FLOAT(val_0276,5.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0277,4.840760);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0346 348
DEF_STATIC_CONST_VAL_FLOAT(val_0278,0.610326);
DEF_STATIC_CONST_VAL_FLOAT(val_0279,4.818300);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0348 350
DEF_STATIC_CONST_VAL_FLOAT(val_0280,4.795650);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0350 352
DEF_STATIC_CONST_VAL_FLOAT(val_0281,4.777600);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0345 353
DEF_STATIC_CONST_VAL_STRING(val_0282,"to");
DEF_STATIC_CONST_VAL_FLOAT(val_0283,4.820100);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0353 355
DEF_STATIC_CONST_VAL_FLOAT(val_0284,4.753910);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0356 358
DEF_STATIC_CONST_VAL_FLOAT(val_0285,4.707080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0355 359
DEF_STATIC_CONST_VAL_FLOAT(val_0286,21.200001);
DEF_STATIC_CONST_VAL_FLOAT(val_0287,0.557143);
DEF_STATIC_CONST_VAL_FLOAT(val_0288,2.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0289,4.812760);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0364 366
DEF_STATIC_CONST_VAL_FLOAT(val_0290,4.752730);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0366 368
DEF_STATIC_CONST_VAL_FLOAT(val_0291,4.799020);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0363 369
DEF_STATIC_CONST_VAL_FLOAT(val_0292,4.753120);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0362 370
DEF_STATIC_CONST_VAL_FLOAT(val_0293,0.591964);
DEF_STATIC_CONST_VAL_FLOAT(val_0294,4.775280);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0370 372
DEF_STATIC_CONST_VAL_FLOAT(val_0295,0.651429);
DEF_STATIC_CONST_VAL_FLOAT(val_0296,4.699460);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0373 375
DEF_STATIC_CONST_VAL_FLOAT(val_0297,4.756590);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0372 376
DEF_STATIC_CONST_VAL_FLOAT(val_0298,0.719298);
DEF_STATIC_CONST_VAL_FLOAT(val_0299,4.745890);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0377 379
DEF_STATIC_CONST_VAL_FLOAT(val_0300,4.778480);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0376 380
DEF_STATIC_CONST_VAL_FLOAT(val_0301,0.742857);
DEF_STATIC_CONST_VAL_FLOAT(val_0302,4.763690);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0380 382
DEF_STATIC_CONST_VAL_FLOAT(val_0303,4.729540);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0361 383
DEF_STATIC_CONST_VAL_FLOAT(val_0304,4.722270);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0360 384
DEF_STATIC_CONST_VAL_FLOAT(val_0305,4.702670);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0359 385
DEF_STATIC_CONST_VAL_FLOAT(val_0306,0.665546);
DEF_STATIC_CONST_VAL_FLOAT(val_0307,0.559664);
DEF_STATIC_CONST_VAL_FLOAT(val_0308,4.757330);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0390 392
DEF_STATIC_CONST_VAL_FLOAT(val_0309,4.806200);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0389 393
DEF_STATIC_CONST_VAL_FLOAT(val_0310,4.754850);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0388 394
DEF_STATIC_CONST_VAL_FLOAT(val_0311,0.616807);
DEF_STATIC_CONST_VAL_FLOAT(val_0312,4.730830);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0394 396
DEF_STATIC_CONST_VAL_FLOAT(val_0313,4.759540);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0387 397
DEF_STATIC_CONST_VAL_FLOAT(val_0314,4.798920);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0386 398
DEF_STATIC_CONST_VAL_FLOAT(val_0315,4.778270);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0398 400
DEF_STATIC_CONST_VAL_FLOAT(val_0316,9.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0317,4.703020);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0400 402
DEF_STATIC_CONST_VAL_FLOAT(val_0318,12.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0319,4.733210);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0403 405
DEF_STATIC_CONST_VAL_FLOAT(val_0320,4.787390);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0402 406
DEF_STATIC_CONST_VAL_FLOAT(val_0321,4.711770);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0406 408
DEF_STATIC_CONST_VAL_FLOAT(val_0322,4.758100);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0385 409
DEF_STATIC_CONST_VAL_FLOAT(val_0323,0.515584);
DEF_STATIC_CONST_VAL_FLOAT(val_0324,0.457143);
DEF_STATIC_CONST_VAL_FLOAT(val_0325,4.809370);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0411 413
DEF_STATIC_CONST_VAL_FLOAT(val_0326,6.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0327,4.764030);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0413 415
DEF_STATIC_CONST_VAL_FLOAT(val_0328,4.800000);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0410 416
DEF_STATIC_CONST_VAL_FLOAT(val_0329,4.757210);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0409 417
DEF_STATIC_CONST_VAL_FLOAT(val_0330,0.557792);
DEF_STATIC_CONST_VAL_FLOAT(val_0331,4.754410);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0418 420
DEF_STATIC_CONST_VAL_FLOAT(val_0332,4.689980);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0417 421
DEF_STATIC_CONST_VAL_FLOAT(val_0333,0.670833);
DEF_STATIC_CONST_VAL_FLOAT(val_0334,4.817980);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0423 425
DEF_STATIC_CONST_VAL_FLOAT(val_0335,4.788640);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0422 426
DEF_STATIC_CONST_VAL_FLOAT(val_0336,15.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0337,4.759580);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0426 428
DEF_STATIC_CONST_VAL_FLOAT(val_0338,17.799999);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0428 430
DEF_STATIC_CONST_VAL_FLOAT(val_0339,4.772120);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0421 431
DEF_STATIC_CONST_VAL_FLOAT(val_0340,0.618421);
DEF_STATIC_CONST_VAL_FLOAT(val_0341,0.583654);
DEF_STATIC_CONST_VAL_FLOAT(val_0342,4.796430);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0432 434
DEF_STATIC_CONST_VAL_FLOAT(val_0343,4.775700);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0431 435
DEF_STATIC_CONST_VAL_FLOAT(val_0344,7.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_0345,4.732640);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0436 438
DEF_STATIC_CONST_VAL_FLOAT(val_0346,16.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0347,4.786090);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0439 441
DEF_STATIC_CONST_VAL_FLOAT(val_0348,4.753010);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0438 442
DEF_STATIC_CONST_VAL_FLOAT(val_0349,4.745420);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0435 443
DEF_STATIC_CONST_VAL_FLOAT(val_0350,4.784700);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0204 444
DEF_STATIC_CONST_VAL_FLOAT(val_0351,4.631990);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0446 448
DEF_STATIC_CONST_VAL_FLOAT(val_0352,4.599080);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0445 449
DEF_STATIC_CONST_VAL_FLOAT(val_0353,4.491050);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0449 451
DEF_STATIC_CONST_VAL_FLOAT(val_0354,4.546900);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0444 452
DEF_STATIC_CONST_VAL_FLOAT(val_0355,1.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0356,4.727650);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0452 454
DEF_STATIC_CONST_VAL_FLOAT(val_0357,4.631630);
#define CTNODE_cmu_us_awb_spamf0_phrase_NO_0454 456
DEF_STATIC_CONST_VAL_FLOAT(val_0358,4.571320);
