DEF_STATIC_CONST_VAL_FLOAT(val_0000,0.231000);
DEF_STATIC_CONST_VAL_STRING(val_0001,"0");
DEF_STATIC_CONST_VAL_FLOAT(val_0002,0.100000);
DEF_STATIC_CONST_VAL_STRING(val_0003,"1");
DEF_STATIC_CONST_VAL_FLOAT(val_0004,0.144000);
DEF_STATIC_CONST_VAL_STRING(val_0005,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0006,4.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0007,0.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0006 8
DEF_STATIC_CONST_VAL_FLOAT(val_0008,1.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0005 9
DEF_STATIC_CONST_VAL_FLOAT(val_0009,2.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0004 10
DEF_STATIC_CONST_VAL_FLOAT(val_0010,4.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0011,3.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0010 12
DEF_STATIC_CONST_VAL_FLOAT(val_0012,4.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0003 13
DEF_STATIC_CONST_VAL_STRING(val_0013,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0014,5.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0013 15
DEF_STATIC_CONST_VAL_FLOAT(val_0015,0.101000);
DEF_STATIC_CONST_VAL_FLOAT(val_0016,6.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0015 17
DEF_STATIC_CONST_VAL_FLOAT(val_0017,1.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0018,7.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0017 19
DEF_STATIC_CONST_VAL_STRING(val_0019,"ax");
DEF_STATIC_CONST_VAL_FLOAT(val_0020,8.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0019 21
DEF_STATIC_CONST_VAL_FLOAT(val_0021,9.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0002 22
DEF_STATIC_CONST_VAL_FLOAT(val_0022,7.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0023,10.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0023 25
DEF_STATIC_CONST_VAL_FLOAT(val_0024,11.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0022 26
DEF_STATIC_CONST_VAL_FLOAT(val_0025,0.165500);
DEF_STATIC_CONST_VAL_FLOAT(val_0026,12.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0027 29
DEF_STATIC_CONST_VAL_FLOAT(val_0027,6.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0028,13.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0029 31
DEF_STATIC_CONST_VAL_FLOAT(val_0029,14.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0026 32
DEF_STATIC_CONST_VAL_FLOAT(val_0030,15.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0032 34
DEF_STATIC_CONST_VAL_FLOAT(val_0031,0.187000);
DEF_STATIC_CONST_VAL_FLOAT(val_0032,16.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0035 37
DEF_STATIC_CONST_VAL_FLOAT(val_0033,17.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0034 38
DEF_STATIC_CONST_VAL_FLOAT(val_0034,18.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0001 39
DEF_STATIC_CONST_VAL_STRING(val_0035,"det");
DEF_STATIC_CONST_VAL_FLOAT(val_0036,19.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0042 44
DEF_STATIC_CONST_VAL_FLOAT(val_0037,20.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0041 45
DEF_STATIC_CONST_VAL_FLOAT(val_0038,0.079500);
DEF_STATIC_CONST_VAL_FLOAT(val_0039,21.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0045 47
DEF_STATIC_CONST_VAL_FLOAT(val_0040,3.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0041,22.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0047 49
DEF_STATIC_CONST_VAL_FLOAT(val_0042,23.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0040 50
DEF_STATIC_CONST_VAL_FLOAT(val_0043,0.170000);
DEF_STATIC_CONST_VAL_FLOAT(val_0044,24.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0052 54
DEF_STATIC_CONST_VAL_FLOAT(val_0045,25.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0054 56
DEF_STATIC_CONST_VAL_FLOAT(val_0046,26.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0056 58
DEF_STATIC_CONST_VAL_FLOAT(val_0047,27.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0051 59
DEF_STATIC_CONST_VAL_FLOAT(val_0048,28.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0060 62
DEF_STATIC_CONST_VAL_FLOAT(val_0049,29.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0059 63
DEF_STATIC_CONST_VAL_FLOAT(val_0050,2.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0051,30.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0063 65
DEF_STATIC_CONST_VAL_FLOAT(val_0052,31.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0050 66
DEF_STATIC_CONST_VAL_STRING(val_0053,"aa");
DEF_STATIC_CONST_VAL_FLOAT(val_0054,32.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0066 68
DEF_STATIC_CONST_VAL_FLOAT(val_0055,0.190000);
DEF_STATIC_CONST_VAL_FLOAT(val_0056,2.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_0057,33.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0070 72
DEF_STATIC_CONST_VAL_FLOAT(val_0058,0.142000);
DEF_STATIC_CONST_VAL_FLOAT(val_0059,34.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0072 74
DEF_STATIC_CONST_VAL_FLOAT(val_0060,35.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0069 75
DEF_STATIC_CONST_VAL_FLOAT(val_0061,36.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0068 76
DEF_STATIC_CONST_VAL_FLOAT(val_0062,0.193000);
DEF_STATIC_CONST_VAL_FLOAT(val_0063,37.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0076 78
DEF_STATIC_CONST_VAL_FLOAT(val_0064,38.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0039 79
DEF_STATIC_CONST_VAL_FLOAT(val_0065,1.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0066,39.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0079 81
DEF_STATIC_CONST_VAL_FLOAT(val_0067,0.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0068,0.158000);
DEF_STATIC_CONST_VAL_FLOAT(val_0069,40.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0082 84
DEF_STATIC_CONST_VAL_FLOAT(val_0070,41.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0085 87
DEF_STATIC_CONST_VAL_FLOAT(val_0071,42.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0084 88
DEF_STATIC_CONST_VAL_FLOAT(val_0072,43.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0081 89
DEF_STATIC_CONST_VAL_FLOAT(val_0073,44.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0089 91
DEF_STATIC_CONST_VAL_FLOAT(val_0074,0.179000);
DEF_STATIC_CONST_VAL_FLOAT(val_0075,0.140500);
DEF_STATIC_CONST_VAL_FLOAT(val_0076,45.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0093 95
DEF_STATIC_CONST_VAL_FLOAT(val_0077,46.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0092 96
DEF_STATIC_CONST_VAL_FLOAT(val_0078,47.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0096 98
DEF_STATIC_CONST_VAL_FLOAT(val_0079,48.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0091 99
DEF_STATIC_CONST_VAL_FLOAT(val_0080,49.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0000 100
DEF_STATIC_CONST_VAL_FLOAT(val_0081,0.435000);
DEF_STATIC_CONST_VAL_FLOAT(val_0082,50.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0103 105
DEF_STATIC_CONST_VAL_FLOAT(val_0083,51.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0105 107
DEF_STATIC_CONST_VAL_FLOAT(val_0084,52.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0102 108
DEF_STATIC_CONST_VAL_FLOAT(val_0085,0.391000);
DEF_STATIC_CONST_VAL_FLOAT(val_0086,0.343500);
DEF_STATIC_CONST_VAL_FLOAT(val_0087,53.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0109 111
DEF_STATIC_CONST_VAL_FLOAT(val_0088,54.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0108 112
DEF_STATIC_CONST_VAL_FLOAT(val_0089,55.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0101 113
DEF_STATIC_CONST_VAL_FLOAT(val_0090,0.555000);
DEF_STATIC_CONST_VAL_FLOAT(val_0091,4.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0092,56.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0114 116
DEF_STATIC_CONST_VAL_FLOAT(val_0093,57.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0113 117
DEF_STATIC_CONST_VAL_FLOAT(val_0094,58.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0100 118
DEF_STATIC_CONST_VAL_FLOAT(val_0095,0.411000);
DEF_STATIC_CONST_VAL_FLOAT(val_0096,0.284500);
DEF_STATIC_CONST_VAL_FLOAT(val_0097,59.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0124 126
DEF_STATIC_CONST_VAL_FLOAT(val_0098,60.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0123 127
DEF_STATIC_CONST_VAL_FLOAT(val_0099,61.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0128 130
DEF_STATIC_CONST_VAL_FLOAT(val_0100,62.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0127 131
DEF_STATIC_CONST_VAL_FLOAT(val_0101,0.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_0102,63.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0131 133
DEF_STATIC_CONST_VAL_FLOAT(val_0103,64.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0122 134
DEF_STATIC_CONST_VAL_FLOAT(val_0104,65.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0121 135
DEF_STATIC_CONST_VAL_STRING(val_0105,"ae");
DEF_STATIC_CONST_VAL_FLOAT(val_0106,66.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0135 137
DEF_STATIC_CONST_VAL_STRING(val_0107,"in");
DEF_STATIC_CONST_VAL_FLOAT(val_0108,67.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0137 139
DEF_STATIC_CONST_VAL_FLOAT(val_0109,68.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0120 140
DEF_STATIC_CONST_VAL_FLOAT(val_0110,3.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0111,69.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0140 142
DEF_STATIC_CONST_VAL_FLOAT(val_0112,70.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0119 143
DEF_STATIC_CONST_VAL_FLOAT(val_0113,0.367000);
DEF_STATIC_CONST_VAL_FLOAT(val_0114,71.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0144 146
DEF_STATIC_CONST_VAL_FLOAT(val_0115,72.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0147 149
DEF_STATIC_CONST_VAL_FLOAT(val_0116,73.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0146 150
DEF_STATIC_CONST_VAL_FLOAT(val_0117,74.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0150 152
DEF_STATIC_CONST_VAL_FLOAT(val_0118,75.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0152 154
DEF_STATIC_CONST_VAL_FLOAT(val_0119,76.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0143 155
DEF_STATIC_CONST_VAL_FLOAT(val_0120,1.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0121,77.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0155 157
DEF_STATIC_CONST_VAL_FLOAT(val_0122,0.457000);
DEF_STATIC_CONST_VAL_FLOAT(val_0123,78.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0157 159
DEF_STATIC_CONST_VAL_FLOAT(val_0124,79.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0118 160
DEF_STATIC_CONST_VAL_FLOAT(val_0125,0.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0126,0.309000);
DEF_STATIC_CONST_VAL_FLOAT(val_0127,0.277000);
DEF_STATIC_CONST_VAL_FLOAT(val_0128,80.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0163 165
DEF_STATIC_CONST_VAL_FLOAT(val_0129,81.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0162 166
DEF_STATIC_CONST_VAL_FLOAT(val_0130,82.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0161 167
DEF_STATIC_CONST_VAL_FLOAT(val_0131,6.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0132,83.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0167 169
DEF_STATIC_CONST_VAL_FLOAT(val_0133,84.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0160 170
DEF_STATIC_CONST_VAL_FLOAT(val_0134,0.361000);
DEF_STATIC_CONST_VAL_FLOAT(val_0135,3.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0136,85.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0173 175
DEF_STATIC_CONST_VAL_FLOAT(val_0137,86.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0172 176
DEF_STATIC_CONST_VAL_FLOAT(val_0138,87.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0171 177
DEF_STATIC_CONST_VAL_FLOAT(val_0139,88.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0170 178
DEF_STATIC_CONST_VAL_FLOAT(val_0140,89.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0179 181
DEF_STATIC_CONST_VAL_FLOAT(val_0141,90.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0178 182
DEF_STATIC_CONST_VAL_FLOAT(val_0142,91.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0182 184
DEF_STATIC_CONST_VAL_FLOAT(val_0143,92.000000);
#define CTNODE_cmu_us_rms_spamf0_accent_NO_0184 186
DEF_STATIC_CONST_VAL_FLOAT(val_0144,93.000000);
