/*****************************************************/
/**  Autogenerated cmu_us_slt phrase carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_slt_spamf0_phrase.h"

static const cst_cart_node cmu_us_slt_spamf0_phrase_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0002, (cst_val *)&val_0002},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0003, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0004, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0005 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0006, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0006 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0008, (cst_val *)&val_0007},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0009, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0011, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0015, (cst_val *)&val_0014},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0016, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0018, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0019, (cst_val *)&val_0018},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0020, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0022, (cst_val *)&val_0020},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0023, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0025, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0028, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0028 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0031, (cst_val *)&val_0029},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0032, (cst_val *)&val_0020},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0033, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0035 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0039, (cst_val *)&val_0036},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0040, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0044, (cst_val *)&val_0014},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0045, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0046, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0047, (cst_val *)&val_0020},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0048, (cst_val *)&val_0042},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0049, (cst_val *)&val_0021},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0050, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0053, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0056, (cst_val *)&val_0048},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0057, (cst_val *)&val_0049},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0058, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0059, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0062, (cst_val *)&val_0053},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0063, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0066, (cst_val *)&val_0056},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0067, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0071, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0073, (cst_val *)&val_0062},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0074, (cst_val *)&val_0063},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0064 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0076, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0079, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0082, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0085, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0086, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0089, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0091, (cst_val *)&val_0073},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0092, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0095, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0098, (cst_val *)&val_0021},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0099, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0100, (cst_val *)&val_0020},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0101, (cst_val *)&val_0082},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0102, (cst_val *)&val_0083},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0103, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0107, (cst_val *)&val_0083},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0108, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0112, (cst_val *)&val_0092},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0113, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0116, (cst_val *)&val_0096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0119, (cst_val *)&val_0099},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0120, (cst_val *)&val_0100},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0121, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0123, (cst_val *)&val_0082},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0124, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0126, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0129, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0107 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0132, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0136, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0139, (cst_val *)&val_0048},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0140, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0141, (cst_val *)&val_0113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0143, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0146, (cst_val *)&val_0020},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0147, (cst_val *)&val_0118},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0148, (cst_val *)&val_0068},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0149, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0152, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0155, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0158, (cst_val *)&val_0127},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0159, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0163, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0165, (cst_val *)&val_0133},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0166, (cst_val *)&val_0134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0170, (cst_val *)&val_0138},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0171, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0172, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0175, (cst_val *)&val_0141},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0176, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0179, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0182, (cst_val *)&val_0148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0185, (cst_val *)&val_0065},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0186, (cst_val *)&val_0151},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0187, (cst_val *)&val_0148},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0188, (cst_val *)&val_0053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0193, (cst_val *)&val_0020},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0194, (cst_val *)&val_0156},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0195, (cst_val *)&val_0157},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0197, (cst_val *)&val_0159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0161 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0200, (cst_val *)&val_0162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0202, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0164 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0204, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0207, (cst_val *)&val_0138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0209, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0211, (cst_val *)&val_0029},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0212, (cst_val *)&val_0096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0171 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0216, (cst_val *)&val_0172},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0217, (cst_val *)&val_0173},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0218, (cst_val *)&val_0174},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0219, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0220, (cst_val *)&val_0014},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0221, (cst_val *)&val_0175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0224, (cst_val *)&val_0141},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0225, (cst_val *)&val_0148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0229, (cst_val *)&val_0181},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0230, (cst_val *)&val_0182},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0231, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0232, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0188 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0238, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0239, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0242, (cst_val *)&val_0192},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0243, (cst_val *)&val_0193},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0244, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0195 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0246, (cst_val *)&val_0196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0200 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0251, (cst_val *)&val_0201},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0252, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0255, (cst_val *)&val_0204},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0256, (cst_val *)&val_0205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0260, (cst_val *)&val_0148},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0261, (cst_val *)&val_0209},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0262, (cst_val *)&val_0210},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0263, (cst_val *)&val_0175},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0264, (cst_val *)&val_0193},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0265, (cst_val *)&val_0211},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0266, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0271, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0274, (cst_val *)&val_0062},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0275, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0279, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0280, (cst_val *)&val_0222},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0281, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0284, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0285, (cst_val *)&val_0020},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0286, (cst_val *)&val_0225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0228 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0290, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0292, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0231 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0295, (cst_val *)&val_0014},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0296, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0298, (cst_val *)&val_0020},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0299, (cst_val *)&val_0182},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0300, (cst_val *)&val_0234},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0303, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0239 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0307, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0309, (cst_val *)&val_0020},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0310, (cst_val *)&val_0241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0314, (cst_val *)&val_0245},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0315, (cst_val *)&val_0042},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0316, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0319, (cst_val *)&val_0248},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0320, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0321, (cst_val *)&val_0249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0146 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0324, (cst_val *)&val_0020},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0325, (cst_val *)&val_0251},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0326, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0252 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0328, (cst_val *)&val_0253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0332, (cst_val *)&val_0257},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0259 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0335, (cst_val *)&val_0260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0337, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0338, (cst_val *)&val_0020},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0339, (cst_val *)&val_0262},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0340, (cst_val *)&val_0263},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0341, (cst_val *)&val_0196},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0342, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0265 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0345, (cst_val *)&val_0251},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0346, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0349, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0351, (cst_val *)&val_0269},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0352, (cst_val *)&val_0148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0358, (cst_val *)&val_0003},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0359, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0360, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0276 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0363, (cst_val *)&val_0127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0278 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0366, (cst_val *)&val_0193},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0367, (cst_val *)&val_0279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0369, (cst_val *)&val_0281},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0370, (cst_val *)&val_0282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0374, (cst_val *)&val_0286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0288 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0377, (cst_val *)&val_0289},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0378, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0379, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0381, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0382, (cst_val *)&val_0291},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0294 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0386, (cst_val *)&val_0196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0295 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0388, (cst_val *)&val_0056},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0389, (cst_val *)&val_0296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0299 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0393, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0394, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0395, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0398, (cst_val *)&val_0303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0401, (cst_val *)&val_0306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0403, (cst_val *)&val_0308},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0404, (cst_val *)&val_0083},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0405, (cst_val *)&val_0309},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0406, (cst_val *)&val_0310},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0407, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0410, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0412, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0315 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0415, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0420, (cst_val *)&val_0320},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0421, (cst_val *)&val_0321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0423, (cst_val *)&val_0020},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0424, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0425, (cst_val *)&val_0323},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0426, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0430, (cst_val *)&val_0327},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0431, (cst_val *)&val_0148},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0432, (cst_val *)&val_0328},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0433, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0437, (cst_val *)&val_0128},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0438, (cst_val *)&val_0332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0443, (cst_val *)&val_0337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0445, (cst_val *)&val_0339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0341 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0448, (cst_val *)&val_0162},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0449, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0452, (cst_val *)&val_0127},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0453, (cst_val *)&val_0344},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0346 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0456, (cst_val *)&val_0347},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_spamf0_phrase_NO_0457, (cst_val *)&val_0348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_spamf0_phrase_feat_table[] = {
"R:SylStructure.parent.lisp_cg_syl_ratio",
"R:SylStructure.parent.parent.R:Word.pos_in_phrase",
"R:SylStructure.parent.R:Syllable.syl_in",
"R:SylStructure.parent.R:Syllable.n.n.lisp_cg_break",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_phrase_ratio",
"R:SylStructure.parent.R:Syllable.n.lisp_cg_break",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_find_phrase_number",
"R:SylStructure.parent.parent.gpos",
"lisp_cg_content_words_in_phrase",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_syls_in_phrase",
"R:SylStructure.parent.R:Syllable.syl_break",
"R:SylStructure.parent.R:Syllable.p.p.lisp_cg_break",
"R:SylStructure.parent.R:Syllable.syl_out",
"R:SylStructure.parent.R:Syllable.position_type",
"R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_spamf0_phrase_cart = {
  cmu_us_slt_spamf0_phrase_cart_nodes,
  cmu_us_slt_spamf0_phrase_feat_table
};
