/*****************************************************/
/**  Autogenerated cmu_us_rms phrase carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_rms_spamf0_phrase.h"

static const cst_cart_node cmu_us_rms_spamf0_phrase_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0000, (cst_val *)&val_0000},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0001, (cst_val *)&val_0001},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0002, (cst_val *)&val_0002},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0003, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0004, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0005, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0008, (cst_val *)&val_0008},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0009, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0010, (cst_val *)&val_0002},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0011, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0014, (cst_val *)&val_0013},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0015, (cst_val *)&val_0014},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0016, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0018, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0021 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0023, (cst_val *)&val_0022},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0024, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0027, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0029, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0032, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0033, (cst_val *)&val_0031},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0034, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0037, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0041, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0040 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0043, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0044, (cst_val *)&val_0042},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0045, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0046, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0050, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0053, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0056, (cst_val *)&val_0026},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0057, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0060, (cst_val *)&val_0002},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0061, (cst_val *)&val_0057},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0062, (cst_val *)&val_0002},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0063, (cst_val *)&val_0058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0066, (cst_val *)&val_0061},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0067, (cst_val *)&val_0062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0069, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0073, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0076, (cst_val *)&val_0070},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0077, (cst_val *)&val_0044},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0078, (cst_val *)&val_0071},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0079, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0081, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0084, (cst_val *)&val_0076},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0085, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0087, (cst_val *)&val_0078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0089, (cst_val *)&val_0080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0093, (cst_val *)&val_0084},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0094, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0098, (cst_val *)&val_0042},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0099, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0101, (cst_val *)&val_0090},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0102, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0104, (cst_val *)&val_0092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0093 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0106, (cst_val *)&val_0094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0109, (cst_val *)&val_0097},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0110, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0112, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0114, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0117, (cst_val *)&val_0104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0120, (cst_val *)&val_0107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0123, (cst_val *)&val_0110},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0124, (cst_val *)&val_0111},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0125, (cst_val *)&val_0112},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0126, (cst_val *)&val_0113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0128, (cst_val *)&val_0115},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0129, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0131, (cst_val *)&val_0117},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0132, (cst_val *)&val_0118},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0133, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0136, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0139, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0141, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0145, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0147, (cst_val *)&val_0130},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0148, (cst_val *)&val_0131},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0149, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0154, (cst_val *)&val_0117},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0155, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0157, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0160, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0162, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0165, (cst_val *)&val_0002},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0166, (cst_val *)&val_0088},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0167, (cst_val *)&val_0004},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0168, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0170, (cst_val *)&val_0145},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0171, (cst_val *)&val_0146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0175, (cst_val *)&val_0150},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0176, (cst_val *)&val_0151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0153 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0179, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0156 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0182, (cst_val *)&val_0157},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0183, (cst_val *)&val_0057},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0184, (cst_val *)&val_0043},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0185, (cst_val *)&val_0158},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0186, (cst_val *)&val_0159},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0187, (cst_val *)&val_0160},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0188, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0164 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0192, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0194, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0196, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0198, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0171 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0201, (cst_val *)&val_0172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0174 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0204, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0205, (cst_val *)&val_0175},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0206, (cst_val *)&val_0176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0211, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0182 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0213, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0216, (cst_val *)&val_0088},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0217, (cst_val *)&val_0186},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0218, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0220, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0224, (cst_val *)&val_0004},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0225, (cst_val *)&val_0119},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0226, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0192 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0229, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0194 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0232, (cst_val *)&val_0195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0235, (cst_val *)&val_0198},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0236, (cst_val *)&val_0199},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0237, (cst_val *)&val_0200},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0238, (cst_val *)&val_0057},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0239, (cst_val *)&val_0201},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0240, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0242, (cst_val *)&val_0203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0245, (cst_val *)&val_0206},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0246, (cst_val *)&val_0097},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0247, (cst_val *)&val_0009},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0248, (cst_val *)&val_0207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0252, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0256, (cst_val *)&val_0215},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0259, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0260, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0264, (cst_val *)&val_0117},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0265, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0267, (cst_val *)&val_0115},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0268, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0223 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0270, (cst_val *)&val_0044},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0271, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0275, (cst_val *)&val_0227},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0276, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0279, (cst_val *)&val_0231},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0280, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0281, (cst_val *)&val_0233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0285, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0288, (cst_val *)&val_0002},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0289, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0292, (cst_val *)&val_0241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0242 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0294, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0297, (cst_val *)&val_0245},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0246 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0299, (cst_val *)&val_0022},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0300, (cst_val *)&val_0247},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0301, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0248 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0303, (cst_val *)&val_0249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0252 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0307, (cst_val *)&val_0131},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0308, (cst_val *)&val_0253},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0309, (cst_val *)&val_0117},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0310, (cst_val *)&val_0254},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0311, (cst_val *)&val_0009},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0312, (cst_val *)&val_0255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0314, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0316, (cst_val *)&val_0258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0259 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0318, (cst_val *)&val_0260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0262 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0321, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0265 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0325, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0327, (cst_val *)&val_0267},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0328, (cst_val *)&val_0227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0270 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0332, (cst_val *)&val_0002},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0333, (cst_val *)&val_0271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0335, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0337, (cst_val *)&val_0275},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0338, (cst_val *)&val_0276},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0339, (cst_val *)&val_0277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0344, (cst_val *)&val_0282},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0345, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0348, (cst_val *)&val_0005},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0349, (cst_val *)&val_0117},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0350, (cst_val *)&val_0286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0352, (cst_val *)&val_0288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0355, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0358, (cst_val *)&val_0293},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0359, (cst_val *)&val_0294},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0360, (cst_val *)&val_0117},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0361, (cst_val *)&val_0295},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0362, (cst_val *)&val_0296},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0363, (cst_val *)&val_0297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0299 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0366, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0303 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0370, (cst_val *)&val_0304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0374, (cst_val *)&val_0308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0377, (cst_val *)&val_0028},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0378, (cst_val *)&val_0131},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0379, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0383, (cst_val *)&val_0314},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0384, (cst_val *)&val_0315},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0385, (cst_val *)&val_0316},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0386, (cst_val *)&val_0260},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0387, (cst_val *)&val_0317},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0392, (cst_val *)&val_0322},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0393, (cst_val *)&val_0117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0324 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0396, (cst_val *)&val_0009},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0397, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0328 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0401, (cst_val *)&val_0329},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0402, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0333 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0406, (cst_val *)&val_0334},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0407, (cst_val *)&val_0335},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0409, (cst_val *)&val_0181},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0410, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0413, (cst_val *)&val_0339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0340 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0415, (cst_val *)&val_0341},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0416, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0344 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0420, (cst_val *)&val_0131},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0421, (cst_val *)&val_0345},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0422, (cst_val *)&val_0043},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0423, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0346 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0425, (cst_val *)&val_0267},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0426, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0349 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0430, (cst_val *)&val_0013},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0431, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0435, (cst_val *)&val_0354},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0436, (cst_val *)&val_0097},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0437, (cst_val *)&val_0078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0358 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0442, (cst_val *)&val_0057},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0443, (cst_val *)&val_0014},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0444, (cst_val *)&val_0092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0359 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0446, (cst_val *)&val_0097},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0447, (cst_val *)&val_0078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0361 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0450, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0364 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0453, (cst_val *)&val_0365},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0454, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0368 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0458, (cst_val *)&val_0002},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0459, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0370 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_spamf0_phrase_NO_0462, (cst_val *)&val_0260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0372 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_spamf0_phrase_feat_table[] = {
"R:SylStructure.parent.lisp_cg_syl_ratio",
"R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:SylStructure.parent.R:Syllable.position_type",
"lisp_cg_content_words_in_phrase",
"R:SylStructure.parent.parent.gpos",
"R:SylStructure.parent.R:Syllable.n.n.lisp_cg_break",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_syls_in_phrase",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_phrase_ratio",
"R:SylStructure.parent.parent.R:Word.pos_in_phrase",
"R:SylStructure.parent.R:Syllable.syl_break",
"R:SylStructure.parent.parent.R:Phrase.parent.lisp_cg_find_phrase_number",
"R:SylStructure.parent.R:Syllable.n.lisp_cg_break",
"R:SylStructure.parent.R:Syllable.p.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_spamf0_phrase_cart = {
  cmu_us_rms_spamf0_phrase_cart_nodes,
  cmu_us_rms_spamf0_phrase_feat_table
};
