/*****************************************************/
/**  Autogenerated phonestate_cg for cmu_us_rms    */
/*****************************************************/
const char * const cmu_us_rms_aa_ps[] = { "aa", "aa_1", "aa_2", "aa_3",  0};
const char * const cmu_us_rms_ae_ps[] = { "ae", "ae_6", "ae_7", "ae_8",  0};
const char * const cmu_us_rms_ah_ps[] = { "ah", "ah_11", "ah_12", "ah_13",  0};
const char * const cmu_us_rms_ao_ps[] = { "ao", "ao_16", "ao_17", "ao_18",  0};
const char * const cmu_us_rms_aw_ps[] = { "aw", "aw_21", "aw_22", "aw_23",  0};
const char * const cmu_us_rms_ax_ps[] = { "ax", "ax_26", "ax_27", "ax_28",  0};
const char * const cmu_us_rms_ay_ps[] = { "ay", "ay_31", "ay_32", "ay_33",  0};
const char * const cmu_us_rms_b_ps[] = { "b", "b_36", "b_37", "b_38",  0};
const char * const cmu_us_rms_ch_ps[] = { "ch", "ch_41", "ch_42", "ch_43",  0};
const char * const cmu_us_rms_d_ps[] = { "d", "d_46", "d_47", "d_48",  0};
const char * const cmu_us_rms_dh_ps[] = { "dh", "dh_51", "dh_52", "dh_53",  0};
const char * const cmu_us_rms_eh_ps[] = { "eh", "eh_56", "eh_57", "eh_58",  0};
const char * const cmu_us_rms_er_ps[] = { "er", "er_61", "er_62", "er_63",  0};
const char * const cmu_us_rms_ey_ps[] = { "ey", "ey_66", "ey_67", "ey_68",  0};
const char * const cmu_us_rms_f_ps[] = { "f", "f_71", "f_72", "f_73",  0};
const char * const cmu_us_rms_g_ps[] = { "g", "g_76", "g_77", "g_78",  0};
const char * const cmu_us_rms_hh_ps[] = { "hh", "hh_81", "hh_82", "hh_83",  0};
const char * const cmu_us_rms_ih_ps[] = { "ih", "ih_86", "ih_87", "ih_88",  0};
const char * const cmu_us_rms_iy_ps[] = { "iy", "iy_91", "iy_92", "iy_93",  0};
const char * const cmu_us_rms_jh_ps[] = { "jh", "jh_96", "jh_97", "jh_98",  0};
const char * const cmu_us_rms_k_ps[] = { "k", "k_101", "k_102", "k_103",  0};
const char * const cmu_us_rms_l_ps[] = { "l", "l_106", "l_107", "l_108",  0};
const char * const cmu_us_rms_m_ps[] = { "m", "m_111", "m_112", "m_113",  0};
const char * const cmu_us_rms_n_ps[] = { "n", "n_116", "n_117", "n_118",  0};
const char * const cmu_us_rms_ng_ps[] = { "ng", "ng_121", "ng_122", "ng_123",  0};
const char * const cmu_us_rms_ow_ps[] = { "ow", "ow_126", "ow_127", "ow_128",  0};
const char * const cmu_us_rms_oy_ps[] = { "oy", "oy_131", "oy_132", "oy_133",  0};
const char * const cmu_us_rms_p_ps[] = { "p", "p_136", "p_137", "p_138",  0};
const char * const cmu_us_rms_pau_ps[] = { "pau", "pau_141", "pau_142", "pau_143",  0};
const char * const cmu_us_rms_r_ps[] = { "r", "r_146", "r_147", "r_148",  0};
const char * const cmu_us_rms_s_ps[] = { "s", "s_151", "s_152", "s_153",  0};
const char * const cmu_us_rms_sh_ps[] = { "sh", "sh_156", "sh_157", "sh_158",  0};
const char * const cmu_us_rms_ssil_ps[] = { "ssil", "pau_161",  0};
const char * const cmu_us_rms_t_ps[] = { "t", "t_164", "t_165", "t_166",  0};
const char * const cmu_us_rms_th_ps[] = { "th", "th_169", "th_170", "th_171",  0};
const char * const cmu_us_rms_uh_ps[] = { "uh", "uh_174", "uh_175", "uh_176",  0};
const char * const cmu_us_rms_uw_ps[] = { "uw", "uw_179", "uw_180", "uw_181",  0};
const char * const cmu_us_rms_v_ps[] = { "v", "v_184", "v_185", "v_186",  0};
const char * const cmu_us_rms_w_ps[] = { "w", "w_189", "w_190", "w_191",  0};
const char * const cmu_us_rms_y_ps[] = { "y", "y_194", "y_195", "y_196",  0};
const char * const cmu_us_rms_z_ps[] = { "z", "z_199", "z_200", "z_201",  0};
const char * const cmu_us_rms_zh_ps[] = { "zh", "zh_204", "zh_205", "zh_206",  0};
const char * const * const cmu_us_rms_phone_states[] = {
   cmu_us_rms_aa_ps,
   cmu_us_rms_ae_ps,
   cmu_us_rms_ah_ps,
   cmu_us_rms_ao_ps,
   cmu_us_rms_aw_ps,
   cmu_us_rms_ax_ps,
   cmu_us_rms_ay_ps,
   cmu_us_rms_b_ps,
   cmu_us_rms_ch_ps,
   cmu_us_rms_d_ps,
   cmu_us_rms_dh_ps,
   cmu_us_rms_eh_ps,
   cmu_us_rms_er_ps,
   cmu_us_rms_ey_ps,
   cmu_us_rms_f_ps,
   cmu_us_rms_g_ps,
   cmu_us_rms_hh_ps,
   cmu_us_rms_ih_ps,
   cmu_us_rms_iy_ps,
   cmu_us_rms_jh_ps,
   cmu_us_rms_k_ps,
   cmu_us_rms_l_ps,
   cmu_us_rms_m_ps,
   cmu_us_rms_n_ps,
   cmu_us_rms_ng_ps,
   cmu_us_rms_ow_ps,
   cmu_us_rms_oy_ps,
   cmu_us_rms_p_ps,
   cmu_us_rms_pau_ps,
   cmu_us_rms_r_ps,
   cmu_us_rms_s_ps,
   cmu_us_rms_sh_ps,
   cmu_us_rms_ssil_ps,
   cmu_us_rms_t_ps,
   cmu_us_rms_th_ps,
   cmu_us_rms_uh_ps,
   cmu_us_rms_uw_ps,
   cmu_us_rms_v_ps,
   cmu_us_rms_w_ps,
   cmu_us_rms_y_ps,
   cmu_us_rms_z_ps,
   cmu_us_rms_zh_ps,
   0};
