DEF_STATIC_CONST_VAL_STRING(val_0000,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0001,0.321000);
DEF_STATIC_CONST_VAL_FLOAT(val_0002,0.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0003,0.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0002 4
DEF_STATIC_CONST_VAL_FLOAT(val_0004,0.190000);
DEF_STATIC_CONST_VAL_FLOAT(val_0005,1.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0004 6
DEF_STATIC_CONST_VAL_FLOAT(val_0006,2.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0007,2.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0006 8
DEF_STATIC_CONST_VAL_FLOAT(val_0008,0.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0009,3.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0008 10
DEF_STATIC_CONST_VAL_FLOAT(val_0010,4.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0001 11
DEF_STATIC_CONST_VAL_STRING(val_0011,"0");
DEF_STATIC_CONST_VAL_FLOAT(val_0012,0.507000);
DEF_STATIC_CONST_VAL_FLOAT(val_0013,0.397000);
DEF_STATIC_CONST_VAL_FLOAT(val_0014,5.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0013 15
DEF_STATIC_CONST_VAL_FLOAT(val_0015,6.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0015 17
DEF_STATIC_CONST_VAL_FLOAT(val_0016,7.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0012 18
DEF_STATIC_CONST_VAL_FLOAT(val_0017,8.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0011 19
DEF_STATIC_CONST_VAL_FLOAT(val_0018,9.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0000 20
DEF_STATIC_CONST_VAL_FLOAT(val_0019,0.199500);
DEF_STATIC_CONST_VAL_FLOAT(val_0020,0.105000);
DEF_STATIC_CONST_VAL_STRING(val_0021,"ah");
DEF_STATIC_CONST_VAL_FLOAT(val_0022,10.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0023 25
DEF_STATIC_CONST_VAL_FLOAT(val_0023,0.400000);
DEF_STATIC_CONST_VAL_STRING(val_0024,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0025,0.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0026,11.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0028 30
DEF_STATIC_CONST_VAL_FLOAT(val_0027,12.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0027 31
DEF_STATIC_CONST_VAL_FLOAT(val_0028,0.069000);
DEF_STATIC_CONST_VAL_FLOAT(val_0029,13.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0032 34
DEF_STATIC_CONST_VAL_FLOAT(val_0030,14.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0031 35
DEF_STATIC_CONST_VAL_FLOAT(val_0031,15.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0026 36
DEF_STATIC_CONST_VAL_STRING(val_0032,"1");
DEF_STATIC_CONST_VAL_FLOAT(val_0033,16.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0037 39
DEF_STATIC_CONST_VAL_FLOAT(val_0034,17.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0036 40
DEF_STATIC_CONST_VAL_FLOAT(val_0035,0.060000);
DEF_STATIC_CONST_VAL_FLOAT(val_0036,18.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0040 42
DEF_STATIC_CONST_VAL_FLOAT(val_0037,19.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0025 43
DEF_STATIC_CONST_VAL_FLOAT(val_0038,0.078000);
DEF_STATIC_CONST_VAL_FLOAT(val_0039,20.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0043 45
DEF_STATIC_CONST_VAL_FLOAT(val_0040,21.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0022 46
DEF_STATIC_CONST_VAL_STRING(val_0041,"aux");
DEF_STATIC_CONST_VAL_FLOAT(val_0042,1.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0043,22.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0048 50
DEF_STATIC_CONST_VAL_FLOAT(val_0044,23.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0050 52
DEF_STATIC_CONST_VAL_FLOAT(val_0045,24.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0047 53
DEF_STATIC_CONST_VAL_STRING(val_0046,"in");
DEF_STATIC_CONST_VAL_FLOAT(val_0047,2.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0048,25.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0055 57
DEF_STATIC_CONST_VAL_FLOAT(val_0049,0.150000);
DEF_STATIC_CONST_VAL_FLOAT(val_0050,26.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0057 59
DEF_STATIC_CONST_VAL_FLOAT(val_0051,27.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0054 60
DEF_STATIC_CONST_VAL_STRING(val_0052,"ae");
DEF_STATIC_CONST_VAL_FLOAT(val_0053,28.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0060 62
DEF_STATIC_CONST_VAL_FLOAT(val_0054,29.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0064 66
DEF_STATIC_CONST_VAL_FLOAT(val_0055,30.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0063 67
DEF_STATIC_CONST_VAL_FLOAT(val_0056,31.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0062 68
DEF_STATIC_CONST_VAL_FLOAT(val_0057,0.168000);
DEF_STATIC_CONST_VAL_FLOAT(val_0058,32.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0069 71
DEF_STATIC_CONST_VAL_FLOAT(val_0059,33.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0068 72
DEF_STATIC_CONST_VAL_FLOAT(val_0060,34.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0053 73
DEF_STATIC_CONST_VAL_STRING(val_0061,"ax");
DEF_STATIC_CONST_VAL_FLOAT(val_0062,35.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0073 75
DEF_STATIC_CONST_VAL_FLOAT(val_0063,36.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0076 78
DEF_STATIC_CONST_VAL_FLOAT(val_0064,37.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0075 79
DEF_STATIC_CONST_VAL_FLOAT(val_0065,38.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0046 80
DEF_STATIC_CONST_VAL_FLOAT(val_0066,39.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0082 84
DEF_STATIC_CONST_VAL_FLOAT(val_0067,40.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0081 85
DEF_STATIC_CONST_VAL_FLOAT(val_0068,41.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0080 86
DEF_STATIC_CONST_VAL_FLOAT(val_0069,42.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0086 88
DEF_STATIC_CONST_VAL_FLOAT(val_0070,43.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0088 90
DEF_STATIC_CONST_VAL_FLOAT(val_0071,2.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0072,44.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0091 93
DEF_STATIC_CONST_VAL_FLOAT(val_0073,45.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0093 95
DEF_STATIC_CONST_VAL_FLOAT(val_0074,46.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0090 96
DEF_STATIC_CONST_VAL_FLOAT(val_0075,47.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0021 97
DEF_STATIC_CONST_VAL_FLOAT(val_0076,48.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0098 100
DEF_STATIC_CONST_VAL_FLOAT(val_0077,0.159000);
DEF_STATIC_CONST_VAL_FLOAT(val_0078,49.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0101 103
DEF_STATIC_CONST_VAL_FLOAT(val_0079,50.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0100 104
DEF_STATIC_CONST_VAL_FLOAT(val_0080,3.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0081,51.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0104 106
DEF_STATIC_CONST_VAL_FLOAT(val_0082,52.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0097 107
DEF_STATIC_CONST_VAL_STRING(val_0083,"ay");
DEF_STATIC_CONST_VAL_FLOAT(val_0084,53.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0107 109
DEF_STATIC_CONST_VAL_FLOAT(val_0085,0.600000);
DEF_STATIC_CONST_VAL_STRING(val_0086,"iy");
DEF_STATIC_CONST_VAL_FLOAT(val_0087,54.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0111 113
DEF_STATIC_CONST_VAL_FLOAT(val_0088,55.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0113 115
DEF_STATIC_CONST_VAL_FLOAT(val_0089,56.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0110 116
DEF_STATIC_CONST_VAL_FLOAT(val_0090,57.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0116 118
DEF_STATIC_CONST_VAL_FLOAT(val_0091,58.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0109 119
DEF_STATIC_CONST_VAL_FLOAT(val_0092,59.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0020 120
DEF_STATIC_CONST_VAL_FLOAT(val_0093,0.249000);
DEF_STATIC_CONST_VAL_FLOAT(val_0094,60.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0123 125
DEF_STATIC_CONST_VAL_FLOAT(val_0095,61.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0122 126
DEF_STATIC_CONST_VAL_FLOAT(val_0096,62.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0127 129
DEF_STATIC_CONST_VAL_FLOAT(val_0097,63.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0126 130
DEF_STATIC_CONST_VAL_FLOAT(val_0098,64.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0130 132
DEF_STATIC_CONST_VAL_FLOAT(val_0099,65.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0132 134
DEF_STATIC_CONST_VAL_FLOAT(val_0100,66.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0121 135
DEF_STATIC_CONST_VAL_FLOAT(val_0101,0.241000);
DEF_STATIC_CONST_VAL_FLOAT(val_0102,0.216000);
DEF_STATIC_CONST_VAL_FLOAT(val_0103,0.206000);
DEF_STATIC_CONST_VAL_FLOAT(val_0104,67.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0138 140
DEF_STATIC_CONST_VAL_FLOAT(val_0105,68.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0137 141
DEF_STATIC_CONST_VAL_FLOAT(val_0106,69.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0141 143
DEF_STATIC_CONST_VAL_FLOAT(val_0107,70.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0136 144
DEF_STATIC_CONST_VAL_FLOAT(val_0108,0.391000);
DEF_STATIC_CONST_VAL_FLOAT(val_0109,0.332000);
DEF_STATIC_CONST_VAL_FLOAT(val_0110,6.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0111,71.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0148 150
DEF_STATIC_CONST_VAL_FLOAT(val_0112,72.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0147 151
DEF_STATIC_CONST_VAL_FLOAT(val_0113,73.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0146 152
DEF_STATIC_CONST_VAL_FLOAT(val_0114,74.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0145 153
DEF_STATIC_CONST_VAL_FLOAT(val_0115,75.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0144 154
DEF_STATIC_CONST_VAL_FLOAT(val_0116,76.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0135 155
DEF_STATIC_CONST_VAL_FLOAT(val_0117,0.243000);
DEF_STATIC_CONST_VAL_FLOAT(val_0118,77.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0156 158
DEF_STATIC_CONST_VAL_FLOAT(val_0119,78.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0155 159
DEF_STATIC_CONST_VAL_FLOAT(val_0120,0.322000);
DEF_STATIC_CONST_VAL_FLOAT(val_0121,79.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0160 162
DEF_STATIC_CONST_VAL_FLOAT(val_0122,80.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0162 164
DEF_STATIC_CONST_VAL_FLOAT(val_0123,81.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0159 165
DEF_STATIC_CONST_VAL_FLOAT(val_0124,0.355500);
DEF_STATIC_CONST_VAL_FLOAT(val_0125,82.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0165 167
DEF_STATIC_CONST_VAL_FLOAT(val_0126,83.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0120 168
DEF_STATIC_CONST_VAL_FLOAT(val_0127,84.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0170 172
DEF_STATIC_CONST_VAL_FLOAT(val_0128,85.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0172 174
DEF_STATIC_CONST_VAL_FLOAT(val_0129,86.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0169 175
DEF_STATIC_CONST_VAL_FLOAT(val_0130,87.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0168 176
DEF_STATIC_CONST_VAL_FLOAT(val_0131,88.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0177 179
DEF_STATIC_CONST_VAL_FLOAT(val_0132,89.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0176 180
DEF_STATIC_CONST_VAL_FLOAT(val_0133,1.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0134,90.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0181 183
DEF_STATIC_CONST_VAL_FLOAT(val_0135,91.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0180 184
DEF_STATIC_CONST_VAL_FLOAT(val_0136,0.297500);
DEF_STATIC_CONST_VAL_FLOAT(val_0137,92.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0185 187
DEF_STATIC_CONST_VAL_FLOAT(val_0138,93.000000);
#define CTNODE_cmu_us_awb_spamf0_accent_NO_0184 188
DEF_STATIC_CONST_VAL_FLOAT(val_0139,94.000000);
