DEF_STATIC_CONST_VAL_STRING(val_0000,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0001,0.367500);
DEF_STATIC_CONST_VAL_FLOAT(val_0002,0.270500);
DEF_STATIC_CONST_VAL_FLOAT(val_0003,1.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0004,0.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0003 5
DEF_STATIC_CONST_VAL_FLOAT(val_0005,1.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0002 6
DEF_STATIC_CONST_VAL_FLOAT(val_0006,2.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0007,2.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0006 8
DEF_STATIC_CONST_VAL_FLOAT(val_0008,5.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0009,3.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0008 10
DEF_STATIC_CONST_VAL_FLOAT(val_0010,4.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0001 11
DEF_STATIC_CONST_VAL_FLOAT(val_0011,0.433000);
DEF_STATIC_CONST_VAL_FLOAT(val_0012,5.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0012 14
DEF_STATIC_CONST_VAL_FLOAT(val_0013,6.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0011 15
DEF_STATIC_CONST_VAL_FLOAT(val_0014,6.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0015,7.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0015 17
DEF_STATIC_CONST_VAL_FLOAT(val_0016,0.485000);
DEF_STATIC_CONST_VAL_FLOAT(val_0017,8.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0017 19
DEF_STATIC_CONST_VAL_FLOAT(val_0018,9.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0000 20
DEF_STATIC_CONST_VAL_FLOAT(val_0019,0.201000);
DEF_STATIC_CONST_VAL_STRING(val_0020,"ah");
DEF_STATIC_CONST_VAL_FLOAT(val_0021,0.132000);
DEF_STATIC_CONST_VAL_STRING(val_0022,"0");
DEF_STATIC_CONST_VAL_FLOAT(val_0023,10.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0023 25
DEF_STATIC_CONST_VAL_FLOAT(val_0024,11.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0022 26
DEF_STATIC_CONST_VAL_FLOAT(val_0025,12.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0021 27
DEF_STATIC_CONST_VAL_FLOAT(val_0026,1.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0027,13.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0029 31
DEF_STATIC_CONST_VAL_FLOAT(val_0028,14.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0028 32
DEF_STATIC_CONST_VAL_FLOAT(val_0029,15.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0033 35
DEF_STATIC_CONST_VAL_FLOAT(val_0030,16.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0032 36
DEF_STATIC_CONST_VAL_STRING(val_0031,"ax");
DEF_STATIC_CONST_VAL_FLOAT(val_0032,17.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0036 38
DEF_STATIC_CONST_VAL_FLOAT(val_0033,18.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0027 39
DEF_STATIC_CONST_VAL_FLOAT(val_0034,0.600000);
DEF_STATIC_CONST_VAL_STRING(val_0035,"ae");
DEF_STATIC_CONST_VAL_FLOAT(val_0036,1.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0037,0.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0038,19.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0042 44
DEF_STATIC_CONST_VAL_FLOAT(val_0039,20.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0041 45
DEF_STATIC_CONST_VAL_FLOAT(val_0040,0.120000);
DEF_STATIC_CONST_VAL_FLOAT(val_0041,21.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0045 47
DEF_STATIC_CONST_VAL_FLOAT(val_0042,22.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0047 49
DEF_STATIC_CONST_VAL_FLOAT(val_0043,23.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0040 50
DEF_STATIC_CONST_VAL_STRING(val_0044,"aux");
DEF_STATIC_CONST_VAL_FLOAT(val_0045,4.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0046,2.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0047,24.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0052 54
DEF_STATIC_CONST_VAL_FLOAT(val_0048,25.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0051 55
DEF_STATIC_CONST_VAL_FLOAT(val_0049,26.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0050 56
DEF_STATIC_CONST_VAL_STRING(val_0050,"to");
DEF_STATIC_CONST_VAL_FLOAT(val_0051,27.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0056 58
DEF_STATIC_CONST_VAL_FLOAT(val_0052,0.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0053,28.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0060 62
DEF_STATIC_CONST_VAL_FLOAT(val_0054,0.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0055,29.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0062 64
DEF_STATIC_CONST_VAL_FLOAT(val_0056,30.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0064 66
DEF_STATIC_CONST_VAL_FLOAT(val_0057,31.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0066 68
DEF_STATIC_CONST_VAL_FLOAT(val_0058,32.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0059 69
DEF_STATIC_CONST_VAL_FLOAT(val_0059,33.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0070 72
DEF_STATIC_CONST_VAL_STRING(val_0060,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0061,34.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0073 75
DEF_STATIC_CONST_VAL_FLOAT(val_0062,35.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0072 76
DEF_STATIC_CONST_VAL_FLOAT(val_0063,36.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0069 77
DEF_STATIC_CONST_VAL_FLOAT(val_0064,37.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0058 78
DEF_STATIC_CONST_VAL_FLOAT(val_0065,0.070000);
DEF_STATIC_CONST_VAL_FLOAT(val_0066,38.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0080 82
DEF_STATIC_CONST_VAL_FLOAT(val_0067,39.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0079 83
DEF_STATIC_CONST_VAL_FLOAT(val_0068,4.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0069,40.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0084 86
DEF_STATIC_CONST_VAL_FLOAT(val_0070,41.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0083 87
DEF_STATIC_CONST_VAL_STRING(val_0071,"ih");
DEF_STATIC_CONST_VAL_FLOAT(val_0072,42.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0087 89
DEF_STATIC_CONST_VAL_FLOAT(val_0073,43.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0078 90
DEF_STATIC_CONST_VAL_FLOAT(val_0074,0.154500);
DEF_STATIC_CONST_VAL_FLOAT(val_0075,44.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0091 93
DEF_STATIC_CONST_VAL_FLOAT(val_0076,2.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0077,45.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0093 95
DEF_STATIC_CONST_VAL_FLOAT(val_0078,46.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0090 96
DEF_STATIC_CONST_VAL_FLOAT(val_0079,0.174000);
DEF_STATIC_CONST_VAL_FLOAT(val_0080,47.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0097 99
DEF_STATIC_CONST_VAL_FLOAT(val_0081,48.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0096 100
DEF_STATIC_CONST_VAL_FLOAT(val_0082,49.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0039 101
DEF_STATIC_CONST_VAL_FLOAT(val_0083,0.149000);
DEF_STATIC_CONST_VAL_FLOAT(val_0084,50.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0102 104
DEF_STATIC_CONST_VAL_FLOAT(val_0085,51.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0104 106
DEF_STATIC_CONST_VAL_STRING(val_0086,"er");
DEF_STATIC_CONST_VAL_FLOAT(val_0087,52.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0106 108
DEF_STATIC_CONST_VAL_FLOAT(val_0088,0.099000);
DEF_STATIC_CONST_VAL_FLOAT(val_0089,53.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0108 110
DEF_STATIC_CONST_VAL_FLOAT(val_0090,54.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0110 112
DEF_STATIC_CONST_VAL_FLOAT(val_0091,55.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0101 113
DEF_STATIC_CONST_VAL_FLOAT(val_0092,3.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0093,1.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0094,56.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0115 117
DEF_STATIC_CONST_VAL_FLOAT(val_0095,57.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0114 118
DEF_STATIC_CONST_VAL_FLOAT(val_0096,58.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0113 119
DEF_STATIC_CONST_VAL_FLOAT(val_0097,0.170000);
DEF_STATIC_CONST_VAL_FLOAT(val_0098,59.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0120 122
DEF_STATIC_CONST_VAL_FLOAT(val_0099,60.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0119 123
DEF_STATIC_CONST_VAL_FLOAT(val_0100,61.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0123 125
DEF_STATIC_CONST_VAL_FLOAT(val_0101,62.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0020 126
DEF_STATIC_CONST_VAL_FLOAT(val_0102,2.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0103,3.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_0104,63.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0128 130
DEF_STATIC_CONST_VAL_FLOAT(val_0105,64.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0130 132
DEF_STATIC_CONST_VAL_FLOAT(val_0106,65.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0127 133
DEF_STATIC_CONST_VAL_FLOAT(val_0107,0.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0108,6.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0109,66.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0135 137
DEF_STATIC_CONST_VAL_FLOAT(val_0110,67.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0134 138
DEF_STATIC_CONST_VAL_FLOAT(val_0111,68.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0138 140
DEF_STATIC_CONST_VAL_FLOAT(val_0112,69.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0133 141
DEF_STATIC_CONST_VAL_FLOAT(val_0113,70.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0141 143
DEF_STATIC_CONST_VAL_FLOAT(val_0114,71.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0126 144
DEF_STATIC_CONST_VAL_FLOAT(val_0115,0.291000);
DEF_STATIC_CONST_VAL_FLOAT(val_0116,72.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0146 148
DEF_STATIC_CONST_VAL_FLOAT(val_0117,73.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0145 149
DEF_STATIC_CONST_VAL_FLOAT(val_0118,8.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0119,0.239000);
DEF_STATIC_CONST_VAL_FLOAT(val_0120,74.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0151 153
DEF_STATIC_CONST_VAL_FLOAT(val_0121,75.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0150 154
DEF_STATIC_CONST_VAL_FLOAT(val_0122,76.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0155 157
DEF_STATIC_CONST_VAL_FLOAT(val_0123,77.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0154 158
DEF_STATIC_CONST_VAL_FLOAT(val_0124,78.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0159 161
DEF_STATIC_CONST_VAL_FLOAT(val_0125,79.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0158 162
DEF_STATIC_CONST_VAL_FLOAT(val_0126,5.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0127,80.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0162 164
DEF_STATIC_CONST_VAL_FLOAT(val_0128,81.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0149 165
DEF_STATIC_CONST_VAL_FLOAT(val_0129,82.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0166 168
DEF_STATIC_CONST_VAL_FLOAT(val_0130,83.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0165 169
DEF_STATIC_CONST_VAL_FLOAT(val_0131,84.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0169 171
DEF_STATIC_CONST_VAL_FLOAT(val_0132,85.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0144 172
DEF_STATIC_CONST_VAL_FLOAT(val_0133,86.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0174 176
DEF_STATIC_CONST_VAL_FLOAT(val_0134,87.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0173 177
DEF_STATIC_CONST_VAL_FLOAT(val_0135,88.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0172 178
DEF_STATIC_CONST_VAL_FLOAT(val_0136,3.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0137,89.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0179 181
DEF_STATIC_CONST_VAL_FLOAT(val_0138,90.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0178 182
DEF_STATIC_CONST_VAL_FLOAT(val_0139,91.000000);
#define CTNODE_cmu_us_slt_spamf0_accent_NO_0182 184
DEF_STATIC_CONST_VAL_FLOAT(val_0140,92.000000);
