/*****************************************************/
/**  Autogenerated cmu_us_rms single_mcep carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_rms_cg_single_mcep_trees.h"

static const cst_cart_node cmu_us_rms_single_mcep_zh_204_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0001, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0002 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0004 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0005, (cst_val *)&val_0005},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_zh_204_NO_0008, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_zh_204_feat_table[] = {
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_zh_204_cart = {
  cmu_us_rms_single_mcep_zh_204_cart_nodes,
  cmu_us_rms_single_mcep_zh_204_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_zh_205_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_205_NO_0000, (cst_val *)&val_0013},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_205_NO_0001, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_205_NO_0004, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_zh_205_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_zh_205_cart = {
  cmu_us_rms_single_mcep_zh_205_cart_nodes,
  cmu_us_rms_single_mcep_zh_205_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_zh_206_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_206_NO_0000, (cst_val *)&val_0020},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_zh_206_NO_0001, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_zh_206_feat_table[] = {
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_zh_206_cart = {
  cmu_us_rms_single_mcep_zh_206_cart_nodes,
  cmu_us_rms_single_mcep_zh_206_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_oy_131_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0001, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0003, (cst_val *)&val_0028},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0004, (cst_val *)&val_0029},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0005, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0008, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0035 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0011, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0014, (cst_val *)&val_0039},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0041 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0017, (cst_val *)&val_0042},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0018, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0021, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0022, (cst_val *)&val_0046},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0023, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0028, (cst_val *)&val_0051},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0029, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0031, (cst_val *)&val_0053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0033, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0035, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0038, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0039, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0041, (cst_val *)&val_0062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0064 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0044, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0046, (cst_val *)&val_0067},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_131_NO_0047, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_oy_131_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_single_mcep_oy_131_cart = {
  cmu_us_rms_single_mcep_oy_131_cart_nodes,
  cmu_us_rms_single_mcep_oy_131_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_oy_132_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0000, (cst_val *)&val_0072},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0002, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0003, (cst_val *)&val_0011},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0004, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0007, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0009, (cst_val *)&val_0079},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0010, (cst_val *)&val_0080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0013, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0017, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0019, (cst_val *)&val_0087},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0020, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0023, (cst_val *)&val_0091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0093 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_132_NO_0026, (cst_val *)&val_0094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_oy_132_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_oy_132_cart = {
  cmu_us_rms_single_mcep_oy_132_cart_nodes,
  cmu_us_rms_single_mcep_oy_132_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_oy_133_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0000, (cst_val *)&val_0097},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0002, (cst_val *)&val_0098},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0003, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0005, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0007, (cst_val *)&val_0103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0011, (cst_val *)&val_0107},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0012, (cst_val *)&val_0108},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0013, (cst_val *)&val_0109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0016, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0018, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0022, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0023, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0025, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0027, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0030, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0032, (cst_val *)&val_0127},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_oy_133_NO_0033, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_oy_133_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_oy_133_cart = {
  cmu_us_rms_single_mcep_oy_133_cart_nodes,
  cmu_us_rms_single_mcep_oy_133_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ch_41_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0000, (cst_val *)&val_0132},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0001, (cst_val *)&val_0120},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0002, (cst_val *)&val_0133},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0003, (cst_val *)&val_0134},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0004, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0007, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0010, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0141 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0012, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0015, (cst_val *)&val_0044},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0016, (cst_val *)&val_0145},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0017, (cst_val *)&val_0146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0020, (cst_val *)&val_0149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0024, (cst_val *)&val_0153},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0025, (cst_val *)&val_0154},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0026, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0028, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0029, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0159 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0033, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0034, (cst_val *)&val_0160},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0035, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0164 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0039, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0041, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_41_NO_0044, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0170 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ch_41_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_ch_41_cart = {
  cmu_us_rms_single_mcep_ch_41_cart_nodes,
  cmu_us_rms_single_mcep_ch_41_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ch_42_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0000, (cst_val *)&val_0171},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0001, (cst_val *)&val_0172},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0002, (cst_val *)&val_0173},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0003, (cst_val *)&val_0174},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0007, (cst_val *)&val_0178},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0008, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0009, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0011, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0182 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0014, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0017, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0019, (cst_val *)&val_0188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0022, (cst_val *)&val_0191},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0023, (cst_val *)&val_0043},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0024, (cst_val *)&val_0192},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0025, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0194 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0027, (cst_val *)&val_0195},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0032, (cst_val *)&val_0199},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0033, (cst_val *)&val_0008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0034, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0038, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0039, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0043, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0044, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0047, (cst_val *)&val_0209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0049, (cst_val *)&val_0211},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0050, (cst_val *)&val_0212},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0051, (cst_val *)&val_0213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0056, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0058, (cst_val *)&val_0219},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0059, (cst_val *)&val_0043},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0060, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0063, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0225 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0066, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0068, (cst_val *)&val_0227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0228 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_42_NO_0070, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ch_42_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_ch_42_cart = {
  cmu_us_rms_single_mcep_ch_42_cart_nodes,
  cmu_us_rms_single_mcep_ch_42_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ch_43_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0000, (cst_val *)&val_0231},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0001, (cst_val *)&val_0050},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0002, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0004, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0007, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0010, (cst_val *)&val_0036},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0011, (cst_val *)&val_0239},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0012, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0241 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0015, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0242 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0017, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0245 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0020, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ch_43_NO_0022, (cst_val *)&val_0248},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ch_43_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_single_mcep_ch_43_cart = {
  cmu_us_rms_single_mcep_ch_43_cart_nodes,
  cmu_us_rms_single_mcep_ch_43_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aw_21_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0002, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0252 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0004, (cst_val *)&val_0253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0254 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0006, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0255 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0008, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0010, (cst_val *)&val_0075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0259 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0013, (cst_val *)&val_0260},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0014, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0019, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0264 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0021, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0023, (cst_val *)&val_0267},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0024, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0027, (cst_val *)&val_0270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0030, (cst_val *)&val_0010},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0031, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0032, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0033, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0273 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0035, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0276 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0039, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0041, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0279 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0043, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0046, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0047, (cst_val *)&val_0282},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0048, (cst_val *)&val_0283},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0049, (cst_val *)&val_0183},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0050, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0051, (cst_val *)&val_0068},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0052, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0288 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0057, (cst_val *)&val_0289},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0058, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0060, (cst_val *)&val_0291},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0293 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0063, (cst_val *)&val_0294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0296 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0066, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0067, (cst_val *)&val_0297},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0068, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0300 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0075, (cst_val *)&val_0045},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0076, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0077, (cst_val *)&val_0303},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0078, (cst_val *)&val_0304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0081, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0084, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0086, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0089, (cst_val *)&val_0314},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0090, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0094, (cst_val *)&val_0318},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0095, (cst_val *)&val_0319},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0096, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0099, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0323 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0101, (cst_val *)&val_0324},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0102, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0327 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_21_NO_0105, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aw_21_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_aw_21_cart = {
  cmu_us_rms_single_mcep_aw_21_cart_nodes,
  cmu_us_rms_single_mcep_aw_21_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aw_22_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0000, (cst_val *)&val_0183},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0001, (cst_val *)&val_0332},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0002, (cst_val *)&val_0333},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0003, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0004, (cst_val *)&val_0334},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0009, (cst_val *)&val_0334},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0010, (cst_val *)&val_0339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0340 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0012, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0016, (cst_val *)&val_0344},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0017, (cst_val *)&val_0345},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0018, (cst_val *)&val_0251},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0019, (cst_val *)&val_0346},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0020, (cst_val *)&val_0347},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0021, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0350 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0025, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0028, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0030, (cst_val *)&val_0354},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0031, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0357 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0034, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0360 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0037, (cst_val *)&val_0361},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0038, (cst_val *)&val_0068},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0039, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0364 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0042, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0367 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0045, (cst_val *)&val_0368},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0046, (cst_val *)&val_0369},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0047, (cst_val *)&val_0370},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0048, (cst_val *)&val_0371},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0049, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0372 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0051, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0374 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0054, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0375 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0056, (cst_val *)&val_0376},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0057, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0378 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0060, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0381 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0064, (cst_val *)&val_0045},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0065, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0383 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0068, (cst_val *)&val_0384},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0069, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0385 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0071, (cst_val *)&val_0386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0387 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0073, (cst_val *)&val_0388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0389 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0075, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0391 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0078, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0079, (cst_val *)&val_0392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0394 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0082, (cst_val *)&val_0395},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0083, (cst_val *)&val_0396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0400 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_22_NO_0088, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0402 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aw_22_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_rms_single_mcep_aw_22_cart = {
  cmu_us_rms_single_mcep_aw_22_cart_nodes,
  cmu_us_rms_single_mcep_aw_22_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aw_23_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0000, (cst_val *)&val_0403},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0001, (cst_val *)&val_0051},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0002, (cst_val *)&val_0404},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0003, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0406 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0006, (cst_val *)&val_0407},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0007, (cst_val *)&val_0013},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0008, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0409 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0010, (cst_val *)&val_0410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0412 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0013, (cst_val *)&val_0413},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0014, (cst_val *)&val_0414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0416 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0017, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0420 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0021, (cst_val *)&val_0421},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0022, (cst_val *)&val_0422},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0023, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0427 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0028, (cst_val *)&val_0428},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0029, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0030, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0430 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0032, (cst_val *)&val_0431},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0033, (cst_val *)&val_0432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0435 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0037, (cst_val *)&val_0436},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0038, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0437 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0040, (cst_val *)&val_0438},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0041, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0042, (cst_val *)&val_0439},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0043, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0443 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0047, (cst_val *)&val_0444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0447 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0051, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0450 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0054, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0055, (cst_val *)&val_0451},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0056, (cst_val *)&val_0452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0454 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0059, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0455 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0061, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0064, (cst_val *)&val_0458},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0065, (cst_val *)&val_0040},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0066, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0461 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0069, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0462 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0071, (cst_val *)&val_0297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0464 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0074, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0075, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0465 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0077, (cst_val *)&val_0466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0467 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0079, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0469 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0082, (cst_val *)&val_0183},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aw_23_NO_0083, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0472 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aw_23_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_aw_23_cart = {
  cmu_us_rms_single_mcep_aw_23_cart_nodes,
  cmu_us_rms_single_mcep_aw_23_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ow_126_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0001, (cst_val *)&val_0325},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0002, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0473 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0004, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0475 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0006, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0476 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0008, (cst_val *)&val_0477},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0009, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0479 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0011, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0480 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0013, (cst_val *)&val_0481},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0484 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0017, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0486 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0019, (cst_val *)&val_0487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0488 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0021, (cst_val *)&val_0489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0491 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0024, (cst_val *)&val_0026},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0025, (cst_val *)&val_0492},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0026, (cst_val *)&val_0493},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0027, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0495 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0030, (cst_val *)&val_0496},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0498 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0033, (cst_val *)&val_0112},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0034, (cst_val *)&val_0499},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0501 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0037, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0038, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0502 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0040, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0504 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0042, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0507 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0045, (cst_val *)&val_0493},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0046, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0509 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0049, (cst_val *)&val_0510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0512 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0052, (cst_val *)&val_0361},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0053, (cst_val *)&val_0052},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0054, (cst_val *)&val_0513},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0055, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0516 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0059, (cst_val *)&val_0517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0518 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0061, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0520 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0064, (cst_val *)&val_0025},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0065, (cst_val *)&val_0028},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0066, (cst_val *)&val_0492},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0067, (cst_val *)&val_0521},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0068, (cst_val *)&val_0019},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0069, (cst_val *)&val_0522},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0070, (cst_val *)&val_0523},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0525 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0073, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0528 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0076, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0531 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0079, (cst_val *)&val_0532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0534 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0082, (cst_val *)&val_0045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0083, (cst_val *)&val_0015},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0084, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0536 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0087, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0538 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0090, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0540 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0092, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0541 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0094, (cst_val *)&val_0542},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0095, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0545 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0099, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0100, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0547 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0102, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0549 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0105, (cst_val *)&val_0550},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0106, (cst_val *)&val_0551},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0107, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0552 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0109, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0554 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0112, (cst_val *)&val_0165},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0113, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0114, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0558 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0119, (cst_val *)&val_0040},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0120, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0561 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0124, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0563 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0126, (cst_val *)&val_0564},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0127, (cst_val *)&val_0125},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0128, (cst_val *)&val_0565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0567 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0131, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0568 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0133, (cst_val *)&val_0569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0571 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0136, (cst_val *)&val_0114},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0137, (cst_val *)&val_0040},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0138, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0573 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0141, (cst_val *)&val_0045},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0142, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0576 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0145, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0146, (cst_val *)&val_0376},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_126_NO_0147, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0581 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ow_126_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
NULL };

const cst_cart cmu_us_rms_single_mcep_ow_126_cart = {
  cmu_us_rms_single_mcep_ow_126_cart_nodes,
  cmu_us_rms_single_mcep_ow_126_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ow_127_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0000, (cst_val *)&val_0582},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0001, (cst_val *)&val_0183},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0002, (cst_val *)&val_0031},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0003, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0583 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0005, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0006, (cst_val *)&val_0584},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0007, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0587 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0011, (cst_val *)&val_0588},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0012, (cst_val *)&val_0589},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0591 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0015, (cst_val *)&val_0592},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0016, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0595 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0020, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0596 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0022, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0597 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0024, (cst_val *)&val_0598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0600 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0027, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0028, (cst_val *)&val_0601},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0029, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0030, (cst_val *)&val_0602},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0031, (cst_val *)&val_0603},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0032, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0605 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0035, (cst_val *)&val_0606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0607 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0037, (cst_val *)&val_0608},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0610 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0040, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0041, (cst_val *)&val_0611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0614 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0045, (cst_val *)&val_0615},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0046, (cst_val *)&val_0165},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0047, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0617 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0050, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0619 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0053, (cst_val *)&val_0620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0621 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0055, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0623 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0058, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0624 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0060, (cst_val *)&val_0625},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0061, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0628 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0064, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0630 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0066, (cst_val *)&val_0631},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0067, (cst_val *)&val_0632},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0068, (cst_val *)&val_0633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0636 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0072, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0639 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0075, (cst_val *)&val_0640},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0076, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0641 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0078, (cst_val *)&val_0325},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0079, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0643 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0081, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0646 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0084, (cst_val *)&val_0358},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0085, (cst_val *)&val_0025},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0086, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0648 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0089, (cst_val *)&val_0125},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0090, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0650 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0093, (cst_val *)&val_0651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0652 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0095, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0098, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0655 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0100, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0656 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0102, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0658 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0105, (cst_val *)&val_0251},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0106, (cst_val *)&val_0278},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0107, (cst_val *)&val_0165},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0108, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0662 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0113, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0114, (cst_val *)&val_0291},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0115, (cst_val *)&val_0663},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0664 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0117, (cst_val *)&val_0665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0668 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0121, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0670 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0123, (cst_val *)&val_0671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0673 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0126, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0127, (cst_val *)&val_0125},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0128, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0675 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0131, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0676 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0133, (cst_val *)&val_0183},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0134, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0679 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0138, (cst_val *)&val_0626},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0139, (cst_val *)&val_0040},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0140, (cst_val *)&val_0680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0682 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0143, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0684 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0146, (cst_val *)&val_0045},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0147, (cst_val *)&val_0685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0687 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0150, (cst_val *)&val_0688},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_127_NO_0151, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0691 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ow_127_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_ow_127_cart = {
  cmu_us_rms_single_mcep_ow_127_cart_nodes,
  cmu_us_rms_single_mcep_ow_127_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ow_128_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0001, (cst_val *)&val_0692},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0002, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0694 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0004, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0695 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0006, (cst_val *)&val_0048},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0007, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0698 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0011, (cst_val *)&val_0693},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0012, (cst_val *)&val_0699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0700 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0014, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0702 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0017, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0018, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0704 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0021, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0023, (cst_val *)&val_0707},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0024, (cst_val *)&val_0708},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0025, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0712 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0030, (cst_val *)&val_0713},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0031, (cst_val *)&val_0714},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0032, (cst_val *)&val_0715},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0033, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0717 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0036, (cst_val *)&val_0718},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0037, (cst_val *)&val_0719},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0722 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0041, (cst_val *)&val_0723},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0042, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0725 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0044, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0728 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0047, (cst_val *)&val_0183},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0048, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0729 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0050, (cst_val *)&val_0730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0732 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0053, (cst_val *)&val_0733},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0054, (cst_val *)&val_0734},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0055, (cst_val *)&val_0735},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0738 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0059, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0740 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0061, (cst_val *)&val_0267},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0062, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0743 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0066, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0744 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0068, (cst_val *)&val_0183},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0069, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0747 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0072, (cst_val *)&val_0748},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0073, (cst_val *)&val_0723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0749 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0075, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0750 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0077, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0751 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0079, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0752 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ow_128_NO_0081, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0755 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ow_128_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_rms_single_mcep_ow_128_cart = {
  cmu_us_rms_single_mcep_ow_128_cart_nodes,
  cmu_us_rms_single_mcep_ow_128_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_b_36_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0000, (cst_val *)&val_0756},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0001, (cst_val *)&val_0043},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0002, (cst_val *)&val_0757},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0003, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0004, (cst_val *)&val_0758},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0759 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0006, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0762 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0009, (cst_val *)&val_0763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0765 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0012, (cst_val *)&val_0766},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0013, (cst_val *)&val_0297},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0014, (cst_val *)&val_0358},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0015, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0767 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0017, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0770 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0021, (cst_val *)&val_0771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0773 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0024, (cst_val *)&val_0771},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0025, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0026, (cst_val *)&val_0774},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0027, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0779 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0033, (cst_val *)&val_0780},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0034, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0781 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0036, (cst_val *)&val_0782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0784 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0039, (cst_val *)&val_0785},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0040, (cst_val *)&val_0008},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0041, (cst_val *)&val_0786},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0788 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0044, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0789 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0046, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0791 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0049, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0050, (cst_val *)&val_0792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0793 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0052, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0795 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0055, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0797 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0058, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0059, (cst_val *)&val_0798},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0060, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0061, (cst_val *)&val_0799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0801 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0064, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0065, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0802 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0067, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0803 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0069, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0805 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0807 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0075, (cst_val *)&val_0808},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0076, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0809 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0078, (cst_val *)&val_0810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0812 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0081, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0082, (cst_val *)&val_0008},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0083, (cst_val *)&val_0813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0815 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0086, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0817 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0089, (cst_val *)&val_0818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0820 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0092, (cst_val *)&val_0193},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0093, (cst_val *)&val_0821},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0094, (cst_val *)&val_0822},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0095, (cst_val *)&val_0823},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0096, (cst_val *)&val_0824},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0097, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0828 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0102, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0830 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0104, (cst_val *)&val_0831},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0105, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0834 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0109, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0835 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0111, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0836 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0113, (cst_val *)&val_0008},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0114, (cst_val *)&val_0059},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0115, (cst_val *)&val_0837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0840 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0119, (cst_val *)&val_0841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0843 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0122, (cst_val *)&val_0844},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0123, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0845 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0125, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0847 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0128, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0129, (cst_val *)&val_0246},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0130, (cst_val *)&val_0848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0850 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0133, (cst_val *)&val_0851},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0134, (cst_val *)&val_0852},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0135, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0854 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0138, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0857 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_36_NO_0142, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0859 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_b_36_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_b_36_cart = {
  cmu_us_rms_single_mcep_b_36_cart_nodes,
  cmu_us_rms_single_mcep_b_36_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_b_37_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0000, (cst_val *)&val_0145},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0001, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0002, (cst_val *)&val_0860},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0003, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0862 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0006, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0863 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0008, (cst_val *)&val_0864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0866 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0011, (cst_val *)&val_0867},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0012, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0869 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0014, (cst_val *)&val_0774},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0015, (cst_val *)&val_0870},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0016, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0872 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0019, (cst_val *)&val_0873},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0020, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0874 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0022, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0023, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0877 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0027, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0880 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0030, (cst_val *)&val_0025},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0031, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0881 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0033, (cst_val *)&val_0786},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0034, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0885 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0038, (cst_val *)&val_0025},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0039, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0887 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0042, (cst_val *)&val_0888},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0043, (cst_val *)&val_0165},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0044, (cst_val *)&val_0889},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0045, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0891 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0048, (cst_val *)&val_0837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0895 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0053, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0898 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0056, (cst_val *)&val_0056},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0057, (cst_val *)&val_0899},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0058, (cst_val *)&val_0900},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0059, (cst_val *)&val_0901},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0060, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0904 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0063, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0906 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0066, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0908 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0069, (cst_val *)&val_0909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0911 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0912 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0074, (cst_val *)&val_0913},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_37_NO_0075, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0917 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_b_37_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_b_37_cart = {
  cmu_us_rms_single_mcep_b_37_cart_nodes,
  cmu_us_rms_single_mcep_b_37_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_b_38_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0000, (cst_val *)&val_0056},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0001, (cst_val *)&val_0918},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0002, (cst_val *)&val_0919},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0003, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0920 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0005, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0921 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0007, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0923 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0010, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0924 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0012, (cst_val *)&val_0925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0927 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0015, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0929 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0018, (cst_val *)&val_0145},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0019, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0020, (cst_val *)&val_0930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0932 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0023, (cst_val *)&val_0933},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0024, (cst_val *)&val_0934},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0025, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0935 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0027, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0937 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0030, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0939 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0033, (cst_val *)&val_0940},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0034, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0943 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0038, (cst_val *)&val_0008},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0039, (cst_val *)&val_0944},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0040, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0946 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0043, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0948 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0046, (cst_val *)&val_0949},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0047, (cst_val *)&val_0165},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_b_38_NO_0048, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0954 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_b_38_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_b_38_cart = {
  cmu_us_rms_single_mcep_b_38_cart_nodes,
  cmu_us_rms_single_mcep_b_38_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_g_76_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0000, (cst_val *)&val_0955},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0002, (cst_val *)&val_0956},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0003, (cst_val *)&val_0957},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0004, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0959 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0007, (cst_val *)&val_0043},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0008, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0961 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0011, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0963 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0014, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0965 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0017, (cst_val *)&val_0966},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0018, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0968 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0021, (cst_val *)&val_0145},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0022, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0972 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0026, (cst_val *)&val_0008},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0027, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0974 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0029, (cst_val *)&val_0975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0977 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0032, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0033, (cst_val *)&val_0978},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0034, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0981 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0037, (cst_val *)&val_0982},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0038, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0984 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0041, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0986 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0044, (cst_val *)&val_0011},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0045, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0988 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0048, (cst_val *)&val_0989},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0049, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0990 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0051, (cst_val *)&val_0991},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_76_NO_0052, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0996 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_g_76_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_single_mcep_g_76_cart = {
  cmu_us_rms_single_mcep_g_76_cart_nodes,
  cmu_us_rms_single_mcep_g_76_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_g_77_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0000, (cst_val *)&val_0186},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0001, (cst_val *)&val_0997},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0002, (cst_val *)&val_0950},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0003, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0998 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0005, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0006, (cst_val *)&val_0999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1003 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0011, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1005 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0014, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0015, (cst_val *)&val_1006},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0016, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1007 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0018, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1010 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0021, (cst_val *)&val_1011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1013 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0024, (cst_val *)&val_0016},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0025, (cst_val *)&val_1014},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0026, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1015 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_77_NO_0028, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1019 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_g_77_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_g_77_cart = {
  cmu_us_rms_single_mcep_g_77_cart_nodes,
  cmu_us_rms_single_mcep_g_77_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_g_78_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0000, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0001, (cst_val *)&val_0297},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0002, (cst_val *)&val_0940},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0003, (cst_val *)&val_1020},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0004, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1023 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0008, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1024 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0010, (cst_val *)&val_1025},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0011, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1028 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0015, (cst_val *)&val_1029},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0016, (cst_val *)&val_0103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1031 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0019, (cst_val *)&val_1032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1034 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0022, (cst_val *)&val_1035},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0023, (cst_val *)&val_0051},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0024, (cst_val *)&val_1036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1037 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0026, (cst_val *)&val_1038},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0027, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1041 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0031, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1043 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0034, (cst_val *)&val_0056},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0035, (cst_val *)&val_0934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1044 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0037, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1046 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0040, (cst_val *)&val_1047},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0041, (cst_val *)&val_0361},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0042, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0043, (cst_val *)&val_0956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1049 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0046, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1051 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0049, (cst_val *)&val_0251},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0050, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1052 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0052, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1055 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0056, (cst_val *)&val_0040},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0057, (cst_val *)&val_0361},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0058, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1057 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_g_78_NO_0061, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1060 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_g_78_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_g_78_cart = {
  cmu_us_rms_single_mcep_g_78_cart_nodes,
  cmu_us_rms_single_mcep_g_78_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ng_121_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0000, (cst_val *)&val_0361},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0001, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1061 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0003, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1063 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0006, (cst_val *)&val_0021},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0007, (cst_val *)&val_1064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0008, (cst_val *)&val_1065},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0009, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1067 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0012, (cst_val *)&val_0251},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0013, (cst_val *)&val_1068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1070 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0016, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1073 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0019, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0020, (cst_val *)&val_0165},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0021, (cst_val *)&val_0493},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0022, (cst_val *)&val_0934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0025, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1077 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0028, (cst_val *)&val_0408},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0029, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1079 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0031, (cst_val *)&val_0774},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0032, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1083 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0037, (cst_val *)&val_0493},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0038, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0039, (cst_val *)&val_0026},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0040, (cst_val *)&val_0489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1087 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0045, (cst_val *)&val_1088},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0046, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1091 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0050, (cst_val *)&val_1092},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0051, (cst_val *)&val_1093},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0052, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1095 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0055, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1097 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0058, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1098 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0060, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1099 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_121_NO_0062, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1101 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ng_121_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_ng_121_cart = {
  cmu_us_rms_single_mcep_ng_121_cart_nodes,
  cmu_us_rms_single_mcep_ng_121_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ng_122_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0000, (cst_val *)&val_1102},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0002, (cst_val *)&val_0165},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0003, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0004, (cst_val *)&val_1103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1106 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0008, (cst_val *)&val_1107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1109 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0011, (cst_val *)&val_1110},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0012, (cst_val *)&val_0626},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0013, (cst_val *)&val_0128},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0014, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1113 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0018, (cst_val *)&val_0231},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0019, (cst_val *)&val_0008},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0020, (cst_val *)&val_0056},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0021, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1115 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0024, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1118 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0028, (cst_val *)&val_0008},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0029, (cst_val *)&val_1119},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0030, (cst_val *)&val_0975},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0031, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1121 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0034, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1122 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0036, (cst_val *)&val_1123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1124 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0038, (cst_val *)&val_1125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1126 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0040, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0041, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1129 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0045, (cst_val *)&val_1130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1131 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0047, (cst_val *)&val_1132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1134 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0050, (cst_val *)&val_0165},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0051, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1137 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0055, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0056, (cst_val *)&val_1138},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0057, (cst_val *)&val_1139},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0058, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0059, (cst_val *)&val_1140},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0060, (cst_val *)&val_1141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1142 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0062, (cst_val *)&val_1143},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1145 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0065, (cst_val *)&val_1146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1151 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0071, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1153 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0074, (cst_val *)&val_0059},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0075, (cst_val *)&val_0008},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0076, (cst_val *)&val_0007},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0077, (cst_val *)&val_1154},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0078, (cst_val *)&val_1155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1157 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0081, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0084, (cst_val *)&val_0088},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0085, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1162 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0088, (cst_val *)&val_1163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1164 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0090, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0091, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1167 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0095, (cst_val *)&val_0199},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0096, (cst_val *)&val_1168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0099, (cst_val *)&val_1171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1173 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0102, (cst_val *)&val_0132},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0103, (cst_val *)&val_1174},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1175 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0105, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1176 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0107, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1177 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0109, (cst_val *)&val_0140},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0110, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1180 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_122_NO_0114, (cst_val *)&val_1181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1183 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ng_122_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_ng_122_cart = {
  cmu_us_rms_single_mcep_ng_122_cart_nodes,
  cmu_us_rms_single_mcep_ng_122_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ng_123_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0000, (cst_val *)&val_0651},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0002, (cst_val *)&val_0008},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0003, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1186 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0007, (cst_val *)&val_1119},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0008, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1187 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0010, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0011, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1188 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0013, (cst_val *)&val_1189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1192 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0017, (cst_val *)&val_1193},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0018, (cst_val *)&val_0550},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0019, (cst_val *)&val_1194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1196 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0022, (cst_val *)&val_1197},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0023, (cst_val *)&val_1198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1202 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0028, (cst_val *)&val_0270},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0029, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0030, (cst_val *)&val_0040},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0031, (cst_val *)&val_1203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1204 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0033, (cst_val *)&val_1205},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0034, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1206 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0036, (cst_val *)&val_0165},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0037, (cst_val *)&val_1207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1209 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0040, (cst_val *)&val_0723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1210 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0042, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1212 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0045, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1217 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ng_123_NO_0050, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1220 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ng_123_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ng_123_cart = {
  cmu_us_rms_single_mcep_ng_123_cart_nodes,
  cmu_us_rms_single_mcep_ng_123_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uw_179_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0000, (cst_val *)&val_0145},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0001, (cst_val *)&val_1221},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0002, (cst_val *)&val_1222},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0003, (cst_val *)&val_1223},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0004, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1224 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0006, (cst_val *)&val_1225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1227 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0009, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1228 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0011, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0012, (cst_val *)&val_0025},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0013, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1231 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0017, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0018, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1235 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0022, (cst_val *)&val_1236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1237 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0024, (cst_val *)&val_1238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1240 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0027, (cst_val *)&val_0307},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0028, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1242 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0031, (cst_val *)&val_0361},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0032, (cst_val *)&val_1243},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0033, (cst_val *)&val_1244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1246 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0036, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1248 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0039, (cst_val *)&val_1249},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0040, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1250 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0042, (cst_val *)&val_0978},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0043, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1254 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0048, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0049, (cst_val *)&val_1255},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0050, (cst_val *)&val_0297},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0051, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1257 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0054, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1259 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0057, (cst_val *)&val_1260},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0058, (cst_val *)&val_1261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1264 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0062, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_179_NO_0063, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1268 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uw_179_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_uw_179_cart = {
  cmu_us_rms_single_mcep_uw_179_cart_nodes,
  cmu_us_rms_single_mcep_uw_179_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uw_180_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0000, (cst_val *)&val_0978},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0002, (cst_val *)&val_0978},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0003, (cst_val *)&val_0220},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0004, (cst_val *)&val_1269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1272 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0008, (cst_val *)&val_1273},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0009, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1275 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0012, (cst_val *)&val_1276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0015, (cst_val *)&val_1265},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0016, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1279 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0018, (cst_val *)&val_0025},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0019, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1281 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0022, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1282 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0024, (cst_val *)&val_1283},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0025, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1286 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0029, (cst_val *)&val_1287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1288 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0031, (cst_val *)&val_1289},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0032, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1291 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0035, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1292 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0037, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1294 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0040, (cst_val *)&val_1295},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0041, (cst_val *)&val_1296},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0042, (cst_val *)&val_1297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1298 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0044, (cst_val *)&val_1299},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0045, (cst_val *)&val_1300},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0046, (cst_val *)&val_1301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1304 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0050, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1306 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0053, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0054, (cst_val *)&val_0125},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0055, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1308 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0058, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1309 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0060, (cst_val *)&val_1310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1311 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0062, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1313 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0065, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1314 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0067, (cst_val *)&val_0256},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0068, (cst_val *)&val_1315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1317 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0071, (cst_val *)&val_1318},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0072, (cst_val *)&val_1319},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0073, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1320 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0075, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1322 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0078, (cst_val *)&val_1323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1325 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0081, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1327 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0084, (cst_val *)&val_1328},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0085, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1329 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0087, (cst_val *)&val_1330},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0088, (cst_val *)&val_1331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1334 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_180_NO_0092, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1336 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uw_180_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_uw_180_cart = {
  cmu_us_rms_single_mcep_uw_180_cart_nodes,
  cmu_us_rms_single_mcep_uw_180_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uw_181_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0001, (cst_val *)&val_0015},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0002, (cst_val *)&val_1337},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0003, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1338 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0005, (cst_val *)&val_0040},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0006, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1341 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0010, (cst_val *)&val_1342},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0011, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1345 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0015, (cst_val *)&val_0422},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0016, (cst_val *)&val_1276},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0017, (cst_val *)&val_1346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1348 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0020, (cst_val *)&val_1349},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1352 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0024, (cst_val *)&val_1353},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0025, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1354 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0027, (cst_val *)&val_1355},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0028, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1358 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0031, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0032, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1359 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0034, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1361 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0037, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1362 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0039, (cst_val *)&val_1363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1364 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0041, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1366 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0044, (cst_val *)&val_0077},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0045, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1369 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0048, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0049, (cst_val *)&val_1194},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0050, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1370 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0052, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1372 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0055, (cst_val *)&val_0051},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0056, (cst_val *)&val_1373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1376 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0060, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1377 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0062, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1379 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0064, (cst_val *)&val_0088},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0065, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1382 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uw_181_NO_0068, (cst_val *)&val_1383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1385 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uw_181_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_single_mcep_uw_181_cart = {
  cmu_us_rms_single_mcep_uw_181_cart_nodes,
  cmu_us_rms_single_mcep_uw_181_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_sh_156_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0000, (cst_val *)&val_1386},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0001, (cst_val *)&val_0059},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0002, (cst_val *)&val_0171},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0003, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1388 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0005, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1390 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0008, (cst_val *)&val_0043},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0009, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1393 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0013, (cst_val *)&val_0043},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0014, (cst_val *)&val_0059},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1396 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0019, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1398 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0022, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1399 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0024, (cst_val *)&val_1400},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1401 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0026, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1402 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_156_NO_0028, (cst_val *)&val_1403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1405 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_sh_156_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_sh_156_cart = {
  cmu_us_rms_single_mcep_sh_156_cart_nodes,
  cmu_us_rms_single_mcep_sh_156_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_sh_157_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0000, (cst_val *)&val_0145},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0001, (cst_val *)&val_0219},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0002, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0003, (cst_val *)&val_0982},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0004, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1407 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0007, (cst_val *)&val_0220},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0008, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1409 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0011, (cst_val *)&val_1410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1411 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0013, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0014, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1414 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0018, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1415 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0020, (cst_val *)&val_0220},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0021, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1416 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0023, (cst_val *)&val_1417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1419 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0026, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1420 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1422 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0031, (cst_val *)&val_1423},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0032, (cst_val *)&val_0059},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0033, (cst_val *)&val_1424},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0034, (cst_val *)&val_0251},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0035, (cst_val *)&val_1425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1426 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0037, (cst_val *)&val_1427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1429 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0040, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0041, (cst_val *)&val_1430},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1431 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0043, (cst_val *)&val_0629},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0044, (cst_val *)&val_0008},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0045, (cst_val *)&val_1432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1435 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0049, (cst_val *)&val_1436},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0050, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1440 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0055, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0056, (cst_val *)&val_0629},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0057, (cst_val *)&val_1441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1442 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0059, (cst_val *)&val_1443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1444 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0061, (cst_val *)&val_1445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1447 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0064, (cst_val *)&val_0631},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0065, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1449 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0067, (cst_val *)&val_1450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1452 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0070, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1454 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0073, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1455 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0075, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1457 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0078, (cst_val *)&val_1458},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0079, (cst_val *)&val_0125},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0080, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1460 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0082, (cst_val *)&val_0422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1461 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0084, (cst_val *)&val_1462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1465 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0088, (cst_val *)&val_1466},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0089, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1467 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0091, (cst_val *)&val_1468},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0092, (cst_val *)&val_1469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1471 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0095, (cst_val *)&val_1472},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0096, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1473 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0098, (cst_val *)&val_0040},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0099, (cst_val *)&val_1474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1476 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0102, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1478 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0105, (cst_val *)&val_0040},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0106, (cst_val *)&val_1479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1482 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0110, (cst_val *)&val_0040},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0111, (cst_val *)&val_1483},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0112, (cst_val *)&val_1484},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1486 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0115, (cst_val *)&val_1487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1489 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0118, (cst_val *)&val_1490},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1491 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0120, (cst_val *)&val_1492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1493 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0122, (cst_val *)&val_1494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1496 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0125, (cst_val *)&val_0978},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0126, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0127, (cst_val *)&val_1497},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0128, (cst_val *)&val_0125},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0129, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1499 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0132, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1501 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0135, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1503 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0138, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1506 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0141, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1507 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0143, (cst_val *)&val_0008},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0144, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1509 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0147, (cst_val *)&val_1510},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0148, (cst_val *)&val_1511},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0149, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1515 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0154, (cst_val *)&val_0651},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0155, (cst_val *)&val_0045},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0156, (cst_val *)&val_1516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1517 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0158, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1519 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0161, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1521 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0164, (cst_val *)&val_1522},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0165, (cst_val *)&val_0059},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_157_NO_0166, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1526 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_sh_157_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_single_mcep_sh_157_cart = {
  cmu_us_rms_single_mcep_sh_157_cart_nodes,
  cmu_us_rms_single_mcep_sh_157_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_sh_158_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0000, (cst_val *)&val_1386},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0001, (cst_val *)&val_1527},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0002, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1528 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0004, (cst_val *)&val_1529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1531 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0007, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0008, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1532 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0010, (cst_val *)&val_1533},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0011, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1535 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0014, (cst_val *)&val_1536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1538 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0017, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1540 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0020, (cst_val *)&val_1541},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0021, (cst_val *)&val_0914},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0022, (cst_val *)&val_1542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1543 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0024, (cst_val *)&val_1249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1544 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0026, (cst_val *)&val_1545},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0027, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1549 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0033, (cst_val *)&val_0361},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0034, (cst_val *)&val_1289},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1550 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0036, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1552 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0039, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0040, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1555 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_sh_158_NO_0044, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1557 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_sh_158_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_sh_158_cart = {
  cmu_us_rms_single_mcep_sh_158_cart_nodes,
  cmu_us_rms_single_mcep_sh_158_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uh_174_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0000, (cst_val *)&val_0403},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0001, (cst_val *)&val_1558},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0002, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1559 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0004, (cst_val *)&val_1560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1562 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0007, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1564 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0010, (cst_val *)&val_1565},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0011, (cst_val *)&val_1566},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1568 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0014, (cst_val *)&val_1569},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0015, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1571 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0018, (cst_val *)&val_0841},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0019, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1572 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_174_NO_0021, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1575 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uh_174_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_uh_174_cart = {
  cmu_us_rms_single_mcep_uh_174_cart_nodes,
  cmu_us_rms_single_mcep_uh_174_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uh_175_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0000, (cst_val *)&val_0219},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0001, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1577 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0004, (cst_val *)&val_1424},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0005, (cst_val *)&val_1578},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0006, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1580 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0008, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1581 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0010, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1583 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0013, (cst_val *)&val_0068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0014, (cst_val *)&val_1584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1587 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0018, (cst_val *)&val_0671},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0019, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_175_NO_0021, (cst_val *)&val_1578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1592 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uh_175_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_uh_175_cart = {
  cmu_us_rms_single_mcep_uh_175_cart_nodes,
  cmu_us_rms_single_mcep_uh_175_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_uh_176_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0000, (cst_val *)&val_0239},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0001, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1593 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0003, (cst_val *)&val_0043},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0004, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0005, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1597 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0009, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1599 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0012, (cst_val *)&val_1600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1601 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0014, (cst_val *)&val_0088},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0015, (cst_val *)&val_1602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1603 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_uh_176_NO_0017, (cst_val *)&val_1604},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1607 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_uh_176_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_uh_176_cart = {
  cmu_us_rms_single_mcep_uh_176_cart_nodes,
  cmu_us_rms_single_mcep_uh_176_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_hh_81_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0000, (cst_val *)&val_1608},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0001, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1609 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0003, (cst_val *)&val_0239},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0004, (cst_val *)&val_0043},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0005, (cst_val *)&val_1610},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0006, (cst_val *)&val_1611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1613 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0009, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1616 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0012, (cst_val *)&val_1617},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0013, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1621 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0017, (cst_val *)&val_1622},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0018, (cst_val *)&val_1618},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0019, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1624 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0022, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1626 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0025, (cst_val *)&val_0125},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0026, (cst_val *)&val_1627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1629 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0029, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1631 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0032, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0033, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0034, (cst_val *)&val_0860},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0035, (cst_val *)&val_0870},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0036, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1633 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0039, (cst_val *)&val_1634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1636 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0042, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1637 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0044, (cst_val *)&val_1445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1639 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0047, (cst_val *)&val_0760},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0048, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1641 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0051, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0052, (cst_val *)&val_0821},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0053, (cst_val *)&val_1511},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0054, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1646 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0059, (cst_val *)&val_1647},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0060, (cst_val *)&val_0818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1648 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0062, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1650 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0065, (cst_val *)&val_0307},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0066, (cst_val *)&val_1424},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0067, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1652 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0070, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1654 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0073, (cst_val *)&val_1618},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0074, (cst_val *)&val_1655},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0075, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1658 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0079, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0080, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1661 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0084, (cst_val *)&val_0492},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0085, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1663 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0088, (cst_val *)&val_0077},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0089, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1664 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0091, (cst_val *)&val_1665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1667 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0094, (cst_val *)&val_0663},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0095, (cst_val *)&val_0059},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0096, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1669 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0099, (cst_val *)&val_0059},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0100, (cst_val *)&val_1670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1673 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0104, (cst_val *)&val_0246},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0105, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1674 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0107, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1675 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0109, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1677 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0112, (cst_val *)&val_0417},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0113, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1679 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_81_NO_0116, (cst_val *)&val_0332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1681 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_hh_81_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_hh_81_cart = {
  cmu_us_rms_single_mcep_hh_81_cart_nodes,
  cmu_us_rms_single_mcep_hh_81_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_hh_82_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0000, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0001, (cst_val *)&val_0128},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0002, (cst_val *)&val_0043},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0003, (cst_val *)&val_0128},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0004, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1682 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0006, (cst_val *)&val_1683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1685 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0009, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1687 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0012, (cst_val *)&val_1688},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0013, (cst_val *)&val_1689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1692 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0017, (cst_val *)&val_1693},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0018, (cst_val *)&val_1579},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0019, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1694 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0021, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1696 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0024, (cst_val *)&val_1218},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0025, (cst_val *)&val_1697},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1699 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0028, (cst_val *)&val_1700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1702 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0031, (cst_val *)&val_1703},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0032, (cst_val *)&val_1704},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0033, (cst_val *)&val_1705},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0034, (cst_val *)&val_1706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1710 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0039, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0040, (cst_val *)&val_1711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1714 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0044, (cst_val *)&val_1627},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0045, (cst_val *)&val_0008},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0046, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0047, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1715 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0049, (cst_val *)&val_1716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1718 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0052, (cst_val *)&val_0008},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0053, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1719 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0055, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1720 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0057, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0058, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1722 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0061, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1724 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0064, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0065, (cst_val *)&val_1725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1727 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0068, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1729 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0071, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0072, (cst_val *)&val_1730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1732 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0075, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1734 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0078, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0079, (cst_val *)&val_1735},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0080, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0081, (cst_val *)&val_1736},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1739 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0085, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0086, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1742 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0089, (cst_val *)&val_1743},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0090, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1745 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0093, (cst_val *)&val_1697},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1747 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0096, (cst_val *)&val_1748},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0097, (cst_val *)&val_1749},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0098, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1750 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0100, (cst_val *)&val_1751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1754 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0104, (cst_val *)&val_1755},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0105, (cst_val *)&val_1756},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0106, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1758 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0109, (cst_val *)&val_0246},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0110, (cst_val *)&val_1759},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1761 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0113, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1762 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0115, (cst_val *)&val_1763},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0116, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1766 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_82_NO_0120, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1768 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_hh_82_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_hh_82_cart = {
  cmu_us_rms_single_mcep_hh_82_cart_nodes,
  cmu_us_rms_single_mcep_hh_82_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_hh_83_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0000, (cst_val *)&val_1769},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0001, (cst_val *)&val_1770},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0002, (cst_val *)&val_1771},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0003, (cst_val *)&val_1772},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0004, (cst_val *)&val_1773},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1775 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0007, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0010, (cst_val *)&val_1778},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0011, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0012, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1782 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1784 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0020, (cst_val *)&val_0008},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0021, (cst_val *)&val_0723},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0022, (cst_val *)&val_0361},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0023, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1786 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0026, (cst_val *)&val_0239},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0027, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1787 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0029, (cst_val *)&val_1788},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0030, (cst_val *)&val_1789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1791 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0033, (cst_val *)&val_1323},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0034, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1794 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0038, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1797 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0041, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1798 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0043, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0044, (cst_val *)&val_1799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1801 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0047, (cst_val *)&val_1618},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0048, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1802 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0050, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1804 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0053, (cst_val *)&val_0831},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0054, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1807 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0058, (cst_val *)&val_1808},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0059, (cst_val *)&val_1809},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1811 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0062, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1812 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_hh_83_NO_0064, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1814 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_hh_83_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_single_mcep_hh_83_cart = {
  cmu_us_rms_single_mcep_hh_83_cart_nodes,
  cmu_us_rms_single_mcep_hh_83_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ae_6_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0001, (cst_val *)&val_0097},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0002, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0003, (cst_val *)&val_0074},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0004, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0005, (cst_val *)&val_1815},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0006, (cst_val *)&val_1816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1817 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0008, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0009, (cst_val *)&val_1818},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0010, (cst_val *)&val_1819},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0011, (cst_val *)&val_1820},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0012, (cst_val *)&val_1647},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0013, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1822 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0015, (cst_val *)&val_1823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1830 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0023, (cst_val *)&val_0311},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0024, (cst_val *)&val_0219},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0025, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1832 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0028, (cst_val *)&val_1833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1834 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0030, (cst_val *)&val_1835},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0031, (cst_val *)&val_1014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1838 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0035, (cst_val *)&val_1839},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1841 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0038, (cst_val *)&val_1842},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0039, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1844 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0042, (cst_val *)&val_1845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1847 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0045, (cst_val *)&val_0417},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0046, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0047, (cst_val *)&val_1848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1852 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0052, (cst_val *)&val_1853},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0053, (cst_val *)&val_0955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1854 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0055, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1855 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0057, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1856 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0059, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0060, (cst_val *)&val_0417},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0061, (cst_val *)&val_1857},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0062, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1860 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0066, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1861 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0068, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1863 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0071, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1867 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0075, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0076, (cst_val *)&val_1868},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0077, (cst_val *)&val_1869},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0078, (cst_val *)&val_1870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1872 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0081, (cst_val *)&val_0120},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0082, (cst_val *)&val_1873},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0083, (cst_val *)&val_1874},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0084, (cst_val *)&val_1875},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1877 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0087, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1878 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0089, (cst_val *)&val_1879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1881 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0092, (cst_val *)&val_1882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1884 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0095, (cst_val *)&val_1885},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0096, (cst_val *)&val_1886},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1888 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0099, (cst_val *)&val_1289},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0100, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1891 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0104, (cst_val *)&val_1892},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0105, (cst_val *)&val_1647},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0106, (cst_val *)&val_1893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1895 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0109, (cst_val *)&val_1896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1898 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0112, (cst_val *)&val_0059},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0113, (cst_val *)&val_1899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1902 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0117, (cst_val *)&val_0626},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0118, (cst_val *)&val_1870},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0119, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0120, (cst_val *)&val_0760},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0121, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1907 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0126, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0127, (cst_val *)&val_1908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1912 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0132, (cst_val *)&val_0009},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0133, (cst_val *)&val_0068},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0134, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1913 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0136, (cst_val *)&val_0562},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0137, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1914 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0139, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1916 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0142, (cst_val *)&val_1917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1918 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0144, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1920 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0147, (cst_val *)&val_1921},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0148, (cst_val *)&val_1922},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0149, (cst_val *)&val_0056},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0150, (cst_val *)&val_1923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1925 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0153, (cst_val *)&val_1926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1929 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0157, (cst_val *)&val_0077},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0158, (cst_val *)&val_0629},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0159, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1930 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0161, (cst_val *)&val_1931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1934 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0165, (cst_val *)&val_0505},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0166, (cst_val *)&val_1935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1937 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0169, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0170, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1939 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0173, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1941 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0176, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0177, (cst_val *)&val_1602},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0178, (cst_val *)&val_0088},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0179, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1943 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0182, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1945 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0185, (cst_val *)&val_1946},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0186, (cst_val *)&val_1921},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0187, (cst_val *)&val_1947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1949 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0190, (cst_val *)&val_1950},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0191, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1953 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0194, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1956 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0198, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0199, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1957 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0201, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1959 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0204, (cst_val *)&val_0562},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0205, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1961 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0208, (cst_val *)&val_1778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1962 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_6_NO_0210, (cst_val *)&val_1225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1964 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ae_6_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_single_mcep_ae_6_cart = {
  cmu_us_rms_single_mcep_ae_6_cart_nodes,
  cmu_us_rms_single_mcep_ae_6_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ae_7_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0000, (cst_val *)&val_0183},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0001, (cst_val *)&val_0868},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0002, (cst_val *)&val_0026},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0003, (cst_val *)&val_0056},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0004, (cst_val *)&val_1965},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0005, (cst_val *)&val_1966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1967 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0007, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1970 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0011, (cst_val *)&val_1579},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0012, (cst_val *)&val_1971},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0013, (cst_val *)&val_1972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1974 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0016, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1975 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0018, (cst_val *)&val_0035},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0019, (cst_val *)&val_1976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1979 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0023, (cst_val *)&val_1980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0026, (cst_val *)&val_1163},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0027, (cst_val *)&val_0799},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0028, (cst_val *)&val_1386},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0029, (cst_val *)&val_0118},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0030, (cst_val *)&val_1983},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1987 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0035, (cst_val *)&val_0165},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0036, (cst_val *)&val_1988},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1991 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0040, (cst_val *)&val_1992},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0041, (cst_val *)&val_1594},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0042, (cst_val *)&val_0824},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0043, (cst_val *)&val_1993},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0044, (cst_val *)&val_1994},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0045, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1997 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0049, (cst_val *)&val_1998},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0052, (cst_val *)&val_2001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0053, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2002 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0055, (cst_val *)&val_2003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0056, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2008 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0061, (cst_val *)&val_2009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0062, (cst_val *)&val_2010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2013 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0066, (cst_val *)&val_2014},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0067, (cst_val *)&val_2015},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0068, (cst_val *)&val_2016},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0069, (cst_val *)&val_2017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2020 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0073, (cst_val *)&val_2021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2022 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0075, (cst_val *)&val_0870},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0076, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2024 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0079, (cst_val *)&val_0758},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0080, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2027 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0084, (cst_val *)&val_2004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0085, (cst_val *)&val_2028},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0086, (cst_val *)&val_2029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2031 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0089, (cst_val *)&val_2032},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0090, (cst_val *)&val_2033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2036 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0094, (cst_val *)&val_2037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0096, (cst_val *)&val_1310},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0097, (cst_val *)&val_2039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2041 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0100, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2043 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0103, (cst_val *)&val_2044},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0104, (cst_val *)&val_2045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0105, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2046 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0107, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2047 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0109, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2048 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0111, (cst_val *)&val_2049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2051 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0114, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2052 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0116, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2054 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0119, (cst_val *)&val_0125},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0120, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2055 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0122, (cst_val *)&val_2056},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0123, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2057 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0125, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2059 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0128, (cst_val *)&val_1992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2061 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0131, (cst_val *)&val_0165},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0132, (cst_val *)&val_0145},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0133, (cst_val *)&val_2062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2063 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0135, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2066 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0138, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2068 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0140, (cst_val *)&val_2069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2070 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0142, (cst_val *)&val_0043},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0143, (cst_val *)&val_2071},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0144, (cst_val *)&val_2072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2073 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0146, (cst_val *)&val_0251},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0147, (cst_val *)&val_2074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2076 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0150, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2078 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0153, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2079 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0155, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2082 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0159, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2084 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0161, (cst_val *)&val_0025},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0162, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0163, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2085 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0165, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2087 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0168, (cst_val *)&val_2088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0169, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2091 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0173, (cst_val *)&val_2092},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0174, (cst_val *)&val_2093},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0175, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2096 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0179, (cst_val *)&val_2097},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0180, (cst_val *)&val_0979},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0181, (cst_val *)&val_2098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2100 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0184, (cst_val *)&val_1238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2102 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0187, (cst_val *)&val_0145},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0188, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2105 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0191, (cst_val *)&val_2106},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0192, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2107 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0194, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2110 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0198, (cst_val *)&val_2111},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0199, (cst_val *)&val_0978},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0200, (cst_val *)&val_2069},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0201, (cst_val *)&val_2112},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0202, (cst_val *)&val_2113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2114 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0204, (cst_val *)&val_2115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2118 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0208, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2119 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0210, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2120 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0212, (cst_val *)&val_0068},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0213, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2121 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0215, (cst_val *)&val_2122},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0216, (cst_val *)&val_0074},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0217, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2125 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0221, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2127 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0224, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2129 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0227, (cst_val *)&val_2130},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0228, (cst_val *)&val_0012},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0229, (cst_val *)&val_0328},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0230, (cst_val *)&val_2131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2133 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0233, (cst_val *)&val_2134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2135 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0235, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2136 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0237, (cst_val *)&val_1158},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0238, (cst_val *)&val_2137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2138 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0240, (cst_val *)&val_0899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2140 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0243, (cst_val *)&val_0068},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0244, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2143 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0248, (cst_val *)&val_2144},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0249, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2145 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0251, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2146 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0253, (cst_val *)&val_2147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2148 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0255, (cst_val *)&val_2149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2151 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0258, (cst_val *)&val_2152},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0259, (cst_val *)&val_1885},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0260, (cst_val *)&val_2153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2156 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0264, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2158 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0267, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0268, (cst_val *)&val_2159},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0269, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2160 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0271, (cst_val *)&val_2161},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0272, (cst_val *)&val_2162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2163 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0274, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2165 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0276, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2166 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0278, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2168 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0281, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2169 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0283, (cst_val *)&val_0015},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0284, (cst_val *)&val_2170},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0285, (cst_val *)&val_2171},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0286, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2177 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0293, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2178 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0295, (cst_val *)&val_2179},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0296, (cst_val *)&val_2180},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0297, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2181 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0299, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2183 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0302, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2187 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0306, (cst_val *)&val_1579},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0307, (cst_val *)&val_0068},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0308, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2188 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0310, (cst_val *)&val_2189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2192 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_7_NO_0314, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2194 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ae_7_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_ae_7_cart = {
  cmu_us_rms_single_mcep_ae_7_cart_nodes,
  cmu_us_rms_single_mcep_ae_7_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ae_8_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0000, (cst_val *)&val_2195},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0003, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0004, (cst_val *)&val_2196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2199 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0008, (cst_val *)&val_2200},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0009, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2201 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0011, (cst_val *)&val_2202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2203 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0013, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2205 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0016, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2207 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0019, (cst_val *)&val_2208},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0020, (cst_val *)&val_1610},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0021, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2210 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0024, (cst_val *)&val_2211},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0025, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2212 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0027, (cst_val *)&val_2213},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0028, (cst_val *)&val_2214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2217 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0032, (cst_val *)&val_0489},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0033, (cst_val *)&val_0027},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0034, (cst_val *)&val_2218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2220 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0037, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0038, (cst_val *)&val_2221},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0039, (cst_val *)&val_2222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2225 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0043, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2227 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0046, (cst_val *)&val_0631},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0047, (cst_val *)&val_2228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2231 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0051, (cst_val *)&val_2232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0052, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0053, (cst_val *)&val_2233},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0054, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2234 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0056, (cst_val *)&val_2235},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0057, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2236 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0059, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2238 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0061, (cst_val *)&val_2239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2240 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0063, (cst_val *)&val_2241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2243 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0066, (cst_val *)&val_2244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2245 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0068, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2246 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0070, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2247 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0072, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0073, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2249 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0076, (cst_val *)&val_2250},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0077, (cst_val *)&val_2239},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0078, (cst_val *)&val_0059},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0079, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2251 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0081, (cst_val *)&val_2252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2253 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0083, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2255 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0086, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2256 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0088, (cst_val *)&val_2257},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2259 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0091, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2260 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0093, (cst_val *)&val_2261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2264 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0097, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2265 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0099, (cst_val *)&val_2266},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2268 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0102, (cst_val *)&val_2069},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0103, (cst_val *)&val_2269},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0104, (cst_val *)&val_2270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2271 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0106, (cst_val *)&val_2272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2274 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0109, (cst_val *)&val_2275},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2277 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0112, (cst_val *)&val_0125},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0113, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0114, (cst_val *)&val_2278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2280 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0117, (cst_val *)&val_2281},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0118, (cst_val *)&val_2282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2283 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0120, (cst_val *)&val_0077},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0121, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2285 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0124, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0125, (cst_val *)&val_2028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2287 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0128, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2289 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0131, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2291 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0134, (cst_val *)&val_2122},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0135, (cst_val *)&val_0328},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0136, (cst_val *)&val_2292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2294 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0139, (cst_val *)&val_2295},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0140, (cst_val *)&val_2296},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0141, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2298 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0144, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2300 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0147, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2302 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0149, (cst_val *)&val_0477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2304 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0152, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0153, (cst_val *)&val_2305},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0154, (cst_val *)&val_2306},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0155, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2307 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0157, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2308 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0159, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2309 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0161, (cst_val *)&val_2310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2311 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0163, (cst_val *)&val_2312},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0164, (cst_val *)&val_2313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2314 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0166, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2315 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0168, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2320 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0174, (cst_val *)&val_2321},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0175, (cst_val *)&val_2322},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0176, (cst_val *)&val_2323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2326 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0180, (cst_val *)&val_0068},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0181, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2329 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0185, (cst_val *)&val_0011},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0186, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2331 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0189, (cst_val *)&val_2332},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0190, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2333 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0192, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2334 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0194, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0195, (cst_val *)&val_2122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2335 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0197, (cst_val *)&val_0025},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0198, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2338 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0202, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0203, (cst_val *)&val_2339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2341 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0206, (cst_val *)&val_2342},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2344 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0209, (cst_val *)&val_2345},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0210, (cst_val *)&val_2346},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0211, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0212, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2347 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0214, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2349 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0217, (cst_val *)&val_2350},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0218, (cst_val *)&val_2351},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2354 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0222, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2356 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0225, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2357 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0227, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2358 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0229, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0230, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2359 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0232, (cst_val *)&val_2360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2362 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0235, (cst_val *)&val_2363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2364 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0237, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2366 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0240, (cst_val *)&val_0183},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0241, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0242, (cst_val *)&val_2367},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0243, (cst_val *)&val_0120},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0244, (cst_val *)&val_0745},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0245, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2369 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0248, (cst_val *)&val_2370},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0249, (cst_val *)&val_2371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2372 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0251, (cst_val *)&val_2373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2375 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0254, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2377 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0257, (cst_val *)&val_0088},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0258, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2378 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0260, (cst_val *)&val_2379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2381 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0263, (cst_val *)&val_2382},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2383 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0265, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2385 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0268, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2387 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0271, (cst_val *)&val_0004},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0272, (cst_val *)&val_2388},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0273, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2389 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0275, (cst_val *)&val_1323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2392 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0279, (cst_val *)&val_2393},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0280, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2394 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0282, (cst_val *)&val_1198},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0283, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2398 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0287, (cst_val *)&val_1604},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0288, (cst_val *)&val_2221},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0289, (cst_val *)&val_2184},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0290, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2400 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0293, (cst_val *)&val_2401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2404 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0297, (cst_val *)&val_2405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2407 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0300, (cst_val *)&val_0220},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0301, (cst_val *)&val_0733},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0302, (cst_val *)&val_2408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2410 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0305, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0306, (cst_val *)&val_0714},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0307, (cst_val *)&val_2411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2413 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0310, (cst_val *)&val_0145},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0311, (cst_val *)&val_0739},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0312, (cst_val *)&val_2414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2416 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0315, (cst_val *)&val_2417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2419 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0318, (cst_val *)&val_0739},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0319, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2422 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0323, (cst_val *)&val_0705},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0324, (cst_val *)&val_2423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2425 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0327, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0328, (cst_val *)&val_2426},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0329, (cst_val *)&val_2427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2428 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0331, (cst_val *)&val_2429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2432 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0335, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2434 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0337, (cst_val *)&val_0145},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0338, (cst_val *)&val_2435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2436 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0340, (cst_val *)&val_2122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2438 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0343, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2439 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0345, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2441 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0348, (cst_val *)&val_0361},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0349, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2444 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0352, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2445 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0354, (cst_val *)&val_0219},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0355, (cst_val *)&val_0077},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0356, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2446 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0358, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2447 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0360, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2449 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0363, (cst_val *)&val_0112},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0364, (cst_val *)&val_2450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2452 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0367, (cst_val *)&val_1386},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0368, (cst_val *)&val_0025},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0369, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2455 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0373, (cst_val *)&val_0008},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0374, (cst_val *)&val_2456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2459 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0378, (cst_val *)&val_0045},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0379, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2461 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0382, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2462 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0384, (cst_val *)&val_2463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2464 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0386, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2465 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ae_8_NO_0388, (cst_val *)&val_2466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2468 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ae_8_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ae_8_cart = {
  cmu_us_rms_single_mcep_ae_8_cart_nodes,
  cmu_us_rms_single_mcep_ae_8_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_y_194_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0001, (cst_val *)&val_0417},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0002, (cst_val *)&val_0132},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0003, (cst_val *)&val_1608},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0004, (cst_val *)&val_0073},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0005, (cst_val *)&val_2469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2473 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0010, (cst_val *)&val_2474},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0011, (cst_val *)&val_2469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2476 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0014, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2478 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0017, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2480 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0020, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0021, (cst_val *)&val_2481},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0022, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2484 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0026, (cst_val *)&val_0219},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0027, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2485 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0029, (cst_val *)&val_0043},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0030, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2486 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0032, (cst_val *)&val_2487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2489 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0035, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2490 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0037, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2491 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0039, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2493 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0042, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2494 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0044, (cst_val *)&val_0112},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0045, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2496 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0048, (cst_val *)&val_2497},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0049, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2499 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_194_NO_0051, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2502 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_y_194_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_single_mcep_y_194_cart = {
  cmu_us_rms_single_mcep_y_194_cart_nodes,
  cmu_us_rms_single_mcep_y_194_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_y_195_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0000, (cst_val *)&val_2503},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0001, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2504 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0003, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2505 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0005, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2506 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0007, (cst_val *)&val_2507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2509 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0010, (cst_val *)&val_2345},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0011, (cst_val *)&val_2510},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0012, (cst_val *)&val_2511},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0013, (cst_val *)&val_0979},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0014, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2513 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0017, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2515 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0020, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2517 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0023, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0024, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2518 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0026, (cst_val *)&val_2519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2521 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0029, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2522 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0031, (cst_val *)&val_0328},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0032, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2524 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0035, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2525 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0037, (cst_val *)&val_0417},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0038, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2527 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0041, (cst_val *)&val_2528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2529 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0043, (cst_val *)&val_2530},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0044, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2531 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0046, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2534 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0050, (cst_val *)&val_0165},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0051, (cst_val *)&val_2535},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_195_NO_0052, (cst_val *)&val_2536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2540 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_y_195_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_y_195_cart = {
  cmu_us_rms_single_mcep_y_195_cart_nodes,
  cmu_us_rms_single_mcep_y_195_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_y_196_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0001, (cst_val *)&val_0979},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0002, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2542 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0005, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2544 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0008, (cst_val *)&val_1602},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0009, (cst_val *)&val_0246},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0010, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2545 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0012, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2547 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0015, (cst_val *)&val_0145},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0016, (cst_val *)&val_0088},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0017, (cst_val *)&val_2548},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0018, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0019, (cst_val *)&val_2549},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0020, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2551 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0023, (cst_val *)&val_2552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2555 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0027, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2556 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0029, (cst_val *)&val_2557},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2559 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0032, (cst_val *)&val_0278},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0033, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2562 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0037, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2563 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0039, (cst_val *)&val_2564},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0040, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2567 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0044, (cst_val *)&val_2568},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0045, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0046, (cst_val *)&val_0010},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0047, (cst_val *)&val_2569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2572 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0051, (cst_val *)&val_2573},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0052, (cst_val *)&val_0125},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0053, (cst_val *)&val_2574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2577 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0057, (cst_val *)&val_0025},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0058, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2579 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0061, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2580 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0063, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2581 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0065, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2583 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0068, (cst_val *)&val_2584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2585 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0070, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2586 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0072, (cst_val *)&val_0023},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0073, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2587 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0075, (cst_val *)&val_2588},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0076, (cst_val *)&val_1205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2591 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_y_196_NO_0080, (cst_val *)&val_2592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2594 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_y_196_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_y_196_cart = {
  cmu_us_rms_single_mcep_y_196_cart_nodes,
  cmu_us_rms_single_mcep_y_196_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_k_101_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0000, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0001, (cst_val *)&val_0009},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0002, (cst_val *)&val_0077},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0003, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2596 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0006, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2597 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0008, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2598 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0010, (cst_val *)&val_0019},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0011, (cst_val *)&val_0008},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0012, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2601 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0016, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0017, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2603 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0020, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0021, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2604 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0023, (cst_val *)&val_0043},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0024, (cst_val *)&val_2605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2608 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2610 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0031, (cst_val *)&val_0631},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0032, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0033, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2611 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0035, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2612 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0037, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2614 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0040, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2616 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0043, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2618 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0045, (cst_val *)&val_0088},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0046, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2620 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0049, (cst_val *)&val_2621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2622 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0051, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2624 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0054, (cst_val *)&val_2625},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0055, (cst_val *)&val_0145},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0056, (cst_val *)&val_1249},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0057, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2627 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0059, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2629 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0062, (cst_val *)&val_0059},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0063, (cst_val *)&val_0011},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0064, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2630 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0066, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2631 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0068, (cst_val *)&val_2632},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2634 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0071, (cst_val *)&val_0246},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0072, (cst_val *)&val_2635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2636 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0074, (cst_val *)&val_2637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2639 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0077, (cst_val *)&val_2640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2641 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0079, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2643 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0082, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2644 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0084, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2647 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0087, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2648 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0089, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2650 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0091, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2652 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0094, (cst_val *)&val_0088},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0095, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2654 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_101_NO_0098, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2656 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_k_101_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_rms_single_mcep_k_101_cart = {
  cmu_us_rms_single_mcep_k_101_cart_nodes,
  cmu_us_rms_single_mcep_k_101_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_k_102_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0000, (cst_val *)&val_0145},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0002, (cst_val *)&val_0417},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0003, (cst_val *)&val_0040},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0004, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2657 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0006, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2660 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0010, (cst_val *)&val_2661},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0011, (cst_val *)&val_2662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2664 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0014, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2665 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2666 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0018, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2668 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0021, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0022, (cst_val *)&val_2669},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0023, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2673 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0027, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0028, (cst_val *)&val_0132},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0029, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2674 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0031, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2675 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0033, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2677 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0036, (cst_val *)&val_0040},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0037, (cst_val *)&val_2678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2680 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0040, (cst_val *)&val_2681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2682 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0042, (cst_val *)&val_2683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2685 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0045, (cst_val *)&val_0025},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0046, (cst_val *)&val_0027},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0047, (cst_val *)&val_0125},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0048, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2687 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0051, (cst_val *)&val_0059},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0052, (cst_val *)&val_2688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2692 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0057, (cst_val *)&val_0025},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0058, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2693 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0060, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2694 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0062, (cst_val *)&val_2695},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2697 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0065, (cst_val *)&val_0745},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0066, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2698 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0068, (cst_val *)&val_2699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2701 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0071, (cst_val *)&val_2702},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0072, (cst_val *)&val_2703},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2705 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0075, (cst_val *)&val_0008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0076, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2707 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0079, (cst_val *)&val_0029},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0080, (cst_val *)&val_0132},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0081, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2709 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0084, (cst_val *)&val_0059},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0085, (cst_val *)&val_2710},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2714 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0090, (cst_val *)&val_1386},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0091, (cst_val *)&val_0171},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0092, (cst_val *)&val_2715},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0093, (cst_val *)&val_2716},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0094, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2717 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0096, (cst_val *)&val_0925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2719 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0099, (cst_val *)&val_2720},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0100, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2722 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0103, (cst_val *)&val_2723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2725 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0106, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2726 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0108, (cst_val *)&val_0040},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0109, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2727 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0111, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2728 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0113, (cst_val *)&val_2729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2732 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0117, (cst_val *)&val_0239},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0118, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2735 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0122, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2736 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0124, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0125, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2738 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0128, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2739 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0130, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2740 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_102_NO_0132, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2742 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_k_102_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_k_102_cart = {
  cmu_us_rms_single_mcep_k_102_cart_nodes,
  cmu_us_rms_single_mcep_k_102_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_k_103_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0000, (cst_val *)&val_0120},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0001, (cst_val *)&val_0056},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0002, (cst_val *)&val_2743},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0003, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0004, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2745 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0006, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2747 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0009, (cst_val *)&val_1522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2748 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0011, (cst_val *)&val_0008},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0012, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2750 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0015, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2751 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0017, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0018, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2752 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0020, (cst_val *)&val_2753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2757 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0025, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0026, (cst_val *)&val_0128},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0027, (cst_val *)&val_0043},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0028, (cst_val *)&val_0841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2759 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0031, (cst_val *)&val_2760},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0032, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0033, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2763 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0037, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2765 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0040, (cst_val *)&val_1756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2766 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0042, (cst_val *)&val_2767},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0043, (cst_val *)&val_0297},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0044, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2768 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0046, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2770 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0049, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2771 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0051, (cst_val *)&val_0059},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0052, (cst_val *)&val_2772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2775 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0056, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0057, (cst_val *)&val_2776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2778 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0060, (cst_val *)&val_2779},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0061, (cst_val *)&val_2780},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0062, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2782 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0065, (cst_val *)&val_2783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2785 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0068, (cst_val *)&val_2786},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2788 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0071, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0072, (cst_val *)&val_0010},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0073, (cst_val *)&val_0043},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0074, (cst_val *)&val_1527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2789 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0076, (cst_val *)&val_2790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2792 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0079, (cst_val *)&val_1527},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0080, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2794 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0083, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2795 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0085, (cst_val *)&val_2796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2798 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0088, (cst_val *)&val_1527},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0089, (cst_val *)&val_0745},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0090, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2801 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0094, (cst_val *)&val_2802},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2803 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0096, (cst_val *)&val_2804},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0097, (cst_val *)&val_2805},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0098, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2807 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0101, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2808 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0103, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2810 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0106, (cst_val *)&val_2805},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0107, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2813 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0110, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2814 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0112, (cst_val *)&val_2815},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0113, (cst_val *)&val_2816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2818 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0116, (cst_val *)&val_2819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2821 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0119, (cst_val *)&val_0251},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0120, (cst_val *)&val_0132},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0121, (cst_val *)&val_0982},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0122, (cst_val *)&val_2822},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0123, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2825 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0127, (cst_val *)&val_0059},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0128, (cst_val *)&val_0025},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0129, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2827 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0132, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2828 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0134, (cst_val *)&val_0009},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0135, (cst_val *)&val_2829},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0136, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2834 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0142, (cst_val *)&val_0029},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0143, (cst_val *)&val_0693},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0144, (cst_val *)&val_0008},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0145, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2836 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0148, (cst_val *)&val_0785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2838 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0151, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2839 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0153, (cst_val *)&val_2840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2842 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0156, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2844 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0159, (cst_val *)&val_0733},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0160, (cst_val *)&val_2845},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0161, (cst_val *)&val_2744},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0162, (cst_val *)&val_2846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2849 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0166, (cst_val *)&val_2850},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0167, (cst_val *)&val_0785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2852 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0170, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2854 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0173, (cst_val *)&val_2855},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0174, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0175, (cst_val *)&val_0220},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0176, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2857 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0179, (cst_val *)&val_2858},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2860 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0182, (cst_val *)&val_0008},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0183, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2862 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0186, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2863 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0188, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2865 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0191, (cst_val *)&val_2214},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0192, (cst_val *)&val_2858},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2866 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0194, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2867 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0196, (cst_val *)&val_1035},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0197, (cst_val *)&val_1025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0198, (cst_val *)&val_2868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2871 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0202, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2873 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0205, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2875 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0208, (cst_val *)&val_0008},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0209, (cst_val *)&val_2876},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0210, (cst_val *)&val_2877},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0211, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2879 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0214, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2880 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0216, (cst_val *)&val_2881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2883 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0219, (cst_val *)&val_2877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2884 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0221, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2886 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0224, (cst_val *)&val_0059},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0225, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0226, (cst_val *)&val_2887},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0227, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2889 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0230, (cst_val *)&val_2890},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2892 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0233, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2895 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0236, (cst_val *)&val_0059},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0237, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0238, (cst_val *)&val_0145},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0239, (cst_val *)&val_2896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2899 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0243, (cst_val *)&val_2796},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0244, (cst_val *)&val_2900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2902 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0247, (cst_val *)&val_1207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2904 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0250, (cst_val *)&val_0043},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0251, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2905 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0253, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0254, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2907 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0257, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2909 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0260, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2910 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_k_103_NO_0262, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2912 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_k_103_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_k_103_cart = {
  cmu_us_rms_single_mcep_k_103_cart_nodes,
  cmu_us_rms_single_mcep_k_103_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aa_1_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0000, (cst_val *)&val_1565},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0001, (cst_val *)&val_0860},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0002, (cst_val *)&val_1363},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0003, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2913 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0005, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2915 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0008, (cst_val *)&val_0019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0009, (cst_val *)&val_2916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2918 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0012, (cst_val *)&val_2919},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0013, (cst_val *)&val_2149},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0014, (cst_val *)&val_2920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2923 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0018, (cst_val *)&val_1472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2925 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0021, (cst_val *)&val_2926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2927 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0023, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2929 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0026, (cst_val *)&val_2930},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0027, (cst_val *)&val_0492},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0028, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2931 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0030, (cst_val *)&val_2932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2933 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0032, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2935 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0035, (cst_val *)&val_0417},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0036, (cst_val *)&val_0760},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0037, (cst_val *)&val_2936},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0038, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2938 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0041, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2941 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0045, (cst_val *)&val_0403},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0046, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2943 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0049, (cst_val *)&val_0307},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0050, (cst_val *)&val_2944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2946 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0053, (cst_val *)&val_2947},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0054, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0055, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0056, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2949 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0059, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2951 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0062, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2952 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0064, (cst_val *)&val_0077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0065, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2955 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0069, (cst_val *)&val_1917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2956 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0071, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2957 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0073, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2958 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0075, (cst_val *)&val_2959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2960 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0077, (cst_val *)&val_2961},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2963 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0080, (cst_val *)&val_0183},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0081, (cst_val *)&val_2149},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0082, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0083, (cst_val *)&val_2964},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0084, (cst_val *)&val_2965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2968 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0088, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2970 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0091, (cst_val *)&val_2971},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0092, (cst_val *)&val_0640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2972 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0094, (cst_val *)&val_2973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2975 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0097, (cst_val *)&val_0422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2977 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0100, (cst_val *)&val_2978},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0101, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2979 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0103, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0104, (cst_val *)&val_0251},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0105, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2981 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0108, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2983 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0111, (cst_val *)&val_2984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2985 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0113, (cst_val *)&val_2986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2988 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0116, (cst_val *)&val_2989},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0117, (cst_val *)&val_2990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2991 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0119, (cst_val *)&val_2992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2994 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_1_NO_0122, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2996 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aa_1_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_aa_1_cart = {
  cmu_us_rms_single_mcep_aa_1_cart_nodes,
  cmu_us_rms_single_mcep_aa_1_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aa_2_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0000, (cst_val *)&val_2997},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0001, (cst_val *)&val_0860},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0002, (cst_val *)&val_0219},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0003, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2999 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0006, (cst_val *)&val_3000},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0007, (cst_val *)&val_1158},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0008, (cst_val *)&val_1249},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0009, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3003 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0013, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3006 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0017, (cst_val *)&val_0183},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0018, (cst_val *)&val_3007},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0019, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3008 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0021, (cst_val *)&val_0481},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3009 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0023, (cst_val *)&val_3010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3012 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0026, (cst_val *)&val_3013},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0027, (cst_val *)&val_3014},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0028, (cst_val *)&val_1036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3017 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0032, (cst_val *)&val_3018},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0033, (cst_val *)&val_0008},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0034, (cst_val *)&val_3019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3020 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0036, (cst_val *)&val_0165},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0037, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3022 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0040, (cst_val *)&val_3023},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0041, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3024 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0043, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3027 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0047, (cst_val *)&val_0408},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0048, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3029 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0051, (cst_val *)&val_2244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3030 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0053, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3033 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0057, (cst_val *)&val_3034},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0058, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0059, (cst_val *)&val_0039},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0060, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3035 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0062, (cst_val *)&val_0631},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0063, (cst_val *)&val_3036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3037 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0065, (cst_val *)&val_1093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3038 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0067, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3040 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0070, (cst_val *)&val_0758},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0071, (cst_val *)&val_3041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3043 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0074, (cst_val *)&val_3044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3046 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0077, (cst_val *)&val_3047},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0078, (cst_val *)&val_0251},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0079, (cst_val *)&val_0165},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0080, (cst_val *)&val_3048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3049 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0082, (cst_val *)&val_1994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3050 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0084, (cst_val *)&val_0165},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0085, (cst_val *)&val_3051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3056 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0091, (cst_val *)&val_0051},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0092, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3059 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0096, (cst_val *)&val_3060},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0097, (cst_val *)&val_3061},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0098, (cst_val *)&val_0165},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0099, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3063 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0102, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3065 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0105, (cst_val *)&val_3066},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0106, (cst_val *)&val_3067},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0107, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3068 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0109, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0110, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3070 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0113, (cst_val *)&val_2237},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0114, (cst_val *)&val_3071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3074 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0118, (cst_val *)&val_3075},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0119, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3076 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0121, (cst_val *)&val_3077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3079 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0124, (cst_val *)&val_1994},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0125, (cst_val *)&val_3080},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0126, (cst_val *)&val_3081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3084 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0130, (cst_val *)&val_0841},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0131, (cst_val *)&val_3085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3088 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0135, (cst_val *)&val_3089},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0136, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3090 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0138, (cst_val *)&val_3091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3092 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0140, (cst_val *)&val_0440},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0141, (cst_val *)&val_1510},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0142, (cst_val *)&val_3093},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0143, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3095 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0146, (cst_val *)&val_0251},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0147, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3100 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0153, (cst_val *)&val_0870},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0154, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3103 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0158, (cst_val *)&val_3104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3105 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0160, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3106 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0162, (cst_val *)&val_3107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3108 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0164, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3110 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0167, (cst_val *)&val_0403},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0168, (cst_val *)&val_3111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3113 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0171, (cst_val *)&val_0297},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0172, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3115 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0175, (cst_val *)&val_0088},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0176, (cst_val *)&val_3116},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0177, (cst_val *)&val_3117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3118 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0179, (cst_val *)&val_3119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3121 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0182, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3123 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0185, (cst_val *)&val_3124},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0186, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3125 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0188, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3126 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0190, (cst_val *)&val_3127},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0191, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3131 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0196, (cst_val *)&val_0183},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0197, (cst_val *)&val_0219},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0198, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3132 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0200, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3133 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0202, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3135 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0205, (cst_val *)&val_1036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3137 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0208, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3138 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0210, (cst_val *)&val_0651},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0211, (cst_val *)&val_3139},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0212, (cst_val *)&val_3140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3142 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0215, (cst_val *)&val_0007},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0216, (cst_val *)&val_1205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3145 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0220, (cst_val *)&val_3146},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0221, (cst_val *)&val_0632},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3148 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0224, (cst_val *)&val_0025},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0225, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3150 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_2_NO_0228, (cst_val *)&val_3151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3153 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aa_2_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_aa_2_cart = {
  cmu_us_rms_single_mcep_aa_2_cart_nodes,
  cmu_us_rms_single_mcep_aa_2_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_aa_3_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0000, (cst_val *)&val_0714},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0001, (cst_val *)&val_1579},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0002, (cst_val *)&val_0043},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0003, (cst_val *)&val_3154},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0004, (cst_val *)&val_0957},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0005, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3156 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0008, (cst_val *)&val_3157},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3159 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0011, (cst_val *)&val_1683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3161 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0014, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0015, (cst_val *)&val_3162},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0016, (cst_val *)&val_3163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3166 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0020, (cst_val *)&val_3167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3169 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0023, (cst_val *)&val_1065},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0024, (cst_val *)&val_2626},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0025, (cst_val *)&val_2729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3171 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0028, (cst_val *)&val_3172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3174 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0031, (cst_val *)&val_3175},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0032, (cst_val *)&val_3176},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0033, (cst_val *)&val_3177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3180 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0037, (cst_val *)&val_3181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3183 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0040, (cst_val *)&val_0045},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0041, (cst_val *)&val_1035},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0042, (cst_val *)&val_0841},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0043, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3184 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0045, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3185 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0047, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3187 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0050, (cst_val *)&val_3188},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0051, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3190 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0054, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3191 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0056, (cst_val *)&val_3192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3194 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0059, (cst_val *)&val_0733},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0060, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3195 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0062, (cst_val *)&val_3196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3198 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0065, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0066, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3199 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0068, (cst_val *)&val_0239},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0069, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3201 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0072, (cst_val *)&val_3202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3204 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0075, (cst_val *)&val_3205},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0076, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3207 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0079, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3209 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0082, (cst_val *)&val_3210},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0083, (cst_val *)&val_3211},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0084, (cst_val *)&val_1363},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0085, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3212 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0087, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3216 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0092, (cst_val *)&val_0025},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0093, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3217 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0095, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3219 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0098, (cst_val *)&val_3220},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_aa_3_NO_0099, (cst_val *)&val_0955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3223 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_aa_3_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_aa_3_cart = {
  cmu_us_rms_single_mcep_aa_3_cart_nodes,
  cmu_us_rms_single_mcep_aa_3_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ay_31_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0001, (cst_val *)&val_0016},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0002, (cst_val *)&val_3224},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0003, (cst_val *)&val_0774},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0004, (cst_val *)&val_0043},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0005, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3226 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0008, (cst_val *)&val_3227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3229 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0011, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3231 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0014, (cst_val *)&val_0417},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0015, (cst_val *)&val_3232},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0016, (cst_val *)&val_3233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3234 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0018, (cst_val *)&val_3235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3237 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0021, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3238 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0023, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3241 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0027, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3243 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0031, (cst_val *)&val_0760},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0032, (cst_val *)&val_2617},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0033, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3245 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0036, (cst_val *)&val_0077},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0037, (cst_val *)&val_3246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3247 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0039, (cst_val *)&val_3248},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3251 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0043, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3253 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0046, (cst_val *)&val_0569},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0047, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0048, (cst_val *)&val_3254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3255 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0050, (cst_val *)&val_3256},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0051, (cst_val *)&val_0913},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0052, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3258 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0055, (cst_val *)&val_0251},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0056, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3262 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0061, (cst_val *)&val_0403},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0062, (cst_val *)&val_0503},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0063, (cst_val *)&val_2649},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0064, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3265 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0068, (cst_val *)&val_3266},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3267 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0070, (cst_val *)&val_0332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3269 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0073, (cst_val *)&val_0505},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0074, (cst_val *)&val_0913},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0075, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0076, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3271 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0079, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3273 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0082, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3275 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0085, (cst_val *)&val_0043},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0086, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3276 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0088, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3277 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0090, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3278 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0092, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3280 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0095, (cst_val *)&val_0045},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0096, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3282 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0099, (cst_val *)&val_3283},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0100, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3285 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0103, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3287 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0106, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0107, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0108, (cst_val *)&val_3288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3290 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0111, (cst_val *)&val_0045},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0112, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3291 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0114, (cst_val *)&val_3292},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0115, (cst_val *)&val_0640},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0116, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3294 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0119, (cst_val *)&val_3295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3298 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0123, (cst_val *)&val_0068},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0124, (cst_val *)&val_2414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3300 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0127, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3302 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0129, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3304 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0132, (cst_val *)&val_0388},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0133, (cst_val *)&val_3305},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0134, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3306 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0136, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0137, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3308 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0140, (cst_val *)&val_3309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3311 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0143, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3312 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0145, (cst_val *)&val_3313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3315 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0148, (cst_val *)&val_0183},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0149, (cst_val *)&val_3316},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0150, (cst_val *)&val_2850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3317 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0152, (cst_val *)&val_0370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3318 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0154, (cst_val *)&val_3319},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3320 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0156, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3323 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0160, (cst_val *)&val_0183},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0161, (cst_val *)&val_0320},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0162, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3324 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0164, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3325 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0166, (cst_val *)&val_3326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3328 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0169, (cst_val *)&val_3329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3331 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0172, (cst_val *)&val_0060},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0173, (cst_val *)&val_3332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3334 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0176, (cst_val *)&val_0505},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0177, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3335 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0179, (cst_val *)&val_2846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3337 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0182, (cst_val *)&val_2345},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0183, (cst_val *)&val_0403},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0184, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3339 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0187, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0188, (cst_val *)&val_0103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3341 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0191, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3342 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0193, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3344 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0196, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3345 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_31_NO_0198, (cst_val *)&val_0632},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3347 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ay_31_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_ay_31_cart = {
  cmu_us_rms_single_mcep_ay_31_cart_nodes,
  cmu_us_rms_single_mcep_ay_31_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ay_32_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0000, (cst_val *)&val_0361},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0001, (cst_val *)&val_0029},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0003, (cst_val *)&val_3348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3349 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0005, (cst_val *)&val_1994},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0006, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3352 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0010, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3353 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0012, (cst_val *)&val_3354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3356 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0015, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3357 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0017, (cst_val *)&val_3354},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0018, (cst_val *)&val_3358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3360 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0021, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3362 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0024, (cst_val *)&val_0097},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0025, (cst_val *)&val_1602},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0026, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3363 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0028, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0029, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3365 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0032, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3366 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0034, (cst_val *)&val_0403},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0035, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3368 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0038, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0039, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3370 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0042, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3371 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0044, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3373 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0047, (cst_val *)&val_0183},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0048, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0049, (cst_val *)&val_1602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3375 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0052, (cst_val *)&val_3376},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0053, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3377 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0055, (cst_val *)&val_3378},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0056, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3380 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0059, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3383 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0063, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0064, (cst_val *)&val_1579},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0065, (cst_val *)&val_0304},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0066, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3386 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0070, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3387 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0072, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3389 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0075, (cst_val *)&val_0417},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0076, (cst_val *)&val_0068},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0077, (cst_val *)&val_3390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3392 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0080, (cst_val *)&val_3393},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0081, (cst_val *)&val_3394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3395 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0083, (cst_val *)&val_0038},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0084, (cst_val *)&val_2184},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0085, (cst_val *)&val_3396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3400 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0090, (cst_val *)&val_1472},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0091, (cst_val *)&val_3401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3403 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0094, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3404 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0096, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3406 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0099, (cst_val *)&val_3407},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0100, (cst_val *)&val_0059},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0101, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3408 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0103, (cst_val *)&val_3409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3411 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0106, (cst_val *)&val_0040},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0107, (cst_val *)&val_3412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3413 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0109, (cst_val *)&val_3414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3415 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0111, (cst_val *)&val_3416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3418 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0114, (cst_val *)&val_3419},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0115, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3421 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0118, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3422 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0120, (cst_val *)&val_0043},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0121, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3425 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0125, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3426 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0127, (cst_val *)&val_3427},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0128, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3428 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0130, (cst_val *)&val_0077},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0131, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3430 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0134, (cst_val *)&val_3431},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0135, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3432 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0137, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3435 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0141, (cst_val *)&val_0251},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0142, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3437 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0145, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3438 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0147, (cst_val *)&val_3439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3440 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0149, (cst_val *)&val_0888},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0150, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3442 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0153, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3444 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0156, (cst_val *)&val_0068},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0157, (cst_val *)&val_0651},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0158, (cst_val *)&val_3445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3446 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0160, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3447 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0162, (cst_val *)&val_3448},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0163, (cst_val *)&val_3449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3450 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0165, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3452 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0168, (cst_val *)&val_0304},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0169, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3455 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0173, (cst_val *)&val_3456},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0174, (cst_val *)&val_3457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3459 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0177, (cst_val *)&val_3460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3462 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0180, (cst_val *)&val_0183},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0181, (cst_val *)&val_0068},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0182, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3464 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0185, (cst_val *)&val_3465},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0186, (cst_val *)&val_3466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3468 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0189, (cst_val *)&val_1756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3470 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0192, (cst_val *)&val_0056},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0193, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3472 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0196, (cst_val *)&val_3473},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0197, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0198, (cst_val *)&val_0510},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0199, (cst_val *)&val_3474},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0200, (cst_val *)&val_3475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3477 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0203, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3479 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0206, (cst_val *)&val_3480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3482 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0209, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0210, (cst_val *)&val_3483},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3485 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0213, (cst_val *)&val_0040},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0214, (cst_val *)&val_3486},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0215, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3488 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0218, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3490 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0221, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3491 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0223, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3492 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0225, (cst_val *)&val_0517},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0226, (cst_val *)&val_3493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3495 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0229, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3497 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0232, (cst_val *)&val_2161},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0233, (cst_val *)&val_3498},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0234, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3499 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0236, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3503 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0240, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0241, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3505 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_32_NO_0244, (cst_val *)&val_3506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3508 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ay_32_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_ay_32_cart = {
  cmu_us_rms_single_mcep_ay_32_cart_nodes,
  cmu_us_rms_single_mcep_ay_32_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ay_33_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0000, (cst_val *)&val_0097},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0003, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3510 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0005, (cst_val *)&val_3511},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0006, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3514 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0010, (cst_val *)&val_0978},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0011, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3516 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0014, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3518 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0017, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0018, (cst_val *)&val_3519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3520 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0020, (cst_val *)&val_3521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3522 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0022, (cst_val *)&val_1378},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0023, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3524 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0026, (cst_val *)&val_2497},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0027, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3526 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0030, (cst_val *)&val_3527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3529 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0033, (cst_val *)&val_0101},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0034, (cst_val *)&val_0068},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0035, (cst_val *)&val_0045},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0036, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3530 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0038, (cst_val *)&val_3531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3532 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0040, (cst_val *)&val_0165},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0041, (cst_val *)&val_3533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3536 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0045, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3537 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0047, (cst_val *)&val_3538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3540 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0050, (cst_val *)&val_3541},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0051, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3542 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0053, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3543 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0055, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3545 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0058, (cst_val *)&val_3546},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0059, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0060, (cst_val *)&val_3547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3548 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0062, (cst_val *)&val_3549},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3550 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0064, (cst_val *)&val_3551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3553 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0067, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3554 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0069, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3555 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0071, (cst_val *)&val_0066},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0072, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3556 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0074, (cst_val *)&val_3557},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0075, (cst_val *)&val_3558},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0076, (cst_val *)&val_2213},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0077, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3559 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0079, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3564 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0085, (cst_val *)&val_2202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3566 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0088, (cst_val *)&val_3567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3569 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0091, (cst_val *)&val_0714},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0092, (cst_val *)&val_3246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3570 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0094, (cst_val *)&val_3571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3572 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0096, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3574 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0099, (cst_val *)&val_3575},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0100, (cst_val *)&val_0824},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0101, (cst_val *)&val_0068},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0102, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3576 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0104, (cst_val *)&val_3577},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0105, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3578 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0107, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3579 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0109, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3580 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0111, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3583 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0115, (cst_val *)&val_3541},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3584 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0117, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3585 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0119, (cst_val *)&val_3586},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0120, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3587 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0122, (cst_val *)&val_3588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3590 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0125, (cst_val *)&val_3591},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0126, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3594 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0130, (cst_val *)&val_2877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3595 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0132, (cst_val *)&val_3596},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3597 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0134, (cst_val *)&val_0027},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0135, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3598 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0137, (cst_val *)&val_0448},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0138, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3599 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0140, (cst_val *)&val_0040},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0141, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3601 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0144, (cst_val *)&val_3602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3605 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0148, (cst_val *)&val_1527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3606 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0150, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3608 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0153, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3610 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0156, (cst_val *)&val_0059},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0157, (cst_val *)&val_3611},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0158, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3612 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0160, (cst_val *)&val_3613},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0161, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3615 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0164, (cst_val *)&val_3616},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0165, (cst_val *)&val_0068},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0166, (cst_val *)&val_3617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3619 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0169, (cst_val *)&val_2564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3621 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0172, (cst_val *)&val_3622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3624 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0175, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0176, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3626 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0179, (cst_val *)&val_0705},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0180, (cst_val *)&val_3627},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0181, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3630 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0185, (cst_val *)&val_3631},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0186, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3632 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0188, (cst_val *)&val_3596},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0189, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3634 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0192, (cst_val *)&val_3635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3636 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0194, (cst_val *)&val_0043},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0195, (cst_val *)&val_3637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3639 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0198, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3642 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0201, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3644 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0204, (cst_val *)&val_0183},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0205, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3645 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0207, (cst_val *)&val_1378},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0208, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3647 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0211, (cst_val *)&val_0220},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0212, (cst_val *)&val_3648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3650 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0215, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3652 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0218, (cst_val *)&val_0025},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0219, (cst_val *)&val_0236},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0220, (cst_val *)&val_0714},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0221, (cst_val *)&val_2876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3654 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0224, (cst_val *)&val_0145},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0225, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3657 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0229, (cst_val *)&val_3658},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0230, (cst_val *)&val_2626},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0231, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3660 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0234, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3663 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0238, (cst_val *)&val_3664},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0239, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3665 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0241, (cst_val *)&val_0008},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0242, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3667 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0245, (cst_val *)&val_0246},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0246, (cst_val *)&val_3668},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0247, (cst_val *)&val_3669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3672 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0251, (cst_val *)&val_3673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3674 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0253, (cst_val *)&val_1683},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0254, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3677 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ay_33_NO_0258, (cst_val *)&val_0087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3679 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ay_33_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ay_33_cart = {
  cmu_us_rms_single_mcep_ay_33_cart_nodes,
  cmu_us_rms_single_mcep_ay_33_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_w_189_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0000, (cst_val *)&val_3680},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0002, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0003, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0004, (cst_val *)&val_1608},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3683 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0008, (cst_val *)&val_3684},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0009, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3685 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0011, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3687 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0014, (cst_val *)&val_0417},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0015, (cst_val *)&val_1689},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0016, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3689 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0019, (cst_val *)&val_3690},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0020, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3691 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0022, (cst_val *)&val_3692},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3695 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0026, (cst_val *)&val_0493},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0027, (cst_val *)&val_1472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3697 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0030, (cst_val *)&val_3698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3700 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0033, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3701 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0035, (cst_val *)&val_0403},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0036, (cst_val *)&val_3702},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0037, (cst_val *)&val_3456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3705 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0041, (cst_val *)&val_3706},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0042, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3707 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0044, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3710 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0047, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0048, (cst_val *)&val_0056},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0049, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3712 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0052, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3713 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0054, (cst_val *)&val_0043},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0055, (cst_val *)&val_3714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3717 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0059, (cst_val *)&val_0183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0060, (cst_val *)&val_1323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3720 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0064, (cst_val *)&val_0077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0065, (cst_val *)&val_0051},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0066, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0067, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3722 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0070, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3723 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0072, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3725 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0075, (cst_val *)&val_3726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3728 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0078, (cst_val *)&val_0251},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0079, (cst_val *)&val_3729},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0080, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3730 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0082, (cst_val *)&val_0059},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0083, (cst_val *)&val_0246},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0084, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3732 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0087, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3733 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0089, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0090, (cst_val *)&val_0016},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0091, (cst_val *)&val_3734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3737 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0095, (cst_val *)&val_3738},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3740 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0098, (cst_val *)&val_0267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3741 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0100, (cst_val *)&val_2548},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0101, (cst_val *)&val_3742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3745 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0105, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3746 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0107, (cst_val *)&val_2645},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0108, (cst_val *)&val_3747},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0109, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3748 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0111, (cst_val *)&val_3749},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0112, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3750 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0114, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3753 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0118, (cst_val *)&val_3754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3756 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0121, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3758 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_189_NO_0124, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3760 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_w_189_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_w_189_cart = {
  cmu_us_rms_single_mcep_w_189_cart_nodes,
  cmu_us_rms_single_mcep_w_189_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_w_190_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0000, (cst_val *)&val_0039},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0001, (cst_val *)&val_0059},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0002, (cst_val *)&val_3761},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0003, (cst_val *)&val_3762},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0004, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3763 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0006, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3765 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0009, (cst_val *)&val_3766},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0010, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3767 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0012, (cst_val *)&val_2670},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0013, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3768 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0015, (cst_val *)&val_3769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3772 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0019, (cst_val *)&val_3773},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3774 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0021, (cst_val *)&val_3775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3777 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0024, (cst_val *)&val_1992},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0025, (cst_val *)&val_0933},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0026, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3779 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0029, (cst_val *)&val_0068},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0030, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3781 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0033, (cst_val *)&val_0165},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0034, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3782 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0036, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3784 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0039, (cst_val *)&val_0841},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0040, (cst_val *)&val_3785},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0041, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3789 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0046, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3790 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0048, (cst_val *)&val_0022},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0049, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3791 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0051, (cst_val *)&val_3792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3793 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0053, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3796 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0057, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3797 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0059, (cst_val *)&val_0165},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0060, (cst_val *)&val_0125},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0061, (cst_val *)&val_1627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3799 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0064, (cst_val *)&val_0403},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0065, (cst_val *)&val_3800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3802 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0068, (cst_val *)&val_0056},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0069, (cst_val *)&val_3803},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3805 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0072, (cst_val *)&val_0008},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0073, (cst_val *)&val_0008},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0074, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3808 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0077, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3809 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0079, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3812 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0082, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3813 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0084, (cst_val *)&val_0060},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0085, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3816 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0089, (cst_val *)&val_3729},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0090, (cst_val *)&val_3817},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0091, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3819 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0094, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3820 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0096, (cst_val *)&val_3821},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0097, (cst_val *)&val_3822},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3825 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0101, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3827 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0104, (cst_val *)&val_0140},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0105, (cst_val *)&val_3828},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0106, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3829 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0108, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0109, (cst_val *)&val_0989},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0110, (cst_val *)&val_0955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3833 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0115, (cst_val *)&val_3834},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0116, (cst_val *)&val_0388},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0117, (cst_val *)&val_0246},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0118, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3836 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0121, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3837 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0123, (cst_val *)&val_0145},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0124, (cst_val *)&val_0008},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0125, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3839 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0128, (cst_val *)&val_3840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3842 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0131, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3844 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0134, (cst_val *)&val_3845},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0135, (cst_val *)&val_3846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3847 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0137, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3849 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0140, (cst_val *)&val_0165},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0141, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3850 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0143, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3852 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0146, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3854 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0149, (cst_val *)&val_0008},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0150, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3856 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0153, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3857 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0155, (cst_val *)&val_0165},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0156, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3860 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0160, (cst_val *)&val_0297},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0161, (cst_val *)&val_3861},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0162, (cst_val *)&val_0068},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0163, (cst_val *)&val_0328},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0164, (cst_val *)&val_3862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3864 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0167, (cst_val *)&val_0008},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0168, (cst_val *)&val_3865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3867 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0171, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3868 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0173, (cst_val *)&val_3869},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3871 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0176, (cst_val *)&val_0629},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0177, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3873 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0180, (cst_val *)&val_3874},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0181, (cst_val *)&val_3875},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3876 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0183, (cst_val *)&val_3877},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0184, (cst_val *)&val_1992},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0185, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3881 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0190, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3883 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0193, (cst_val *)&val_3884},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0194, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3886 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0197, (cst_val *)&val_0165},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0198, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3888 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0201, (cst_val *)&val_1558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3890 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0204, (cst_val *)&val_0165},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0205, (cst_val *)&val_3891},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0206, (cst_val *)&val_0008},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0207, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3892 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0209, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3894 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0212, (cst_val *)&val_1445},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0213, (cst_val *)&val_3445},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0214, (cst_val *)&val_3895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3898 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0218, (cst_val *)&val_3899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3901 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0221, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3902 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0223, (cst_val *)&val_1545},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0224, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3903 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0226, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3906 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0230, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0231, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0232, (cst_val *)&val_1882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3908 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0235, (cst_val *)&val_3909},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0236, (cst_val *)&val_3910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3912 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0239, (cst_val *)&val_3913},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0240, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3916 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0244, (cst_val *)&val_3917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3918 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_190_NO_0246, (cst_val *)&val_3919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3921 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_w_190_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_w_190_cart = {
  cmu_us_rms_single_mcep_w_190_cart_nodes,
  cmu_us_rms_single_mcep_w_190_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_w_191_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0000, (cst_val *)&val_0860},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0001, (cst_val *)&val_3922},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0002, (cst_val *)&val_0128},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0003, (cst_val *)&val_0043},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0004, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3924 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0007, (cst_val *)&val_1789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3926 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0010, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3927 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0012, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3928 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0014, (cst_val *)&val_3929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3931 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0017, (cst_val *)&val_2796},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0018, (cst_val *)&val_2469},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0019, (cst_val *)&val_3932},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0020, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3933 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0022, (cst_val *)&val_0940},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0023, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3935 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0026, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3937 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0029, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3939 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0032, (cst_val *)&val_2959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3941 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0035, (cst_val *)&val_0145},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0036, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3944 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0040, (cst_val *)&val_0008},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0041, (cst_val *)&val_0979},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0042, (cst_val *)&val_0270},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0043, (cst_val *)&val_3945},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0044, (cst_val *)&val_1511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3947 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0047, (cst_val *)&val_3948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3950 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0050, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3951 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0052, (cst_val *)&val_1870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3953 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0055, (cst_val *)&val_0165},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0056, (cst_val *)&val_0284},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0057, (cst_val *)&val_0328},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0058, (cst_val *)&val_3954},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0059, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3957 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0063, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3960 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0067, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3961 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0069, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3963 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0072, (cst_val *)&val_3964},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0073, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0074, (cst_val *)&val_0165},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0075, (cst_val *)&val_0097},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0076, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3967 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0080, (cst_val *)&val_3968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3969 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0082, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3971 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0085, (cst_val *)&val_0651},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0086, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3972 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0088, (cst_val *)&val_0043},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0089, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3973 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0091, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3975 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0094, (cst_val *)&val_3976},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0095, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3979 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0099, (cst_val *)&val_3980},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0100, (cst_val *)&val_3981},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3983 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0103, (cst_val *)&val_3483},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3984 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0105, (cst_val *)&val_3985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3986 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0107, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3988 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0110, (cst_val *)&val_0243},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0111, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3990 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0114, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3991 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0116, (cst_val *)&val_0417},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0117, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3993 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0120, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0121, (cst_val *)&val_3994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3995 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0123, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3997 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0126, (cst_val *)&val_1993},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_w_191_NO_0127, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4000 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_w_191_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_w_191_cart = {
  cmu_us_rms_single_mcep_w_191_cart_nodes,
  cmu_us_rms_single_mcep_w_191_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_m_111_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0002, (cst_val *)&val_1992},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0003, (cst_val *)&val_0043},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0004, (cst_val *)&val_4001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4003 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0007, (cst_val *)&val_0220},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0008, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4004 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0010, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4006 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0013, (cst_val *)&val_4007},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0014, (cst_val *)&val_0328},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0015, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4009 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0018, (cst_val *)&val_4010},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0019, (cst_val *)&val_0444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4012 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0022, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4013 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0024, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4016 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0028, (cst_val *)&val_4017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0029, (cst_val *)&val_1328},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0030, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4020 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0034, (cst_val *)&val_0671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4021 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0036, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4023 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0039, (cst_val *)&val_2661},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0040, (cst_val *)&val_0059},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0041, (cst_val *)&val_4024},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0042, (cst_val *)&val_0957},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0043, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4026 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0046, (cst_val *)&val_4027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4028 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0048, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4030 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0051, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4031 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0053, (cst_val *)&val_0068},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0054, (cst_val *)&val_0758},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4034 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0058, (cst_val *)&val_0140},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0059, (cst_val *)&val_4035},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0060, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4037 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0063, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0064, (cst_val *)&val_0799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4040 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0068, (cst_val *)&val_4041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0069, (cst_val *)&val_4042},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0070, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4044 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0073, (cst_val *)&val_4045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0074, (cst_val *)&val_4046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4049 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0078, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4050 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0080, (cst_val *)&val_0251},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0081, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4053 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0085, (cst_val *)&val_4054},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0086, (cst_val *)&val_4055},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0087, (cst_val *)&val_0035},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0088, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4056 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0090, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4058 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0093, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4060 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0096, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4061 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0098, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4062 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0100, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4064 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0103, (cst_val *)&val_0059},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0104, (cst_val *)&val_4065},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0105, (cst_val *)&val_4066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4067 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0107, (cst_val *)&val_4068},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0108, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0109, (cst_val *)&val_3493},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0110, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4071 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0114, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4073 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0117, (cst_val *)&val_4007},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0118, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4076 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0122, (cst_val *)&val_4077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0123, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4078 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0125, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4079 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0127, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4081 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0130, (cst_val *)&val_4082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4083 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0132, (cst_val *)&val_4084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4085 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0134, (cst_val *)&val_0925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4087 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0137, (cst_val *)&val_0008},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0138, (cst_val *)&val_4088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4089 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0140, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4090 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0142, (cst_val *)&val_4091},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0143, (cst_val *)&val_1749},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0144, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4094 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0148, (cst_val *)&val_0023},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0149, (cst_val *)&val_0040},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0150, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4097 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0154, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4099 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0157, (cst_val *)&val_0025},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0158, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4100 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0160, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4102 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0163, (cst_val *)&val_4103},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0164, (cst_val *)&val_0251},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0165, (cst_val *)&val_0068},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0166, (cst_val *)&val_4104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4105 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0168, (cst_val *)&val_4106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4109 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0172, (cst_val *)&val_0246},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0173, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4110 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0175, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4113 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0179, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4115 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0182, (cst_val *)&val_1158},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0183, (cst_val *)&val_0183},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0184, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4116 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0186, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4118 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0189, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0190, (cst_val *)&val_4119},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0191, (cst_val *)&val_4120},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0192, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4122 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0195, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4124 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0198, (cst_val *)&val_4125},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0199, (cst_val *)&val_4126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4127 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0201, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4129 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0204, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4130 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0206, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4132 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0209, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4133 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0211, (cst_val *)&val_2221},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0212, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4136 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0216, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0217, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4138 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0220, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0221, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4140 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0224, (cst_val *)&val_2959},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0225, (cst_val *)&val_4141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4142 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0227, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4144 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0230, (cst_val *)&val_0088},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_111_NO_0231, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4147 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_m_111_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_single_mcep_m_111_cart = {
  cmu_us_rms_single_mcep_m_111_cart_nodes,
  cmu_us_rms_single_mcep_m_111_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_m_112_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0001, (cst_val *)&val_1386},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0002, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0003, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4148 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0005, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4150 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0008, (cst_val *)&val_4151},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0009, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0010, (cst_val *)&val_2214},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0011, (cst_val *)&val_4152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4155 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0015, (cst_val *)&val_4156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4158 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0018, (cst_val *)&val_1522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4160 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0021, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4161 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0023, (cst_val *)&val_0079},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0024, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4162 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0026, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0027, (cst_val *)&val_0019},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0028, (cst_val *)&val_4163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4166 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0032, (cst_val *)&val_4167},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0033, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4171 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0037, (cst_val *)&val_4172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4174 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0040, (cst_val *)&val_2959},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0041, (cst_val *)&val_0008},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0042, (cst_val *)&val_0145},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0043, (cst_val *)&val_0973},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0044, (cst_val *)&val_4175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4178 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0048, (cst_val *)&val_0008},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0049, (cst_val *)&val_4179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4181 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0052, (cst_val *)&val_4182},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0053, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4185 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0057, (cst_val *)&val_0251},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0058, (cst_val *)&val_0251},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0059, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4187 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0062, (cst_val *)&val_0043},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0063, (cst_val *)&val_0040},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0064, (cst_val *)&val_4188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4190 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0067, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0068, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4192 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0071, (cst_val *)&val_0663},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0072, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4194 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0075, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4196 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0078, (cst_val *)&val_4197},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0079, (cst_val *)&val_4198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4201 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0083, (cst_val *)&val_4202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4203 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0085, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4205 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0088, (cst_val *)&val_0059},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0089, (cst_val *)&val_4206},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0090, (cst_val *)&val_0417},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0091, (cst_val *)&val_3668},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0092, (cst_val *)&val_1853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4208 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0095, (cst_val *)&val_4209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4210 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0097, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4213 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0101, (cst_val *)&val_0629},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0102, (cst_val *)&val_4214},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0103, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4217 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0107, (cst_val *)&val_0361},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0108, (cst_val *)&val_4218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4220 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0111, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0112, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4223 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0116, (cst_val *)&val_0008},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0117, (cst_val *)&val_0059},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0118, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4224 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0120, (cst_val *)&val_4225},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0121, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0122, (cst_val *)&val_4226},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0123, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4229 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0127, (cst_val *)&val_1349},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4231 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0130, (cst_val *)&val_0008},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0131, (cst_val *)&val_0059},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0132, (cst_val *)&val_4232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4235 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0136, (cst_val *)&val_4236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4237 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0138, (cst_val *)&val_4238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4239 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0140, (cst_val *)&val_4240},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4242 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0143, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4243 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0145, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0146, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4245 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0149, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4247 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0152, (cst_val *)&val_0361},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0153, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4248 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0155, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4250 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0158, (cst_val *)&val_0008},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0159, (cst_val *)&val_4251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4252 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0161, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4253 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0163, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4255 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0166, (cst_val *)&val_0040},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0167, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0168, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4257 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0171, (cst_val *)&val_3806},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0172, (cst_val *)&val_4258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4261 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_112_NO_0176, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4263 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_m_112_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_m_112_cart = {
  cmu_us_rms_single_mcep_m_112_cart_nodes,
  cmu_us_rms_single_mcep_m_112_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_m_113_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0001, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4264 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0003, (cst_val *)&val_4265},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0004, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0005, (cst_val *)&val_4266},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0006, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4268 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0009, (cst_val *)&val_4269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4270 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0011, (cst_val *)&val_4271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4273 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0014, (cst_val *)&val_0097},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0015, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4276 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0019, (cst_val *)&val_4277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4278 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0021, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4279 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0023, (cst_val *)&val_3107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4280 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0025, (cst_val *)&val_4281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4283 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0028, (cst_val *)&val_0039},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0029, (cst_val *)&val_0008},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0030, (cst_val *)&val_0056},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0031, (cst_val *)&val_4284},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0032, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4287 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0036, (cst_val *)&val_0140},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0037, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0038, (cst_val *)&val_4288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4290 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0041, (cst_val *)&val_0493},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0042, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4293 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0046, (cst_val *)&val_0592},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0047, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4296 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0051, (cst_val *)&val_4297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4298 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0053, (cst_val *)&val_0008},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0054, (cst_val *)&val_4299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4300 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0056, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4301 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0058, (cst_val *)&val_4302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4303 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0060, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4305 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0063, (cst_val *)&val_0056},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0064, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4307 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0067, (cst_val *)&val_1868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4308 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0069, (cst_val *)&val_2796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4310 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0072, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0073, (cst_val *)&val_4311},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0074, (cst_val *)&val_2149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4312 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0076, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4315 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_m_113_NO_0080, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4317 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_m_113_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_m_113_cart = {
  cmu_us_rms_single_mcep_m_113_cart_nodes,
  cmu_us_rms_single_mcep_m_113_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_pau_143_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0000, (cst_val *)&val_3313},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0001, (cst_val *)&val_4318},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0002, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0003, (cst_val *)&val_0128},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0004, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0005, (cst_val *)&val_4319},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0006, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4320 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0008, (cst_val *)&val_3586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4322 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0011, (cst_val *)&val_4323},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0012, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4324 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0014, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4325 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0016, (cst_val *)&val_4326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4327 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0018, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0019, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4329 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0022, (cst_val *)&val_3577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4330 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0024, (cst_val *)&val_2846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4331 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0026, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0027, (cst_val *)&val_4332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4335 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0031, (cst_val *)&val_1328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4337 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0034, (cst_val *)&val_1466},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0035, (cst_val *)&val_4338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4339 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0037, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4341 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0040, (cst_val *)&val_1705},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0041, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4342 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0043, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4343 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0045, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4344 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0047, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0048, (cst_val *)&val_0114},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0049, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4346 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0052, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4349 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0056, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4351 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0059, (cst_val *)&val_0012},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0060, (cst_val *)&val_2626},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0061, (cst_val *)&val_4352},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0062, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4353 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0064, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4355 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0067, (cst_val *)&val_0038},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0068, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4356 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0070, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4357 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0072, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4358 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0074, (cst_val *)&val_1951},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0075, (cst_val *)&val_4359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4361 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0078, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0079, (cst_val *)&val_4332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4362 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0081, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4366 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0086, (cst_val *)&val_4319},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0087, (cst_val *)&val_3586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4368 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0090, (cst_val *)&val_0037},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0091, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4369 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0093, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4370 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0095, (cst_val *)&val_0693},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0096, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4371 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0098, (cst_val *)&val_1244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4373 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0101, (cst_val *)&val_1700},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0102, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4376 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0105, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4379 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0109, (cst_val *)&val_0074},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0110, (cst_val *)&val_0824},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0111, (cst_val *)&val_4380},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0112, (cst_val *)&val_0059},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0113, (cst_val *)&val_4381},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4383 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0116, (cst_val *)&val_4007},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0117, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0118, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4385 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0121, (cst_val *)&val_4386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4389 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0125, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4390 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0127, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0128, (cst_val *)&val_4391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4394 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0132, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4395 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0134, (cst_val *)&val_0091},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0135, (cst_val *)&val_0429},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0136, (cst_val *)&val_4359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4398 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0140, (cst_val *)&val_2405},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0141, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4399 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0143, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4400 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0145, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4402 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0148, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4404 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0151, (cst_val *)&val_4405},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0152, (cst_val *)&val_0040},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0153, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4406 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0155, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4408 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0158, (cst_val *)&val_4409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4410 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0160, (cst_val *)&val_0077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0161, (cst_val *)&val_4411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4414 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0165, (cst_val *)&val_1853},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0166, (cst_val *)&val_0040},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0167, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4415 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0169, (cst_val *)&val_4416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4418 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0172, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4421 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0176, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0177, (cst_val *)&val_3319},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4423 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0180, (cst_val *)&val_0693},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0181, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4424 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0183, (cst_val *)&val_4425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4426 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0185, (cst_val *)&val_4427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4429 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0188, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4431 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0191, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0192, (cst_val *)&val_0051},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0193, (cst_val *)&val_1992},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0194, (cst_val *)&val_2346},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0195, (cst_val *)&val_0097},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0196, (cst_val *)&val_0358},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0197, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4432 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0199, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4434 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0202, (cst_val *)&val_0021},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0203, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4435 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0205, (cst_val *)&val_4024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4437 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0208, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4438 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0210, (cst_val *)&val_3981},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0211, (cst_val *)&val_4439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4441 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0214, (cst_val *)&val_4359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4443 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0217, (cst_val *)&val_4444},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0218, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4445 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0220, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4448 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0224, (cst_val *)&val_4449},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0225, (cst_val *)&val_0029},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0226, (cst_val *)&val_0125},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0227, (cst_val *)&val_1363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4451 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0230, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4452 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0232, (cst_val *)&val_4453},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0233, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0234, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4455 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0237, (cst_val *)&val_4456},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0238, (cst_val *)&val_4457},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0239, (cst_val *)&val_4458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4460 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0242, (cst_val *)&val_4461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4463 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0245, (cst_val *)&val_4464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4466 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0248, (cst_val *)&val_0693},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0249, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4469 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0253, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0254, (cst_val *)&val_2530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4471 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0257, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0258, (cst_val *)&val_3616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4473 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0261, (cst_val *)&val_4461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4475 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0264, (cst_val *)&val_4374},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0265, (cst_val *)&val_4476},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4478 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0268, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4479 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0270, (cst_val *)&val_4480},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0271, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0272, (cst_val *)&val_4481},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4484 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0276, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4485 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0278, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4487 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0281, (cst_val *)&val_1139},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0282, (cst_val *)&val_4488},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0283, (cst_val *)&val_0040},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0284, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0285, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4491 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0289, (cst_val *)&val_4492},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0290, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4494 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0293, (cst_val *)&val_2149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4496 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0296, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4497 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0298, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4498 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0300, (cst_val *)&val_0015},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0301, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4499 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0303, (cst_val *)&val_1951},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0304, (cst_val *)&val_4500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4502 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0307, (cst_val *)&val_4503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4505 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0310, (cst_val *)&val_0040},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0311, (cst_val *)&val_0059},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0312, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4507 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0315, (cst_val *)&val_4332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4509 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0318, (cst_val *)&val_4510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4512 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0321, (cst_val *)&val_1367},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0322, (cst_val *)&val_4513},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0323, (cst_val *)&val_3176},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0324, (cst_val *)&val_4514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4516 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0327, (cst_val *)&val_2321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4518 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0330, (cst_val *)&val_0347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4520 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0333, (cst_val *)&val_4521},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0334, (cst_val *)&val_4522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4523 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0336, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4525 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0339, (cst_val *)&val_0059},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0340, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0341, (cst_val *)&val_1301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4527 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0344, (cst_val *)&val_1610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4529 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0347, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0348, (cst_val *)&val_1301},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0349, (cst_val *)&val_4461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4532 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0353, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4534 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0356, (cst_val *)&val_4535},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0357, (cst_val *)&val_4536},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0358, (cst_val *)&val_4537},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0359, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4538 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0361, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4540 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0364, (cst_val *)&val_4541},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0365, (cst_val *)&val_4374},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0366, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4543 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0369, (cst_val *)&val_0989},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0370, (cst_val *)&val_2564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4545 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0373, (cst_val *)&val_0693},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0374, (cst_val *)&val_4546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4549 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0378, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0379, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4551 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0382, (cst_val *)&val_4552},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0383, (cst_val *)&val_4553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4556 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0387, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0388, (cst_val *)&val_4557},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0389, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4559 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0392, (cst_val *)&val_0120},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0393, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4562 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0397, (cst_val *)&val_1367},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0398, (cst_val *)&val_4457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4563 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0400, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4564 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0402, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4566 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0405, (cst_val *)&val_4567},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0406, (cst_val *)&val_0125},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0407, (cst_val *)&val_4568},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4570 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0410, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4571 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0412, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4572 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0414, (cst_val *)&val_4573},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0415, (cst_val *)&val_1310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4575 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0418, (cst_val *)&val_0114},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0419, (cst_val *)&val_4576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4578 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0422, (cst_val *)&val_4579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4581 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0425, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4582 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0427, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4583 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0429, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4584 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0431, (cst_val *)&val_4457},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0432, (cst_val *)&val_4585},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4586 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0434, (cst_val *)&val_4458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4589 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0438, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4590 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0440, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0441, (cst_val *)&val_1993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4591 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0443, (cst_val *)&val_4592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4595 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0447, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0448, (cst_val *)&val_0097},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0449, (cst_val *)&val_4596},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0450, (cst_val *)&val_0933},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0451, (cst_val *)&val_0077},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0452, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4598 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0455, (cst_val *)&val_4599},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4600 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0457, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4602 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0460, (cst_val *)&val_0193},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0461, (cst_val *)&val_0077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0462, (cst_val *)&val_4603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4604 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0464, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4606 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0467, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4608 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0470, (cst_val *)&val_0025},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0471, (cst_val *)&val_1139},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0472, (cst_val *)&val_4609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4612 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0476, (cst_val *)&val_4613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4615 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0479, (cst_val *)&val_0693},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0480, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0481, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4617 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0484, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4618 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0486, (cst_val *)&val_4619},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0487, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4621 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0490, (cst_val *)&val_4622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4625 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0494, (cst_val *)&val_0120},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0495, (cst_val *)&val_0074},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0496, (cst_val *)&val_4626},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0497, (cst_val *)&val_0077},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0498, (cst_val *)&val_4627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4630 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0502, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4632 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0505, (cst_val *)&val_4633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4634 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0507, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4636 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0510, (cst_val *)&val_4332},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0511, (cst_val *)&val_3527},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0512, (cst_val *)&val_1818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4638 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0515, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0516, (cst_val *)&val_0297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4640 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0519, (cst_val *)&val_4641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4643 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0522, (cst_val *)&val_2876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4644 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0524, (cst_val *)&val_1705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4646 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0527, (cst_val *)&val_0040},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0528, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4647 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0530, (cst_val *)&val_0120},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0531, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4650 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0535, (cst_val *)&val_0171},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0536, (cst_val *)&val_4651},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0537, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4654 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0541, (cst_val *)&val_4655},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0542, (cst_val *)&val_4656},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0543, (cst_val *)&val_2275},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0544, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4658 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0547, (cst_val *)&val_4659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4661 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0550, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4662 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0552, (cst_val *)&val_4663},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0553, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4667 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0558, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0559, (cst_val *)&val_4668},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0560, (cst_val *)&val_4669},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0561, (cst_val *)&val_1367},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0562, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4672 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0566, (cst_val *)&val_2014},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0567, (cst_val *)&val_4332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4674 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0570, (cst_val *)&val_4675},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0571, (cst_val *)&val_4676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4679 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0575, (cst_val *)&val_4680},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0576, (cst_val *)&val_1367},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0577, (cst_val *)&val_4681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4684 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0581, (cst_val *)&val_1367},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0582, (cst_val *)&val_4685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4688 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0586, (cst_val *)&val_4689},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0587, (cst_val *)&val_4690},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0588, (cst_val *)&val_0040},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0589, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0590, (cst_val *)&val_4691},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0591, (cst_val *)&val_4692},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4694 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0594, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4696 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0597, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4698 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0600, (cst_val *)&val_3493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4701 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0604, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0605, (cst_val *)&val_4702},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0606, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4704 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0609, (cst_val *)&val_4705},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0610, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4708 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0614, (cst_val *)&val_0145},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0615, (cst_val *)&val_4709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4711 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_143_NO_0618, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4713 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_pau_143_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_pau_143_cart = {
  cmu_us_rms_single_mcep_pau_143_cart_nodes,
  cmu_us_rms_single_mcep_pau_143_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ao_16_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0001, (cst_val *)&val_4714},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0002, (cst_val *)&val_0760},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0003, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4715 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0005, (cst_val *)&val_4045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4716 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0007, (cst_val *)&val_4717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4719 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0010, (cst_val *)&val_4720},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0011, (cst_val *)&val_1951},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0012, (cst_val *)&val_4721},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4724 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0016, (cst_val *)&val_4725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4727 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0019, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4728 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0021, (cst_val *)&val_4729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4730 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0023, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4732 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0026, (cst_val *)&val_1386},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0027, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0028, (cst_val *)&val_0403},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0029, (cst_val *)&val_3256},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0030, (cst_val *)&val_4733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4735 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0033, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4736 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0035, (cst_val *)&val_1261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4738 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0038, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4739 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0040, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4741 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0043, (cst_val *)&val_0043},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0044, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4742 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0046, (cst_val *)&val_0056},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0047, (cst_val *)&val_2498},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0048, (cst_val *)&val_0304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4745 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0052, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4747 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0055, (cst_val *)&val_2498},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0056, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4750 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0060, (cst_val *)&val_0045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0061, (cst_val *)&val_0013},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0062, (cst_val *)&val_4751},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0063, (cst_val *)&val_0125},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0064, (cst_val *)&val_2270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4752 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0066, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4756 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0071, (cst_val *)&val_1594},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0072, (cst_val *)&val_4757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4759 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0075, (cst_val *)&val_4760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4762 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0078, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0079, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4764 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0082, (cst_val *)&val_0362},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0083, (cst_val *)&val_4765},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0084, (cst_val *)&val_4766},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0085, (cst_val *)&val_4767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4769 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0088, (cst_val *)&val_3486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4772 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_16_NO_0092, (cst_val *)&val_1705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4774 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ao_16_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_ao_16_cart = {
  cmu_us_rms_single_mcep_ao_16_cart_nodes,
  cmu_us_rms_single_mcep_ao_16_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ao_17_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0000, (cst_val *)&val_0403},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0001, (cst_val *)&val_4024},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0003, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4776 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0006, (cst_val *)&val_0774},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0007, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4779 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0011, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4780 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0013, (cst_val *)&val_0077},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0014, (cst_val *)&val_4781},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0015, (cst_val *)&val_4782},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0016, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0017, (cst_val *)&val_4783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4786 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0021, (cst_val *)&val_2241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4789 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0025, (cst_val *)&val_4782},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0026, (cst_val *)&val_0183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0027, (cst_val *)&val_2548},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0028, (cst_val *)&val_4790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4793 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0032, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4795 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0035, (cst_val *)&val_4767},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0036, (cst_val *)&val_4796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4799 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0040, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0041, (cst_val *)&val_4800},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0042, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0043, (cst_val *)&val_0041},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0044, (cst_val *)&val_4801},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0045, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4804 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0049, (cst_val *)&val_3475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4806 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0052, (cst_val *)&val_4807},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0053, (cst_val *)&val_2557},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0054, (cst_val *)&val_0615},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0055, (cst_val *)&val_4808},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4810 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0058, (cst_val *)&val_4811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4813 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0061, (cst_val *)&val_4814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4818 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0066, (cst_val *)&val_0171},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0067, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0068, (cst_val *)&val_4819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4820 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0070, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4821 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0072, (cst_val *)&val_4822},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0073, (cst_val *)&val_4823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4825 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0076, (cst_val *)&val_4826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4827 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0078, (cst_val *)&val_3456},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0079, (cst_val *)&val_4352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4830 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0083, (cst_val *)&val_4831},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0084, (cst_val *)&val_3316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4833 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0087, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0088, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4834 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0090, (cst_val *)&val_0125},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0091, (cst_val *)&val_4835},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4838 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0095, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4839 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0097, (cst_val *)&val_4840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4841 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0099, (cst_val *)&val_4842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4844 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0102, (cst_val *)&val_0045},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0103, (cst_val *)&val_0361},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0104, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0105, (cst_val *)&val_0064},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0106, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4848 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0111, (cst_val *)&val_0251},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0112, (cst_val *)&val_4849},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0113, (cst_val *)&val_0417},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0114, (cst_val *)&val_4850},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0115, (cst_val *)&val_4851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4853 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0118, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4855 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0121, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4857 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0124, (cst_val *)&val_4858},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0125, (cst_val *)&val_4859},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0126, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4861 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0129, (cst_val *)&val_0417},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0130, (cst_val *)&val_4862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4865 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0134, (cst_val *)&val_0165},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0135, (cst_val *)&val_4866},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4869 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0139, (cst_val *)&val_4024},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0140, (cst_val *)&val_0304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4870 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0142, (cst_val *)&val_4871},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0143, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4874 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0147, (cst_val *)&val_0183},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0148, (cst_val *)&val_2423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4875 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0150, (cst_val *)&val_4876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4878 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0153, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4881 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0156, (cst_val *)&val_4882},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0157, (cst_val *)&val_4883},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0158, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4884 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0160, (cst_val *)&val_0044},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0161, (cst_val *)&val_1992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4887 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0165, (cst_val *)&val_0125},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0166, (cst_val *)&val_4888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4890 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0169, (cst_val *)&val_4891},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0170, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4892 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0172, (cst_val *)&val_4893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4896 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0176, (cst_val *)&val_4897},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_17_NO_0177, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4900 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ao_17_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_single_mcep_ao_17_cart = {
  cmu_us_rms_single_mcep_ao_17_cart_nodes,
  cmu_us_rms_single_mcep_ao_17_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ao_18_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0000, (cst_val *)&val_1035},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0001, (cst_val *)&val_0040},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0002, (cst_val *)&val_0251},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0003, (cst_val *)&val_4901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4902 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0005, (cst_val *)&val_0294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4905 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0009, (cst_val *)&val_0059},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0010, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0011, (cst_val *)&val_4352},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0012, (cst_val *)&val_0097},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0013, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4908 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0017, (cst_val *)&val_0328},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0018, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4910 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0021, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4912 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0024, (cst_val *)&val_0038},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0025, (cst_val *)&val_0978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4915 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0029, (cst_val *)&val_0539},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0030, (cst_val *)&val_0403},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0031, (cst_val *)&val_4916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4918 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0034, (cst_val *)&val_4919},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0035, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4921 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0038, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4923 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0041, (cst_val *)&val_4492},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0042, (cst_val *)&val_4924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4925 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0044, (cst_val *)&val_4926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4929 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0048, (cst_val *)&val_4930},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0049, (cst_val *)&val_0040},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0050, (cst_val *)&val_2067},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0051, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4931 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0053, (cst_val *)&val_1297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4933 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0056, (cst_val *)&val_4934},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0057, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4936 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0060, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4938 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0063, (cst_val *)&val_4939},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0064, (cst_val *)&val_1864},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0065, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4940 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0067, (cst_val *)&val_4941},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4943 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0070, (cst_val *)&val_2435},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0071, (cst_val *)&val_0841},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0072, (cst_val *)&val_4944},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0073, (cst_val *)&val_0088},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0074, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4946 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0077, (cst_val *)&val_4947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4950 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0081, (cst_val *)&val_4951},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0082, (cst_val *)&val_4952},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0083, (cst_val *)&val_0025},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0084, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4954 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0087, (cst_val *)&val_3124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4957 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0091, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0092, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4960 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0096, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0097, (cst_val *)&val_0318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4962 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0100, (cst_val *)&val_4963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4965 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0103, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4966 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0105, (cst_val *)&val_1992},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0106, (cst_val *)&val_4967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4969 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0109, (cst_val *)&val_4970},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0110, (cst_val *)&val_0068},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0111, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4972 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0114, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4974 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0117, (cst_val *)&val_0165},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0118, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4977 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0122, (cst_val *)&val_0059},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0123, (cst_val *)&val_3210},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0124, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4978 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0126, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4979 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0128, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4981 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0131, (cst_val *)&val_4982},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0132, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4983 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0134, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4986 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0138, (cst_val *)&val_0733},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0139, (cst_val *)&val_0231},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0140, (cst_val *)&val_4987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4989 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0143, (cst_val *)&val_4990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4992 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0146, (cst_val *)&val_4993},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0147, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4995 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0150, (cst_val *)&val_0361},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0151, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4997 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0154, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4998 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0156, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4999 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0158, (cst_val *)&val_0068},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0159, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5001 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ao_18_NO_0162, (cst_val *)&val_3210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5003 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ao_18_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_ao_18_cart = {
  cmu_us_rms_single_mcep_ao_18_cart_nodes,
  cmu_us_rms_single_mcep_ao_18_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_th_169_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0000, (cst_val *)&val_5004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0001, (cst_val *)&val_0040},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0003, (cst_val *)&val_0940},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0004, (cst_val *)&val_2625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5007 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0008, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5008 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0010, (cst_val *)&val_5009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5011 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0013, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0014, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5014 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0018, (cst_val *)&val_3256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5015 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0020, (cst_val *)&val_5016},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0021, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0022, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5018 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0025, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5020 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0028, (cst_val *)&val_0429},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0029, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5022 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_169_NO_0032, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5024 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_th_169_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_th_169_cart = {
  cmu_us_rms_single_mcep_th_169_cart_nodes,
  cmu_us_rms_single_mcep_th_169_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_th_170_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0001, (cst_val *)&val_2405},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0002, (cst_val *)&val_0007},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0003, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5026 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0006, (cst_val *)&val_0013},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0007, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5028 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0010, (cst_val *)&val_0239},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0011, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5030 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0014, (cst_val *)&val_5031},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0015, (cst_val *)&val_5032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5033 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0017, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5035 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0020, (cst_val *)&val_1885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5037 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0023, (cst_val *)&val_0417},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0024, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5039 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0027, (cst_val *)&val_0073},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0028, (cst_val *)&val_5040},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0029, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5042 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0032, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0033, (cst_val *)&val_5043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5044 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0035, (cst_val *)&val_5045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5049 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0040, (cst_val *)&val_1038},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0041, (cst_val *)&val_0403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0042, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5051 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0045, (cst_val *)&val_0020},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0046, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5052 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0048, (cst_val *)&val_0033},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0049, (cst_val *)&val_5053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5057 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0054, (cst_val *)&val_0978},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0055, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0056, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5060 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0060, (cst_val *)&val_5061},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0061, (cst_val *)&val_0251},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0062, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5062 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0064, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5063 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0066, (cst_val *)&val_0774},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0067, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5064 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0069, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5067 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0073, (cst_val *)&val_4024},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0074, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5069 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0077, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0078, (cst_val *)&val_5070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5071 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0080, (cst_val *)&val_0417},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0081, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5074 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0085, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5076 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0088, (cst_val *)&val_5077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5078 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_170_NO_0090, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5080 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_th_170_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_single_mcep_th_170_cart = {
  cmu_us_rms_single_mcep_th_170_cart_nodes,
  cmu_us_rms_single_mcep_th_170_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_th_171_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0001, (cst_val *)&val_0493},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0002, (cst_val *)&val_2159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5083 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0006, (cst_val *)&val_0626},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0007, (cst_val *)&val_5084},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0008, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5085 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0010, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5087 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0013, (cst_val *)&val_5088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5089 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0015, (cst_val *)&val_3483},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5091 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0018, (cst_val *)&val_1035},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_th_171_NO_0019, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5094 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_th_171_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.n.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_th_171_cart = {
  cmu_us_rms_single_mcep_th_171_cart_nodes,
  cmu_us_rms_single_mcep_th_171_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ah_11_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0001, (cst_val *)&val_2661},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0002, (cst_val *)&val_0841},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0003, (cst_val *)&val_5095},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0004, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5098 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0008, (cst_val *)&val_4202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5099 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0010, (cst_val *)&val_0417},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0011, (cst_val *)&val_4919},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0012, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5102 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5104 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0019, (cst_val *)&val_0417},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0020, (cst_val *)&val_5105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5106 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0022, (cst_val *)&val_5107},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0023, (cst_val *)&val_5108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0024, (cst_val *)&val_2159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5110 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0027, (cst_val *)&val_5111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5113 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0030, (cst_val *)&val_5114},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0031, (cst_val *)&val_0358},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0032, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5116 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0035, (cst_val *)&val_5117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5120 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0039, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0040, (cst_val *)&val_5121},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0041, (cst_val *)&val_5122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5125 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0045, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0046, (cst_val *)&val_5126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5128 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0049, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5129 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0051, (cst_val *)&val_5130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5132 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0054, (cst_val *)&val_5133},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0055, (cst_val *)&val_0068},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0056, (cst_val *)&val_0046},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0057, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5135 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0060, (cst_val *)&val_5136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5138 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0063, (cst_val *)&val_0077},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0064, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5140 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0067, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5141 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0069, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5142 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0071, (cst_val *)&val_5143},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0072, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5146 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0076, (cst_val *)&val_3256},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0077, (cst_val *)&val_0489},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0078, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5147 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0080, (cst_val *)&val_5148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5150 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0083, (cst_val *)&val_5151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5153 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0086, (cst_val *)&val_5154},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0087, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5155 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0089, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0090, (cst_val *)&val_5156},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0091, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5158 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0094, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0095, (cst_val *)&val_5159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5161 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0098, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5163 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0101, (cst_val *)&val_5164},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0102, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5166 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0105, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5168 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0108, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5169 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0110, (cst_val *)&val_5170},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0111, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5172 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_11_NO_0114, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5174 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ah_11_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ah_11_cart = {
  cmu_us_rms_single_mcep_ah_11_cart_nodes,
  cmu_us_rms_single_mcep_ah_11_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ah_12_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0000, (cst_val *)&val_0219},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0001, (cst_val *)&val_0068},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0002, (cst_val *)&val_1386},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0003, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5175 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0005, (cst_val *)&val_0007},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0006, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5178 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0010, (cst_val *)&val_5179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5181 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0013, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0014, (cst_val *)&val_0183},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0015, (cst_val *)&val_0025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0016, (cst_val *)&val_1386},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0017, (cst_val *)&val_5182},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5185 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0021, (cst_val *)&val_2959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5186 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0023, (cst_val *)&val_5187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5189 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0026, (cst_val *)&val_0056},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0027, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5190 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0029, (cst_val *)&val_0165},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0030, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5194 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0035, (cst_val *)&val_1386},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0036, (cst_val *)&val_5195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5198 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0040, (cst_val *)&val_0361},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0041, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5199 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0043, (cst_val *)&val_5200},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0044, (cst_val *)&val_0020},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0045, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5204 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0050, (cst_val *)&val_0026},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0051, (cst_val *)&val_0251},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0052, (cst_val *)&val_0012},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0053, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0054, (cst_val *)&val_5205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5208 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0058, (cst_val *)&val_5209},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0059, (cst_val *)&val_0417},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0060, (cst_val *)&val_5210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5214 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0065, (cst_val *)&val_5215},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0066, (cst_val *)&val_0125},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0067, (cst_val *)&val_5216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5218 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0070, (cst_val *)&val_3486},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0071, (cst_val *)&val_5219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5221 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0074, (cst_val *)&val_0165},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0075, (cst_val *)&val_5222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5224 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0078, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5226 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0081, (cst_val *)&val_0183},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0082, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5228 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0085, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0086, (cst_val *)&val_2345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5231 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0090, (cst_val *)&val_0077},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0091, (cst_val *)&val_0165},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0092, (cst_val *)&val_1328},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0093, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5232 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0095, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5233 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0097, (cst_val *)&val_5234},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0098, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5235 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0100, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5237 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0103, (cst_val *)&val_0642},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0104, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5239 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0107, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5242 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0111, (cst_val *)&val_0013},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0112, (cst_val *)&val_5243},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0113, (cst_val *)&val_5244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5245 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0115, (cst_val *)&val_5246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5248 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0118, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0119, (cst_val *)&val_1634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5251 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0123, (cst_val *)&val_5252},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0124, (cst_val *)&val_4391},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0125, (cst_val *)&val_5253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5256 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0129, (cst_val *)&val_1579},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0130, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5259 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0134, (cst_val *)&val_5260},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0135, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0136, (cst_val *)&val_0097},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0137, (cst_val *)&val_0542},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0138, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0139, (cst_val *)&val_5261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5263 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0142, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5264 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0144, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5266 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0147, (cst_val *)&val_5267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5269 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0150, (cst_val *)&val_5270},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0151, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5273 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0155, (cst_val *)&val_0132},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0156, (cst_val *)&val_5274},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0157, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5277 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0161, (cst_val *)&val_0056},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0162, (cst_val *)&val_5278},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0163, (cst_val *)&val_5279},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0164, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5281 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0167, (cst_val *)&val_2153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5283 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0170, (cst_val *)&val_5284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5286 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0173, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0174, (cst_val *)&val_0989},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0175, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5287 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0177, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5290 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0181, (cst_val *)&val_0256},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0182, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5291 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_12_NO_0184, (cst_val *)&val_5292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5296 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ah_12_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_single_mcep_ah_12_cart = {
  cmu_us_rms_single_mcep_ah_12_cart_nodes,
  cmu_us_rms_single_mcep_ah_12_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ah_13_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0001, (cst_val *)&val_0183},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0002, (cst_val *)&val_2208},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0003, (cst_val *)&val_3301},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0004, (cst_val *)&val_3439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5298 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0007, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5300 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0010, (cst_val *)&val_0068},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0011, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5302 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0014, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5303 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0016, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5305 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0019, (cst_val *)&val_1579},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0020, (cst_val *)&val_0060},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0021, (cst_val *)&val_5306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5307 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0023, (cst_val *)&val_1683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5309 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0026, (cst_val *)&val_2417},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0027, (cst_val *)&val_5310},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0028, (cst_val *)&val_1158},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0029, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5312 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0032, (cst_val *)&val_5313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5315 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0035, (cst_val *)&val_5252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5316 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0037, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5317 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0039, (cst_val *)&val_2716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5319 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0042, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5321 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0045, (cst_val *)&val_0019},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0046, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5323 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0049, (cst_val *)&val_5324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5325 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0051, (cst_val *)&val_5326},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0052, (cst_val *)&val_5327},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5329 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0055, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5331 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0058, (cst_val *)&val_5332},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0059, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5333 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0061, (cst_val *)&val_5334},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5335 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0063, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5337 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0066, (cst_val *)&val_5338},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0067, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5340 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0070, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0071, (cst_val *)&val_5341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5343 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0074, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ah_13_NO_0075, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5346 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ah_13_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ah_13_cart = {
  cmu_us_rms_single_mcep_ah_13_cart_nodes,
  cmu_us_rms_single_mcep_ah_13_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_v_184_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0000, (cst_val *)&val_1522},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0001, (cst_val *)&val_2625},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0002, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5347 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0004, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0005, (cst_val *)&val_5348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5350 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0008, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5351 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0010, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0011, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5354 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0015, (cst_val *)&val_5355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5356 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0017, (cst_val *)&val_5357},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5359 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0020, (cst_val *)&val_5360},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0021, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0022, (cst_val *)&val_2152},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0023, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5362 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0026, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5364 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0029, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5365 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0031, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5366 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0033, (cst_val *)&val_5355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5368 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0036, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5369 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0038, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0039, (cst_val *)&val_0771},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0040, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5371 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0043, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5373 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0046, (cst_val *)&val_0745},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0047, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5375 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0050, (cst_val *)&val_0015},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0051, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_184_NO_0052, (cst_val *)&val_5376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5380 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_v_184_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_v_184_cart = {
  cmu_us_rms_single_mcep_v_184_cart_nodes,
  cmu_us_rms_single_mcep_v_184_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_v_185_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0000, (cst_val *)&val_2625},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0001, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5381 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0003, (cst_val *)&val_1922},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0004, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5382 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0006, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5384 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0009, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0010, (cst_val *)&val_5348},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0011, (cst_val *)&val_3456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5386 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0014, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0015, (cst_val *)&val_5387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5389 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0018, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5392 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0022, (cst_val *)&val_5393},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0023, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0024, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5394 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0026, (cst_val *)&val_0165},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0027, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5397 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0031, (cst_val *)&val_5398},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0032, (cst_val *)&val_5399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5401 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0035, (cst_val *)&val_5402},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0036, (cst_val *)&val_5403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5405 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0039, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5407 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0042, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5408 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0044, (cst_val *)&val_0097},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0045, (cst_val *)&val_0246},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0046, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5410 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0049, (cst_val *)&val_0246},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0050, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5413 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0054, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0055, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5415 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_185_NO_0058, (cst_val *)&val_5416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5418 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_v_185_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_v_185_cart = {
  cmu_us_rms_single_mcep_v_185_cart_nodes,
  cmu_us_rms_single_mcep_v_185_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_v_186_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0000, (cst_val *)&val_5419},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0002, (cst_val *)&val_5420},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0003, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0004, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5422 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0007, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5423 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0009, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5425 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0012, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5426 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0014, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5428 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0017, (cst_val *)&val_0060},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0018, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5430 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0021, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0022, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5431 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0024, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5432 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0026, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5434 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0029, (cst_val *)&val_5435},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0030, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5438 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0034, (cst_val *)&val_0060},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0035, (cst_val *)&val_1614},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0036, (cst_val *)&val_5439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5441 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0039, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5442 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0041, (cst_val *)&val_5398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5444 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0044, (cst_val *)&val_0145},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0045, (cst_val *)&val_0040},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0046, (cst_val *)&val_0045},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0047, (cst_val *)&val_0029},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0048, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5445 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0050, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5447 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0053, (cst_val *)&val_5448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5450 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0056, (cst_val *)&val_5451},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0057, (cst_val *)&val_1331},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0058, (cst_val *)&val_0978},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0059, (cst_val *)&val_5452},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0060, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5453 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0062, (cst_val *)&val_0220},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0063, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5455 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0066, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5458 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0070, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5460 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0073, (cst_val *)&val_0128},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0074, (cst_val *)&val_0246},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0075, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5463 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0079, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5464 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0081, (cst_val *)&val_5465},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0082, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0083, (cst_val *)&val_0403},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0084, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5467 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0087, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5471 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0092, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0093, (cst_val *)&val_5472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5473 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0095, (cst_val *)&val_5474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5476 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0098, (cst_val *)&val_0625},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0099, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5479 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0103, (cst_val *)&val_2670},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0104, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5480 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0106, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5482 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0109, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5483 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0111, (cst_val *)&val_5484},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0112, (cst_val *)&val_5105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5486 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0115, (cst_val *)&val_5487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5489 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0118, (cst_val *)&val_0056},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0119, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5490 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0121, (cst_val *)&val_5491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5493 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0124, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0125, (cst_val *)&val_1331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5495 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_v_186_NO_0128, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5497 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_v_186_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_rms_single_mcep_v_186_cart = {
  cmu_us_rms_single_mcep_v_186_cart_nodes,
  cmu_us_rms_single_mcep_v_186_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_dh_51_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0000, (cst_val *)&val_0077},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0001, (cst_val *)&val_3412},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0002, (cst_val *)&val_5498},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0003, (cst_val *)&val_5499},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5502 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0007, (cst_val *)&val_0328},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0008, (cst_val *)&val_5498},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0009, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5505 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0013, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5506 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0015, (cst_val *)&val_5507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5508 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0017, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5509 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0019, (cst_val *)&val_0012},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0020, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5511 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0023, (cst_val *)&val_5512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5514 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0026, (cst_val *)&val_0251},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0027, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5515 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0029, (cst_val *)&val_1038},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0030, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5517 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0033, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5519 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0036, (cst_val *)&val_0068},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0037, (cst_val *)&val_5520},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0038, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0039, (cst_val *)&val_5521},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0040, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5523 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0043, (cst_val *)&val_0307},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0044, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5525 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0047, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5526 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0049, (cst_val *)&val_5527},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0050, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5530 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0054, (cst_val *)&val_5531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5533 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0057, (cst_val *)&val_5534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5536 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0060, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0061, (cst_val *)&val_1139},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0062, (cst_val *)&val_5537},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0063, (cst_val *)&val_5538},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0064, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5540 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0067, (cst_val *)&val_0997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5541 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0069, (cst_val *)&val_1249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5543 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0072, (cst_val *)&val_4458},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0073, (cst_val *)&val_0165},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0074, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5544 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0076, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5546 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0079, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5549 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0083, (cst_val *)&val_0097},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0084, (cst_val *)&val_4987},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0085, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0086, (cst_val *)&val_2919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5550 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0088, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5551 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0090, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5553 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0093, (cst_val *)&val_0626},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0094, (cst_val *)&val_3233},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0095, (cst_val *)&val_3412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5554 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0097, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5556 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0100, (cst_val *)&val_4685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5558 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0103, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5560 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0106, (cst_val *)&val_0015},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0107, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5561 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0109, (cst_val *)&val_5562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5564 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0112, (cst_val *)&val_1608},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0113, (cst_val *)&val_1213},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0114, (cst_val *)&val_1383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5566 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0117, (cst_val *)&val_5567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5570 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0121, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0122, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0123, (cst_val *)&val_4546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5572 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0126, (cst_val *)&val_1756},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0127, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5574 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0130, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5576 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0133, (cst_val *)&val_2617},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0134, (cst_val *)&val_5577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5580 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0138, (cst_val *)&val_5581},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0139, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0140, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5583 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0143, (cst_val *)&val_5584},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0144, (cst_val *)&val_0183},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0145, (cst_val *)&val_0278},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0146, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5587 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0150, (cst_val *)&val_5348},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0151, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5589 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0154, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5591 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0157, (cst_val *)&val_5592},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0158, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0159, (cst_val *)&val_2152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5596 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0164, (cst_val *)&val_3627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5597 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_51_NO_0166, (cst_val *)&val_1472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5599 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_dh_51_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_dh_51_cart = {
  cmu_us_rms_single_mcep_dh_51_cart_nodes,
  cmu_us_rms_single_mcep_dh_51_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_dh_52_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0000, (cst_val *)&val_2670},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0001, (cst_val *)&val_4168},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0002, (cst_val *)&val_0651},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0003, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5601 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0006, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5602 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0008, (cst_val *)&val_0325},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0009, (cst_val *)&val_3567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5605 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0013, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0014, (cst_val *)&val_0120},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0015, (cst_val *)&val_0542},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0016, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5606 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0018, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5607 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0020, (cst_val *)&val_2196},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0021, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5608 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0023, (cst_val *)&val_0489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5610 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0026, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5613 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0030, (cst_val *)&val_3210},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0031, (cst_val *)&val_5614},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0032, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5616 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0035, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5618 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0038, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5619 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0040, (cst_val *)&val_5620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5621 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0042, (cst_val *)&val_5622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5624 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0045, (cst_val *)&val_5625},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0046, (cst_val *)&val_5626},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0047, (cst_val *)&val_4944},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0048, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5627 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0050, (cst_val *)&val_5628},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5629 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0052, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5631 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0055, (cst_val *)&val_0059},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0056, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5632 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0058, (cst_val *)&val_0097},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0059, (cst_val *)&val_5633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5636 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0063, (cst_val *)&val_5637},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0064, (cst_val *)&val_5638},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0065, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5639 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0067, (cst_val *)&val_5640},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0068, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5643 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0071, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5645 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0074, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5647 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0077, (cst_val *)&val_0120},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0078, (cst_val *)&val_5648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5649 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0080, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5652 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0084, (cst_val *)&val_0417},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0085, (cst_val *)&val_0239},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0086, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5654 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0089, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5655 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0091, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5657 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0094, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5659 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0097, (cst_val *)&val_5095},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0098, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5660 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0100, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5661 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0102, (cst_val *)&val_5662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5663 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0104, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5665 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0107, (cst_val *)&val_0417},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0108, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5668 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0112, (cst_val *)&val_0417},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0113, (cst_val *)&val_5669},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0114, (cst_val *)&val_1892},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0115, (cst_val *)&val_5670},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0116, (cst_val *)&val_5671},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0117, (cst_val *)&val_2237},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0118, (cst_val *)&val_5672},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0119, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5676 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0124, (cst_val *)&val_3445},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0125, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5679 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0129, (cst_val *)&val_0193},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0130, (cst_val *)&val_5680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5684 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0135, (cst_val *)&val_5685},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0136, (cst_val *)&val_5686},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0137, (cst_val *)&val_1853},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0138, (cst_val *)&val_0034},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0139, (cst_val *)&val_5687},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0140, (cst_val *)&val_0818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5689 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0143, (cst_val *)&val_4456},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0144, (cst_val *)&val_1472},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0145, (cst_val *)&val_5690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5694 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0150, (cst_val *)&val_1558},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0151, (cst_val *)&val_4323},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0152, (cst_val *)&val_0029},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0153, (cst_val *)&val_0785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5695 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0155, (cst_val *)&val_2239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5697 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0158, (cst_val *)&val_5698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5701 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0162, (cst_val *)&val_5702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5704 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0165, (cst_val *)&val_5705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5707 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0168, (cst_val *)&val_5708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5710 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0171, (cst_val *)&val_0212},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0172, (cst_val *)&val_5711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5713 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0175, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5715 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0178, (cst_val *)&val_3486},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0179, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5717 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_52_NO_0182, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5719 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_dh_52_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_dh_52_cart = {
  cmu_us_rms_single_mcep_dh_52_cart_nodes,
  cmu_us_rms_single_mcep_dh_52_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_dh_53_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0001, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0002, (cst_val *)&val_5720},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0003, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5722 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0006, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0007, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5726 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0012, (cst_val *)&val_1223},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0013, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0014, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0015, (cst_val *)&val_0979},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0016, (cst_val *)&val_5727},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0017, (cst_val *)&val_5728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5730 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0020, (cst_val *)&val_0246},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0021, (cst_val *)&val_0631},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0022, (cst_val *)&val_2093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5732 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0025, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5735 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0029, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5737 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0032, (cst_val *)&val_0824},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0033, (cst_val *)&val_4035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5739 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0036, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5740 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0038, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0039, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5741 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0041, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5742 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0043, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5744 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0046, (cst_val *)&val_0171},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0047, (cst_val *)&val_5745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5748 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0051, (cst_val *)&val_0232},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0052, (cst_val *)&val_0193},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0053, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5750 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0056, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5751 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0058, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5753 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0061, (cst_val *)&val_0060},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0062, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0063, (cst_val *)&val_0569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5755 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0066, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5756 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0068, (cst_val *)&val_5757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5759 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0071, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5761 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0074, (cst_val *)&val_0539},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0075, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0076, (cst_val *)&val_5762},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0077, (cst_val *)&val_0989},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0078, (cst_val *)&val_0145},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0079, (cst_val *)&val_5763},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0080, (cst_val *)&val_5764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5766 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0083, (cst_val *)&val_3319},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5770 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0088, (cst_val *)&val_1527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5771 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0090, (cst_val *)&val_0068},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0091, (cst_val *)&val_5772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5775 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0095, (cst_val *)&val_5776},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0096, (cst_val *)&val_0060},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0097, (cst_val *)&val_5777},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5780 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0101, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5782 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0104, (cst_val *)&val_5783},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0105, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5784 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0107, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0108, (cst_val *)&val_5785},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0109, (cst_val *)&val_1993},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0110, (cst_val *)&val_2584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5789 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0115, (cst_val *)&val_5790},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0116, (cst_val *)&val_2014},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0117, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5792 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0120, (cst_val *)&val_5793},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0121, (cst_val *)&val_0888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5796 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0125, (cst_val *)&val_3762},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_dh_53_NO_0126, (cst_val *)&val_5797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5801 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_dh_53_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.n.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_dh_53_cart = {
  cmu_us_rms_single_mcep_dh_53_cart_nodes,
  cmu_us_rms_single_mcep_dh_53_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_d_46_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0000, (cst_val *)&val_2959},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0002, (cst_val *)&val_5802},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0003, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0004, (cst_val *)&val_0015},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0005, (cst_val *)&val_5803},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0006, (cst_val *)&val_5804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5806 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0009, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5808 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0012, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5810 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0015, (cst_val *)&val_0026},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0016, (cst_val *)&val_2423},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0017, (cst_val *)&val_2723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5812 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0020, (cst_val *)&val_5813},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0021, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5816 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0025, (cst_val *)&val_5817},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0026, (cst_val *)&val_5818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5820 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0029, (cst_val *)&val_0973},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0030, (cst_val *)&val_5813},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0031, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5821 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0033, (cst_val *)&val_3246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5824 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0037, (cst_val *)&val_5825},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5827 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0040, (cst_val *)&val_5828},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0041, (cst_val *)&val_0043},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0042, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5829 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0044, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5831 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0047, (cst_val *)&val_5832},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5833 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0049, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5835 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0052, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5837 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0055, (cst_val *)&val_0183},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0056, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0057, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5839 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0060, (cst_val *)&val_0026},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0061, (cst_val *)&val_0056},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0062, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5840 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0064, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5842 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0067, (cst_val *)&val_5843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5844 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0069, (cst_val *)&val_5845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5847 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0072, (cst_val *)&val_0973},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0073, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5848 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0075, (cst_val *)&val_1363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5850 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0078, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5851 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0080, (cst_val *)&val_4891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5853 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0083, (cst_val *)&val_0505},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0084, (cst_val *)&val_5854},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0085, (cst_val *)&val_0073},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0086, (cst_val *)&val_5855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5859 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0091, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5860 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0093, (cst_val *)&val_0013},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0094, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5862 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0097, (cst_val *)&val_5863},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0098, (cst_val *)&val_5864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5865 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0100, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5868 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0104, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0105, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0106, (cst_val *)&val_5869},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0107, (cst_val *)&val_0056},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0108, (cst_val *)&val_3669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5871 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0111, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0112, (cst_val *)&val_1602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5873 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0115, (cst_val *)&val_5874},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0116, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5877 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0120, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5879 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0123, (cst_val *)&val_0231},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0124, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5880 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0126, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5881 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0128, (cst_val *)&val_0569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5882 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0130, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5884 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0133, (cst_val *)&val_5885},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0134, (cst_val *)&val_5886},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0135, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5887 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0137, (cst_val *)&val_5888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5891 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0141, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5893 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0144, (cst_val *)&val_0183},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0145, (cst_val *)&val_5894},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0146, (cst_val *)&val_0199},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0147, (cst_val *)&val_0236},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0148, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5895 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0150, (cst_val *)&val_0841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5897 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0153, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5899 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0156, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5900 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0158, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5903 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0162, (cst_val *)&val_5904},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0163, (cst_val *)&val_0505},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0164, (cst_val *)&val_3828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5906 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0167, (cst_val *)&val_3419},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0168, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5908 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0171, (cst_val *)&val_0799},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0172, (cst_val *)&val_2564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5911 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0176, (cst_val *)&val_0024},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0177, (cst_val *)&val_0417},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_46_NO_0178, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5915 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_d_46_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_d_46_cart = {
  cmu_us_rms_single_mcep_d_46_cart_nodes,
  cmu_us_rms_single_mcep_d_46_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_d_47_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0000, (cst_val *)&val_1383},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0001, (cst_val *)&val_0171},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0002, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0003, (cst_val *)&val_5916},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0004, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5917 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0006, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5919 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0009, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5921 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0012, (cst_val *)&val_0978},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0013, (cst_val *)&val_5922},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0014, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0015, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5924 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0018, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5925 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0020, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5927 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0023, (cst_val *)&val_0183},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0024, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5929 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0027, (cst_val *)&val_5930},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0028, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5933 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0032, (cst_val *)&val_5934},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0033, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5935 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0035, (cst_val *)&val_5936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5937 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0037, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5938 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0039, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5940 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0042, (cst_val *)&val_0165},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0043, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5942 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0046, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0047, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5945 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0051, (cst_val *)&val_5946},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0052, (cst_val *)&val_5947},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0053, (cst_val *)&val_5948},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0054, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5949 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0056, (cst_val *)&val_5950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5952 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0059, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0060, (cst_val *)&val_0059},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0061, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5954 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0064, (cst_val *)&val_5955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5958 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0068, (cst_val *)&val_0043},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0069, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5959 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0071, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0072, (cst_val *)&val_0040},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0073, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5963 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0078, (cst_val *)&val_0059},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0079, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5965 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0082, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0083, (cst_val *)&val_0003},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0084, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5969 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0089, (cst_val *)&val_0040},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0090, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5971 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0093, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5972 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0095, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5974 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0098, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0099, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5976 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0102, (cst_val *)&val_5977},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0103, (cst_val *)&val_0059},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0104, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5978 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0106, (cst_val *)&val_0629},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0107, (cst_val *)&val_3445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5980 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0110, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5982 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0113, (cst_val *)&val_5983},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0114, (cst_val *)&val_5095},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0115, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5984 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0117, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5986 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0120, (cst_val *)&val_5987},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0121, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5990 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0125, (cst_val *)&val_1864},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0126, (cst_val *)&val_5991},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0127, (cst_val *)&val_0297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5993 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0130, (cst_val *)&val_0043},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0131, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5995 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0134, (cst_val *)&val_5996},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0135, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6000 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0140, (cst_val *)&val_0018},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0141, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6001 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0143, (cst_val *)&val_6002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6003 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_47_NO_0145, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6006 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_d_47_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_d_47_cart = {
  cmu_us_rms_single_mcep_d_47_cart_nodes,
  cmu_us_rms_single_mcep_d_47_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_d_48_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0000, (cst_val *)&val_0171},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0001, (cst_val *)&val_6007},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0002, (cst_val *)&val_0056},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0003, (cst_val *)&val_5934},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0004, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0005, (cst_val *)&val_6008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0006, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6010 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0009, (cst_val *)&val_6011},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0010, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6014 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0014, (cst_val *)&val_0219},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0015, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0016, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6017 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0020, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0021, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6020 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0025, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6021 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0027, (cst_val *)&val_0045},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6023 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0031, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6025 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0034, (cst_val *)&val_4152},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0035, (cst_val *)&val_5934},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0036, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0037, (cst_val *)&val_6026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6027 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0039, (cst_val *)&val_6028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6030 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0042, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6031 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0044, (cst_val *)&val_6032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0045, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6035 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0049, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6036 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0051, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6037 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0053, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6039 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0056, (cst_val *)&val_6040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0057, (cst_val *)&val_6041},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0058, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6043 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0061, (cst_val *)&val_6044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6045 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0063, (cst_val *)&val_6046},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0064, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6049 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0068, (cst_val *)&val_3486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6051 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0071, (cst_val *)&val_0059},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0072, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6052 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0074, (cst_val *)&val_0760},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0075, (cst_val *)&val_6053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6056 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0079, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6057 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0081, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6058 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0083, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6060 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0086, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0087, (cst_val *)&val_6061},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0088, (cst_val *)&val_0569},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0089, (cst_val *)&val_6062},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0090, (cst_val *)&val_0760},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0091, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6063 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0093, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6065 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0096, (cst_val *)&val_6066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6067 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0098, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6069 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0101, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6070 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0103, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6071 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0105, (cst_val *)&val_0183},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0106, (cst_val *)&val_3167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6074 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0110, (cst_val *)&val_0165},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0111, (cst_val *)&val_0459},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0112, (cst_val *)&val_6075},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0113, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6076 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0115, (cst_val *)&val_6077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6078 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0117, (cst_val *)&val_0362},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0118, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6079 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0120, (cst_val *)&val_6080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6083 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0124, (cst_val *)&val_6084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6087 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0128, (cst_val *)&val_6088},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0129, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6091 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0133, (cst_val *)&val_0132},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0134, (cst_val *)&val_0220},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0135, (cst_val *)&val_5863},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6093 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0138, (cst_val *)&val_3828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6094 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0140, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6096 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0143, (cst_val *)&val_0074},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0144, (cst_val *)&val_6097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6100 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0148, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0149, (cst_val *)&val_0015},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0150, (cst_val *)&val_0191},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0151, (cst_val *)&val_0774},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0152, (cst_val *)&val_6101},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0153, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6103 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0156, (cst_val *)&val_6104},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0157, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6105 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0159, (cst_val *)&val_2503},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0160, (cst_val *)&val_6106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6108 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0163, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6110 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0166, (cst_val *)&val_0723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6111 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0168, (cst_val *)&val_6112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6114 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0171, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6115 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0173, (cst_val *)&val_6116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6118 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0176, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0177, (cst_val *)&val_0723},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0178, (cst_val *)&val_5252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6120 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0181, (cst_val *)&val_5376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6122 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0184, (cst_val *)&val_0320},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0185, (cst_val *)&val_2919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6124 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0188, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6126 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0191, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6127 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0193, (cst_val *)&val_6128},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0194, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6131 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0198, (cst_val *)&val_6132},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0199, (cst_val *)&val_0403},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0200, (cst_val *)&val_0933},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0201, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6134 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0204, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6136 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0207, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6137 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0209, (cst_val *)&val_4592},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0210, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6138 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0212, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6139 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0214, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6142 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0218, (cst_val *)&val_0626},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0219, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6143 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_d_48_NO_0221, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6146 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_d_48_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_rms_single_mcep_d_48_cart = {
  cmu_us_rms_single_mcep_d_48_cart_nodes,
  cmu_us_rms_single_mcep_d_48_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_n_116_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0001, (cst_val *)&val_0358},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0002, (cst_val *)&val_6147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0003, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6149 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0006, (cst_val *)&val_0088},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0007, (cst_val *)&val_1158},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0008, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6152 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0012, (cst_val *)&val_6153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6155 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0015, (cst_val *)&val_6156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6158 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0018, (cst_val *)&val_1627},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0019, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0020, (cst_val *)&val_2670},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0021, (cst_val *)&val_0043},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0022, (cst_val *)&val_0040},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0023, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6160 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0026, (cst_val *)&val_0010},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0027, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0028, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0029, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6162 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0032, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6164 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0035, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6166 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0038, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6168 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0041, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6169 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0043, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0044, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6172 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0048, (cst_val *)&val_0361},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0049, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6173 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0051, (cst_val *)&val_0040},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0052, (cst_val *)&val_6174},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6177 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0056, (cst_val *)&val_6178},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0057, (cst_val *)&val_6179},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0058, (cst_val *)&val_6180},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0059, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6181 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0061, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6184 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0065, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6186 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0068, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6187 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0070, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6189 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0073, (cst_val *)&val_6190},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0074, (cst_val *)&val_0040},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0075, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6192 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0078, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0079, (cst_val *)&val_0025},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0080, (cst_val *)&val_0982},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0081, (cst_val *)&val_1618},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0082, (cst_val *)&val_6193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6196 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0086, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6198 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0089, (cst_val *)&val_0629},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0090, (cst_val *)&val_2640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6200 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0093, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6201 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0095, (cst_val *)&val_2312},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0096, (cst_val *)&val_6202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6203 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0098, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6207 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0103, (cst_val *)&val_2164},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0104, (cst_val *)&val_0251},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0105, (cst_val *)&val_0251},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0106, (cst_val *)&val_6208},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0107, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0108, (cst_val *)&val_6209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6210 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0110, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6213 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0114, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6215 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0117, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6216 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0119, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6218 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0122, (cst_val *)&val_5355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6219 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0124, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6220 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0126, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6222 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0129, (cst_val *)&val_0251},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0130, (cst_val *)&val_6223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6224 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0132, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6225 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0134, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6226 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0136, (cst_val *)&val_0388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6228 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0139, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6230 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0142, (cst_val *)&val_0489},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0143, (cst_val *)&val_0919},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0144, (cst_val *)&val_0142},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0145, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0146, (cst_val *)&val_0025},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0147, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6232 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0150, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6234 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0153, (cst_val *)&val_0056},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0154, (cst_val *)&val_0008},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0155, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6235 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0157, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6237 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0160, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6238 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0162, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6239 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0164, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6241 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0167, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6242 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0169, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6245 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0173, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6246 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0175, (cst_val *)&val_6247},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0176, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6248 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0178, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6251 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0182, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0183, (cst_val *)&val_6252},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0184, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0185, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6253 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0187, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6254 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0189, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6256 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0192, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6257 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0194, (cst_val *)&val_0008},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0195, (cst_val *)&val_6258},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0196, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6260 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0199, (cst_val *)&val_6261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6263 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0202, (cst_val *)&val_3981},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0203, (cst_val *)&val_6264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6266 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0206, (cst_val *)&val_6267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6269 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0209, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0210, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6270 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0212, (cst_val *)&val_0361},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0213, (cst_val *)&val_0603},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0214, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6273 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0218, (cst_val *)&val_3486},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0219, (cst_val *)&val_0956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6276 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0223, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0224, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6278 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0227, (cst_val *)&val_6279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6280 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0229, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6282 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0232, (cst_val *)&val_0297},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0233, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0234, (cst_val *)&val_6283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6284 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0236, (cst_val *)&val_0008},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0237, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6286 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0240, (cst_val *)&val_6287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6289 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0243, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0244, (cst_val *)&val_6290},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0245, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0246, (cst_val *)&val_3000},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0247, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6293 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0251, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6296 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0255, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6297 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0257, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6298 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0259, (cst_val *)&val_6299},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0260, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0261, (cst_val *)&val_6300},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0262, (cst_val *)&val_3412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6301 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0264, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6304 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0268, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6307 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0272, (cst_val *)&val_6308},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0273, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0274, (cst_val *)&val_0077},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0275, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6311 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0279, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0280, (cst_val *)&val_0251},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0281, (cst_val *)&val_0068},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0282, (cst_val *)&val_1545},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0283, (cst_val *)&val_4332},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0284, (cst_val *)&val_6312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6316 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0289, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0290, (cst_val *)&val_0489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6317 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0292, (cst_val *)&val_4323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6319 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0295, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6321 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0298, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6323 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0301, (cst_val *)&val_4391},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0302, (cst_val *)&val_6324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6325 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0304, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6327 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0307, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6329 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0310, (cst_val *)&val_6330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6331 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_116_NO_0312, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6333 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_n_116_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_n_116_cart = {
  cmu_us_rms_single_mcep_n_116_cart_nodes,
  cmu_us_rms_single_mcep_n_116_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_n_117_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0001, (cst_val *)&val_1038},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0002, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0003, (cst_val *)&val_2626},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0004, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0005, (cst_val *)&val_6334},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6335 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0007, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6336 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0009, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6337 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0011, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0012, (cst_val *)&val_6338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6341 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0016, (cst_val *)&val_0220},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0017, (cst_val *)&val_0056},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0018, (cst_val *)&val_6342},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6345 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0022, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6347 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0025, (cst_val *)&val_1213},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0026, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6348 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0028, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6350 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0031, (cst_val *)&val_3806},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0032, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6352 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0035, (cst_val *)&val_6353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6355 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0038, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0039, (cst_val *)&val_6002},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0040, (cst_val *)&val_0220},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0041, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6357 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0044, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6359 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0047, (cst_val *)&val_0161},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0048, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6362 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0052, (cst_val *)&val_0043},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0053, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6363 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0055, (cst_val *)&val_6364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6365 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0057, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6367 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0060, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0061, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0062, (cst_val *)&val_6368},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6372 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0067, (cst_val *)&val_6373},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0068, (cst_val *)&val_6374},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0069, (cst_val *)&val_0040},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0070, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6376 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0073, (cst_val *)&val_6377},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0074, (cst_val *)&val_6378},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0075, (cst_val *)&val_6379},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0076, (cst_val *)&val_6380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6381 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0078, (cst_val *)&val_0025},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0079, (cst_val *)&val_6382},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6383 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0081, (cst_val *)&val_6384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6386 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0084, (cst_val *)&val_0040},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0085, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6387 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0087, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6390 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0091, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6392 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0094, (cst_val *)&val_0246},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0095, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6393 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0097, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6396 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0101, (cst_val *)&val_4323},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0102, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6397 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0104, (cst_val *)&val_4077},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0105, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6401 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0110, (cst_val *)&val_1558},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0111, (cst_val *)&val_0015},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0112, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0113, (cst_val *)&val_0016},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0114, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6404 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0118, (cst_val *)&val_0246},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0119, (cst_val *)&val_0314},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6407 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0123, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6408 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0125, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6409 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0127, (cst_val *)&val_6410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6413 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0131, (cst_val *)&val_5105},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0132, (cst_val *)&val_6414},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0133, (cst_val *)&val_1857},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0134, (cst_val *)&val_6415},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0135, (cst_val *)&val_6416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6420 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0140, (cst_val *)&val_6421},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0141, (cst_val *)&val_0246},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0142, (cst_val *)&val_6422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6425 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0146, (cst_val *)&val_0007},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0147, (cst_val *)&val_6426},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0148, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6427 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0150, (cst_val *)&val_4546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6428 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0152, (cst_val *)&val_6429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6433 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0157, (cst_val *)&val_6434},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0158, (cst_val *)&val_6435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6437 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0161, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0162, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6440 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0166, (cst_val *)&val_0145},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0167, (cst_val *)&val_1029},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0168, (cst_val *)&val_6441},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0169, (cst_val *)&val_0008},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0170, (cst_val *)&val_1756},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0171, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6444 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0175, (cst_val *)&val_0246},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0176, (cst_val *)&val_6445},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0177, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6446 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0179, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6448 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0182, (cst_val *)&val_0165},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0183, (cst_val *)&val_6449},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0184, (cst_val *)&val_6450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6453 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0188, (cst_val *)&val_0251},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0189, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6456 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0193, (cst_val *)&val_6457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6459 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0196, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0197, (cst_val *)&val_0785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6461 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0200, (cst_val *)&val_6462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6464 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0203, (cst_val *)&val_1386},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0204, (cst_val *)&val_0651},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0205, (cst_val *)&val_0868},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0206, (cst_val *)&val_6465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6467 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0209, (cst_val *)&val_0973},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0210, (cst_val *)&val_0120},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0211, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6469 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0214, (cst_val *)&val_0045},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0215, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6472 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0219, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6473 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0221, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6475 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0224, (cst_val *)&val_0040},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0225, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0226, (cst_val *)&val_6476},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0227, (cst_val *)&val_6477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6479 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0230, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6481 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0233, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0234, (cst_val *)&val_6482},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6483 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0236, (cst_val *)&val_0068},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0237, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6484 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0239, (cst_val *)&val_1602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6487 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0243, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6488 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0245, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6490 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0248, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6491 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0250, (cst_val *)&val_0629},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0251, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6493 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0254, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6495 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0257, (cst_val *)&val_0008},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0258, (cst_val *)&val_1448},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0259, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6497 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0262, (cst_val *)&val_0068},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0263, (cst_val *)&val_0251},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0264, (cst_val *)&val_6498},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0265, (cst_val *)&val_6499},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0266, (cst_val *)&val_6500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6503 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0270, (cst_val *)&val_0975},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0271, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6506 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0275, (cst_val *)&val_6507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6509 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0278, (cst_val *)&val_4168},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0279, (cst_val *)&val_0629},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0280, (cst_val *)&val_6510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6512 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0283, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6514 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0286, (cst_val *)&val_6515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6516 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0288, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6518 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0291, (cst_val *)&val_6519},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0292, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0293, (cst_val *)&val_0629},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0294, (cst_val *)&val_0888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6522 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0298, (cst_val *)&val_0745},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0299, (cst_val *)&val_6523},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0300, (cst_val *)&val_6524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6526 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0303, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6528 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0306, (cst_val *)&val_6529},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0307, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6530 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0309, (cst_val *)&val_6531},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0310, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6533 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0313, (cst_val *)&val_0361},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0314, (cst_val *)&val_6534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6535 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0316, (cst_val *)&val_6536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6538 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0319, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6540 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0322, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6542 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0325, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0326, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0327, (cst_val *)&val_6543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6546 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0331, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6547 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0333, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6548 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0335, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6550 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0338, (cst_val *)&val_2626},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0339, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0340, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0341, (cst_val *)&val_6551},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0342, (cst_val *)&val_2345},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0343, (cst_val *)&val_0868},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0344, (cst_val *)&val_1778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6555 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0349, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6556 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0351, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6558 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0354, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6559 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0356, (cst_val *)&val_0010},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0357, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6561 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0360, (cst_val *)&val_0251},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0361, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6564 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0365, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6566 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0368, (cst_val *)&val_0045},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0369, (cst_val *)&val_0251},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0370, (cst_val *)&val_6308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6568 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0373, (cst_val *)&val_0220},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0374, (cst_val *)&val_1158},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0375, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6569 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0377, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6570 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0379, (cst_val *)&val_0059},
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0380, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6572 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0383, (cst_val *)&val_6573},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6577 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0388, (cst_val *)&val_0008},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0389, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6579 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0392, (cst_val *)&val_6580},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0393, (cst_val *)&val_6581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6582 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0395, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6583 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0397, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6585 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0400, (cst_val *)&val_6193},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0401, (cst_val *)&val_0914},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0402, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6587 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0405, (cst_val *)&val_6588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6590 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0408, (cst_val *)&val_0251},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_117_NO_0409, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6593 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_n_117_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_n_117_cart = {
  cmu_us_rms_single_mcep_n_117_cart_nodes,
  cmu_us_rms_single_mcep_n_117_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_n_118_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0002, (cst_val *)&val_0039},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0003, (cst_val *)&val_0056},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0004, (cst_val *)&val_0919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6595 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0007, (cst_val *)&val_5785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6596 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0009, (cst_val *)&val_6597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6598 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0011, (cst_val *)&val_1168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6600 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0014, (cst_val *)&val_4692},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0015, (cst_val *)&val_0693},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0016, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6601 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0018, (cst_val *)&val_6602},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0019, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6604 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0022, (cst_val *)&val_6605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6606 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0024, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6608 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0027, (cst_val *)&val_6609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6612 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0031, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0032, (cst_val *)&val_0239},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0033, (cst_val *)&val_0120},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0034, (cst_val *)&val_2893},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0035, (cst_val *)&val_6613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6615 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0038, (cst_val *)&val_6616},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0039, (cst_val *)&val_0692},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6618 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0042, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6619 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0044, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6621 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0047, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6622 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0049, (cst_val *)&val_6623},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0050, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6626 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0054, (cst_val *)&val_2670},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0055, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6627 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0057, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6630 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0061, (cst_val *)&val_4651},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0062, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6631 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0064, (cst_val *)&val_6632},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0065, (cst_val *)&val_1445},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0066, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6635 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0070, (cst_val *)&val_0040},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0071, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0072, (cst_val *)&val_3547},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0073, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6637 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0076, (cst_val *)&val_0626},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0077, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6640 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0081, (cst_val *)&val_1618},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0082, (cst_val *)&val_1194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6642 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0085, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6644 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0088, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6645 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0090, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6648 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0094, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0095, (cst_val *)&val_0251},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0096, (cst_val *)&val_6649},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0097, (cst_val *)&val_6650},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0098, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6652 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0101, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6654 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0104, (cst_val *)&val_1965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6656 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0107, (cst_val *)&val_0056},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0108, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6657 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0110, (cst_val *)&val_0692},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0111, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6659 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0114, (cst_val *)&val_1139},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0115, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6661 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0118, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6663 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0121, (cst_val *)&val_0008},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0122, (cst_val *)&val_0010},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0123, (cst_val *)&val_2588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6665 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0126, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6667 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0129, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0130, (cst_val *)&val_0008},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0131, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6669 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0134, (cst_val *)&val_1383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6671 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0137, (cst_val *)&val_1778},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0138, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6673 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0141, (cst_val *)&val_1634},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0142, (cst_val *)&val_6674},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0143, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6676 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0146, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6679 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0150, (cst_val *)&val_6680},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0151, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0152, (cst_val *)&val_0715},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0153, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6683 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0157, (cst_val *)&val_5863},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0158, (cst_val *)&val_6684},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0159, (cst_val *)&val_6685},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0160, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6687 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0163, (cst_val *)&val_6688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6690 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0166, (cst_val *)&val_0008},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0167, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6692 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0170, (cst_val *)&val_0019},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0171, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6695 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0175, (cst_val *)&val_0256},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0176, (cst_val *)&val_6696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6699 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0180, (cst_val *)&val_0125},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0181, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6700 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0183, (cst_val *)&val_6701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6703 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0186, (cst_val *)&val_0714},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0187, (cst_val *)&val_6704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6706 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0190, (cst_val *)&val_6707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6708 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0192, (cst_val *)&val_0251},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0193, (cst_val *)&val_0043},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0194, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6709 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0196, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6710 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0198, (cst_val *)&val_2959},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0199, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6711 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0201, (cst_val *)&val_6712},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6714 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0204, (cst_val *)&val_6715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6716 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0206, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6719 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0210, (cst_val *)&val_0651},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0211, (cst_val *)&val_0068},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0212, (cst_val *)&val_1533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6721 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0215, (cst_val *)&val_0077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0216, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6724 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_n_118_NO_0220, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6726 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_n_118_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_rms_single_mcep_n_118_cart = {
  cmu_us_rms_single_mcep_n_118_cart_nodes,
  cmu_us_rms_single_mcep_n_118_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_jh_96_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0000, (cst_val *)&val_0010},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0001, (cst_val *)&val_0043},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0002, (cst_val *)&val_1816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6727 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0004, (cst_val *)&val_6728},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0005, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6730 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0008, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6732 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0011, (cst_val *)&val_5419},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6733 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0013, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0014, (cst_val *)&val_3233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6735 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0017, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6737 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0020, (cst_val *)&val_0539},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0021, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0022, (cst_val *)&val_6738},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0023, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6741 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0027, (cst_val *)&val_0975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6743 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0030, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0031, (cst_val *)&val_0841},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0032, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6746 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0036, (cst_val *)&val_0539},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0037, (cst_val *)&val_5793},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0038, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6748 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_96_NO_0041, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6751 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_jh_96_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_single_mcep_jh_96_cart = {
  cmu_us_rms_single_mcep_jh_96_cart_nodes,
  cmu_us_rms_single_mcep_jh_96_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_jh_97_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0000, (cst_val *)&val_1386},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0001, (cst_val *)&val_0056},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0002, (cst_val *)&val_6752},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0003, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6755 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0007, (cst_val *)&val_0043},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0008, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0009, (cst_val *)&val_6756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6759 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0013, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6760 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0015, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0016, (cst_val *)&val_4782},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0017, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6762 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0020, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6765 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0024, (cst_val *)&val_6766},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0025, (cst_val *)&val_0799},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0026, (cst_val *)&val_0015},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0027, (cst_val *)&val_6767},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0028, (cst_val *)&val_6768},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0029, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6771 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0033, (cst_val *)&val_6772},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0034, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6773 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0036, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6775 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0039, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6777 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0042, (cst_val *)&val_0251},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0043, (cst_val *)&val_0251},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0044, (cst_val *)&val_6778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6779 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0046, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0047, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6783 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0052, (cst_val *)&val_6784},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0053, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6786 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0056, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6787 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0058, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6790 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0062, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0063, (cst_val *)&val_0145},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0064, (cst_val *)&val_1799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6791 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0066, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6793 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0069, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6795 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6796 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_97_NO_0074, (cst_val *)&val_6797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6799 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_jh_97_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_single_mcep_jh_97_cart = {
  cmu_us_rms_single_mcep_jh_97_cart_nodes,
  cmu_us_rms_single_mcep_jh_97_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_jh_98_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0001, (cst_val *)&val_2661},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0002, (cst_val *)&val_1594},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0003, (cst_val *)&val_2637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6800 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0005, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6802 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0008, (cst_val *)&val_0973},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0009, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6804 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0012, (cst_val *)&val_6805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6807 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0015, (cst_val *)&val_1799},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0016, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6808 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0018, (cst_val *)&val_3627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6810 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0021, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6811 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0023, (cst_val *)&val_0029},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0024, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6812 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0026, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6813 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0028, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6816 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0032, (cst_val *)&val_6817},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0033, (cst_val *)&val_6818},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0034, (cst_val *)&val_6819},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0035, (cst_val *)&val_1815},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6822 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0039, (cst_val *)&val_6823},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0040, (cst_val *)&val_2088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6826 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_jh_98_NO_0044, (cst_val *)&val_4202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6828 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_jh_98_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_single_mcep_jh_98_cart = {
  cmu_us_rms_single_mcep_jh_98_cart_nodes,
  cmu_us_rms_single_mcep_jh_98_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_r_146_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0001, (cst_val *)&val_1383},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0002, (cst_val *)&val_0043},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0003, (cst_val *)&val_0417},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0004, (cst_val *)&val_0404},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6829 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0006, (cst_val *)&val_0388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6831 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0009, (cst_val *)&val_1232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0010, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6833 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0013, (cst_val *)&val_0056},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0014, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6834 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0016, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6835 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0018, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6837 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0021, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6838 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0023, (cst_val *)&val_6839},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6841 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0026, (cst_val *)&val_0251},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0027, (cst_val *)&val_1994},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0028, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6844 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0032, (cst_val *)&val_0008},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0033, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6846 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0036, (cst_val *)&val_6847},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0037, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6849 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0040, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6851 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0043, (cst_val *)&val_0015},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0044, (cst_val *)&val_0251},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0045, (cst_val *)&val_0246},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0046, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6852 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0048, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6854 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0051, (cst_val *)&val_6855},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0052, (cst_val *)&val_0008},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0053, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6858 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0057, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6860 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0060, (cst_val *)&val_0008},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0061, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6862 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0064, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6863 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0066, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6864 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0068, (cst_val *)&val_4240},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0069, (cst_val *)&val_6865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6868 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0073, (cst_val *)&val_0671},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0074, (cst_val *)&val_0251},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0075, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6869 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0077, (cst_val *)&val_4302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6870 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0079, (cst_val *)&val_2345},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0080, (cst_val *)&val_6871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6872 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0082, (cst_val *)&val_6873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6876 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0086, (cst_val *)&val_6877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6879 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0089, (cst_val *)&val_4668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6881 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0092, (cst_val *)&val_0251},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0093, (cst_val *)&val_6882},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0094, (cst_val *)&val_6883},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0095, (cst_val *)&val_1194},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0096, (cst_val *)&val_6434},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0097, (cst_val *)&val_0165},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0098, (cst_val *)&val_6884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6887 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0102, (cst_val *)&val_0008},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0103, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6888 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0105, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6891 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0109, (cst_val *)&val_0040},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0110, (cst_val *)&val_0068},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0111, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6894 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0115, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6895 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0117, (cst_val *)&val_0311},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0118, (cst_val *)&val_0165},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0119, (cst_val *)&val_0328},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0120, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6900 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0126, (cst_val *)&val_6901},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0127, (cst_val *)&val_0045},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0128, (cst_val *)&val_6902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6904 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0131, (cst_val *)&val_0040},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0132, (cst_val *)&val_6905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6906 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0134, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6909 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0138, (cst_val *)&val_2164},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0139, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6910 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0141, (cst_val *)&val_0040},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0142, (cst_val *)&val_6911},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6914 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0146, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6916 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0149, (cst_val *)&val_1331},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0150, (cst_val *)&val_0361},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0151, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6917 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0153, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6918 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0155, (cst_val *)&val_6919},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0156, (cst_val *)&val_1020},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0157, (cst_val *)&val_1749},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0158, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6922 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0162, (cst_val *)&val_6923},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0163, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6927 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0168, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6928 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0170, (cst_val *)&val_4084},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0171, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0172, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6930 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0175, (cst_val *)&val_6931},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0176, (cst_val *)&val_3617},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0177, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6935 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0182, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6937 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0185, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6938 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0187, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6939 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0189, (cst_val *)&val_4084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6940 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0191, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6942 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0194, (cst_val *)&val_6943},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0195, (cst_val *)&val_0251},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0196, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0197, (cst_val *)&val_3702},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0198, (cst_val *)&val_4084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6946 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0202, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6947 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0204, (cst_val *)&val_0246},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0205, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6949 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0208, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6951 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0211, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6952 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0213, (cst_val *)&val_0056},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0214, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6954 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0217, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6956 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0220, (cst_val *)&val_0040},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0221, (cst_val *)&val_0068},
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0222, (cst_val *)&val_0125},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0223, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6957 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0225, (cst_val *)&val_4084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6959 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0228, (cst_val *)&val_6960},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6962 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0231, (cst_val *)&val_6963},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0232, (cst_val *)&val_0040},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0233, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6965 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0236, (cst_val *)&val_5310},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0237, (cst_val *)&val_3475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6968 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0241, (cst_val *)&val_6969},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0242, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6972 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0246, (cst_val *)&val_0251},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0247, (cst_val *)&val_1223},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0248, (cst_val *)&val_0145},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0249, (cst_val *)&val_0008},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0250, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6976 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0255, (cst_val *)&val_0361},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0256, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6977 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0258, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6978 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0260, (cst_val *)&val_6979},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0261, (cst_val *)&val_4765},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6981 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0264, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6983 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0267, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0268, (cst_val *)&val_3810},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0269, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6985 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0272, (cst_val *)&val_0829},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0273, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6987 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0276, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6989 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0279, (cst_val *)&val_0505},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0280, (cst_val *)&val_0332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6991 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0283, (cst_val *)&val_4862},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0284, (cst_val *)&val_0403},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0285, (cst_val *)&val_6992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6996 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0290, (cst_val *)&val_0046},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0291, (cst_val *)&val_0358},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0292, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6998 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0295, (cst_val *)&val_6999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7001 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0298, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0299, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7002 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0301, (cst_val *)&val_1383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7004 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0304, (cst_val *)&val_7005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7006 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_146_NO_0306, (cst_val *)&val_7007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7009 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_r_146_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_r_146_cart = {
  cmu_us_rms_single_mcep_r_146_cart_nodes,
  cmu_us_rms_single_mcep_r_146_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_r_147_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0001, (cst_val *)&val_1610},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0003, (cst_val *)&val_0403},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0004, (cst_val *)&val_7010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7012 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0007, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0008, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7014 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0011, (cst_val *)&val_0183},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0012, (cst_val *)&val_7015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7017 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0015, (cst_val *)&val_0013},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0016, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7018 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0018, (cst_val *)&val_7019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7021 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0021, (cst_val *)&val_0051},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0022, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7023 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0025, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7025 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0028, (cst_val *)&val_7026},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0029, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0030, (cst_val *)&val_0239},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0031, (cst_val *)&val_0068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0032, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7027 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0034, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7029 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0037, (cst_val *)&val_0251},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0038, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7030 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0040, (cst_val *)&val_0020},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0041, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7033 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0045, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7035 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0048, (cst_val *)&val_5243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7036 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0050, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7037 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0052, (cst_val *)&val_0888},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0053, (cst_val *)&val_7038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7040 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0056, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7042 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0059, (cst_val *)&val_7043},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0060, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7045 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0063, (cst_val *)&val_0642},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0064, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7047 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0067, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7049 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0070, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7051 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0073, (cst_val *)&val_0361},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0074, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0075, (cst_val *)&val_7052},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0076, (cst_val *)&val_3616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7055 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0080, (cst_val *)&val_7056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7057 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7059 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0085, (cst_val *)&val_7060},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0086, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7061 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0088, (cst_val *)&val_0045},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0089, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7063 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0092, (cst_val *)&val_7064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0093, (cst_val *)&val_7065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7067 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0096, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7068 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0098, (cst_val *)&val_1922},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0099, (cst_val *)&val_7069},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0100, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7071 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0103, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7074 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0107, (cst_val *)&val_7075},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0108, (cst_val *)&val_0125},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0109, (cst_val *)&val_0068},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0110, (cst_val *)&val_1545},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0111, (cst_val *)&val_1683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7076 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0113, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7079 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0117, (cst_val *)&val_7080},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0118, (cst_val *)&val_7081},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0119, (cst_val *)&val_7082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7083 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0121, (cst_val *)&val_7084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7086 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0124, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7088 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0127, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0128, (cst_val *)&val_0318},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0129, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7092 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0134, (cst_val *)&val_1594},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0135, (cst_val *)&val_7093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7095 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0138, (cst_val *)&val_3547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7097 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0141, (cst_val *)&val_7098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7099 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0143, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7100 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0145, (cst_val *)&val_7101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7103 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0148, (cst_val *)&val_0008},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0149, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0150, (cst_val *)&val_0651},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0151, (cst_val *)&val_0045},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0152, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7105 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0155, (cst_val *)&val_0651},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0156, (cst_val *)&val_0056},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0157, (cst_val *)&val_1163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7107 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0160, (cst_val *)&val_7108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7109 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0162, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7111 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0165, (cst_val *)&val_0125},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0166, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7113 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0169, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7115 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0172, (cst_val *)&val_5077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0173, (cst_val *)&val_7116},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0174, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7119 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0178, (cst_val *)&val_7120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7121 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0180, (cst_val *)&val_7122},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0181, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7125 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0185, (cst_val *)&val_1213},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0186, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7126 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0188, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7129 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0192, (cst_val *)&val_0979},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0193, (cst_val *)&val_6002},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0194, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0195, (cst_val *)&val_7130},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0196, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7132 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0199, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7134 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0202, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7136 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0205, (cst_val *)&val_0008},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0206, (cst_val *)&val_7137},
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0207, (cst_val *)&val_0493},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0208, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7139 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0211, (cst_val *)&val_7140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7142 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0214, (cst_val *)&val_7143},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7144 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0216, (cst_val *)&val_7145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7147 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0219, (cst_val *)&val_5077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7148 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0221, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0222, (cst_val *)&val_0246},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0223, (cst_val *)&val_7149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7151 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0226, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7153 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0229, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0230, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7155 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0233, (cst_val *)&val_4651},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0234, (cst_val *)&val_7156},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0235, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7158 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0238, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7161 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0242, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0243, (cst_val *)&val_7162},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0244, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7164 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0247, (cst_val *)&val_7165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0248, (cst_val *)&val_0539},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0249, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0250, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7167 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0253, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7169 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0256, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7171 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0259, (cst_val *)&val_0637},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0260, (cst_val *)&val_7172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7175 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0264, (cst_val *)&val_7176},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0265, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0266, (cst_val *)&val_7177},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0267, (cst_val *)&val_5776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7179 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0270, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7181 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0273, (cst_val *)&val_0059},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0274, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7182 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0276, (cst_val *)&val_7183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7185 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0279, (cst_val *)&val_7186},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0280, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7188 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0283, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7189 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0285, (cst_val *)&val_0068},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0286, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7191 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_147_NO_0289, (cst_val *)&val_5776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7194 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_r_147_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_rms_single_mcep_r_147_cart = {
  cmu_us_rms_single_mcep_r_147_cart_nodes,
  cmu_us_rms_single_mcep_r_147_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_r_148_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0002, (cst_val *)&val_7195},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0003, (cst_val *)&val_4168},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0004, (cst_val *)&val_4007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7196 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0006, (cst_val *)&val_7197},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7199 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0009, (cst_val *)&val_7200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7201 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0011, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7202 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0013, (cst_val *)&val_1244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7203 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7204 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0017, (cst_val *)&val_7205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7207 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0020, (cst_val *)&val_0125},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0021, (cst_val *)&val_0361},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0022, (cst_val *)&val_7208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7211 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0026, (cst_val *)&val_0739},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0027, (cst_val *)&val_7212},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0028, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7214 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0031, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7216 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0034, (cst_val *)&val_0077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0035, (cst_val *)&val_1383},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0036, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7218 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0039, (cst_val *)&val_1462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7220 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0042, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7221 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0044, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7223 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0047, (cst_val *)&val_7224},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0048, (cst_val *)&val_7225},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0049, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7226 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0051, (cst_val *)&val_0024},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0052, (cst_val *)&val_0165},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0053, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7228 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0056, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7230 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0059, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7231 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0061, (cst_val *)&val_7232},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0062, (cst_val *)&val_7233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7235 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0065, (cst_val *)&val_7236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7238 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0068, (cst_val *)&val_7239},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0069, (cst_val *)&val_0165},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0070, (cst_val *)&val_1602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7241 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0073, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7243 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0076, (cst_val *)&val_5077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7244 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0078, (cst_val *)&val_7245},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7247 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0081, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0082, (cst_val *)&val_0693},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0083, (cst_val *)&val_7248},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0084, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7249 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0086, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7253 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0091, (cst_val *)&val_0068},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0092, (cst_val *)&val_3596},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0093, (cst_val *)&val_2876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7256 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0097, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0098, (cst_val *)&val_0008},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0099, (cst_val *)&val_5187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7258 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0102, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7259 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0104, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7261 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0107, (cst_val *)&val_0077},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0108, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7262 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0110, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7264 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0113, (cst_val *)&val_0760},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0114, (cst_val *)&val_0220},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0115, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7267 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0119, (cst_val *)&val_0073},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0120, (cst_val *)&val_2469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7270 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0124, (cst_val *)&val_0008},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0125, (cst_val *)&val_0125},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0126, (cst_val *)&val_0040},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0127, (cst_val *)&val_1355},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0128, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7272 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0131, (cst_val *)&val_7273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7275 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0134, (cst_val *)&val_1769},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0135, (cst_val *)&val_0012},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0136, (cst_val *)&val_2661},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0137, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7277 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0140, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7280 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0143, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7282 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0146, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7283 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0148, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7285 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0151, (cst_val *)&val_7286},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0152, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7287 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0154, (cst_val *)&val_7288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7290 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0157, (cst_val *)&val_0745},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0158, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7291 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0160, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7293 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0163, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7295 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0166, (cst_val *)&val_0025},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0167, (cst_val *)&val_0040},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0168, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0169, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7297 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0172, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7298 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0174, (cst_val *)&val_0692},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7300 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0177, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7302 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0180, (cst_val *)&val_0008},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0181, (cst_val *)&val_0165},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0182, (cst_val *)&val_7303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7304 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0184, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7306 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0187, (cst_val *)&val_1289},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0188, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7308 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0191, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7309 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0193, (cst_val *)&val_0870},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0194, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7312 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0198, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0199, (cst_val *)&val_7313},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0200, (cst_val *)&val_7314},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0201, (cst_val *)&val_0043},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0202, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7317 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0206, (cst_val *)&val_0914},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0207, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7319 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0210, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7320 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0212, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7322 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_r_148_NO_0215, (cst_val *)&val_7323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7326 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_r_148_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_r_148_cart = {
  cmu_us_rms_single_mcep_r_148_cart_nodes,
  cmu_us_rms_single_mcep_r_148_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ey_66_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0003, (cst_val *)&val_1994},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0004, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0005, (cst_val *)&val_4326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7330 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0010, (cst_val *)&val_0270},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0011, (cst_val *)&val_7331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7332 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0013, (cst_val *)&val_7333},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0014, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7335 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0017, (cst_val *)&val_7336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7338 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0020, (cst_val *)&val_7339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7341 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0023, (cst_val *)&val_0171},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0024, (cst_val *)&val_0403},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0025, (cst_val *)&val_1565},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0026, (cst_val *)&val_0730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7342 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0028, (cst_val *)&val_7343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7345 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0031, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7346 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0033, (cst_val *)&val_7347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7349 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0036, (cst_val *)&val_3256},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0037, (cst_val *)&val_7350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7352 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0040, (cst_val *)&val_0010},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0041, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7353 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0043, (cst_val *)&val_0056},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0044, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7354 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0046, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7356 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0049, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7357 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0051, (cst_val *)&val_7358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7359 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0053, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7361 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0056, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7363 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0059, (cst_val *)&val_0403},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0060, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0061, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7364 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0063, (cst_val *)&val_3419},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0064, (cst_val *)&val_7365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7368 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0068, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0069, (cst_val *)&val_0251},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0070, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7371 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0074, (cst_val *)&val_7372},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7373 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0076, (cst_val *)&val_7374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7376 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0079, (cst_val *)&val_0429},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0080, (cst_val *)&val_0183},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0081, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0082, (cst_val *)&val_7377},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0083, (cst_val *)&val_7378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7379 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0085, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7382 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0089, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7384 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0092, (cst_val *)&val_0040},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0093, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7385 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0095, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7387 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0098, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0099, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7389 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0102, (cst_val *)&val_0040},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0103, (cst_val *)&val_7390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7391 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0105, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7393 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0108, (cst_val *)&val_3509},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0109, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7395 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0112, (cst_val *)&val_0251},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0113, (cst_val *)&val_7396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7399 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0117, (cst_val *)&val_0193},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0118, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7400 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0120, (cst_val *)&val_7401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7403 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0123, (cst_val *)&val_7404},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7406 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0126, (cst_val *)&val_0128},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0127, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7407 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0129, (cst_val *)&val_0043},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0130, (cst_val *)&val_0068},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0131, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7409 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0134, (cst_val *)&val_0077},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0135, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7412 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0139, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7413 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0141, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7415 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0144, (cst_val *)&val_0183},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0145, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7416 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0147, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7418 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0150, (cst_val *)&val_0361},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0151, (cst_val *)&val_7419},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0152, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7421 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0155, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0156, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7424 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0160, (cst_val *)&val_0068},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0161, (cst_val *)&val_5095},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0162, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7425 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0164, (cst_val *)&val_7426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7429 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0168, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7430 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0170, (cst_val *)&val_7431},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0171, (cst_val *)&val_7432},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0172, (cst_val *)&val_1510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7434 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0175, (cst_val *)&val_4849},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7435 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_66_NO_0177, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7438 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ey_66_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_rms_single_mcep_ey_66_cart = {
  cmu_us_rms_single_mcep_ey_66_cart_nodes,
  cmu_us_rms_single_mcep_ey_66_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ey_67_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0000, (cst_val *)&val_7439},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0003, (cst_val *)&val_0079},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0004, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7440 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0006, (cst_val *)&val_4537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7443 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0010, (cst_val *)&val_7444},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0011, (cst_val *)&val_7445},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0012, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7449 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0017, (cst_val *)&val_0246},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0018, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7451 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0021, (cst_val *)&val_0860},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0022, (cst_val *)&val_7347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7452 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0024, (cst_val *)&val_7453},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0025, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0026, (cst_val *)&val_2557},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7457 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0031, (cst_val *)&val_7458},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0032, (cst_val *)&val_7459},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0033, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7461 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0036, (cst_val *)&val_4767},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0037, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7464 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0041, (cst_val *)&val_7465},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0042, (cst_val *)&val_7466},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0043, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7467 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0045, (cst_val *)&val_0059},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0046, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0047, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7469 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0050, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7471 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0053, (cst_val *)&val_0183},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0054, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7473 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0057, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7475 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0060, (cst_val *)&val_7476},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0061, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0062, (cst_val *)&val_0045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0063, (cst_val *)&val_0032},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0064, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7477 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0066, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7479 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0069, (cst_val *)&val_7480},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0070, (cst_val *)&val_0718},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7483 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0074, (cst_val *)&val_7484},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0075, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7486 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0078, (cst_val *)&val_5534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7488 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0081, (cst_val *)&val_7489},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0082, (cst_val *)&val_7278},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0083, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7492 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0087, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7493 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0089, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7494 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0091, (cst_val *)&val_4492},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0092, (cst_val *)&val_0059},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0093, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7496 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0096, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7499 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0100, (cst_val *)&val_7500},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0101, (cst_val *)&val_2122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7502 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0104, (cst_val *)&val_0039},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0105, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7503 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0107, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7504 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0109, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7506 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0112, (cst_val *)&val_0332},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0113, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7507 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0115, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0116, (cst_val *)&val_5095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7509 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0119, (cst_val *)&val_5095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7511 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0122, (cst_val *)&val_7512},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0123, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0124, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7514 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0127, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7515 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0129, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7518 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0133, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0134, (cst_val *)&val_1462},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0135, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7519 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0137, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7520 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0139, (cst_val *)&val_0756},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0140, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7522 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0143, (cst_val *)&val_2312},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0144, (cst_val *)&val_7523},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7527 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0149, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7528 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0151, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7530 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0154, (cst_val *)&val_0059},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0155, (cst_val *)&val_1579},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0156, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7531 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0158, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0159, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7533 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0162, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7535 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0165, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7536 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0167, (cst_val *)&val_6002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7538 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0170, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7539 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0172, (cst_val *)&val_0569},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0173, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7540 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0175, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7541 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0177, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7543 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0180, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7544 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_67_NO_0182, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7546 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ey_67_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_rms_single_mcep_ey_67_cart = {
  cmu_us_rms_single_mcep_ey_67_cart_nodes,
  cmu_us_rms_single_mcep_ey_67_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ey_68_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0000, (cst_val *)&val_0183},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0002, (cst_val *)&val_0068},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0003, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7549 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0007, (cst_val *)&val_0074},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0008, (cst_val *)&val_0059},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0009, (cst_val *)&val_7550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7551 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0011, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7553 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0014, (cst_val *)&val_0043},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0015, (cst_val *)&val_5690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7555 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0018, (cst_val *)&val_7176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7556 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0020, (cst_val *)&val_5690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7558 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0023, (cst_val *)&val_0009},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0024, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7559 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0026, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7561 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0029, (cst_val *)&val_1378},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0030, (cst_val *)&val_4692},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7562 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0032, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7564 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0035, (cst_val *)&val_7565},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0036, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7566 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0038, (cst_val *)&val_0925},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0039, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7568 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0042, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7571 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0046, (cst_val *)&val_0219},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0047, (cst_val *)&val_0059},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0048, (cst_val *)&val_0040},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0049, (cst_val *)&val_7572},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0050, (cst_val *)&val_7573},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7574 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0052, (cst_val *)&val_7575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7578 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0056, (cst_val *)&val_0140},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0057, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7579 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0059, (cst_val *)&val_2310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7580 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0061, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7581 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0063, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0064, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7582 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0066, (cst_val *)&val_4288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7584 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0069, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7586 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0072, (cst_val *)&val_0160},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0073, (cst_val *)&val_3596},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7589 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0077, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7590 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0079, (cst_val *)&val_3246},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0080, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7591 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0082, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7593 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0085, (cst_val *)&val_0140},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0086, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7595 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0089, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7597 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0092, (cst_val *)&val_0361},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0093, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7598 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0095, (cst_val *)&val_0013},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0096, (cst_val *)&val_7599},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7600 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0098, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7602 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0101, (cst_val *)&val_0029},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0102, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7605 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0106, (cst_val *)&val_7606},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0107, (cst_val *)&val_0045},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0108, (cst_val *)&val_0125},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0109, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7608 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0112, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7609 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0114, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7611 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0117, (cst_val *)&val_0040},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0118, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7613 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0121, (cst_val *)&val_5310},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0122, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0123, (cst_val *)&val_7614},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0124, (cst_val *)&val_7615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7618 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0128, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7620 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0131, (cst_val *)&val_5783},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0132, (cst_val *)&val_0165},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0133, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7624 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0138, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7625 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0140, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7626 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0142, (cst_val *)&val_1249},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0143, (cst_val *)&val_7627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7628 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0145, (cst_val *)&val_7629},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0146, (cst_val *)&val_7630},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7633 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ey_68_NO_0150, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7635 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ey_68_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_ey_68_cart = {
  cmu_us_rms_single_mcep_ey_68_cart_nodes,
  cmu_us_rms_single_mcep_ey_68_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_f_71_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0000, (cst_val *)&val_7636},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0001, (cst_val *)&val_0068},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0002, (cst_val *)&val_5614},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0003, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7639 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0007, (cst_val *)&val_0077},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0008, (cst_val *)&val_5512},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0009, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7641 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0012, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7643 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0015, (cst_val *)&val_0068},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0016, (cst_val *)&val_0307},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0017, (cst_val *)&val_7644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7646 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0020, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7648 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0023, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0024, (cst_val *)&val_7649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7651 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0027, (cst_val *)&val_7652},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0028, (cst_val *)&val_0059},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0029, (cst_val *)&val_5864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7654 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0032, (cst_val *)&val_0040},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0033, (cst_val *)&val_0246},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0034, (cst_val *)&val_0056},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0035, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7657 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0039, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7659 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0042, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0043, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7662 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0047, (cst_val *)&val_0059},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0048, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7664 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0051, (cst_val *)&val_2959},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0052, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7666 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0055, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7667 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0057, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0058, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7670 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0062, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0063, (cst_val *)&val_0040},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0064, (cst_val *)&val_0008},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0065, (cst_val *)&val_7671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7674 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0069, (cst_val *)&val_0663},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0070, (cst_val *)&val_0760},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0071, (cst_val *)&val_3167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7676 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0074, (cst_val *)&val_1647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7677 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0076, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7678 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0078, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7681 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0082, (cst_val *)&val_0878},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0083, (cst_val *)&val_5512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7682 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0085, (cst_val *)&val_0040},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0086, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7683 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0088, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7684 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0090, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7686 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0093, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7688 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0096, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0097, (cst_val *)&val_7689},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0098, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7690 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0100, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7691 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0102, (cst_val *)&val_1885},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0103, (cst_val *)&val_1331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7692 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0105, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0106, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7696 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0111, (cst_val *)&val_7697},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7699 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0114, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7700 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_71_NO_0116, (cst_val *)&val_7701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7703 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_f_71_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_rms_single_mcep_f_71_cart = {
  cmu_us_rms_single_mcep_f_71_cart_nodes,
  cmu_us_rms_single_mcep_f_71_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_f_72_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0000, (cst_val *)&val_6002},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0001, (cst_val *)&val_0171},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0002, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0003, (cst_val *)&val_7704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7706 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0006, (cst_val *)&val_0251},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0007, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7708 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0010, (cst_val *)&val_0270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7709 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0012, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7710 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0014, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0015, (cst_val *)&val_7711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7714 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0019, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0020, (cst_val *)&val_0043},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0021, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7716 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0024, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0025, (cst_val *)&val_7717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7720 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0029, (cst_val *)&val_0251},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0030, (cst_val *)&val_0068},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0031, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7722 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0034, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7724 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0037, (cst_val *)&val_0043},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0038, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7725 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0040, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0041, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7728 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0045, (cst_val *)&val_3313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7729 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0047, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7730 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0049, (cst_val *)&val_0165},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0050, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7733 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0054, (cst_val *)&val_6002},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0055, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0056, (cst_val *)&val_0056},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0057, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7734 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0059, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7736 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0062, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0063, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7738 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0066, (cst_val *)&val_7739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7740 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0068, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7741 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0070, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7743 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0073, (cst_val *)&val_0025},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0074, (cst_val *)&val_0068},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0075, (cst_val *)&val_7744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7746 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0078, (cst_val *)&val_4626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7748 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0081, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0082, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7751 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0086, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0087, (cst_val *)&val_0539},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0088, (cst_val *)&val_0774},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0089, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7753 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0092, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7754 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0094, (cst_val *)&val_0008},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0095, (cst_val *)&val_7755},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7758 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0099, (cst_val *)&val_0040},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0100, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7760 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0103, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7761 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0105, (cst_val *)&val_0403},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0106, (cst_val *)&val_7762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7763 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0108, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7765 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0111, (cst_val *)&val_1994},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0112, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7766 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0114, (cst_val *)&val_7767},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0115, (cst_val *)&val_0165},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0116, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7768 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0118, (cst_val *)&val_7769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7771 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0121, (cst_val *)&val_7772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7773 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0123, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7775 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0126, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7777 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0129, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7778 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0131, (cst_val *)&val_1610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7780 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0134, (cst_val *)&val_0059},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0135, (cst_val *)&val_0040},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0136, (cst_val *)&val_0211},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0137, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7781 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0139, (cst_val *)&val_0165},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0140, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7783 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0143, (cst_val *)&val_7784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7785 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0145, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7787 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0148, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7788 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0150, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7790 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0153, (cst_val *)&val_0034},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0154, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7793 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0158, (cst_val *)&val_0199},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0159, (cst_val *)&val_0125},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0160, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7795 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0163, (cst_val *)&val_0774},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0164, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7796 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0166, (cst_val *)&val_1310},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0167, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7798 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0170, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7800 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0173, (cst_val *)&val_0899},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0174, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7802 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0177, (cst_val *)&val_0403},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0178, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7804 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0181, (cst_val *)&val_0045},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0182, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7805 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0184, (cst_val *)&val_1965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7807 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0187, (cst_val *)&val_7808},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7810 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0190, (cst_val *)&val_7811},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0191, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7812 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0193, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7813 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0195, (cst_val *)&val_0165},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0196, (cst_val *)&val_7814},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0197, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7816 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0200, (cst_val *)&val_0132},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0201, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0202, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7818 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0205, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7820 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0208, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7821 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0210, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7823 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0213, (cst_val *)&val_1594},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0214, (cst_val *)&val_4035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7826 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0218, (cst_val *)&val_1448},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0219, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7828 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0222, (cst_val *)&val_0629},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0223, (cst_val *)&val_7829},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0224, (cst_val *)&val_7830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7832 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0227, (cst_val *)&val_0799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7834 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0230, (cst_val *)&val_0060},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0231, (cst_val *)&val_7835},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0232, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7837 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0235, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0236, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7840 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0240, (cst_val *)&val_0403},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0241, (cst_val *)&val_0040},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0242, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7842 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0245, (cst_val *)&val_0021},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0246, (cst_val *)&val_3577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7844 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0249, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0250, (cst_val *)&val_7845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7847 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0253, (cst_val *)&val_2239},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0254, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7850 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0258, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7851 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0260, (cst_val *)&val_0077},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0261, (cst_val *)&val_7852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7854 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0264, (cst_val *)&val_0059},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0265, (cst_val *)&val_0517},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0266, (cst_val *)&val_7855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7856 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0268, (cst_val *)&val_4842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7858 },
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0271, (cst_val *)&val_7859},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7861 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0274, (cst_val *)&val_0629},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0275, (cst_val *)&val_7862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7864 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0278, (cst_val *)&val_0059},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0279, (cst_val *)&val_7865},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0280, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7868 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0284, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7869 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0286, (cst_val *)&val_7870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7871 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_72_NO_0288, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7873 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_f_72_feat_table[] = {
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_single_mcep_f_72_cart = {
  cmu_us_rms_single_mcep_f_72_cart_nodes,
  cmu_us_rms_single_mcep_f_72_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_f_73_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0001, (cst_val *)&val_0097},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0002, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7874 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0005, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7876 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0008, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7877 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0010, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7879 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0013, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7880 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7882 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0018, (cst_val *)&val_0918},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0019, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7883 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0021, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0022, (cst_val *)&val_2926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7885 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0025, (cst_val *)&val_5633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7887 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0028, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0029, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7889 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0032, (cst_val *)&val_0957},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0033, (cst_val *)&val_4299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7891 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0036, (cst_val *)&val_0125},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0037, (cst_val *)&val_0831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7893 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_f_73_NO_0040, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7895 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_f_73_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_f_73_cart = {
  cmu_us_rms_single_mcep_f_73_cart_nodes,
  cmu_us_rms_single_mcep_f_73_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ih_86_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0000, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0001, (cst_val *)&val_0074},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0002, (cst_val *)&val_0417},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0003, (cst_val *)&val_0097},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0004, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0005, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7897 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0008, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7898 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0010, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0011, (cst_val *)&val_7899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7901 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0014, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7903 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0017, (cst_val *)&val_3483},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0018, (cst_val *)&val_7904},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0019, (cst_val *)&val_0760},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0020, (cst_val *)&val_4338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7906 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0023, (cst_val *)&val_7907},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7910 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0027, (cst_val *)&val_0760},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0028, (cst_val *)&val_4456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7911 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0030, (cst_val *)&val_7912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7914 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0033, (cst_val *)&val_7915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7916 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0035, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7918 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0038, (cst_val *)&val_3061},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0039, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0040, (cst_val *)&val_0925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7919 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0042, (cst_val *)&val_7920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7922 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0045, (cst_val *)&val_0025},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0046, (cst_val *)&val_7923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7924 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0048, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7926 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0051, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7927 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0053, (cst_val *)&val_7928},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0054, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7931 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0058, (cst_val *)&val_0774},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0059, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0060, (cst_val *)&val_7165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7932 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0062, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0063, (cst_val *)&val_1310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7936 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0068, (cst_val *)&val_0008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0069, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7937 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0071, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7939 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0074, (cst_val *)&val_7940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7942 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0077, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7943 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0079, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0080, (cst_val *)&val_7944},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0081, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0082, (cst_val *)&val_7945},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7948 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0086, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7949 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0088, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7950 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0090, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7952 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0093, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7953 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0095, (cst_val *)&val_0417},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0096, (cst_val *)&val_7954},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0097, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7955 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0099, (cst_val *)&val_7956},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0100, (cst_val *)&val_0328},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0101, (cst_val *)&val_7957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7961 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0106, (cst_val *)&val_7962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7963 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0108, (cst_val *)&val_1992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7964 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0110, (cst_val *)&val_7965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7967 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0113, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7969 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0116, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0117, (cst_val *)&val_6053},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0118, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0119, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7971 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0122, (cst_val *)&val_2626},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0123, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7972 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0125, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7973 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0127, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7975 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0130, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7977 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0133, (cst_val *)&val_0068},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0134, (cst_val *)&val_0007},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0135, (cst_val *)&val_0046},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0136, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7979 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0139, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7981 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0142, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7982 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0144, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7984 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0147, (cst_val *)&val_1565},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0148, (cst_val *)&val_0026},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0149, (cst_val *)&val_3669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7986 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0152, (cst_val *)&val_0128},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0153, (cst_val *)&val_0325},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0154, (cst_val *)&val_4690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7988 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0157, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7990 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0160, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7992 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0163, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7993 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0165, (cst_val *)&val_0077},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0166, (cst_val *)&val_0973},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0167, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7995 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0170, (cst_val *)&val_7996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7998 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0173, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7999 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0175, (cst_val *)&val_0505},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0176, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8001 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0179, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8002 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0181, (cst_val *)&val_3256},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0182, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8004 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0185, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8006 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0188, (cst_val *)&val_0056},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0189, (cst_val *)&val_1921},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0190, (cst_val *)&val_8007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8008 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0192, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8010 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0195, (cst_val *)&val_0077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0196, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8011 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0198, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8013 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0201, (cst_val *)&val_1232},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0202, (cst_val *)&val_8014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8017 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0206, (cst_val *)&val_1921},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0207, (cst_val *)&val_0361},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0208, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8019 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0211, (cst_val *)&val_8020},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0212, (cst_val *)&val_8021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8023 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0215, (cst_val *)&val_3111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8024 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0217, (cst_val *)&val_8025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0218, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8028 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0222, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0223, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8029 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0225, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8031 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0228, (cst_val *)&val_8032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0229, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8034 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0232, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8035 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0234, (cst_val *)&val_1008},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_86_NO_0235, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8038 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ih_86_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_ih_86_cart = {
  cmu_us_rms_single_mcep_ih_86_cart_nodes,
  cmu_us_rms_single_mcep_ih_86_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ih_87_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0000, (cst_val *)&val_1065},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0001, (cst_val *)&val_0183},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0002, (cst_val *)&val_0025},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0003, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0004, (cst_val *)&val_6032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8039 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0006, (cst_val *)&val_1249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8040 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0008, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8041 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0010, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8043 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0013, (cst_val *)&val_1821},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0014, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8046 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0018, (cst_val *)&val_0008},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0019, (cst_val *)&val_0220},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0020, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8049 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0024, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8051 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0027, (cst_val *)&val_0009},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0028, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0029, (cst_val *)&val_8052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8054 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0032, (cst_val *)&val_0629},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0033, (cst_val *)&val_8055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8056 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0035, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8058 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0038, (cst_val *)&val_0059},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0039, (cst_val *)&val_0007},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0040, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0041, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0042, (cst_val *)&val_8059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8061 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0045, (cst_val *)&val_1110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8062 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0047, (cst_val *)&val_8063},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8065 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0050, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8066 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0052, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8068 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0055, (cst_val *)&val_0077},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0056, (cst_val *)&val_8069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8071 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0059, (cst_val *)&val_0025},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0060, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8074 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0064, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8075 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0066, (cst_val *)&val_0007},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0067, (cst_val *)&val_3254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8076 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0069, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8077 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0071, (cst_val *)&val_8078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8080 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0074, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8082 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0077, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8083 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0079, (cst_val *)&val_0059},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0080, (cst_val *)&val_0140},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0081, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8084 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0083, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8086 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0086, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8087 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0088, (cst_val *)&val_1386},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0089, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8090 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0093, (cst_val *)&val_0165},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0094, (cst_val *)&val_0068},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0095, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8091 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0097, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8093 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0100, (cst_val *)&val_8094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8096 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0103, (cst_val *)&val_2626},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0104, (cst_val *)&val_8097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8099 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0107, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8101 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0110, (cst_val *)&val_8102},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0111, (cst_val *)&val_8103},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0112, (cst_val *)&val_2069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8104 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0114, (cst_val *)&val_3313},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0115, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0116, (cst_val *)&val_0183},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0117, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8106 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0120, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8108 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0123, (cst_val *)&val_8109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8111 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0126, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8113 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0129, (cst_val *)&val_0361},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0130, (cst_val *)&val_0183},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0131, (cst_val *)&val_2069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8116 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0135, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0136, (cst_val *)&val_0088},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0137, (cst_val *)&val_0039},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0138, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8118 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0141, (cst_val *)&val_8119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8121 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0144, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8122 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0146, (cst_val *)&val_8123},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0147, (cst_val *)&val_8124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8126 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0150, (cst_val *)&val_2649},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0151, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8129 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0155, (cst_val *)&val_2069},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0156, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8130 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0158, (cst_val *)&val_2152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8132 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0161, (cst_val *)&val_0417},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0162, (cst_val *)&val_8133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8135 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0165, (cst_val *)&val_8136},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0166, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0167, (cst_val *)&val_8137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8139 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0170, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8140 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0172, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8142 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0175, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8143 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0177, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8145 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0180, (cst_val *)&val_0403},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0181, (cst_val *)&val_0183},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0182, (cst_val *)&val_0899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8146 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0184, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8148 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0187, (cst_val *)&val_8149},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0188, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8151 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0191, (cst_val *)&val_8152},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0192, (cst_val *)&val_8153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8154 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0194, (cst_val *)&val_4007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8156 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0197, (cst_val *)&val_8157},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8159 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0200, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0201, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0202, (cst_val *)&val_8160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8162 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0205, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8164 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0208, (cst_val *)&val_0040},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0209, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0210, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8165 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0212, (cst_val *)&val_0056},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0213, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8167 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0216, (cst_val *)&val_1819},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0217, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8170 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0221, (cst_val *)&val_0040},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0222, (cst_val *)&val_0045},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0223, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8171 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0225, (cst_val *)&val_2423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8172 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0227, (cst_val *)&val_8173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8174 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0229, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8177 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0233, (cst_val *)&val_8178},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0234, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8179 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0236, (cst_val *)&val_0841},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0237, (cst_val *)&val_0074},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0238, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8184 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0244, (cst_val *)&val_1223},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0245, (cst_val *)&val_0417},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0246, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8185 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0248, (cst_val *)&val_8186},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0249, (cst_val *)&val_8187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8190 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0253, (cst_val *)&val_2069},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0254, (cst_val *)&val_8191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8192 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0256, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8194 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0259, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8195 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0261, (cst_val *)&val_0165},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0262, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8197 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0265, (cst_val *)&val_8198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8199 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0267, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8201 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0270, (cst_val *)&val_8202},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0271, (cst_val *)&val_0068},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0272, (cst_val *)&val_1424},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0273, (cst_val *)&val_1244},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0274, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8203 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0276, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8205 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0279, (cst_val *)&val_8206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8208 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0282, (cst_val *)&val_0860},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0283, (cst_val *)&val_1462},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0284, (cst_val *)&val_2241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8212 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0289, (cst_val *)&val_8213},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0290, (cst_val *)&val_2241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8215 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0293, (cst_val *)&val_1749},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0294, (cst_val *)&val_2122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8218 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0298, (cst_val *)&val_8219},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0299, (cst_val *)&val_0251},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0300, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8221 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0302, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8223 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0305, (cst_val *)&val_2069},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0306, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0307, (cst_val *)&val_8224},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0308, (cst_val *)&val_6247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8228 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0313, (cst_val *)&val_0025},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0314, (cst_val *)&val_0088},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0315, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8229 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0317, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8232 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0321, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0322, (cst_val *)&val_8233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8236 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0326, (cst_val *)&val_2069},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0327, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8238 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0330, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8239 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0332, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_87_NO_0333, (cst_val *)&val_8240},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8243 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ih_87_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_single_mcep_ih_87_cart = {
  cmu_us_rms_single_mcep_ih_87_cart_nodes,
  cmu_us_rms_single_mcep_ih_87_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ih_88_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0000, (cst_val *)&val_0183},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0002, (cst_val *)&val_0663},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0003, (cst_val *)&val_4993},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0004, (cst_val *)&val_0278},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0005, (cst_val *)&val_8244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8245 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0007, (cst_val *)&val_8246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8249 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0011, (cst_val *)&val_0097},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0012, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0013, (cst_val *)&val_8250},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8251 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0015, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8253 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0018, (cst_val *)&val_8254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8256 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0021, (cst_val *)&val_8257},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0022, (cst_val *)&val_8258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8262 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0027, (cst_val *)&val_4993},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0028, (cst_val *)&val_0059},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0029, (cst_val *)&val_0132},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0030, (cst_val *)&val_0025},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0031, (cst_val *)&val_1225},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0032, (cst_val *)&val_8263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8265 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0035, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8267 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0038, (cst_val *)&val_2244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8268 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0040, (cst_val *)&val_0043},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0041, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8270 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0044, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8272 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0047, (cst_val *)&val_0077},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0048, (cst_val *)&val_8273},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0049, (cst_val *)&val_0841},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0050, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8277 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0055, (cst_val *)&val_8278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8280 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0058, (cst_val *)&val_0009},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0059, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0060, (cst_val *)&val_8281},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0061, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8284 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0065, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8286 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0068, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8287 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0070, (cst_val *)&val_8288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8290 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0073, (cst_val *)&val_8291},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0074, (cst_val *)&val_3313},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0075, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0076, (cst_val *)&val_8292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8294 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0079, (cst_val *)&val_2645},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0080, (cst_val *)&val_6839},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8295 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0082, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8296 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0084, (cst_val *)&val_1703},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0085, (cst_val *)&val_2069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8297 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0087, (cst_val *)&val_0978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8299 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0090, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8301 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0093, (cst_val *)&val_0395},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0094, (cst_val *)&val_0251},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0095, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8302 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0097, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8305 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0101, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8307 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0104, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0105, (cst_val *)&val_8308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8309 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0107, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8311 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0110, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8313 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0113, (cst_val *)&val_0165},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0114, (cst_val *)&val_1378},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0115, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8315 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0118, (cst_val *)&val_8316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8317 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0120, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8319 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0123, (cst_val *)&val_0039},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0124, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8321 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0127, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8323 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0130, (cst_val *)&val_0009},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0131, (cst_val *)&val_0059},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0132, (cst_val *)&val_0077},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0133, (cst_val *)&val_0026},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0134, (cst_val *)&val_8324},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0135, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8326 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0138, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8328 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0141, (cst_val *)&val_8329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8330 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0143, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8332 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0146, (cst_val *)&val_3596},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0147, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8333 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0149, (cst_val *)&val_4767},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0150, (cst_val *)&val_0040},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0151, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8335 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0154, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8336 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0156, (cst_val *)&val_1992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8339 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0160, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8340 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0162, (cst_val *)&val_3412},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0163, (cst_val *)&val_8341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8342 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0165, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8345 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0169, (cst_val *)&val_0165},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0170, (cst_val *)&val_0733},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0171, (cst_val *)&val_6728},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0172, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8348 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0176, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0177, (cst_val *)&val_8349},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8351 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0180, (cst_val *)&val_8352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8353 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0182, (cst_val *)&val_2417},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0183, (cst_val *)&val_8354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8356 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0186, (cst_val *)&val_0008},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0187, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8358 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0190, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8360 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0193, (cst_val *)&val_1367},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0194, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8362 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0197, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8363 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0199, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0200, (cst_val *)&val_1594},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0201, (cst_val *)&val_1799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8365 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0204, (cst_val *)&val_8366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8369 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0208, (cst_val *)&val_0361},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0209, (cst_val *)&val_1065},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0210, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8371 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0213, (cst_val *)&val_0025},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0214, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8372 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0216, (cst_val *)&val_8373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8374 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0218, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8376 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0221, (cst_val *)&val_8377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8379 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0224, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0225, (cst_val *)&val_0714},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0226, (cst_val *)&val_0626},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0227, (cst_val *)&val_2152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8380 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0229, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8382 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0232, (cst_val *)&val_8383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8384 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0234, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0235, (cst_val *)&val_8385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8388 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0239, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8389 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0241, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8390 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0243, (cst_val *)&val_0068},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0244, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8392 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0247, (cst_val *)&val_0079},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0248, (cst_val *)&val_0733},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0249, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8393 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0251, (cst_val *)&val_0431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8395 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0254, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8396 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0256, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8399 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0260, (cst_val *)&val_1602},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0261, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8400 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0263, (cst_val *)&val_0128},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0264, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8402 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0267, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8403 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0269, (cst_val *)&val_8404},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8406 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0272, (cst_val *)&val_7954},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0273, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0274, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8407 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0276, (cst_val *)&val_8408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8410 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0279, (cst_val *)&val_8411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8412 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0281, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8414 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ih_88_NO_0284, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8416 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ih_88_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_rms_single_mcep_ih_88_cart = {
  cmu_us_rms_single_mcep_ih_88_cart_nodes,
  cmu_us_rms_single_mcep_ih_88_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_p_136_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0000, (cst_val *)&val_0186},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0001, (cst_val *)&val_2466},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0002, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8417 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0004, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0005, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8419 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0008, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8421 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0011, (cst_val *)&val_6728},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0012, (cst_val *)&val_0043},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0013, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0014, (cst_val *)&val_0120},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0015, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8423 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0018, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8426 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0022, (cst_val *)&val_0278},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0023, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8430 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0028, (cst_val *)&val_0940},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0029, (cst_val *)&val_7480},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0030, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8431 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0032, (cst_val *)&val_0059},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0033, (cst_val *)&val_0056},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0034, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8435 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0039, (cst_val *)&val_8436},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0040, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8439 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0044, (cst_val *)&val_2744},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0045, (cst_val *)&val_8440},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0046, (cst_val *)&val_8441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8444 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0050, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0051, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8446 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_136_NO_0054, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8448 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_p_136_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_p_136_cart = {
  cmu_us_rms_single_mcep_p_136_cart_nodes,
  cmu_us_rms_single_mcep_p_136_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_p_137_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0000, (cst_val *)&val_0957},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0001, (cst_val *)&val_8449},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0002, (cst_val *)&val_5324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8450 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0004, (cst_val *)&val_8451},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0005, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8453 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0008, (cst_val *)&val_7466},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0009, (cst_val *)&val_8454},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8456 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0012, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8459 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0016, (cst_val *)&val_0569},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0017, (cst_val *)&val_0059},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0018, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0019, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8460 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0021, (cst_val *)&val_0056},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0022, (cst_val *)&val_2959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8462 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0025, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8464 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0028, (cst_val *)&val_0068},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0029, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8466 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0032, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8467 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0034, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8469 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0037, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0038, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8470 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0040, (cst_val *)&val_0010},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0041, (cst_val *)&val_0417},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0042, (cst_val *)&val_1993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8472 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0045, (cst_val *)&val_8473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8475 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0048, (cst_val *)&val_0361},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0049, (cst_val *)&val_8476},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8478 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0052, (cst_val *)&val_0125},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0053, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8480 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0056, (cst_val *)&val_0043},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0057, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8482 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0060, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0061, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8483 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0063, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8485 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0066, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8486 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0068, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8488 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0071, (cst_val *)&val_8489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8490 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0073, (cst_val *)&val_0043},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0074, (cst_val *)&val_0077},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0075, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8492 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0078, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8494 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0081, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0082, (cst_val *)&val_8495},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8496 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0084, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8498 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0087, (cst_val *)&val_8499},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8500 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0089, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8502 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0092, (cst_val *)&val_3806},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0093, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0094, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8504 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0097, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8505 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0099, (cst_val *)&val_8506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8508 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0102, (cst_val *)&val_8509},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0103, (cst_val *)&val_5398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8510 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0105, (cst_val *)&val_1289},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0106, (cst_val *)&val_0068},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0107, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8512 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0110, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8513 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0112, (cst_val *)&val_8514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8515 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0114, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8516 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0116, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8517 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0118, (cst_val *)&val_8518},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0119, (cst_val *)&val_8519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8520 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0121, (cst_val *)&val_4871},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0122, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8523 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0126, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0127, (cst_val *)&val_0388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8525 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0130, (cst_val *)&val_8526},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0131, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8528 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0134, (cst_val *)&val_3486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8531 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0138, (cst_val *)&val_0186},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0139, (cst_val *)&val_7466},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0140, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8532 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0142, (cst_val *)&val_8533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8535 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0145, (cst_val *)&val_7208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8537 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_137_NO_0148, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8539 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_p_137_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_p_137_cart = {
  cmu_us_rms_single_mcep_p_137_cart_nodes,
  cmu_us_rms_single_mcep_p_137_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_p_138_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0000, (cst_val *)&val_0056},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0002, (cst_val *)&val_0294},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0003, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8541 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0006, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8543 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0009, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0010, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8545 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0013, (cst_val *)&val_2221},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0014, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8548 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0018, (cst_val *)&val_8549},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0019, (cst_val *)&val_0236},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0020, (cst_val *)&val_0973},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0021, (cst_val *)&val_2414},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0022, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0023, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8552 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0027, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0028, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8554 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0031, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8556 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0034, (cst_val *)&val_8557},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8558 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0036, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8559 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0038, (cst_val *)&val_0403},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0039, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8561 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0042, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0043, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8564 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0047, (cst_val *)&val_0008},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0048, (cst_val *)&val_0040},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0049, (cst_val *)&val_0165},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0050, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8566 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0053, (cst_val *)&val_8567},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0054, (cst_val *)&val_3107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8570 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0058, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8571 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0060, (cst_val *)&val_2877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8572 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0062, (cst_val *)&val_8573},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8575 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0065, (cst_val *)&val_0039},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0066, (cst_val *)&val_0403},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0067, (cst_val *)&val_3806},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0068, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8577 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0071, (cst_val *)&val_0569},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8578 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0074, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8580 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0077, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8581 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0079, (cst_val *)&val_8582},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0080, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8583 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0082, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8585 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0085, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8587 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0088, (cst_val *)&val_2097},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0089, (cst_val *)&val_0040},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0090, (cst_val *)&val_8588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8590 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0093, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8592 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0096, (cst_val *)&val_0733},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0097, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8593 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0099, (cst_val *)&val_0539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8594 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0101, (cst_val *)&val_0542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8596 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0104, (cst_val *)&val_0569},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0105, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8598 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0108, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0109, (cst_val *)&val_6449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8600 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0112, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8601 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0114, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8603 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0117, (cst_val *)&val_0165},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0118, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8605 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0121, (cst_val *)&val_8606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8608 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0124, (cst_val *)&val_0008},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0125, (cst_val *)&val_0008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0126, (cst_val *)&val_8609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8611 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0129, (cst_val *)&val_8612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8614 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0132, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0133, (cst_val *)&val_2896},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0134, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8617 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0138, (cst_val *)&val_0403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0139, (cst_val *)&val_8618},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0140, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8619 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0142, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8622 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0146, (cst_val *)&val_0733},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0147, (cst_val *)&val_8623},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8625 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0150, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8626 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0152, (cst_val *)&val_8627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8628 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_p_138_NO_0154, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8630 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_p_138_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_single_mcep_p_138_cart = {
  cmu_us_rms_single_mcep_p_138_cart_nodes,
  cmu_us_rms_single_mcep_p_138_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_iy_91_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0000, (cst_val *)&val_8631},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0002, (cst_val *)&val_1921},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0003, (cst_val *)&val_8632},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0004, (cst_val *)&val_0056},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0005, (cst_val *)&val_8633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8635 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0008, (cst_val *)&val_1689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8637 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0011, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8639 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0014, (cst_val *)&val_0933},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0015, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0016, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8640 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0018, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8642 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0021, (cst_val *)&val_0574},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0022, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8644 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0025, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8646 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0028, (cst_val *)&val_1319},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0029, (cst_val *)&val_2637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8649 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0033, (cst_val *)&val_1565},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0034, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8651 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0037, (cst_val *)&val_0403},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0038, (cst_val *)&val_0040},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0039, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8652 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0041, (cst_val *)&val_8653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8655 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0044, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8657 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0047, (cst_val *)&val_3256},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0048, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8659 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0051, (cst_val *)&val_0505},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0052, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0053, (cst_val *)&val_8660},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0054, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8661 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0056, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8664 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0060, (cst_val *)&val_0493},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0061, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8667 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0065, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8668 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0067, (cst_val *)&val_0046},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0068, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8670 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0071, (cst_val *)&val_8671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8672 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0073, (cst_val *)&val_1029},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0074, (cst_val *)&val_0068},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0075, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8675 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0079, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8677 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0082, (cst_val *)&val_0361},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0083, (cst_val *)&val_0040},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0084, (cst_val *)&val_0989},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0085, (cst_val *)&val_3202},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0086, (cst_val *)&val_8678},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0087, (cst_val *)&val_8679},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0088, (cst_val *)&val_2715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8683 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0093, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8686 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0097, (cst_val *)&val_8687},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0098, (cst_val *)&val_8688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8690 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0101, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8691 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0103, (cst_val *)&val_1700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8693 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0106, (cst_val *)&val_0651},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0107, (cst_val *)&val_0997},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0108, (cst_val *)&val_0011},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0109, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0110, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0111, (cst_val *)&val_8694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8696 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0114, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8698 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0117, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8699 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0119, (cst_val *)&val_8700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8702 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0122, (cst_val *)&val_0045},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0123, (cst_val *)&val_0165},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0124, (cst_val *)&val_5690},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0125, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8704 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0128, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8706 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0131, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8707 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0133, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8709 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0136, (cst_val *)&val_1029},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0137, (cst_val *)&val_0145},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0138, (cst_val *)&val_8710},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0139, (cst_val *)&val_0888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8712 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0142, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8715 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0146, (cst_val *)&val_3954},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0147, (cst_val *)&val_0003},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0148, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8716 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0150, (cst_val *)&val_8717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8719 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0153, (cst_val *)&val_4831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8722 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0157, (cst_val *)&val_8723},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0158, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8724 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0160, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8726 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0163, (cst_val *)&val_8727},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0164, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0165, (cst_val *)&val_0040},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0166, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8730 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0170, (cst_val *)&val_3533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8732 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0173, (cst_val *)&val_1870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8733 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0175, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8734 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0177, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8736 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0180, (cst_val *)&val_8737},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0181, (cst_val *)&val_0059},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0182, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8738 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0184, (cst_val *)&val_0165},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0185, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8739 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0187, (cst_val *)&val_8740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8742 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0190, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8743 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0192, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8745 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0195, (cst_val *)&val_8746},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0196, (cst_val *)&val_1565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8747 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0198, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8748 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0200, (cst_val *)&val_8749},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0201, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0202, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8752 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0206, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8754 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0209, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0210, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8755 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0212, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8757 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0215, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8758 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0217, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8759 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0219, (cst_val *)&val_3061},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0220, (cst_val *)&val_4782},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0221, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8762 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0225, (cst_val *)&val_0091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8764 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0228, (cst_val *)&val_0403},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0229, (cst_val *)&val_8765},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0230, (cst_val *)&val_0040},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0231, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8766 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0233, (cst_val *)&val_0956},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0234, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8769 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0238, (cst_val *)&val_0314},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0239, (cst_val *)&val_8770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8771 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0241, (cst_val *)&val_8772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8776 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0246, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0247, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8777 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0249, (cst_val *)&val_1029},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0250, (cst_val *)&val_8778},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0251, (cst_val *)&val_0311},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0252, (cst_val *)&val_0091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8781 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0256, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8782 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0258, (cst_val *)&val_2405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8784 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0261, (cst_val *)&val_0574},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0262, (cst_val *)&val_8785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8787 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0265, (cst_val *)&val_8788},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0266, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8789 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0268, (cst_val *)&val_8790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8793 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0272, (cst_val *)&val_0068},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0273, (cst_val *)&val_4202},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0274, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8795 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0277, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8796 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0279, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8798 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0282, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0283, (cst_val *)&val_5252},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0284, (cst_val *)&val_8799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8802 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0288, (cst_val *)&val_8803},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0289, (cst_val *)&val_1921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8805 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0292, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8806 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0294, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0295, (cst_val *)&val_1466},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0296, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_91_NO_0297, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8811 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_iy_91_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_single_mcep_iy_91_cart = {
  cmu_us_rms_single_mcep_iy_91_cart_nodes,
  cmu_us_rms_single_mcep_iy_91_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_iy_92_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0000, (cst_val *)&val_2670},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0002, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0003, (cst_val *)&val_2776},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0004, (cst_val *)&val_0165},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0005, (cst_val *)&val_2312},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0006, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8814 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0010, (cst_val *)&val_8815},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8817 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0013, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0014, (cst_val *)&val_8818},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0015, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8819 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0017, (cst_val *)&val_2004},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0018, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8824 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0024, (cst_val *)&val_0403},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0025, (cst_val *)&val_0043},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0026, (cst_val *)&val_4202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8826 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0029, (cst_val *)&val_0975},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0030, (cst_val *)&val_8827},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8830 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0034, (cst_val *)&val_0140},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0035, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8831 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0037, (cst_val *)&val_1386},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0038, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0039, (cst_val *)&val_0133},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0040, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8834 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0044, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8836 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0047, (cst_val *)&val_8837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8839 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0050, (cst_val *)&val_7019},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0051, (cst_val *)&val_4214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8841 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0054, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8842 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0056, (cst_val *)&val_0251},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0057, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8844 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0060, (cst_val *)&val_0517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8846 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0063, (cst_val *)&val_0140},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0064, (cst_val *)&val_0246},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0065, (cst_val *)&val_0040},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0066, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8847 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0068, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8850 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0072, (cst_val *)&val_0860},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0073, (cst_val *)&val_6308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8851 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0075, (cst_val *)&val_8852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8854 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0078, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0079, (cst_val *)&val_8855},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0080, (cst_val *)&val_8856},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0081, (cst_val *)&val_8857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8860 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0085, (cst_val *)&val_1029},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0086, (cst_val *)&val_8861},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0087, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8863 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0090, (cst_val *)&val_0025},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0091, (cst_val *)&val_8864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8867 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0095, (cst_val *)&val_3547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8868 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0097, (cst_val *)&val_1255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8870 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0100, (cst_val *)&val_0026},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0101, (cst_val *)&val_0077},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0102, (cst_val *)&val_8871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8873 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0105, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8875 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0108, (cst_val *)&val_0068},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0109, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8877 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0112, (cst_val *)&val_0975},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0113, (cst_val *)&val_8878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8880 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0116, (cst_val *)&val_8881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8883 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0119, (cst_val *)&val_1029},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0120, (cst_val *)&val_0040},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0121, (cst_val *)&val_8884},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0122, (cst_val *)&val_1319},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0123, (cst_val *)&val_8885},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0124, (cst_val *)&val_8886},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8888 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0127, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8891 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0131, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8894 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0135, (cst_val *)&val_0020},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0136, (cst_val *)&val_0022},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0137, (cst_val *)&val_8895},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0138, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8896 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0140, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8899 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0144, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0145, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8901 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0148, (cst_val *)&val_0860},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0149, (cst_val *)&val_8902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8904 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0152, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8905 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0154, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8906 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0156, (cst_val *)&val_6616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8908 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0159, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8909 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0161, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0162, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0163, (cst_val *)&val_8910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8914 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0168, (cst_val *)&val_0183},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0169, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8915 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0171, (cst_val *)&val_0361},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0172, (cst_val *)&val_2014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8917 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0175, (cst_val *)&val_8918},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0176, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0177, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8920 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0180, (cst_val *)&val_2069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8921 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0182, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0183, (cst_val *)&val_8922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8925 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0187, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0188, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8926 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0190, (cst_val *)&val_8927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8929 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0193, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8930 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0195, (cst_val *)&val_8931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8933 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0198, (cst_val *)&val_0251},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0199, (cst_val *)&val_8934},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0200, (cst_val *)&val_0068},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0201, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8936 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0204, (cst_val *)&val_8937},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8938 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0206, (cst_val *)&val_8939},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0207, (cst_val *)&val_8940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8941 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0209, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8944 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0213, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8945 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0215, (cst_val *)&val_8946},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0216, (cst_val *)&val_8947},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0217, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8951 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0222, (cst_val *)&val_0040},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0223, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0224, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8952 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0226, (cst_val *)&val_0629},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0227, (cst_val *)&val_8953},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0228, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8955 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0231, (cst_val *)&val_8956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8958 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0234, (cst_val *)&val_0125},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0235, (cst_val *)&val_8959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8962 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0239, (cst_val *)&val_8963},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0240, (cst_val *)&val_0640},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0241, (cst_val *)&val_8964},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0242, (cst_val *)&val_8965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8968 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0246, (cst_val *)&val_2029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8970 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0249, (cst_val *)&val_8971},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0250, (cst_val *)&val_0370},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0251, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8972 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0253, (cst_val *)&val_8973},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0254, (cst_val *)&val_0671},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0255, (cst_val *)&val_8974},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0256, (cst_val *)&val_8975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8977 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0259, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8980 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0263, (cst_val *)&val_6308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8982 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0266, (cst_val *)&val_8213},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0267, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8983 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0269, (cst_val *)&val_8984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8987 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0273, (cst_val *)&val_2149},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0274, (cst_val *)&val_0008},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0275, (cst_val *)&val_1323},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0276, (cst_val *)&val_0328},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0277, (cst_val *)&val_8988},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8990 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0280, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8992 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0283, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8994 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0286, (cst_val *)&val_8995},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0287, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8998 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0291, (cst_val *)&val_4814},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0292, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9001 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0296, (cst_val *)&val_9002},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0297, (cst_val *)&val_8187},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0298, (cst_val *)&val_0860},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0299, (cst_val *)&val_2241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9003 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0301, (cst_val *)&val_1882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9005 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0304, (cst_val *)&val_0045},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0305, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9007 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0308, (cst_val *)&val_9008},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0309, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9009 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0311, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9010 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0313, (cst_val *)&val_9011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9013 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0316, (cst_val *)&val_9014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9016 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0319, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9017 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0321, (cst_val *)&val_9018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9019 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0323, (cst_val *)&val_2029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9021 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0326, (cst_val *)&val_0183},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0327, (cst_val *)&val_9022},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0328, (cst_val *)&val_9023},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0329, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9027 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0334, (cst_val *)&val_9028},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0335, (cst_val *)&val_2069},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0336, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9029 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0338, (cst_val *)&val_9030},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0339, (cst_val *)&val_3729},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0340, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9034 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0345, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0346, (cst_val *)&val_9035},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0347, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9037 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0350, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9039 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0353, (cst_val *)&val_0068},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0354, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9040 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0356, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9042 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0359, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9043 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0361, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9044 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0363, (cst_val *)&val_4068},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0364, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9046 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0367, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9048 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0370, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_92_NO_0371, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9051 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_iy_92_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_rms_single_mcep_iy_92_cart = {
  cmu_us_rms_single_mcep_iy_92_cart_nodes,
  cmu_us_rms_single_mcep_iy_92_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_iy_93_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0001, (cst_val *)&val_0219},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0002, (cst_val *)&val_0860},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0003, (cst_val *)&val_4374},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0004, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9054 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0008, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0009, (cst_val *)&val_0693},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0010, (cst_val *)&val_9055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9056 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0012, (cst_val *)&val_1310},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0013, (cst_val *)&val_9057},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0014, (cst_val *)&val_0145},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0015, (cst_val *)&val_9058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9059 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0017, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9063 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0022, (cst_val *)&val_9064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9066 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0025, (cst_val *)&val_3729},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0026, (cst_val *)&val_3762},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0027, (cst_val *)&val_9067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9069 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0030, (cst_val *)&val_9070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9073 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0034, (cst_val *)&val_0077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0035, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9074 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0037, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9076 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0040, (cst_val *)&val_0043},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0041, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9077 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0043, (cst_val *)&val_0267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9079 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0046, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9081 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0049, (cst_val *)&val_0068},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0050, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9083 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0053, (cst_val *)&val_1139},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0054, (cst_val *)&val_5702},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0055, (cst_val *)&val_9084},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0056, (cst_val *)&val_9085},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0057, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9086 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0059, (cst_val *)&val_9087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9089 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0062, (cst_val *)&val_0602},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0063, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9092 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0067, (cst_val *)&val_9093},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0068, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0069, (cst_val *)&val_9094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9097 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0073, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9098 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0075, (cst_val *)&val_0837},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0076, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9102 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0081, (cst_val *)&val_9103},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0082, (cst_val *)&val_9104},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0083, (cst_val *)&val_9105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9107 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0086, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9108 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0088, (cst_val *)&val_9109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9110 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0090, (cst_val *)&val_9111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9113 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0093, (cst_val *)&val_9114},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0094, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9116 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0097, (cst_val *)&val_0140},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0098, (cst_val *)&val_9117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9120 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0102, (cst_val *)&val_0183},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0103, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9121 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0105, (cst_val *)&val_0251},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0106, (cst_val *)&val_0452},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0107, (cst_val *)&val_1194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9123 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0110, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9126 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0114, (cst_val *)&val_1380},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0115, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9128 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0118, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0119, (cst_val *)&val_0008},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0120, (cst_val *)&val_0165},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0121, (cst_val *)&val_9129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9132 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0125, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0126, (cst_val *)&val_0133},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0127, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9134 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0130, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0131, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9138 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0136, (cst_val *)&val_0008},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0137, (cst_val *)&val_9139},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0138, (cst_val *)&val_0165},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0139, (cst_val *)&val_2877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9141 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0142, (cst_val *)&val_2530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9144 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0146, (cst_val *)&val_0714},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0147, (cst_val *)&val_1602},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0148, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9147 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0152, (cst_val *)&val_0068},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0153, (cst_val *)&val_9148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9150 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0156, (cst_val *)&val_0077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0157, (cst_val *)&val_9151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9153 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0160, (cst_val *)&val_0165},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0161, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9155 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0164, (cst_val *)&val_0165},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_iy_93_NO_0165, (cst_val *)&val_9156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9159 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_iy_93_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_rms_single_mcep_iy_93_cart = {
  cmu_us_rms_single_mcep_iy_93_cart_nodes,
  cmu_us_rms_single_mcep_iy_93_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_l_106_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0001, (cst_val *)&val_9160},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0002, (cst_val *)&val_0361},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0003, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0004, (cst_val *)&val_9161},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0005, (cst_val *)&val_9162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9163 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0007, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9164 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0009, (cst_val *)&val_0025},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0010, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9166 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0013, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0014, (cst_val *)&val_0989},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0015, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9168 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0018, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9171 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0022, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0023, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9172 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0025, (cst_val *)&val_9173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9175 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0028, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0029, (cst_val *)&val_9176},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0030, (cst_val *)&val_9177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9178 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0032, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9180 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0035, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9182 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0038, (cst_val *)&val_9183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9185 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0041, (cst_val *)&val_7347},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0042, (cst_val *)&val_6247},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0043, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9189 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0048, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0049, (cst_val *)&val_6919},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0050, (cst_val *)&val_2221},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0051, (cst_val *)&val_9190},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9192 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0054, (cst_val *)&val_3729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9194 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0057, (cst_val *)&val_9195},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0058, (cst_val *)&val_9196},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0059, (cst_val *)&val_0239},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0060, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9197 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0062, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9198 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0064, (cst_val *)&val_9199},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0065, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9200 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0067, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9202 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0070, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9204 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0073, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9205 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0075, (cst_val *)&val_9206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9207 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0077, (cst_val *)&val_0056},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0078, (cst_val *)&val_2487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9208 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0080, (cst_val *)&val_0611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9210 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0083, (cst_val *)&val_9211},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0084, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9213 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0087, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0088, (cst_val *)&val_9214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9216 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0091, (cst_val *)&val_0246},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0092, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9219 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0096, (cst_val *)&val_0025},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0097, (cst_val *)&val_9206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9220 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0099, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9222 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0102, (cst_val *)&val_0008},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0103, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9224 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0106, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0107, (cst_val *)&val_9225},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0108, (cst_val *)&val_9226},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0109, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9227 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0111, (cst_val *)&val_0212},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0112, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9228 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0114, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9230 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0117, (cst_val *)&val_9231},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0118, (cst_val *)&val_1462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9236 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0124, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0125, (cst_val *)&val_9237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9239 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0128, (cst_val *)&val_0040},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0129, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9240 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0131, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9243 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0135, (cst_val *)&val_9244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9246 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0138, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0139, (cst_val *)&val_9176},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0140, (cst_val *)&val_4781},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0141, (cst_val *)&val_9247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9248 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0143, (cst_val *)&val_9249},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0144, (cst_val *)&val_0008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0145, (cst_val *)&val_0899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9251 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0148, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9252 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0150, (cst_val *)&val_1472},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0151, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9254 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0154, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9256 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0157, (cst_val *)&val_0040},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0158, (cst_val *)&val_6882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9259 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0162, (cst_val *)&val_0978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9260 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0164, (cst_val *)&val_9261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9263 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0167, (cst_val *)&val_9264},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0168, (cst_val *)&val_3968},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0169, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9265 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0171, (cst_val *)&val_0165},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0172, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9267 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0175, (cst_val *)&val_0829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9269 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0178, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9272 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0182, (cst_val *)&val_0569},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0183, (cst_val *)&val_0370},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0184, (cst_val *)&val_9273},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0185, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0186, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9276 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0190, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0191, (cst_val *)&val_2640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9277 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0193, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9279 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0196, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9280 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0198, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0199, (cst_val *)&val_3233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9283 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0203, (cst_val *)&val_8191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9285 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0206, (cst_val *)&val_0283},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0207, (cst_val *)&val_0347},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0208, (cst_val *)&val_6529},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0209, (cst_val *)&val_9286},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0210, (cst_val *)&val_9287},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0211, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9291 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0216, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9292 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0218, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9294 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0221, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9295 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0223, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9296 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0225, (cst_val *)&val_9297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9299 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0228, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9301 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0231, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0232, (cst_val *)&val_0251},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0233, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0234, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9303 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0237, (cst_val *)&val_1065},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0238, (cst_val *)&val_0059},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0239, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9304 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0241, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9306 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0244, (cst_val *)&val_9307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9309 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0247, (cst_val *)&val_0361},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0248, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9311 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0251, (cst_val *)&val_0165},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0252, (cst_val *)&val_0246},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0253, (cst_val *)&val_0611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9313 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0256, (cst_val *)&val_0165},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0257, (cst_val *)&val_0831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9315 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0260, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9316 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0262, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9319 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0266, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9320 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0268, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9322 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0271, (cst_val *)&val_1363},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0272, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0273, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9323 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0275, (cst_val *)&val_9324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9326 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0278, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9327 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0280, (cst_val *)&val_9328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9331 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0284, (cst_val *)&val_0503},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0285, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9332 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0287, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9334 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0290, (cst_val *)&val_0492},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0291, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9336 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0294, (cst_val *)&val_0251},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0295, (cst_val *)&val_9337},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0296, (cst_val *)&val_4302},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0297, (cst_val *)&val_6429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9339 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0300, (cst_val *)&val_0009},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0301, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9340 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0303, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9341 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0305, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9343 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0308, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9345 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0311, (cst_val *)&val_9346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9348 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0314, (cst_val *)&val_9349},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0315, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9350 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0317, (cst_val *)&val_0933},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0318, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9352 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0321, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9354 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0324, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9355 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_106_NO_0326, (cst_val *)&val_3726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9357 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_l_106_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_single_mcep_l_106_cart = {
  cmu_us_rms_single_mcep_l_106_cart_nodes,
  cmu_us_rms_single_mcep_l_106_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_l_107_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0000, (cst_val *)&val_0193},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0002, (cst_val *)&val_0361},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0003, (cst_val *)&val_9358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9360 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0006, (cst_val *)&val_1579},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0007, (cst_val *)&val_9361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9362 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0009, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9363 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0011, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9365 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0014, (cst_val *)&val_0358},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0015, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9366 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0017, (cst_val *)&val_9367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9369 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0020, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9371 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0023, (cst_val *)&val_0008},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0024, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0025, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0026, (cst_val *)&val_6364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9374 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0030, (cst_val *)&val_9375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9376 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0032, (cst_val *)&val_9377},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0033, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9380 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0037, (cst_val *)&val_0403},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0038, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9381 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0040, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9383 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0043, (cst_val *)&val_0251},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0044, (cst_val *)&val_0361},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0045, (cst_val *)&val_9384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9386 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0048, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9387 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0050, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9388 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0052, (cst_val *)&val_3301},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0053, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9389 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0055, (cst_val *)&val_9390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9392 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0058, (cst_val *)&val_0077},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0059, (cst_val *)&val_9393},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9395 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0062, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0063, (cst_val *)&val_9396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9399 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0067, (cst_val *)&val_0043},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0068, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0069, (cst_val *)&val_0925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9401 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0072, (cst_val *)&val_9402},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0073, (cst_val *)&val_3448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9404 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0076, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9405 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0078, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9406 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0080, (cst_val *)&val_9407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9409 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0083, (cst_val *)&val_9410},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0084, (cst_val *)&val_6901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9412 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0087, (cst_val *)&val_0361},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0088, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9414 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0091, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9415 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0093, (cst_val *)&val_9416},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0094, (cst_val *)&val_8518},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9419 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0098, (cst_val *)&val_0040},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0099, (cst_val *)&val_0039},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0100, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0101, (cst_val *)&val_0120},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0102, (cst_val *)&val_9420},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0103, (cst_val *)&val_0012},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0104, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9422 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0107, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0108, (cst_val *)&val_0040},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0109, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9425 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0113, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9426 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0115, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9428 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0118, (cst_val *)&val_0040},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0119, (cst_val *)&val_0011},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0120, (cst_val *)&val_0060},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0121, (cst_val *)&val_9429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9431 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0124, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9433 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0127, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9434 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0129, (cst_val *)&val_0060},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0130, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9437 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0134, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0135, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9438 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0137, (cst_val *)&val_0785},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0138, (cst_val *)&val_9439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9442 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0142, (cst_val *)&val_0219},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0143, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9443 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0145, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9445 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0148, (cst_val *)&val_1222},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0149, (cst_val *)&val_9446},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0150, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0151, (cst_val *)&val_9447},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9449 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0154, (cst_val *)&val_9450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9451 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0156, (cst_val *)&val_0025},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0157, (cst_val *)&val_1225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9454 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0161, (cst_val *)&val_0165},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0162, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9456 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0165, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9459 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0169, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9460 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0171, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9461 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0173, (cst_val *)&val_0145},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0174, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9464 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0178, (cst_val *)&val_9465},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0179, (cst_val *)&val_0009},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0180, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9466 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0182, (cst_val *)&val_0841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9467 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0184, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9469 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0187, (cst_val *)&val_9470},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0188, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9471 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0190, (cst_val *)&val_1749},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0191, (cst_val *)&val_0745},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0192, (cst_val *)&val_3127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9473 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0195, (cst_val *)&val_3456},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0196, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9474 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0198, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9476 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0201, (cst_val *)&val_0165},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0202, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9480 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0207, (cst_val *)&val_0165},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0208, (cst_val *)&val_2535},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0209, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9481 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0211, (cst_val *)&val_1301},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0212, (cst_val *)&val_3509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9483 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0215, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9485 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0218, (cst_val *)&val_9486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9488 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0221, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9489 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0223, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0224, (cst_val *)&val_9490},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9493 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0228, (cst_val *)&val_0088},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0229, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9494 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0231, (cst_val *)&val_9495},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9496 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0233, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9499 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0237, (cst_val *)&val_2617},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0238, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0239, (cst_val *)&val_0384},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0240, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9501 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0243, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9502 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0245, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9504 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0248, (cst_val *)&val_0933},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0249, (cst_val *)&val_0056},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0250, (cst_val *)&val_9505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9507 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0253, (cst_val *)&val_7208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9509 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0256, (cst_val *)&val_0371},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0257, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9510 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0259, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9511 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0261, (cst_val *)&val_0008},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0262, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9513 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0265, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9516 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0269, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9517 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0271, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0272, (cst_val *)&val_9518},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0273, (cst_val *)&val_9519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9522 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0277, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9523 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0279, (cst_val *)&val_4782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9525 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0282, (cst_val *)&val_2637},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0283, (cst_val *)&val_9526},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0284, (cst_val *)&val_0642},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0285, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9528 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0288, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9529 },
{ 35, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0290, (cst_val *)&val_9530},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0291, (cst_val *)&val_4236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9531 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0293, (cst_val *)&val_0008},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0294, (cst_val *)&val_9532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9534 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0297, (cst_val *)&val_0025},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0298, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9537 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0302, (cst_val *)&val_2149},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0303, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9538 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0305, (cst_val *)&val_5698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9541 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0309, (cst_val *)&val_0068},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0310, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9543 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0313, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9544 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0315, (cst_val *)&val_9545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9547 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0318, (cst_val *)&val_4659},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_107_NO_0319, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9550 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_l_107_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_rms_single_mcep_l_107_cart = {
  cmu_us_rms_single_mcep_l_107_cart_nodes,
  cmu_us_rms_single_mcep_l_107_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_l_108_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0001, (cst_val *)&val_9551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9552 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0003, (cst_val *)&val_0693},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0004, (cst_val *)&val_0000},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0005, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9554 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0008, (cst_val *)&val_6153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9555 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0010, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9557 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0013, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0014, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9559 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0017, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9560 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0019, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9562 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0022, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0023, (cst_val *)&val_9563},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0024, (cst_val *)&val_5077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9564 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0026, (cst_val *)&val_9565},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0027, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9567 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0030, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9568 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0032, (cst_val *)&val_1602},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0033, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9571 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0037, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9572 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0039, (cst_val *)&val_0739},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0040, (cst_val *)&val_0493},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0041, (cst_val *)&val_9573},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9575 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0044, (cst_val *)&val_9576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9578 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0047, (cst_val *)&val_0059},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0048, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9580 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0051, (cst_val *)&val_2417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9581 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0053, (cst_val *)&val_9582},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0054, (cst_val *)&val_0267},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0055, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9586 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0060, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0061, (cst_val *)&val_0361},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0062, (cst_val *)&val_1223},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0063, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9588 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0066, (cst_val *)&val_2588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9589 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0068, (cst_val *)&val_1769},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0069, (cst_val *)&val_9590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9593 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0073, (cst_val *)&val_0097},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0074, (cst_val *)&val_0933},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0075, (cst_val *)&val_0165},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0076, (cst_val *)&val_9594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9595 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0078, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9597 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0081, (cst_val *)&val_1029},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0082, (cst_val *)&val_5084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9599 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0085, (cst_val *)&val_9600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9602 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0088, (cst_val *)&val_1029},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0089, (cst_val *)&val_5260},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0090, (cst_val *)&val_9603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9605 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0093, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9607 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0096, (cst_val *)&val_4077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0097, (cst_val *)&val_0128},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0098, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9609 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0101, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9612 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0105, (cst_val *)&val_0125},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0106, (cst_val *)&val_0165},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0107, (cst_val *)&val_5854},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9613 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0109, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9615 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0112, (cst_val *)&val_3810},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0113, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9618 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0117, (cst_val *)&val_0120},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0118, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9620 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0121, (cst_val *)&val_2645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9621 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0123, (cst_val *)&val_9622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9624 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0126, (cst_val *)&val_0128},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0127, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0128, (cst_val *)&val_4299},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0129, (cst_val *)&val_9625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9627 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0132, (cst_val *)&val_0039},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0133, (cst_val *)&val_9628},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9629 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0135, (cst_val *)&val_9630},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9631 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0137, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9632 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0139, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9634 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0142, (cst_val *)&val_0251},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0143, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9637 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0147, (cst_val *)&val_0361},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0148, (cst_val *)&val_9151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9639 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0151, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9640 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0153, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0154, (cst_val *)&val_3061},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0155, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9641 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0157, (cst_val *)&val_3254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9642 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0159, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9644 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0162, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9646 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0165, (cst_val *)&val_5419},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0166, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9648 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0169, (cst_val *)&val_1610},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0170, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9651 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0174, (cst_val *)&val_1527},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0175, (cst_val *)&val_3210},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0176, (cst_val *)&val_3567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9652 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0178, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9654 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0181, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9656 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0184, (cst_val *)&val_2670},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0185, (cst_val *)&val_9657},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0186, (cst_val *)&val_0361},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0187, (cst_val *)&val_0870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9658 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0189, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9660 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0192, (cst_val *)&val_0040},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0193, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9662 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0196, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9665 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0200, (cst_val *)&val_0361},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0201, (cst_val *)&val_3157},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9666 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0203, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9668 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0206, (cst_val *)&val_2805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9669 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0208, (cst_val *)&val_0031},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0209, (cst_val *)&val_0211},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0210, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9671 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0213, (cst_val *)&val_4456},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_l_108_NO_0214, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9675 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_l_108_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_rms_single_mcep_l_108_cart = {
  cmu_us_rms_single_mcep_l_108_cart_nodes,
  cmu_us_rms_single_mcep_l_108_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_z_199_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0000, (cst_val *)&val_0219},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0001, (cst_val *)&val_0979},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0002, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0003, (cst_val *)&val_0128},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0004, (cst_val *)&val_6919},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0005, (cst_val *)&val_2423},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0006, (cst_val *)&val_9676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9679 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0010, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0011, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9680 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0013, (cst_val *)&val_9681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9683 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0016, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9684 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0018, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9686 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0021, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9688 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0024, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9689 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0026, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0027, (cst_val *)&val_9690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9693 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0031, (cst_val *)&val_0361},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0032, (cst_val *)&val_0651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9694 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0034, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9696 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0037, (cst_val *)&val_9697},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0038, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0039, (cst_val *)&val_5776},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0040, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0041, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9698 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0043, (cst_val *)&val_6873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9700 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0046, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9702 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0049, (cst_val *)&val_0007},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0050, (cst_val *)&val_6919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9704 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0053, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9705 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0055, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0056, (cst_val *)&val_8514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9708 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0060, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9710 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0063, (cst_val *)&val_0211},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0064, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9712 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0067, (cst_val *)&val_0043},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0068, (cst_val *)&val_2626},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0069, (cst_val *)&val_9713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9715 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0072, (cst_val *)&val_4537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9717 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0075, (cst_val *)&val_9718},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9720 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0078, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9721 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0080, (cst_val *)&val_3313},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0081, (cst_val *)&val_4573},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0082, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9724 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0086, (cst_val *)&val_1249},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0087, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9725 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0089, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9727 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_199_NO_0092, (cst_val *)&val_2112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9729 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_z_199_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_rms_single_mcep_z_199_cart = {
  cmu_us_rms_single_mcep_z_199_cart_nodes,
  cmu_us_rms_single_mcep_z_199_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_z_200_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0000, (cst_val *)&val_0642},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0001, (cst_val *)&val_0043},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0002, (cst_val *)&val_0403},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0003, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9731 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0006, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0007, (cst_val *)&val_0220},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0008, (cst_val *)&val_7081},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0009, (cst_val *)&val_0056},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0010, (cst_val *)&val_9732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9735 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0014, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9737 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0017, (cst_val *)&val_0145},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0018, (cst_val *)&val_0361},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0019, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9739 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0022, (cst_val *)&val_9740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9741 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0024, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9743 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0027, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9744 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0029, (cst_val *)&val_9745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9746 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0031, (cst_val *)&val_9747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9749 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0034, (cst_val *)&val_0025},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0035, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9750 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0037, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9752 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0040, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9754 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0043, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0044, (cst_val *)&val_1301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9756 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0047, (cst_val *)&val_0045},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0048, (cst_val *)&val_7081},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0049, (cst_val *)&val_0220},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0050, (cst_val *)&val_9732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9758 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0053, (cst_val *)&val_9759},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9760 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0055, (cst_val *)&val_9761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9763 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0058, (cst_val *)&val_0068},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0059, (cst_val *)&val_0220},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0060, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9766 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0064, (cst_val *)&val_9767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9769 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0067, (cst_val *)&val_0025},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0068, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9770 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0070, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9772 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0073, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9774 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0076, (cst_val *)&val_0120},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0077, (cst_val *)&val_9775},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0078, (cst_val *)&val_4573},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0079, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0080, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9776 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0082, (cst_val *)&val_9777},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9778 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0084, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9779 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0086, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9781 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0089, (cst_val *)&val_9782},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0090, (cst_val *)&val_0358},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0091, (cst_val *)&val_0008},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0092, (cst_val *)&val_9783},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0093, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9786 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0097, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9787 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0099, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9789 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0102, (cst_val *)&val_0165},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0103, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9790 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0105, (cst_val *)&val_0025},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0106, (cst_val *)&val_9791},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9793 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0109, (cst_val *)&val_0140},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0110, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9796 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0114, (cst_val *)&val_0860},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0115, (cst_val *)&val_2221},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0116, (cst_val *)&val_3475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9800 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0121, (cst_val *)&val_0008},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0122, (cst_val *)&val_0626},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0123, (cst_val *)&val_0663},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9802 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0126, (cst_val *)&val_3981},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0127, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9805 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0131, (cst_val *)&val_1740},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0132, (cst_val *)&val_9806},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0133, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9808 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0136, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9809 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0138, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9810 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0140, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9812 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0143, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9814 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0146, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0147, (cst_val *)&val_0403},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0148, (cst_val *)&val_9815},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9816 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0150, (cst_val *)&val_6202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9818 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0153, (cst_val *)&val_0025},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0154, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9819 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0156, (cst_val *)&val_9820},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9822 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0159, (cst_val *)&val_0128},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0160, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9823 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0162, (cst_val *)&val_9824},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0163, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9826 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0166, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9829 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0170, (cst_val *)&val_0128},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0171, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9830 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0173, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0174, (cst_val *)&val_9831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9834 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0178, (cst_val *)&val_0403},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0179, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9836 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0182, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9837 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0184, (cst_val *)&val_9838},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0185, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9840 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0188, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9841 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0190, (cst_val *)&val_4024},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0191, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9844 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0195, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0196, (cst_val *)&val_0403},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0197, (cst_val *)&val_6202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9846 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0200, (cst_val *)&val_0128},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0201, (cst_val *)&val_9847},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9848 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0203, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9849 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0205, (cst_val *)&val_9850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9853 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0209, (cst_val *)&val_0036},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0210, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9854 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0212, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9855 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0214, (cst_val *)&val_0030},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0215, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9856 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0217, (cst_val *)&val_9857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9858 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0219, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9860 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0222, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0223, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9861 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0225, (cst_val *)&val_9862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9865 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0229, (cst_val *)&val_2846},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0230, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0231, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9866 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0233, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9868 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0236, (cst_val *)&val_0040},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0237, (cst_val *)&val_0025},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0238, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9870 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0241, (cst_val *)&val_0059},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0242, (cst_val *)&val_0008},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0243, (cst_val *)&val_0165},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0244, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9873 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0248, (cst_val *)&val_2548},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0249, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9875 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0252, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9878 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0256, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9880 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0259, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9881 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0261, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0262, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9883 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0265, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9884 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0267, (cst_val *)&val_0045},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0268, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9887 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0272, (cst_val *)&val_0361},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0273, (cst_val *)&val_0517},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0274, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9889 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0277, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9890 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0279, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9891 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0281, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9893 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0284, (cst_val *)&val_9894},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0285, (cst_val *)&val_0077},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0286, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9895 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0288, (cst_val *)&val_9896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9897 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0290, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9898 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0292, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9900 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0295, (cst_val *)&val_0940},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0296, (cst_val *)&val_0045},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0297, (cst_val *)&val_0637},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0298, (cst_val *)&val_0145},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0299, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9904 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0304, (cst_val *)&val_0025},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0305, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9906 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0308, (cst_val *)&val_5154},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0309, (cst_val *)&val_0145},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0310, (cst_val *)&val_0040},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0311, (cst_val *)&val_2164},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0312, (cst_val *)&val_1992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9910 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0317, (cst_val *)&val_3295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9912 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0320, (cst_val *)&val_7183},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0321, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9915 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0325, (cst_val *)&val_0040},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0326, (cst_val *)&val_4332},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0327, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9916 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0329, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9918 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0332, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9921 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0336, (cst_val *)&val_9922},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0337, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0338, (cst_val *)&val_4782},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0339, (cst_val *)&val_8518},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9926 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_200_NO_0344, (cst_val *)&val_9927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9929 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_z_200_feat_table[] = {
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_single_mcep_z_200_cart = {
  cmu_us_rms_single_mcep_z_200_cart_nodes,
  cmu_us_rms_single_mcep_z_200_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_z_201_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0001, (cst_val *)&val_0231},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0002, (cst_val *)&val_0056},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0003, (cst_val *)&val_9930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9932 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0006, (cst_val *)&val_9933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9935 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0009, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9937 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0012, (cst_val *)&val_0077},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0013, (cst_val *)&val_0629},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0014, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9939 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0017, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9940 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0019, (cst_val *)&val_0358},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0020, (cst_val *)&val_4374},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0021, (cst_val *)&val_6573},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0022, (cst_val *)&val_9941},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9944 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0026, (cst_val *)&val_0097},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0027, (cst_val *)&val_0671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9948 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0032, (cst_val *)&val_0361},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0033, (cst_val *)&val_9949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9950 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0035, (cst_val *)&val_0493},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0036, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9951 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0038, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9953 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0041, (cst_val *)&val_4714},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0042, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9955 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0045, (cst_val *)&val_9956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9957 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0047, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9959 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0050, (cst_val *)&val_9960},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0051, (cst_val *)&val_0739},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0052, (cst_val *)&val_1383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9962 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0055, (cst_val *)&val_4202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9964 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0058, (cst_val *)&val_0220},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0059, (cst_val *)&val_9965},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0060, (cst_val *)&val_2184},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0061, (cst_val *)&val_9966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9968 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0064, (cst_val *)&val_0171},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0065, (cst_val *)&val_7081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9969 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0067, (cst_val *)&val_0040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0068, (cst_val *)&val_6696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9972 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9974 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0075, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0076, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9976 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0079, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9978 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0082, (cst_val *)&val_4651},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0083, (cst_val *)&val_0009},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0084, (cst_val *)&val_9979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9980 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0086, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9983 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_z_201_NO_0090, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9985 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_z_201_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_z_201_cart = {
  cmu_us_rms_single_mcep_z_201_cart_nodes,
  cmu_us_rms_single_mcep_z_201_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_pau_161_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0001, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0002, (cst_val *)&val_1579},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0003, (cst_val *)&val_2097},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0004, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9986 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0006, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9987 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0008, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9989 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0011, (cst_val *)&val_0125},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0012, (cst_val *)&val_0043},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0013, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9991 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0016, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9993 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0019, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0020, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9996 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0024, (cst_val *)&val_0982},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0025, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0026, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9999 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0030, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10000 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0032, (cst_val *)&val_5498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10001 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0034, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10003 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0037, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0038, (cst_val *)&val_1158},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0039, (cst_val *)&val_1232},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0040, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10004 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0042, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10007 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0046, (cst_val *)&val_0051},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0047, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0048, (cst_val *)&val_3227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10009 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0051, (cst_val *)&val_2846},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0052, (cst_val *)&val_0403},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0053, (cst_val *)&val_4537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10011 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0056, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10014 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0060, (cst_val *)&val_0125},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0061, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10016 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0064, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10018 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0067, (cst_val *)&val_0629},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0068, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10020 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0071, (cst_val *)&val_0077},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0072, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0073, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10021 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0075, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10023 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0078, (cst_val *)&val_1700},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0079, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10024 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0081, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10025 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0083, (cst_val *)&val_10026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10028 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0086, (cst_val *)&val_4042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10030 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0089, (cst_val *)&val_10031},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0090, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10032 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0092, (cst_val *)&val_6701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10033 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0094, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10034 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0096, (cst_val *)&val_0025},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0097, (cst_val *)&val_1035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10037 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0101, (cst_val *)&val_1965},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0102, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10038 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0104, (cst_val *)&val_2208},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0105, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10040 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0108, (cst_val *)&val_0574},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0109, (cst_val *)&val_9486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10042 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0112, (cst_val *)&val_0307},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0113, (cst_val *)&val_3810},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0114, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10044 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0117, (cst_val *)&val_4663},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10046 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0120, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0121, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10048 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0124, (cst_val *)&val_1610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10051 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0128, (cst_val *)&val_0068},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0129, (cst_val *)&val_0307},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0130, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10053 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0133, (cst_val *)&val_1579},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0134, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10054 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0136, (cst_val *)&val_5934},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0137, (cst_val *)&val_3596},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10055 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0139, (cst_val *)&val_10056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10058 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0142, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10059 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0144, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10061 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0147, (cst_val *)&val_10062},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0148, (cst_val *)&val_0975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10064 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0151, (cst_val *)&val_0145},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0152, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10067 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0156, (cst_val *)&val_0239},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0157, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0158, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0159, (cst_val *)&val_0043},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0160, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10068 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0162, (cst_val *)&val_5512},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0163, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10070 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0166, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10072 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0169, (cst_val *)&val_0008},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0170, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10074 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0173, (cst_val *)&val_2805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10075 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0175, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10077 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0178, (cst_val *)&val_0785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10079 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0181, (cst_val *)&val_0307},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0182, (cst_val *)&val_0043},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0183, (cst_val *)&val_0029},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0184, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10082 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0188, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10083 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0190, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10085 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0193, (cst_val *)&val_0077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0194, (cst_val *)&val_4374},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0195, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10087 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0198, (cst_val *)&val_0239},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0199, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10088 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0201, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10091 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0205, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0206, (cst_val *)&val_6728},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0207, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0208, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10093 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0211, (cst_val *)&val_0246},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0212, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10095 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0215, (cst_val *)&val_0043},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0216, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10099 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0221, (cst_val *)&val_10100},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0222, (cst_val *)&val_0997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10102 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0225, (cst_val *)&val_0183},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0226, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0227, (cst_val *)&val_0723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10104 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0230, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10106 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0233, (cst_val *)&val_1232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0234, (cst_val *)&val_0724},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0235, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10107 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0237, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10109 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0240, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10111 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0243, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10112 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0245, (cst_val *)&val_6308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10114 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0248, (cst_val *)&val_0307},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0249, (cst_val *)&val_0019},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0250, (cst_val *)&val_10115},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0251, (cst_val *)&val_0715},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0252, (cst_val *)&val_3233},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0253, (cst_val *)&val_1983},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10117 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0256, (cst_val *)&val_10118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10120 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0259, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10123 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0263, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0264, (cst_val *)&val_1749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10124 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0266, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10126 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0269, (cst_val *)&val_1705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10128 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0272, (cst_val *)&val_1857},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0273, (cst_val *)&val_0246},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0274, (cst_val *)&val_3475},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0275, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10130 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0278, (cst_val *)&val_0025},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0279, (cst_val *)&val_9103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10133 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0283, (cst_val *)&val_0361},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0284, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10135 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0287, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0288, (cst_val *)&val_0008},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0289, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10136 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0291, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10138 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0294, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0295, (cst_val *)&val_8519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10140 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0298, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10142 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0301, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10144 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0304, (cst_val *)&val_0492},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0305, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10146 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0308, (cst_val *)&val_10147},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0309, (cst_val *)&val_0629},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0310, (cst_val *)&val_10148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10150 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0313, (cst_val *)&val_6128},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0314, (cst_val *)&val_0059},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0315, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10151 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0317, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10154 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0321, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10155 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0323, (cst_val *)&val_4651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10157 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0326, (cst_val *)&val_0145},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_161_NO_0327, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10160 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_pau_161_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_rms_single_mcep_pau_161_cart = {
  cmu_us_rms_single_mcep_pau_161_cart_nodes,
  cmu_us_rms_single_mcep_pau_161_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_s_151_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0000, (cst_val *)&val_0011},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0001, (cst_val *)&val_1795},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0002, (cst_val *)&val_0025},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0003, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0004, (cst_val *)&val_5512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10161 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0006, (cst_val *)&val_0056},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0007, (cst_val *)&val_0492},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0008, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10164 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0012, (cst_val *)&val_0492},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0013, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10167 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0017, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0018, (cst_val *)&val_2435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10170 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0022, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0023, (cst_val *)&val_0629},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0024, (cst_val *)&val_0040},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0025, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10173 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0029, (cst_val *)&val_4088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10174 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0031, (cst_val *)&val_10175},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0032, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10176 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0034, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10177 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0036, (cst_val *)&val_0829},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0037, (cst_val *)&val_1029},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0038, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10179 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0041, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10181 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0044, (cst_val *)&val_0008},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0045, (cst_val *)&val_6728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10183 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0048, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10185 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0051, (cst_val *)&val_0008},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0052, (cst_val *)&val_2640},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0053, (cst_val *)&val_10186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10189 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0057, (cst_val *)&val_0829},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0058, (cst_val *)&val_0043},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0059, (cst_val *)&val_10190},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10193 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0063, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10195 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0066, (cst_val *)&val_0068},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0067, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10196 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0069, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10198 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0072, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10199 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0074, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10200 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0076, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10201 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0078, (cst_val *)&val_10202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10203 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0080, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10205 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0083, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0084, (cst_val *)&val_0220},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0085, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0086, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10206 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0088, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10208 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0091, (cst_val *)&val_0025},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0092, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10210 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0095, (cst_val *)&val_0068},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0096, (cst_val *)&val_2640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10213 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0100, (cst_val *)&val_0025},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0101, (cst_val *)&val_0030},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0102, (cst_val *)&val_10214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10216 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0105, (cst_val *)&val_2640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10217 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0107, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10219 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0110, (cst_val *)&val_0057},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0111, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10220 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0113, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10221 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0115, (cst_val *)&val_0008},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0116, (cst_val *)&val_10222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10224 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0119, (cst_val *)&val_0025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0120, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10226 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0123, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10228 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0126, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10230 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0129, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0130, (cst_val *)&val_0492},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0131, (cst_val *)&val_0220},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0132, (cst_val *)&val_2275},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10232 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0135, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0136, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10233 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0138, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10236 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0142, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10237 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0144, (cst_val *)&val_0077},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0145, (cst_val *)&val_0362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10239 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0148, (cst_val *)&val_1232},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0149, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0150, (cst_val *)&val_0270},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0151, (cst_val *)&val_0852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10241 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0154, (cst_val *)&val_4302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10243 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0157, (cst_val *)&val_2435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10245 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0160, (cst_val *)&val_3313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10247 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0163, (cst_val *)&val_0112},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0164, (cst_val *)&val_10248},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0165, (cst_val *)&val_10249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10252 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0169, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10253 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0171, (cst_val *)&val_10254},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0172, (cst_val *)&val_10255},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0173, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10257 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0176, (cst_val *)&val_10258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10260 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0179, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10262 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0182, (cst_val *)&val_10263},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0183, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0184, (cst_val *)&val_0492},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0185, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0186, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10264 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0188, (cst_val *)&val_3810},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0189, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10267 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0193, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10269 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0196, (cst_val *)&val_0505},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0197, (cst_val *)&val_10270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10272 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0200, (cst_val *)&val_0040},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0201, (cst_val *)&val_0307},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0202, (cst_val *)&val_2487},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0203, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10275 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0207, (cst_val *)&val_1232},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0208, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10277 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0211, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10279 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0214, (cst_val *)&val_1511},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0215, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10282 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0219, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0220, (cst_val *)&val_0785},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0221, (cst_val *)&val_0068},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0222, (cst_val *)&val_5439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10283 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0224, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10284 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0226, (cst_val *)&val_10285},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10286 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0228, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10288 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0231, (cst_val *)&val_0730},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0232, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10289 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0234, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10290 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0236, (cst_val *)&val_10291},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10292 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0238, (cst_val *)&val_0025},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0239, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10294 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0242, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10296 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0245, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10298 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0248, (cst_val *)&val_0361},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0249, (cst_val *)&val_0629},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0250, (cst_val *)&val_8514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10300 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0253, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10301 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0255, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10303 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0258, (cst_val *)&val_3708},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0259, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10305 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0262, (cst_val *)&val_0629},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0263, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10307 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0266, (cst_val *)&val_10308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10309 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0268, (cst_val *)&val_0068},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0269, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10311 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0272, (cst_val *)&val_0251},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0273, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10313 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0276, (cst_val *)&val_10314},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0277, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10317 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0281, (cst_val *)&val_0112},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0282, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10319 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0285, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0286, (cst_val *)&val_0246},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0287, (cst_val *)&val_10320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10323 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0291, (cst_val *)&val_10324},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0292, (cst_val *)&val_10325},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0293, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10327 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0296, (cst_val *)&val_0040},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0297, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10331 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0302, (cst_val *)&val_10332},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0303, (cst_val *)&val_0040},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0304, (cst_val *)&val_0045},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0305, (cst_val *)&val_10333},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0306, (cst_val *)&val_3708},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0307, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10335 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0310, (cst_val *)&val_0059},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0311, (cst_val *)&val_10336},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0312, (cst_val *)&val_1647},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0313, (cst_val *)&val_0422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10338 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0316, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10340 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0319, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10341 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0321, (cst_val *)&val_0165},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0322, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10343 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0325, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10345 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0328, (cst_val *)&val_0505},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0329, (cst_val *)&val_10346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10348 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0332, (cst_val *)&val_10349},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0333, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10351 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0336, (cst_val *)&val_0492},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0337, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10353 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0340, (cst_val *)&val_0448},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0341, (cst_val *)&val_0246},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0342, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10354 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0344, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10355 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0346, (cst_val *)&val_10356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10357 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0348, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10359 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0351, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10360 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0353, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10362 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0356, (cst_val *)&val_0034},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0357, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10365 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0361, (cst_val *)&val_0018},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0362, (cst_val *)&val_10366},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0363, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10368 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0366, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10370 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0369, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10371 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0371, (cst_val *)&val_10372},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0372, (cst_val *)&val_1647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10374 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0375, (cst_val *)&val_0008},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0376, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10376 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0379, (cst_val *)&val_3316},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0380, (cst_val *)&val_0040},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0381, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10378 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0384, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10379 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0386, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10382 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0390, (cst_val *)&val_0059},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0391, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10383 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0393, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10384 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0395, (cst_val *)&val_2213},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0396, (cst_val *)&val_6312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10387 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0400, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10388 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0402, (cst_val *)&val_10389},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0403, (cst_val *)&val_10390},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0404, (cst_val *)&val_0068},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0405, (cst_val *)&val_10391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10394 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0409, (cst_val *)&val_0068},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0410, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0411, (cst_val *)&val_10395},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0412, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10397 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0415, (cst_val *)&val_10398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10400 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0418, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10401 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0420, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10402 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0422, (cst_val *)&val_0831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10404 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0425, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10406 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0428, (cst_val *)&val_0025},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0429, (cst_val *)&val_2237},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0430, (cst_val *)&val_10407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10408 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0432, (cst_val *)&val_10409},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0433, (cst_val *)&val_0045},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0434, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10414 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0440, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10415 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0442, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10416 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0444, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10418 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0447, (cst_val *)&val_0008},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0448, (cst_val *)&val_10419},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0449, (cst_val *)&val_4172},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0450, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10422 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0454, (cst_val *)&val_0068},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0455, (cst_val *)&val_10423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10424 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0457, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10425 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0459, (cst_val *)&val_10426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10428 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0462, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0463, (cst_val *)&val_8988},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0464, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10431 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0468, (cst_val *)&val_0629},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0469, (cst_val *)&val_10432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10434 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0472, (cst_val *)&val_10435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10437 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0475, (cst_val *)&val_0629},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0476, (cst_val *)&val_8514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10439 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0479, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10440 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0481, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10442 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0484, (cst_val *)&val_0025},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0485, (cst_val *)&val_0068},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0486, (cst_val *)&val_0944},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0487, (cst_val *)&val_0145},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0488, (cst_val *)&val_0043},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0489, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10445 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0493, (cst_val *)&val_10446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10450 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0498, (cst_val *)&val_0297},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0499, (cst_val *)&val_10451},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0500, (cst_val *)&val_0040},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0501, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10452 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0503, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10453 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0505, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10456 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0509, (cst_val *)&val_0040},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0510, (cst_val *)&val_0128},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0511, (cst_val *)&val_10457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10459 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0514, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10462 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0518, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0519, (cst_val *)&val_5520},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0520, (cst_val *)&val_0045},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0521, (cst_val *)&val_0940},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0522, (cst_val *)&val_10463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10465 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0525, (cst_val *)&val_1697},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0526, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10469 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0531, (cst_val *)&val_0145},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0532, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0533, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10471 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0536, (cst_val *)&val_3616},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0537, (cst_val *)&val_10472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10473 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0539, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10476 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0543, (cst_val *)&val_0040},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0544, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10479 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0548, (cst_val *)&val_0008},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0549, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10481 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0552, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10482 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_151_NO_0554, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10484 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_s_151_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_single_mcep_s_151_cart = {
  cmu_us_rms_single_mcep_s_151_cart_nodes,
  cmu_us_rms_single_mcep_s_151_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_s_152_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0000, (cst_val *)&val_10485},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0001, (cst_val *)&val_2855},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0002, (cst_val *)&val_0220},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0003, (cst_val *)&val_0040},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0004, (cst_val *)&val_0056},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0005, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10486 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0007, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10488 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0010, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10490 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0013, (cst_val *)&val_0403},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0014, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10492 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0017, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10494 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0020, (cst_val *)&val_0112},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0021, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10496 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0024, (cst_val *)&val_0403},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0025, (cst_val *)&val_0140},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0026, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10498 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0029, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10500 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0032, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0033, (cst_val *)&val_0128},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0034, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0035, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10503 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0039, (cst_val *)&val_0059},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0040, (cst_val *)&val_0008},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0041, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10505 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0044, (cst_val *)&val_2846},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0045, (cst_val *)&val_7965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10508 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0049, (cst_val *)&val_5855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10510 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0052, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10511 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0054, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10513 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0057, (cst_val *)&val_0010},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0058, (cst_val *)&val_0025},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0059, (cst_val *)&val_0043},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0060, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10514 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0062, (cst_val *)&val_8609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10515 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0064, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10517 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0067, (cst_val *)&val_0024},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0068, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10518 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0070, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10520 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0073, (cst_val *)&val_10521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10523 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0076, (cst_val *)&val_1223},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0077, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10525 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0080, (cst_val *)&val_0068},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0081, (cst_val *)&val_1743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10527 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0084, (cst_val *)&val_1569},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0085, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10528 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0087, (cst_val *)&val_0040},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0088, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10531 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0092, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10533 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0095, (cst_val *)&val_0112},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0096, (cst_val *)&val_0019},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0097, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10534 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0099, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10536 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0102, (cst_val *)&val_2213},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0103, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10537 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0105, (cst_val *)&val_0429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10540 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0109, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0110, (cst_val *)&val_0403},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0111, (cst_val *)&val_0045},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0112, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10542 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0115, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10544 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0118, (cst_val *)&val_0025},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0119, (cst_val *)&val_10545},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0120, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0121, (cst_val *)&val_10546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10547 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0123, (cst_val *)&val_10548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10551 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0127, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10552 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0129, (cst_val *)&val_10553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10555 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0132, (cst_val *)&val_2221},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0133, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10557 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0136, (cst_val *)&val_0040},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0137, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10558 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0139, (cst_val *)&val_0059},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0140, (cst_val *)&val_4007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10560 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0143, (cst_val *)&val_0008},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0144, (cst_val *)&val_10561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10564 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0148, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10566 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0151, (cst_val *)&val_0040},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0152, (cst_val *)&val_3493},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0153, (cst_val *)&val_0045},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0154, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10569 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0158, (cst_val *)&val_0045},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0159, (cst_val *)&val_4214},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0160, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10570 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0162, (cst_val *)&val_0901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10571 },
{ 30, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0164, (cst_val *)&val_10572},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10574 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0167, (cst_val *)&val_10575},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0168, (cst_val *)&val_10576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10578 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0171, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10579 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0173, (cst_val *)&val_0059},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0174, (cst_val *)&val_0008},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0175, (cst_val *)&val_7739},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0176, (cst_val *)&val_1789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10582 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0180, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10584 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0183, (cst_val *)&val_0041},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0184, (cst_val *)&val_2405},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0185, (cst_val *)&val_10585},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10587 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0188, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10588 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0190, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10591 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0194, (cst_val *)&val_0059},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0195, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10593 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0198, (cst_val *)&val_10594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10595 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0200, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10596 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0202, (cst_val *)&val_6202},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0203, (cst_val *)&val_0611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10599 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0207, (cst_val *)&val_10600},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0208, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10601 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0210, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10602 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0212, (cst_val *)&val_0025},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0213, (cst_val *)&val_0016},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0214, (cst_val *)&val_0059},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0215, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10605 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0219, (cst_val *)&val_0122},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0220, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10607 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0223, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10609 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0226, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10611 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0229, (cst_val *)&val_0246},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0230, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0231, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10613 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0234, (cst_val *)&val_7739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10615 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0237, (cst_val *)&val_10616},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0238, (cst_val *)&val_8473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10618 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0241, (cst_val *)&val_0025},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0242, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10619 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0244, (cst_val *)&val_10620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10623 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0248, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0249, (cst_val *)&val_1223},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0250, (cst_val *)&val_0025},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0251, (cst_val *)&val_0068},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0252, (cst_val *)&val_0026},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0253, (cst_val *)&val_1265},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0254, (cst_val *)&val_10624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10626 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0257, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10628 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0260, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10629 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0262, (cst_val *)&val_0956},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0263, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10633 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0268, (cst_val *)&val_0026},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0269, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10634 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0271, (cst_val *)&val_0045},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0272, (cst_val *)&val_2164},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0273, (cst_val *)&val_0902},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0274, (cst_val *)&val_10635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10637 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0277, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10638 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0279, (cst_val *)&val_10639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10641 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0282, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10642 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0284, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10644 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0287, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10646 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0290, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0291, (cst_val *)&val_0973},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0292, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10647 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0294, (cst_val *)&val_10648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10649 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0296, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10650 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0298, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10651 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0300, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10653 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0303, (cst_val *)&val_0008},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0304, (cst_val *)&val_10654},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0305, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10657 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0309, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10658 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0311, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10660 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0314, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10661 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0316, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10662 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0318, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10664 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0321, (cst_val *)&val_0068},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0322, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10665 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0324, (cst_val *)&val_0978},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0325, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10666 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0327, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10668 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0330, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10669 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0332, (cst_val *)&val_10670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10672 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0335, (cst_val *)&val_0539},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0336, (cst_val *)&val_0403},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0337, (cst_val *)&val_10673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10675 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0340, (cst_val *)&val_1795},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0341, (cst_val *)&val_0008},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0342, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10676 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0344, (cst_val *)&val_10677},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10679 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0347, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10680 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0349, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10682 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0352, (cst_val *)&val_0128},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0353, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10683 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0355, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10685 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0358, (cst_val *)&val_0059},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0359, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10687 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0362, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10688 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0364, (cst_val *)&val_10689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10691 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0367, (cst_val *)&val_8618},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0368, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10693 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0371, (cst_val *)&val_0040},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0372, (cst_val *)&val_10694},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0373, (cst_val *)&val_10695},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10697 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0376, (cst_val *)&val_10698},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0377, (cst_val *)&val_0074},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0378, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10700 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0381, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10704 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0386, (cst_val *)&val_0008},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0387, (cst_val *)&val_0236},
{ 30, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0388, (cst_val *)&val_10705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10706 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0390, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10708 },
{ 30, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0393, (cst_val *)&val_10709},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0394, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10711 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0397, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10713 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0400, (cst_val *)&val_0199},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0401, (cst_val *)&val_0025},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0402, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10714 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0404, (cst_val *)&val_6062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10716 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0407, (cst_val *)&val_0629},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0408, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10718 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0411, (cst_val *)&val_8441},
{ 36, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0412, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10719 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0414, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10722 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0418, (cst_val *)&val_1462},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0419, (cst_val *)&val_4651},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0420, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10724 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0423, (cst_val *)&val_9225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10725 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0425, (cst_val *)&val_2405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10727 },
{ 36, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0428, (cst_val *)&val_0220},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0429, (cst_val *)&val_10728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10730 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_152_NO_0432, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10732 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_s_152_feat_table[] = {
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_rms_single_mcep_s_152_cart = {
  cmu_us_rms_single_mcep_s_152_cart_nodes,
  cmu_us_rms_single_mcep_s_152_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_s_153_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0000, (cst_val *)&val_3596},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0001, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0002, (cst_val *)&val_8627},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0003, (cst_val *)&val_0056},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0004, (cst_val *)&val_0283},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0005, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10734 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0008, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10736 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0011, (cst_val *)&val_0973},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0012, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10737 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0014, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10739 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0017, (cst_val *)&val_2815},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10741 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0020, (cst_val *)&val_0251},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0021, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10743 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0024, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10745 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0027, (cst_val *)&val_3107},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0028, (cst_val *)&val_10746},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0029, (cst_val *)&val_0358},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0030, (cst_val *)&val_10747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10748 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0032, (cst_val *)&val_0165},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0033, (cst_val *)&val_10749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10751 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0036, (cst_val *)&val_10752},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10754 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0039, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10755 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0041, (cst_val *)&val_10756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10758 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0044, (cst_val *)&val_0016},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0045, (cst_val *)&val_0145},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0046, (cst_val *)&val_3412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10760 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0049, (cst_val *)&val_8441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10762 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0052, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10765 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0056, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0057, (cst_val *)&val_0097},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0058, (cst_val *)&val_0933},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0059, (cst_val *)&val_10766},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0060, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10767 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0062, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10768 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0064, (cst_val *)&val_10769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10771 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0067, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10773 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0070, (cst_val *)&val_9196},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0071, (cst_val *)&val_10774},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0072, (cst_val *)&val_0934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10777 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0076, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10779 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0079, (cst_val *)&val_0140},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0080, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10780 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0082, (cst_val *)&val_2919},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0083, (cst_val *)&val_10781},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0084, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10783 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0087, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10786 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0091, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10787 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0093, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10789 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0096, (cst_val *)&val_0361},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0097, (cst_val *)&val_0056},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0098, (cst_val *)&val_10790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10792 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0101, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10793 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0103, (cst_val *)&val_10794},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0104, (cst_val *)&val_3968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10796 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0107, (cst_val *)&val_3246},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0108, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10799 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0112, (cst_val *)&val_0933},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0113, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10800 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0115, (cst_val *)&val_0068},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0116, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10802 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0119, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10803 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0121, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10804 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0123, (cst_val *)&val_10805},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0124, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10807 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0127, (cst_val *)&val_10808},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0128, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10811 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0132, (cst_val *)&val_0068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0133, (cst_val *)&val_10812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10814 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0136, (cst_val *)&val_0251},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0137, (cst_val *)&val_10815},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0138, (cst_val *)&val_4024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10817 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0141, (cst_val *)&val_10818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10820 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0144, (cst_val *)&val_0733},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_s_153_NO_0145, (cst_val *)&val_10821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10824 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_s_153_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_s_153_cart = {
  cmu_us_rms_single_mcep_s_153_cart_nodes,
  cmu_us_rms_single_mcep_s_153_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_eh_56_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0001, (cst_val *)&val_0403},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0002, (cst_val *)&val_1565},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0003, (cst_val *)&val_6202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10825 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0005, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10827 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0008, (cst_val *)&val_0408},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0009, (cst_val *)&val_4626},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0010, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10828 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0012, (cst_val *)&val_0068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0013, (cst_val *)&val_1634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10830 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0016, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10834 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0021, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0022, (cst_val *)&val_0403},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0023, (cst_val *)&val_4152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10835 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0025, (cst_val *)&val_10836},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0026, (cst_val *)&val_1993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10838 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0029, (cst_val *)&val_0325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10840 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0032, (cst_val *)&val_2152},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0033, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10841 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0035, (cst_val *)&val_0219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10842 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0037, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10844 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0040, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10846 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0043, (cst_val *)&val_0505},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0044, (cst_val *)&val_0140},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0045, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10848 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0048, (cst_val *)&val_1189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10850 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0051, (cst_val *)&val_0009},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0052, (cst_val *)&val_3256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10851 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0054, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10852 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0056, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10853 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0058, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10854 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0060, (cst_val *)&val_10855},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0061, (cst_val *)&val_10856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10857 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0063, (cst_val *)&val_10858},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10860 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0066, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10862 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0069, (cst_val *)&val_1342},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0070, (cst_val *)&val_1917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10863 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0072, (cst_val *)&val_10864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10865 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0074, (cst_val *)&val_10866},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0075, (cst_val *)&val_1778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10868 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0078, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0079, (cst_val *)&val_0165},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0080, (cst_val *)&val_2469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10872 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0085, (cst_val *)&val_0403},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0086, (cst_val *)&val_10873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10874 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0088, (cst_val *)&val_4513},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10876 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0091, (cst_val *)&val_0112},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0092, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10877 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0094, (cst_val *)&val_0024},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0095, (cst_val *)&val_10878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10881 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0099, (cst_val *)&val_10882},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0100, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10885 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0104, (cst_val *)&val_10886},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0105, (cst_val *)&val_0417},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0106, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10888 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0109, (cst_val *)&val_1921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10889 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0111, (cst_val *)&val_0546},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0112, (cst_val *)&val_0056},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0113, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10892 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0117, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10893 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0119, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10894 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0121, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10896 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0124, (cst_val *)&val_0403},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0125, (cst_val *)&val_10897},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0126, (cst_val *)&val_5922},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0127, (cst_val *)&val_4659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10899 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0130, (cst_val *)&val_10900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10902 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0133, (cst_val *)&val_10903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10905 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0136, (cst_val *)&val_0040},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0137, (cst_val *)&val_10906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10908 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0140, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0141, (cst_val *)&val_5863},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0142, (cst_val *)&val_10909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10910 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0144, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10912 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0147, (cst_val *)&val_5105},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0148, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10913 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0150, (cst_val *)&val_10914},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0151, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10917 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0155, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10919 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0158, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0159, (cst_val *)&val_1921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10921 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0162, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0163, (cst_val *)&val_3000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10923 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0166, (cst_val *)&val_4240},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0167, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10925 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_56_NO_0170, (cst_val *)&val_10926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10928 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_eh_56_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_single_mcep_eh_56_cart = {
  cmu_us_rms_single_mcep_eh_56_cart_nodes,
  cmu_us_rms_single_mcep_eh_56_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_eh_57_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0000, (cst_val *)&val_0183},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0001, (cst_val *)&val_0361},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0002, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10929 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0004, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10930 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0006, (cst_val *)&val_4546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10932 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0009, (cst_val *)&val_1038},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0010, (cst_val *)&val_0944},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0011, (cst_val *)&val_10933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10934 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0013, (cst_val *)&val_0025},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0014, (cst_val *)&val_0978},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0015, (cst_val *)&val_5348},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0016, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10935 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0018, (cst_val *)&val_10936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10937 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0020, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10939 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0023, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10942 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0027, (cst_val *)&val_10943},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10945 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0030, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10947 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0033, (cst_val *)&val_1213},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0034, (cst_val *)&val_1355},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0035, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10949 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0038, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0039, (cst_val *)&val_10950},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0040, (cst_val *)&val_10951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10952 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0042, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10953 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0044, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10955 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0047, (cst_val *)&val_0165},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0048, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10959 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0053, (cst_val *)&val_2122},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0054, (cst_val *)&val_1244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10961 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0057, (cst_val *)&val_0125},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0058, (cst_val *)&val_4232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0059, (cst_val *)&val_4492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10964 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0063, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10965 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0065, (cst_val *)&val_7093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10967 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0068, (cst_val *)&val_0403},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0069, (cst_val *)&val_10968},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0070, (cst_val *)&val_10969},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0071, (cst_val *)&val_10970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10972 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0074, (cst_val *)&val_0077},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0075, (cst_val *)&val_10973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10976 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0079, (cst_val *)&val_0040},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0080, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10978 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0083, (cst_val *)&val_1110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10980 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0086, (cst_val *)&val_0011},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0087, (cst_val *)&val_0220},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0088, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0089, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10982 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0092, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10984 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0095, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10985 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0097, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10986 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0099, (cst_val *)&val_0068},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0100, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10988 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0103, (cst_val *)&val_10989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10991 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0106, (cst_val *)&val_0361},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0107, (cst_val *)&val_0125},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0108, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10993 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0111, (cst_val *)&val_0027},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0112, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0113, (cst_val *)&val_4391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10995 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0116, (cst_val *)&val_7928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10998 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0120, (cst_val *)&val_0640},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0121, (cst_val *)&val_1618},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0122, (cst_val *)&val_0358},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0123, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0124, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10999 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0126, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0127, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11002 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0131, (cst_val *)&val_11003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0132, (cst_val *)&val_11004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11006 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0135, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11008 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0138, (cst_val *)&val_0074},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0139, (cst_val *)&val_0025},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0140, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0141, (cst_val *)&val_11009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11011 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0144, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11013 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0147, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11014 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0149, (cst_val *)&val_11015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11016 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0151, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11018 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0154, (cst_val *)&val_0041},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0155, (cst_val *)&val_0045},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0156, (cst_val *)&val_0068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0157, (cst_val *)&val_11019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11021 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0160, (cst_val *)&val_0640},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0161, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11024 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0165, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0166, (cst_val *)&val_0950},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0167, (cst_val *)&val_11025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11028 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0171, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11031 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0175, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0176, (cst_val *)&val_11032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11033 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0178, (cst_val *)&val_11034},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0179, (cst_val *)&val_6728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11036 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0182, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11038 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0185, (cst_val *)&val_11039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11041 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0188, (cst_val *)&val_0125},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0189, (cst_val *)&val_11042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11044 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0192, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0193, (cst_val *)&val_0032},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0194, (cst_val *)&val_11045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11046 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0196, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11049 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0200, (cst_val *)&val_1799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11050 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_57_NO_0202, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11052 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_eh_57_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_eh_57_cart = {
  cmu_us_rms_single_mcep_eh_57_cart_nodes,
  cmu_us_rms_single_mcep_eh_57_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_eh_58_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0001, (cst_val *)&val_0733},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0002, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11053 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0004, (cst_val *)&val_2149},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0005, (cst_val *)&val_11054},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0006, (cst_val *)&val_11055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11056 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0008, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11058 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0011, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11059 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0013, (cst_val *)&val_11060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11062 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0016, (cst_val *)&val_11063},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0017, (cst_val *)&val_1014},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0018, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11066 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0022, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11067 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0024, (cst_val *)&val_11068},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0025, (cst_val *)&val_11069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11072 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0029, (cst_val *)&val_1035},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0030, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11073 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0032, (cst_val *)&val_0236},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0033, (cst_val *)&val_11074},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0034, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11076 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0037, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11078 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0040, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11080 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0043, (cst_val *)&val_2208},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0044, (cst_val *)&val_0004},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0045, (cst_val *)&val_11081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11082 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0047, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11083 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0049, (cst_val *)&val_11084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11086 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0052, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11088 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0055, (cst_val *)&val_0025},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0056, (cst_val *)&val_0128},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0057, (cst_val *)&val_11089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11092 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0061, (cst_val *)&val_8352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11093 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0063, (cst_val *)&val_2417},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0064, (cst_val *)&val_0128},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0065, (cst_val *)&val_11094},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0066, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11098 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0071, (cst_val *)&val_1378},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0072, (cst_val *)&val_0361},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0073, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11100 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0076, (cst_val *)&val_5640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11103 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0080, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0081, (cst_val *)&val_11104},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0082, (cst_val *)&val_11105},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0083, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11108 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0087, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0088, (cst_val *)&val_1892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11111 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0092, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11112 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0094, (cst_val *)&val_11113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11114 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_eh_58_NO_0096, (cst_val *)&val_1903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11116 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_eh_58_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_rms_single_mcep_eh_58_cart = {
  cmu_us_rms_single_mcep_eh_58_cart_nodes,
  cmu_us_rms_single_mcep_eh_58_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_t_164_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0000, (cst_val *)&val_0128},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0001, (cst_val *)&val_0040},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0002, (cst_val *)&val_0145},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0003, (cst_val *)&val_8349},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0004, (cst_val *)&val_11117},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0005, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0006, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11119 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0009, (cst_val *)&val_0007},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0010, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11120 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0012, (cst_val *)&val_11121},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0013, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11123 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0016, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11125 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0019, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11128 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0023, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0024, (cst_val *)&val_11129},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0025, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11130 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0027, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11131 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0029, (cst_val *)&val_0088},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0030, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11133 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0033, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11136 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0037, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11137 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0039, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11138 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0041, (cst_val *)&val_0760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11139 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0043, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11140 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0045, (cst_val *)&val_0088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0046, (cst_val *)&val_3533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11141 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0048, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11143 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0051, (cst_val *)&val_0043},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0052, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11146 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0056, (cst_val *)&val_11147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0057, (cst_val *)&val_11148},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0058, (cst_val *)&val_0059},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0059, (cst_val *)&val_11149},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0060, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11151 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0063, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11153 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0066, (cst_val *)&val_0171},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0067, (cst_val *)&val_0950},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0068, (cst_val *)&val_1795},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0069, (cst_val *)&val_11154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11158 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0074, (cst_val *)&val_6180},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11160 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0077, (cst_val *)&val_0417},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0078, (cst_val *)&val_5728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11162 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0081, (cst_val *)&val_0171},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0082, (cst_val *)&val_11163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11166 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0086, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11167 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0088, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11168 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0090, (cst_val *)&val_1922},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0091, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11169 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0093, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11171 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0096, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11173 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0099, (cst_val *)&val_10202},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0100, (cst_val *)&val_0077},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0101, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11174 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0103, (cst_val *)&val_5348},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0104, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11176 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0107, (cst_val *)&val_11177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11179 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0110, (cst_val *)&val_11180},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0111, (cst_val *)&val_0045},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0112, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11183 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0116, (cst_val *)&val_0026},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0117, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11186 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0121, (cst_val *)&val_0077},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0122, (cst_val *)&val_0025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0123, (cst_val *)&val_0043},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0124, (cst_val *)&val_6353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11187 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0126, (cst_val *)&val_6153},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0127, (cst_val *)&val_4733},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0128, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11191 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0133, (cst_val *)&val_6353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11192 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0135, (cst_val *)&val_6153},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0136, (cst_val *)&val_9176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11193 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0138, (cst_val *)&val_5324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11196 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0142, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11197 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0144, (cst_val *)&val_11198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11200 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0147, (cst_val *)&val_0043},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0148, (cst_val *)&val_0068},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0149, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11201 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0151, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11203 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0154, (cst_val *)&val_0492},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0155, (cst_val *)&val_11204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11206 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0158, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11207 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0160, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11209 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0163, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11210 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0165, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0166, (cst_val *)&val_10836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11212 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0169, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11213 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0171, (cst_val *)&val_11214},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0172, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11215 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0174, (cst_val *)&val_11216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11219 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0178, (cst_val *)&val_0145},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0179, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0180, (cst_val *)&val_6101},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0181, (cst_val *)&val_0829},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0182, (cst_val *)&val_1983},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11221 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0185, (cst_val *)&val_1373},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0186, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11222 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0188, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11223 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0190, (cst_val *)&val_10148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11224 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0192, (cst_val *)&val_5355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11225 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0194, (cst_val *)&val_5520},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0195, (cst_val *)&val_11226},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11227 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0197, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11228 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0199, (cst_val *)&val_0008},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0200, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11231 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0204, (cst_val *)&val_0013},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0205, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11232 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0207, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11234 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0210, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11237 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0214, (cst_val *)&val_0246},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0215, (cst_val *)&val_3729},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0216, (cst_val *)&val_4066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11238 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0218, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11239 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0220, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11240 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0222, (cst_val *)&val_0837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11243 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0226, (cst_val *)&val_0760},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0227, (cst_val *)&val_11244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11245 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0229, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11247 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0232, (cst_val *)&val_0059},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0233, (cst_val *)&val_11248},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0234, (cst_val *)&val_0934},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0235, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11250 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0238, (cst_val *)&val_4546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11253 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0242, (cst_val *)&val_0246},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0243, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11255 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0246, (cst_val *)&val_3448},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0247, (cst_val *)&val_0361},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0248, (cst_val *)&val_11256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11257 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0250, (cst_val *)&val_11258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11259 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0252, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11261 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0255, (cst_val *)&val_0294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11264 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0259, (cst_val *)&val_0034},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0260, (cst_val *)&val_11265},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0261, (cst_val *)&val_0077},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0262, (cst_val *)&val_6156},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0263, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11267 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0266, (cst_val *)&val_11268},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11270 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0269, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11272 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0272, (cst_val *)&val_11273},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0273, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11274 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0275, (cst_val *)&val_2569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11276 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0278, (cst_val *)&val_0059},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0279, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11278 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0282, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11280 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0285, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11281 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0287, (cst_val *)&val_0212},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0288, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11282 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0290, (cst_val *)&val_0975},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0291, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11284 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0294, (cst_val *)&val_11285},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11287 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0297, (cst_val *)&val_11288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11290 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0300, (cst_val *)&val_1922},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0301, (cst_val *)&val_0059},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0302, (cst_val *)&val_0546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11292 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0305, (cst_val *)&val_0059},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0306, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11293 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0308, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11295 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0311, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11297 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0314, (cst_val *)&val_10249},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0315, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11298 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0317, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11300 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0320, (cst_val *)&val_11301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11302 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_164_NO_0322, (cst_val *)&val_1795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11304 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_t_164_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_single_mcep_t_164_cart = {
  cmu_us_rms_single_mcep_t_164_cart_nodes,
  cmu_us_rms_single_mcep_t_164_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_t_165_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0000, (cst_val *)&val_0009},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0001, (cst_val *)&val_0145},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0002, (cst_val *)&val_1158},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0003, (cst_val *)&val_0059},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0004, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0005, (cst_val *)&val_2926},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0006, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11307 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0010, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11309 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0013, (cst_val *)&val_0068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0014, (cst_val *)&val_0944},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0015, (cst_val *)&val_1065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0016, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11313 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0021, (cst_val *)&val_0973},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0022, (cst_val *)&val_0040},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0023, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11316 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0027, (cst_val *)&val_11317},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11319 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0030, (cst_val *)&val_0973},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0031, (cst_val *)&val_6002},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0032, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11320 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0034, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0035, (cst_val *)&val_11321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11323 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0038, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11324 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0040, (cst_val *)&val_11325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11327 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0043, (cst_val *)&val_0029},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0044, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11328 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0046, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11329 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0048, (cst_val *)&val_11330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11331 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0050, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11333 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0053, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11334 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0055, (cst_val *)&val_0304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11336 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0058, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0059, (cst_val *)&val_6053},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0060, (cst_val *)&val_1735},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0061, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11339 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0065, (cst_val *)&val_2617},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0066, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11341 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0069, (cst_val *)&val_1756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11343 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0072, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11344 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0074, (cst_val *)&val_0011},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0075, (cst_val *)&val_11345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11347 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0078, (cst_val *)&val_11348},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0079, (cst_val *)&val_11349},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11351 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0082, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11353 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0085, (cst_val *)&val_8349},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0086, (cst_val *)&val_0077},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0087, (cst_val *)&val_0251},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0088, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11355 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0091, (cst_val *)&val_0758},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0092, (cst_val *)&val_11356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11359 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0096, (cst_val *)&val_0077},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0097, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11360 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0099, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11362 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0102, (cst_val *)&val_0059},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0103, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11363 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0105, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11365 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0108, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0109, (cst_val *)&val_11366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11367 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0111, (cst_val *)&val_0056},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0112, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11370 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0116, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11372 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0119, (cst_val *)&val_2670},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0120, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0121, (cst_val *)&val_3968},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0122, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11374 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0125, (cst_val *)&val_0774},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0126, (cst_val *)&val_11375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11378 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0130, (cst_val *)&val_0068},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0131, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11380 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0134, (cst_val *)&val_0940},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0135, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11381 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0137, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11383 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0140, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11385 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0143, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11386 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0145, (cst_val *)&val_4042},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0146, (cst_val *)&val_0913},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0147, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11389 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0151, (cst_val *)&val_0024},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0152, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11391 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0155, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11393 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0158, (cst_val *)&val_11394},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0159, (cst_val *)&val_0626},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0160, (cst_val *)&val_0361},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0161, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11395 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0163, (cst_val *)&val_11396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11398 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0166, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0167, (cst_val *)&val_1386},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0168, (cst_val *)&val_0332},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0169, (cst_val *)&val_1735},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0170, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11401 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0174, (cst_val *)&val_2149},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0175, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11403 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0178, (cst_val *)&val_1756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11405 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0181, (cst_val *)&val_5534},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0182, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11406 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0184, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11408 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0187, (cst_val *)&val_2221},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0188, (cst_val *)&val_11409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11410 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0190, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11413 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0194, (cst_val *)&val_0068},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0195, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11415 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0198, (cst_val *)&val_11416},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0199, (cst_val *)&val_11417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11419 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0202, (cst_val *)&val_11420},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0203, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11422 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0206, (cst_val *)&val_1445},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0207, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11425 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0211, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0212, (cst_val *)&val_0040},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0213, (cst_val *)&val_0015},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0214, (cst_val *)&val_6267},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0215, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11426 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0217, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11428 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0220, (cst_val *)&val_0165},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0221, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11429 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0223, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11431 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0226, (cst_val *)&val_5105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11433 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0229, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0230, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11435 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0233, (cst_val *)&val_1749},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0234, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11436 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0236, (cst_val *)&val_1373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11440 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0241, (cst_val *)&val_11441},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0242, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0243, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11443 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0246, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11444 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0248, (cst_val *)&val_0023},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0249, (cst_val *)&val_0040},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0250, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11448 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0255, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11449 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0257, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11451 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0260, (cst_val *)&val_0145},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0261, (cst_val *)&val_10031},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0262, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0263, (cst_val *)&val_2097},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0264, (cst_val *)&val_1594},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0265, (cst_val *)&val_11452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11456 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0270, (cst_val *)&val_11457},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0271, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11458 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0273, (cst_val *)&val_11459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11461 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0276, (cst_val *)&val_2503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11463 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0279, (cst_val *)&val_0025},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0280, (cst_val *)&val_0040},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0281, (cst_val *)&val_0165},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0282, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11466 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0286, (cst_val *)&val_4042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11468 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0289, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11469 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0291, (cst_val *)&val_0251},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0292, (cst_val *)&val_1331},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0293, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11471 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0296, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11473 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0299, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0300, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11474 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0302, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11476 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0305, (cst_val *)&val_2681},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0306, (cst_val *)&val_1740},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0307, (cst_val *)&val_11477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11480 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0311, (cst_val *)&val_11481},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11483 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0314, (cst_val *)&val_5916},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0315, (cst_val *)&val_0979},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0316, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11484 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0318, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11485 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0320, (cst_val *)&val_11486},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0321, (cst_val *)&val_7862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11488 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0324, (cst_val *)&val_5121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11490 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0327, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11491 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0329, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0330, (cst_val *)&val_3167},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0331, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11494 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0335, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11496 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0338, (cst_val *)&val_0043},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0339, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11497 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0341, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11498 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0343, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11500 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_165_NO_0346, (cst_val *)&val_11501},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11503 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_t_165_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_rms_single_mcep_t_165_cart = {
  cmu_us_rms_single_mcep_t_165_cart_nodes,
  cmu_us_rms_single_mcep_t_165_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_t_166_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0001, (cst_val *)&val_0940},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0002, (cst_val *)&val_9287},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0003, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0004, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11504 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0006, (cst_val *)&val_11505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11506 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0008, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11507 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0010, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11509 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0013, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11510 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0015, (cst_val *)&val_11511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11513 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0018, (cst_val *)&val_0211},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0019, (cst_val *)&val_0979},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0020, (cst_val *)&val_5341},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0021, (cst_val *)&val_0040},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0022, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11516 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0026, (cst_val *)&val_0957},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0027, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0028, (cst_val *)&val_11517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11520 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0032, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11521 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0034, (cst_val *)&val_11522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11524 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0037, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11526 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0040, (cst_val *)&val_0025},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0041, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11528 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0044, (cst_val *)&val_0008},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0045, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11530 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0048, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11531 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0050, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11533 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0053, (cst_val *)&val_11180},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0054, (cst_val *)&val_0243},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0055, (cst_val *)&val_2222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11534 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0057, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11536 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0060, (cst_val *)&val_1769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11537 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0062, (cst_val *)&val_11538},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0063, (cst_val *)&val_2535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11540 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0066, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11542 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0069, (cst_val *)&val_11543},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0070, (cst_val *)&val_0243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11544 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0072, (cst_val *)&val_0933},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0073, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11545 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0075, (cst_val *)&val_1778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11547 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0078, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11549 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0081, (cst_val *)&val_11550},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0082, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11552 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0085, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11553 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0087, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11554 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0089, (cst_val *)&val_0955},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0090, (cst_val *)&val_2469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11557 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0094, (cst_val *)&val_0140},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0095, (cst_val *)&val_2893},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0096, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11558 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0098, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11560 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0101, (cst_val *)&val_0693},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0102, (cst_val *)&val_11561},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0103, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11562 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0105, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11564 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0108, (cst_val *)&val_1683},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0109, (cst_val *)&val_0059},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0110, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11567 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0114, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11569 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0117, (cst_val *)&val_0077},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0118, (cst_val *)&val_0361},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0119, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11570 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0121, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11572 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0124, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11573 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0126, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11575 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0129, (cst_val *)&val_0251},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0130, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11576 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0132, (cst_val *)&val_0125},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0133, (cst_val *)&val_3521},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0134, (cst_val *)&val_1743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11579 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0138, (cst_val *)&val_1799},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0139, (cst_val *)&val_1323},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0140, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11580 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0142, (cst_val *)&val_11581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11582 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0144, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11585 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0148, (cst_val *)&val_0059},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0149, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11587 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0152, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11588 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0154, (cst_val *)&val_0251},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0155, (cst_val *)&val_0944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11591 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0159, (cst_val *)&val_0957},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0160, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11593 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0163, (cst_val *)&val_0251},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0164, (cst_val *)&val_11594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11596 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0167, (cst_val *)&val_9747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11598 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0170, (cst_val *)&val_1035},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0171, (cst_val *)&val_6104},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0172, (cst_val *)&val_11599},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0173, (cst_val *)&val_0251},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0174, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11600 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0176, (cst_val *)&val_4513},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11602 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0179, (cst_val *)&val_11603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11605 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0182, (cst_val *)&val_0429},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0183, (cst_val *)&val_0251},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0184, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11607 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0187, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11609 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0190, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11611 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0193, (cst_val *)&val_11612},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0194, (cst_val *)&val_1594},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0195, (cst_val *)&val_3577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11613 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0197, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11617 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0202, (cst_val *)&val_0361},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0203, (cst_val *)&val_0384},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0204, (cst_val *)&val_5955},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0205, (cst_val *)&val_0870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11619 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0208, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11620 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0210, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11622 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0213, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11623 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0215, (cst_val *)&val_3627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11625 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0218, (cst_val *)&val_0008},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0219, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11626 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0221, (cst_val *)&val_1795},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0222, (cst_val *)&val_2312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11629 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0226, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11630 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0228, (cst_val *)&val_0733},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0229, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11632 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0232, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0233, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11634 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0236, (cst_val *)&val_0760},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0237, (cst_val *)&val_1139},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0238, (cst_val *)&val_0040},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0239, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11638 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0244, (cst_val *)&val_11639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11640 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_t_166_NO_0246, (cst_val *)&val_0693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11642 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_t_166_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_single_mcep_t_166_cart = {
  cmu_us_rms_single_mcep_t_166_cart_nodes,
  cmu_us_rms_single_mcep_t_166_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_er_61_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0000, (cst_val *)&val_11643},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0002, (cst_val *)&val_0043},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0003, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0004, (cst_val *)&val_2498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11644 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0006, (cst_val *)&val_1921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11646 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0009, (cst_val *)&val_11647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11648 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0011, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11649 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0013, (cst_val *)&val_0056},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0014, (cst_val *)&val_11650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11653 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0018, (cst_val *)&val_0077},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0019, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11655 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0022, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11657 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0025, (cst_val *)&val_3301},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0026, (cst_val *)&val_11658},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0027, (cst_val *)&val_0097},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0028, (cst_val *)&val_7996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11659 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0030, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11660 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0032, (cst_val *)&val_4782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11663 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0036, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11665 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0039, (cst_val *)&val_1565},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0040, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11666 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0042, (cst_val *)&val_11667},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11669 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0045, (cst_val *)&val_3256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11670 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0047, (cst_val *)&val_0629},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0048, (cst_val *)&val_11671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11673 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0051, (cst_val *)&val_0043},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0052, (cst_val *)&val_5498},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0053, (cst_val *)&val_0640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11675 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0056, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11677 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0059, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11679 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0062, (cst_val *)&val_11680},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0063, (cst_val *)&val_0361},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0064, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0065, (cst_val *)&val_0059},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0066, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11682 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0069, (cst_val *)&val_1565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11684 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0072, (cst_val *)&val_1565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11685 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0074, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11686 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0076, (cst_val *)&val_1853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11688 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0079, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0080, (cst_val *)&val_0020},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0081, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0082, (cst_val *)&val_11689},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0083, (cst_val *)&val_11690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11693 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0087, (cst_val *)&val_0025},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0088, (cst_val *)&val_0361},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0089, (cst_val *)&val_11694},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0090, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11698 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0095, (cst_val *)&val_0361},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0096, (cst_val *)&val_4024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11702 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0101, (cst_val *)&val_0125},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0102, (cst_val *)&val_11703},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0103, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11704 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0105, (cst_val *)&val_0040},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0106, (cst_val *)&val_0008},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0107, (cst_val *)&val_11705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11709 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0112, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11710 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0114, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11712 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0117, (cst_val *)&val_1255},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0118, (cst_val *)&val_0183},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0119, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11713 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0121, (cst_val *)&val_3256},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0122, (cst_val *)&val_11714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11717 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0126, (cst_val *)&val_11718},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0127, (cst_val *)&val_11719},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0128, (cst_val *)&val_0165},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0129, (cst_val *)&val_0950},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0130, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11722 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0134, (cst_val *)&val_0045},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0135, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11724 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0138, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11726 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0141, (cst_val *)&val_0193},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0142, (cst_val *)&val_0056},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0143, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11727 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0145, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11729 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0148, (cst_val *)&val_0125},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0149, (cst_val *)&val_0165},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0150, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11730 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0152, (cst_val *)&val_11731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11733 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0155, (cst_val *)&val_1565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11735 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0158, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0159, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11737 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0162, (cst_val *)&val_0978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11739 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0165, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0166, (cst_val *)&val_11740},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0167, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11743 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0171, (cst_val *)&val_11744},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0172, (cst_val *)&val_0165},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0173, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11747 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0177, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11748 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0179, (cst_val *)&val_6193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11750 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0182, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0183, (cst_val *)&val_0045},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0184, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11751 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0186, (cst_val *)&val_1892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11753 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0189, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11755 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0192, (cst_val *)&val_0950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11757 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0195, (cst_val *)&val_1565},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0196, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11759 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0199, (cst_val *)&val_4850},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0200, (cst_val *)&val_0068},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0201, (cst_val *)&val_11760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11762 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0204, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11763 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0206, (cst_val *)&val_8514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11764 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0208, (cst_val *)&val_0251},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0209, (cst_val *)&val_0040},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0210, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11765 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0212, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11767 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0215, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11769 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0218, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11771 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0221, (cst_val *)&val_11772},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0222, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11775 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0226, (cst_val *)&val_0059},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0227, (cst_val *)&val_11776},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0228, (cst_val *)&val_0025},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0229, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11778 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0232, (cst_val *)&val_1163},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0233, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11780 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0236, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11781 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0238, (cst_val *)&val_2159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11783 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0241, (cst_val *)&val_11784},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0242, (cst_val *)&val_11785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11788 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0246, (cst_val *)&val_7212},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0247, (cst_val *)&val_0040},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0248, (cst_val *)&val_10056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11789 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0250, (cst_val *)&val_11790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11791 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0252, (cst_val *)&val_11792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11794 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0255, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11795 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0257, (cst_val *)&val_1697},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0258, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11798 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0262, (cst_val *)&val_0542},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0263, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11800 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0266, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11801 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0268, (cst_val *)&val_11802},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0269, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11803 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_61_NO_0271, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11806 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_er_61_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_rms_single_mcep_er_61_cart = {
  cmu_us_rms_single_mcep_er_61_cart_nodes,
  cmu_us_rms_single_mcep_er_61_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_er_62_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0000, (cst_val *)&val_6053},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0001, (cst_val *)&val_0059},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0002, (cst_val *)&val_0361},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0003, (cst_val *)&val_2149},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0004, (cst_val *)&val_11807},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11809 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0007, (cst_val *)&val_11810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11812 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0010, (cst_val *)&val_2661},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0011, (cst_val *)&val_0251},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0012, (cst_val *)&val_0637},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0013, (cst_val *)&val_0040},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0014, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11815 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0018, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0019, (cst_val *)&val_2017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11818 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0023, (cst_val *)&val_11819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11820 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0025, (cst_val *)&val_2959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11821 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0027, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0028, (cst_val *)&val_11822},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11824 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0031, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11826 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0034, (cst_val *)&val_1899},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0035, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11827 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0037, (cst_val *)&val_11828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11829 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0039, (cst_val *)&val_11830},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0040, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11832 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0043, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0044, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11834 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0047, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11837 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0051, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0052, (cst_val *)&val_0040},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0053, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11838 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0055, (cst_val *)&val_0008},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0056, (cst_val *)&val_0940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11840 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0059, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11842 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0062, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0063, (cst_val *)&val_11843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11845 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0066, (cst_val *)&val_2423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11847 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0069, (cst_val *)&val_0361},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0070, (cst_val *)&val_11848},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0071, (cst_val *)&val_11849},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11851 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0074, (cst_val *)&val_11852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11854 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0077, (cst_val *)&val_2661},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0078, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0079, (cst_val *)&val_0626},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0080, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11857 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0084, (cst_val *)&val_0068},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0085, (cst_val *)&val_0025},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0086, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11858 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0088, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11861 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0092, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11862 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0094, (cst_val *)&val_0125},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0095, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11864 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0098, (cst_val *)&val_5534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11865 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0100, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11867 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0103, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11868 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0105, (cst_val *)&val_0077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0106, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11870 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0109, (cst_val *)&val_0068},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0110, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11871 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0112, (cst_val *)&val_11872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11874 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0115, (cst_val *)&val_0025},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0116, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11877 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0120, (cst_val *)&val_0361},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0121, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0122, (cst_val *)&val_11878},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0123, (cst_val *)&val_11879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11880 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0125, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11882 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0128, (cst_val *)&val_11883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11884 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0130, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11885 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0132, (cst_val *)&val_11886},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0133, (cst_val *)&val_4167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11889 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0137, (cst_val *)&val_11890},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0138, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11891 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0140, (cst_val *)&val_5669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11893 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0143, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11894 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0145, (cst_val *)&val_1225},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0146, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11897 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0150, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0151, (cst_val *)&val_0125},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0152, (cst_val *)&val_2014},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0153, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11900 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0157, (cst_val *)&val_11901},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0158, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11902 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0160, (cst_val *)&val_0371},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0161, (cst_val *)&val_0059},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0162, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11905 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0166, (cst_val *)&val_11906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11908 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0169, (cst_val *)&val_0745},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0170, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0171, (cst_val *)&val_11909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11911 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0174, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11913 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0177, (cst_val *)&val_11914},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0178, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11916 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0181, (cst_val *)&val_0112},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0182, (cst_val *)&val_11917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11919 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0185, (cst_val *)&val_11920},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0186, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0187, (cst_val *)&val_1036},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0188, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11921 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0190, (cst_val *)&val_2122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11922 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0192, (cst_val *)&val_11923},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0193, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11924 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0195, (cst_val *)&val_0091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11926 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0198, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11929 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0202, (cst_val *)&val_11930},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0203, (cst_val *)&val_0040},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0204, (cst_val *)&val_0165},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0205, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11933 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0209, (cst_val *)&val_0048},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0210, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11934 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0212, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11937 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0216, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11938 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0218, (cst_val *)&val_11939},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11942 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0222, (cst_val *)&val_1992},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0223, (cst_val *)&val_0040},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0224, (cst_val *)&val_11943},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0225, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11945 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0228, (cst_val *)&val_0011},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0229, (cst_val *)&val_11946},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0230, (cst_val *)&val_11947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11949 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0233, (cst_val *)&val_1265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11951 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0236, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11952 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0238, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11953 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0240, (cst_val *)&val_11954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11955 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0242, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11956 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0244, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11958 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0247, (cst_val *)&val_11959},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0248, (cst_val *)&val_11960},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11961 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0250, (cst_val *)&val_0637},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0251, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11963 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0254, (cst_val *)&val_11964},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0255, (cst_val *)&val_11965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11967 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0258, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11970 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0262, (cst_val *)&val_0060},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0263, (cst_val *)&val_11971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11973 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0266, (cst_val *)&val_0029},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0267, (cst_val *)&val_0040},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0268, (cst_val *)&val_0165},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0269, (cst_val *)&val_11974},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11975 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0271, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11977 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0274, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11978 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0276, (cst_val *)&val_11979},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0277, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11982 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0281, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11983 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0283, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11985 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0286, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11986 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0288, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11987 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0290, (cst_val *)&val_3762},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0291, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11988 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0293, (cst_val *)&val_0294},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0294, (cst_val *)&val_0059},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0295, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11989 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0297, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11991 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0300, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11994 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0304, (cst_val *)&val_11995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11996 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_62_NO_0306, (cst_val *)&val_8618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11998 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_er_62_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_single_mcep_er_62_cart = {
  cmu_us_rms_single_mcep_er_62_cart_nodes,
  cmu_us_rms_single_mcep_er_62_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_er_63_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0001, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0002, (cst_val *)&val_0128},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0003, (cst_val *)&val_2893},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0004, (cst_val *)&val_0043},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0005, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12000 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0008, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12002 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0011, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12004 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0014, (cst_val *)&val_12005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12007 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0017, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0018, (cst_val *)&val_0013},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0019, (cst_val *)&val_12008},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0020, (cst_val *)&val_1323},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0021, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12010 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0024, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12011 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0026, (cst_val *)&val_1036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12013 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0029, (cst_val *)&val_3617},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0030, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0031, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12015 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0034, (cst_val *)&val_12016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12019 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0038, (cst_val *)&val_12020},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0039, (cst_val *)&val_9161},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0040, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12021 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0042, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12024 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0046, (cst_val *)&val_12025},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0047, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12028 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0051, (cst_val *)&val_0009},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0052, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12029 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0054, (cst_val *)&val_7347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12031 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0057, (cst_val *)&val_1735},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0058, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12034 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0062, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0063, (cst_val *)&val_0183},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0064, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12036 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0067, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0068, (cst_val *)&val_12037},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0069, (cst_val *)&val_1769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12038 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0071, (cst_val *)&val_12039},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0072, (cst_val *)&val_0870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12042 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0076, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12044 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0079, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12046 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0082, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0083, (cst_val *)&val_0008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0084, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12048 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0087, (cst_val *)&val_0328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12049 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0089, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12051 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0092, (cst_val *)&val_0714},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0093, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12052 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0095, (cst_val *)&val_12053},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0096, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12055 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0099, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12057 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0102, (cst_val *)&val_2208},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0103, (cst_val *)&val_12058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12060 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0106, (cst_val *)&val_8939},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0107, (cst_val *)&val_1378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12061 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0109, (cst_val *)&val_6701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12062 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0111, (cst_val *)&val_0739},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0112, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12065 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0116, (cst_val *)&val_0236},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0117, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12067 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0120, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12068 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_er_63_NO_0122, (cst_val *)&val_12069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12071 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_er_63_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_er_63_cart = {
  cmu_us_rms_single_mcep_er_63_cart_nodes,
  cmu_us_rms_single_mcep_er_63_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ax_26_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0000, (cst_val *)&val_0417},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0001, (cst_val *)&val_2568},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0002, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0003, (cst_val *)&val_12072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12074 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0006, (cst_val *)&val_0220},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0007, (cst_val *)&val_12075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12077 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0010, (cst_val *)&val_0031},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0011, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12079 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0014, (cst_val *)&val_0010},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0015, (cst_val *)&val_0060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12082 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0019, (cst_val *)&val_0019},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0020, (cst_val *)&val_5922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12084 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0023, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12086 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0026, (cst_val *)&val_1244},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0027, (cst_val *)&val_0059},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0028, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0029, (cst_val *)&val_12087},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0030, (cst_val *)&val_11522},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0031, (cst_val *)&val_12088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12090 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0034, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0035, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12091 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0037, (cst_val *)&val_4302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12094 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0041, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12096 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0044, (cst_val *)&val_0574},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0045, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12097 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0047, (cst_val *)&val_2617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12099 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0050, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12100 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0052, (cst_val *)&val_1029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12102 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0055, (cst_val *)&val_0183},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0056, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12103 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0058, (cst_val *)&val_3256},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0059, (cst_val *)&val_1522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12105 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0062, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12107 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0065, (cst_val *)&val_0077},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0066, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12108 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0068, (cst_val *)&val_1163},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0069, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12110 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0072, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12111 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0074, (cst_val *)&val_12112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12113 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0076, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12114 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0078, (cst_val *)&val_0165},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0079, (cst_val *)&val_12115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12117 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0082, (cst_val *)&val_3627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12119 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0085, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0086, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12120 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0088, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12121 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0090, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12123 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0093, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12124 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0095, (cst_val *)&val_1992},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0096, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12125 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0098, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12127 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0101, (cst_val *)&val_12128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12130 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0104, (cst_val *)&val_2959},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0105, (cst_val *)&val_0183},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0106, (cst_val *)&val_12131},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0107, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12132 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0109, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12134 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0112, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12135 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0114, (cst_val *)&val_0008},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0115, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12136 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0117, (cst_val *)&val_0956},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0118, (cst_val *)&val_3000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12139 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0122, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12141 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0125, (cst_val *)&val_0015},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0126, (cst_val *)&val_0010},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0127, (cst_val *)&val_0059},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0128, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12142 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0130, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12143 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0132, (cst_val *)&val_12144},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0133, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0134, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12148 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0139, (cst_val *)&val_12149},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0140, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12151 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0143, (cst_val *)&val_12152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12154 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0146, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12155 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0148, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12156 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0150, (cst_val *)&val_7996},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0151, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12158 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0154, (cst_val *)&val_0297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12160 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0157, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12161 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0159, (cst_val *)&val_12162},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0160, (cst_val *)&val_0025},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0161, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12164 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0164, (cst_val *)&val_7996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12166 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0167, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0168, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12168 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0171, (cst_val *)&val_3483},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12170 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0174, (cst_val *)&val_0040},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0175, (cst_val *)&val_0045},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0176, (cst_val *)&val_0068},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0177, (cst_val *)&val_0307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12172 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0180, (cst_val *)&val_0574},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0181, (cst_val *)&val_0569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12175 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0185, (cst_val *)&val_12176},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0186, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12179 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0190, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0191, (cst_val *)&val_12180},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0192, (cst_val *)&val_1029},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0193, (cst_val *)&val_12181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12184 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0197, (cst_val *)&val_0165},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0198, (cst_val *)&val_3256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12187 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0202, (cst_val *)&val_1579},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0203, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12188 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0205, (cst_val *)&val_0059},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0206, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12189 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0208, (cst_val *)&val_1232},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0209, (cst_val *)&val_0913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12191 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0212, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12193 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0215, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0216, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12194 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0218, (cst_val *)&val_3401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12196 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0221, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12198 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0224, (cst_val *)&val_11522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12199 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0226, (cst_val *)&val_0165},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0227, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12200 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0229, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12201 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0231, (cst_val *)&val_12202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12204 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0234, (cst_val *)&val_12205},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0235, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0236, (cst_val *)&val_12206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12208 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0239, (cst_val *)&val_12209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12211 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_26_NO_0242, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12213 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ax_26_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_single_mcep_ax_26_cart = {
  cmu_us_rms_single_mcep_ax_26_cart_nodes,
  cmu_us_rms_single_mcep_ax_26_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ax_27_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0001, (cst_val *)&val_0384},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0002, (cst_val *)&val_0774},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0003, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0004, (cst_val *)&val_0007},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0005, (cst_val *)&val_0077},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0006, (cst_val *)&val_12214},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0007, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12217 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0011, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12219 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0014, (cst_val *)&val_12220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12222 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0017, (cst_val *)&val_0125},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0018, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12224 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0021, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12225 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0023, (cst_val *)&val_0077},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0024, (cst_val *)&val_12226},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12227 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0026, (cst_val *)&val_9273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12229 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0029, (cst_val *)&val_9286},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0030, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12230 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0032, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12233 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0036, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12234 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0038, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0039, (cst_val *)&val_0358},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0040, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12236 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0043, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12238 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0046, (cst_val *)&val_0328},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0047, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12240 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0050, (cst_val *)&val_0774},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0051, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12241 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0053, (cst_val *)&val_12242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12243 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0055, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12245 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0058, (cst_val *)&val_12246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12248 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0061, (cst_val *)&val_0251},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0062, (cst_val *)&val_12249},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0063, (cst_val *)&val_12250},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12251 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0065, (cst_val *)&val_0334},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12252 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0067, (cst_val *)&val_12253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12255 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0070, (cst_val *)&val_12256},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0071, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12257 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0073, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12260 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0077, (cst_val *)&val_12261},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0078, (cst_val *)&val_2681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12263 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0081, (cst_val *)&val_0361},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0082, (cst_val *)&val_12264},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0083, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0084, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12268 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0089, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12269 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0091, (cst_val *)&val_0517},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0092, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12270 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0094, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12271 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0096, (cst_val *)&val_12272},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0097, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12275 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0101, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12277 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0104, (cst_val *)&val_0125},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0105, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12278 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0107, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0108, (cst_val *)&val_12279},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0109, (cst_val *)&val_12280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12283 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0113, (cst_val *)&val_4271},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0114, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12284 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0116, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12286 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0119, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12288 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0122, (cst_val *)&val_0125},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0123, (cst_val *)&val_1579},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0124, (cst_val *)&val_0403},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0125, (cst_val *)&val_0914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12290 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0128, (cst_val *)&val_0183},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0129, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12291 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0131, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12293 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0134, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12294 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0136, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12296 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0139, (cst_val *)&val_12297},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0140, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12299 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0143, (cst_val *)&val_0251},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0144, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12300 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0146, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12301 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0148, (cst_val *)&val_12302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12304 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0151, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12305 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0153, (cst_val *)&val_2122},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0154, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12308 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0158, (cst_val *)&val_0040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0159, (cst_val *)&val_0183},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0160, (cst_val *)&val_0574},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0161, (cst_val *)&val_3680},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0162, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12311 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0166, (cst_val *)&val_0899},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0167, (cst_val *)&val_1579},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0168, (cst_val *)&val_3000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12313 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0171, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12314 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0173, (cst_val *)&val_0059},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0174, (cst_val *)&val_12315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12317 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0177, (cst_val *)&val_12318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12320 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0180, (cst_val *)&val_12321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12323 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0183, (cst_val *)&val_12324},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0184, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12327 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0188, (cst_val *)&val_0183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0189, (cst_val *)&val_1445},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0190, (cst_val *)&val_5419},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0191, (cst_val *)&val_0574},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0192, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12328 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0194, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12330 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0197, (cst_val *)&val_12331},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0198, (cst_val *)&val_12332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12333 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0200, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12335 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0203, (cst_val *)&val_1029},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0204, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12337 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0207, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12339 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0210, (cst_val *)&val_0183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0211, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12341 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0214, (cst_val *)&val_0395},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0215, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12342 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0217, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12343 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0219, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0220, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12344 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0222, (cst_val *)&val_12345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12347 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0225, (cst_val *)&val_6002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12348 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0227, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12350 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0230, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12353 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0234, (cst_val *)&val_0251},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0235, (cst_val *)&val_0024},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0236, (cst_val *)&val_0569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12354 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0238, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12357 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0242, (cst_val *)&val_0199},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0243, (cst_val *)&val_0009},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0244, (cst_val *)&val_0068},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0245, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12358 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0247, (cst_val *)&val_4214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12360 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0250, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12362 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0253, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12364 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0256, (cst_val *)&val_0629},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0257, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12366 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0260, (cst_val *)&val_1065},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0261, (cst_val *)&val_0165},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0262, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12368 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0265, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12370 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_27_NO_0268, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12372 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ax_27_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_single_mcep_ax_27_cart = {
  cmu_us_rms_single_mcep_ax_27_cart_nodes,
  cmu_us_rms_single_mcep_ax_27_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_ax_28_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0000, (cst_val *)&val_0059},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0001, (cst_val *)&val_0642},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0002, (cst_val *)&val_2893},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0003, (cst_val *)&val_0940},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0004, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0005, (cst_val *)&val_1594},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0006, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12373 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0008, (cst_val *)&val_12374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12378 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0013, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12380 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0016, (cst_val *)&val_0944},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0017, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12381 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0019, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0020, (cst_val *)&val_4374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12382 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0022, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12384 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0025, (cst_val *)&val_0705},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0026, (cst_val *)&val_12385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12387 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0029, (cst_val *)&val_0040},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0030, (cst_val *)&val_12388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12390 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0033, (cst_val *)&val_8281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12392 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0036, (cst_val *)&val_0629},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0037, (cst_val *)&val_0774},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0038, (cst_val *)&val_2487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12395 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0042, (cst_val *)&val_11522},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0043, (cst_val *)&val_0267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12397 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0046, (cst_val *)&val_0040},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0047, (cst_val *)&val_3669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12399 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0050, (cst_val *)&val_3726},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0051, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12401 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0054, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12403 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0057, (cst_val *)&val_2122},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0058, (cst_val *)&val_12404},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0059, (cst_val *)&val_0165},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0060, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12406 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0063, (cst_val *)&val_12407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12410 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0067, (cst_val *)&val_11522},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0068, (cst_val *)&val_12411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12413 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0071, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12415 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0074, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0075, (cst_val *)&val_12416},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0076, (cst_val *)&val_2122},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0077, (cst_val *)&val_12417},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0078, (cst_val *)&val_0009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0079, (cst_val *)&val_3316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12419 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0082, (cst_val *)&val_2017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12421 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0085, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12422 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0087, (cst_val *)&val_3176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12423 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0089, (cst_val *)&val_2584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12425 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0092, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12427 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0095, (cst_val *)&val_11522},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0096, (cst_val *)&val_0246},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0097, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12430 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0101, (cst_val *)&val_0008},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0102, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12432 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0105, (cst_val *)&val_12433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12434 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0107, (cst_val *)&val_0008},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0108, (cst_val *)&val_12435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12438 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0112, (cst_val *)&val_0733},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0113, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12439 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0115, (cst_val *)&val_12440},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0116, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12441 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0118, (cst_val *)&val_0040},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0119, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12442 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0121, (cst_val *)&val_0128},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0122, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12443 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0124, (cst_val *)&val_0068},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0125, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12446 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0129, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12447 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0131, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12449 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0134, (cst_val *)&val_0251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12452 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0138, (cst_val *)&val_0125},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0139, (cst_val *)&val_4202},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0140, (cst_val *)&val_6701},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0141, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12454 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0144, (cst_val *)&val_1378},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0145, (cst_val *)&val_12455},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0146, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12459 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0151, (cst_val *)&val_0251},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0152, (cst_val *)&val_0165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12462 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0156, (cst_val *)&val_12463},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0157, (cst_val *)&val_2208},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0158, (cst_val *)&val_5419},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0159, (cst_val *)&val_1383},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0160, (cst_val *)&val_0165},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0161, (cst_val *)&val_0171},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0162, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12466 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0166, (cst_val *)&val_0056},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0167, (cst_val *)&val_1743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12468 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0170, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12469 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0172, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12472 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0176, (cst_val *)&val_1323},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0177, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12475 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0181, (cst_val *)&val_1035},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0182, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12477 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0185, (cst_val *)&val_0358},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0186, (cst_val *)&val_8352},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0187, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12478 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0189, (cst_val *)&val_2649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12480 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0192, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0193, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12482 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0196, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12483 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0198, (cst_val *)&val_8220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12484 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0200, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12486 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0203, (cst_val *)&val_8352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12488 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0206, (cst_val *)&val_2208},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0207, (cst_val *)&val_0574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12489 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_ax_28_NO_0209, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12492 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_ax_28_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_single_mcep_ax_28_cart = {
  cmu_us_rms_single_mcep_ax_28_cart_nodes,
  cmu_us_rms_single_mcep_ax_28_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_pau_141_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0001, (cst_val *)&val_0056},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0002, (cst_val *)&val_3668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12493 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0004, (cst_val *)&val_0005},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0005, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12494 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0007, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12495 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0009, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0010, (cst_val *)&val_12496},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12498 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0013, (cst_val *)&val_0079},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0014, (cst_val *)&val_12499},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12500 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0016, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12501 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0018, (cst_val *)&val_1244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12504 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0022, (cst_val *)&val_1328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12506 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0025, (cst_val *)&val_0933},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0026, (cst_val *)&val_3668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12507 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0028, (cst_val *)&val_0005},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0029, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12508 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0031, (cst_val *)&val_3702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12509 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0033, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12510 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0035, (cst_val *)&val_0079},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0036, (cst_val *)&val_3577},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0037, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12511 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0039, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12513 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0042, (cst_val *)&val_1468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12514 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0044, (cst_val *)&val_0040},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0045, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12518 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0050, (cst_val *)&val_1328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12521 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0054, (cst_val *)&val_1647},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0055, (cst_val *)&val_0417},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0056, (cst_val *)&val_0012},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0057, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0058, (cst_val *)&val_0043},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0059, (cst_val *)&val_8947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12522 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0061, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12523 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0063, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12525 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0066, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12526 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0068, (cst_val *)&val_6106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12528 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0071, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0072, (cst_val *)&val_0008},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0073, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12530 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0076, (cst_val *)&val_0043},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0077, (cst_val *)&val_2164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12533 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0081, (cst_val *)&val_0774},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0082, (cst_val *)&val_1740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12536 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0086, (cst_val *)&val_0059},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0087, (cst_val *)&val_2067},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0088, (cst_val *)&val_6429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12538 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0091, (cst_val *)&val_1647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12539 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0093, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12541 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0096, (cst_val *)&val_0008},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0097, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12543 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0100, (cst_val *)&val_1363},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0101, (cst_val *)&val_0239},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0102, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12545 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0105, (cst_val *)&val_12496},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0106, (cst_val *)&val_1647},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0107, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12547 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0110, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12548 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0112, (cst_val *)&val_12549},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12552 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0116, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12553 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0118, (cst_val *)&val_12554},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12556 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0121, (cst_val *)&val_0059},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0122, (cst_val *)&val_0040},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0123, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12557 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0125, (cst_val *)&val_0562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12558 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0127, (cst_val *)&val_12559},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0128, (cst_val *)&val_5452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12562 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0132, (cst_val *)&val_10485},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0133, (cst_val *)&val_1232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0134, (cst_val *)&val_0024},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0135, (cst_val *)&val_0220},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0136, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12564 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0139, (cst_val *)&val_0756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12567 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0143, (cst_val *)&val_1821},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0144, (cst_val *)&val_5520},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0145, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12571 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0150, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12573 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0153, (cst_val *)&val_0068},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0154, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0155, (cst_val *)&val_2637},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0156, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12574 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0158, (cst_val *)&val_0140},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0159, (cst_val *)&val_9407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12578 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0164, (cst_val *)&val_0478},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0165, (cst_val *)&val_2535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12580 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0168, (cst_val *)&val_12581},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0169, (cst_val *)&val_1511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12584 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0173, (cst_val *)&val_0008},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0174, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0175, (cst_val *)&val_0013},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0176, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12586 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0179, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12588 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0182, (cst_val *)&val_0199},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0183, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12590 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0186, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0187, (cst_val *)&val_3586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12593 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0191, (cst_val *)&val_1604},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0192, (cst_val *)&val_0492},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0193, (cst_val *)&val_0009},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0194, (cst_val *)&val_0056},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0195, (cst_val *)&val_7347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12595 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0198, (cst_val *)&val_0724},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0199, (cst_val *)&val_1243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12598 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0203, (cst_val *)&val_4045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0204, (cst_val *)&val_5534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12599 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0206, (cst_val *)&val_0956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12601 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0209, (cst_val *)&val_2626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12602 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0211, (cst_val *)&val_3616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12604 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0214, (cst_val *)&val_0403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0215, (cst_val *)&val_3254},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0216, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12605 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0218, (cst_val *)&val_1618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12607 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0221, (cst_val *)&val_0284},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0222, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12608 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0224, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12611 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0228, (cst_val *)&val_0077},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0229, (cst_val *)&val_2423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12612 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0231, (cst_val *)&val_12613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12615 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0234, (cst_val *)&val_10100},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0235, (cst_val *)&val_2221},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0236, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12616 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0238, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12619 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0242, (cst_val *)&val_4066},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0243, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12621 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0246, (cst_val *)&val_0040},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0247, (cst_val *)&val_2184},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0248, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12622 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0250, (cst_val *)&val_3256},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0251, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12625 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0255, (cst_val *)&val_12626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12628 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0258, (cst_val *)&val_12629},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0259, (cst_val *)&val_1432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12632 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0263, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12633 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0265, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12634 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0267, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12635 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0269, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12636 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0271, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12638 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0274, (cst_val *)&val_0171},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0275, (cst_val *)&val_0077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0276, (cst_val *)&val_0007},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0277, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0278, (cst_val *)&val_0056},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0279, (cst_val *)&val_3762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12640 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0282, (cst_val *)&val_12641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12644 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0286, (cst_val *)&val_0239},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0287, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0288, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12648 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0293, (cst_val *)&val_0038},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0294, (cst_val *)&val_0068},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0295, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12649 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0297, (cst_val *)&val_0003},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0298, (cst_val *)&val_0025},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0299, (cst_val *)&val_5507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12652 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0303, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12654 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0306, (cst_val *)&val_0403},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0307, (cst_val *)&val_2405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12655 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0309, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12657 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0312, (cst_val *)&val_0040},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0313, (cst_val *)&val_0183},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0314, (cst_val *)&val_1310},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0315, (cst_val *)&val_2564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12659 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0318, (cst_val *)&val_3256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12660 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0320, (cst_val *)&val_7466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12662 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0323, (cst_val *)&val_12663},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0324, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12665 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0327, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12666 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0329, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12669 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0333, (cst_val *)&val_0403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0334, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12670 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0336, (cst_val *)&val_12671},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0337, (cst_val *)&val_5521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12672 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0339, (cst_val *)&val_3456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12675 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0343, (cst_val *)&val_0183},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0344, (cst_val *)&val_0492},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0345, (cst_val *)&val_8885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12677 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0348, (cst_val *)&val_12678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12680 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0351, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12681 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0353, (cst_val *)&val_0361},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0354, (cst_val *)&val_12682},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0355, (cst_val *)&val_12683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12684 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0357, (cst_val *)&val_12685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12688 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0361, (cst_val *)&val_0505},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0362, (cst_val *)&val_12689},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0363, (cst_val *)&val_6002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12691 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0366, (cst_val *)&val_1634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12694 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0370, (cst_val *)&val_0191},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0371, (cst_val *)&val_12695},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0372, (cst_val *)&val_0492},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0373, (cst_val *)&val_2678},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0374, (cst_val *)&val_9526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12697 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0377, (cst_val *)&val_1885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12699 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0380, (cst_val *)&val_0077},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0381, (cst_val *)&val_12700},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0382, (cst_val *)&val_2184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12701 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0384, (cst_val *)&val_0025},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0385, (cst_val *)&val_4537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12704 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0389, (cst_val *)&val_12705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12706 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0391, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12708 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0394, (cst_val *)&val_2776},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0395, (cst_val *)&val_0125},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0396, (cst_val *)&val_3708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12709 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0398, (cst_val *)&val_4513},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12711 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0401, (cst_val *)&val_12712},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0402, (cst_val *)&val_0037},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0403, (cst_val *)&val_0505},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0404, (cst_val *)&val_12713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12715 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0407, (cst_val *)&val_0403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0408, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12716 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0410, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12718 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0413, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12719 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0415, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12721 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0418, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12723 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0421, (cst_val *)&val_0045},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0422, (cst_val *)&val_4088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12725 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0425, (cst_val *)&val_12726},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0426, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12727 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0428, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12730 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0432, (cst_val *)&val_0068},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0433, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12732 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0436, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12733 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0438, (cst_val *)&val_2846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12735 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0441, (cst_val *)&val_0913},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0442, (cst_val *)&val_5641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12736 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0444, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12738 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0447, (cst_val *)&val_0077},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0448, (cst_val *)&val_1992},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0449, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0450, (cst_val *)&val_1749},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0451, (cst_val *)&val_12739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12744 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0457, (cst_val *)&val_0492},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0458, (cst_val *)&val_2678},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0459, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12746 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0462, (cst_val *)&val_5793},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12748 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0465, (cst_val *)&val_11647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12749 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0467, (cst_val *)&val_0505},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0468, (cst_val *)&val_9237},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0469, (cst_val *)&val_7278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12751 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0472, (cst_val *)&val_12752},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12754 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0475, (cst_val *)&val_12755},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0476, (cst_val *)&val_0629},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0477, (cst_val *)&val_12756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12758 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0480, (cst_val *)&val_0403},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0481, (cst_val *)&val_3456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12759 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0483, (cst_val *)&val_12760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12762 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0486, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12763 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0488, (cst_val *)&val_3316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12764 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0490, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0491, (cst_val *)&val_2753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12767 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0495, (cst_val *)&val_0025},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0496, (cst_val *)&val_0503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12768 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0498, (cst_val *)&val_6247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12770 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0501, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12771 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0503, (cst_val *)&val_0361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12772 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0505, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12773 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0507, (cst_val *)&val_4546},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0508, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12776 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0512, (cst_val *)&val_0320},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0513, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12777 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0515, (cst_val *)&val_2855},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0516, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12779 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0519, (cst_val *)&val_0145},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0520, (cst_val *)&val_0077},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0521, (cst_val *)&val_1993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12783 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0526, (cst_val *)&val_1032},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0527, (cst_val *)&val_0492},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0528, (cst_val *)&val_5260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12785 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0531, (cst_val *)&val_12786},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0532, (cst_val *)&val_12787},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0533, (cst_val *)&val_0505},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0534, (cst_val *)&val_12788},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12790 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0537, (cst_val *)&val_0629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12791 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0539, (cst_val *)&val_12792},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0540, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12793 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0542, (cst_val *)&val_1545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12795 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0545, (cst_val *)&val_12796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12798 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0548, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12800 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0551, (cst_val *)&val_0059},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0552, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12802 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0555, (cst_val *)&val_12803},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0556, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12805 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0559, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12806 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0561, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12808 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0564, (cst_val *)&val_12809},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0565, (cst_val *)&val_0294},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0566, (cst_val *)&val_0505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12810 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0568, (cst_val *)&val_6602},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0569, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12812 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0572, (cst_val *)&val_8476},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12815 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0576, (cst_val *)&val_12816},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0577, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12818 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0580, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12819 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_141_NO_0582, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12821 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_pau_141_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_rms_single_mcep_pau_141_cart = {
  cmu_us_rms_single_mcep_pau_141_cart_nodes,
  cmu_us_rms_single_mcep_pau_141_feat_table
};

static const cst_cart_node cmu_us_rms_single_mcep_pau_142_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0001, (cst_val *)&val_0039},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0002, (cst_val *)&val_0068},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0003, (cst_val *)&val_0629},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0004, (cst_val *)&val_1331},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0005, (cst_val *)&val_12822},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12824 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0008, (cst_val *)&val_12825},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0009, (cst_val *)&val_0602},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0010, (cst_val *)&val_12826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12830 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0015, (cst_val *)&val_2244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12831 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0017, (cst_val *)&val_0043},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0018, (cst_val *)&val_0626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12834 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0022, (cst_val *)&val_11214},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0023, (cst_val *)&val_0145},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0024, (cst_val *)&val_0358},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0025, (cst_val *)&val_4568},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12835 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0027, (cst_val *)&val_12836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12838 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0030, (cst_val *)&val_12839},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12841 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0033, (cst_val *)&val_0183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0034, (cst_val *)&val_0236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12842 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0036, (cst_val *)&val_0611},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0037, (cst_val *)&val_2213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12845 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0041, (cst_val *)&val_0114},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0042, (cst_val *)&val_12846},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0043, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12850 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0048, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12851 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0050, (cst_val *)&val_0183},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0051, (cst_val *)&val_12852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12855 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0055, (cst_val *)&val_5310},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0056, (cst_val *)&val_0059},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0057, (cst_val *)&val_0012},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0058, (cst_val *)&val_2244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12856 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0060, (cst_val *)&val_1634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12859 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0064, (cst_val *)&val_4024},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0065, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12860 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0067, (cst_val *)&val_0629},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0068, (cst_val *)&val_9273},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0069, (cst_val *)&val_1225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12864 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0074, (cst_val *)&val_3631},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0075, (cst_val *)&val_0068},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0076, (cst_val *)&val_5783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12866 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0079, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12867 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0081, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12870 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0085, (cst_val *)&val_3475},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0086, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12871 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0088, (cst_val *)&val_0027},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0089, (cst_val *)&val_12872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12873 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0091, (cst_val *)&val_0145},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0092, (cst_val *)&val_12874},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0093, (cst_val *)&val_2239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12877 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0097, (cst_val *)&val_0183},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0098, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12878 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0100, (cst_val *)&val_12879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12882 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0104, (cst_val *)&val_2115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12884 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0107, (cst_val *)&val_2152},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0108, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12885 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0110, (cst_val *)&val_1870},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0111, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12886 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0113, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12888 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0116, (cst_val *)&val_0145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12889 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0118, (cst_val *)&val_12890},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12891 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0120, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12893 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0123, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12895 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0126, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0127, (cst_val *)&val_8815},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0128, (cst_val *)&val_2893},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0129, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12897 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0132, (cst_val *)&val_2427},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0133, (cst_val *)&val_0979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12899 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0136, (cst_val *)&val_2926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12900 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0138, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12902 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0141, (cst_val *)&val_0059},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0142, (cst_val *)&val_12903},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0143, (cst_val *)&val_12904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12906 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0146, (cst_val *)&val_12907},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0147, (cst_val *)&val_1950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12909 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0150, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12910 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0152, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12912 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0155, (cst_val *)&val_12913},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0156, (cst_val *)&val_4374},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0157, (cst_val *)&val_12914},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0158, (cst_val *)&val_12915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12917 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0161, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12919 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0164, (cst_val *)&val_0068},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0165, (cst_val *)&val_0023},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0166, (cst_val *)&val_12920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12921 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0168, (cst_val *)&val_0256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12923 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0171, (cst_val *)&val_12924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12926 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0174, (cst_val *)&val_12927},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0175, (cst_val *)&val_0693},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0176, (cst_val *)&val_1448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12928 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0178, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12929 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0180, (cst_val *)&val_0051},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0181, (cst_val *)&val_1243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12932 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0185, (cst_val *)&val_12933},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0186, (cst_val *)&val_0297},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0187, (cst_val *)&val_5934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12938 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0193, (cst_val *)&val_7176},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0194, (cst_val *)&val_12939},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12942 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0198, (cst_val *)&val_0008},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0199, (cst_val *)&val_0417},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0200, (cst_val *)&val_0493},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0201, (cst_val *)&val_0493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12944 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0204, (cst_val *)&val_4167},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0205, (cst_val *)&val_1853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12947 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0209, (cst_val *)&val_0199},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0210, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12948 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0212, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12949 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0214, (cst_val *)&val_3412},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0215, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12952 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0219, (cst_val *)&val_0318},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0220, (cst_val *)&val_0183},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0221, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12953 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0223, (cst_val *)&val_9237},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0224, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12956 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0228, (cst_val *)&val_9093},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0229, (cst_val *)&val_9820},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0230, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12957 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0232, (cst_val *)&val_3726},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0233, (cst_val *)&val_0978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12958 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0235, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12960 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0238, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12965 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0244, (cst_val *)&val_12966},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0245, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0246, (cst_val *)&val_4232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12968 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0249, (cst_val *)&val_0542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12969 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0251, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12970 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0253, (cst_val *)&val_2855},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0254, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12971 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0256, (cst_val *)&val_11394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12974 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0260, (cst_val *)&val_0478},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0261, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12975 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0263, (cst_val *)&val_1367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12976 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0265, (cst_val *)&val_1697},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0266, (cst_val *)&val_1380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12979 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0270, (cst_val *)&val_1367},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0271, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0272, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12980 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0274, (cst_val *)&val_12981},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0275, (cst_val *)&val_12982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12985 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0279, (cst_val *)&val_12256},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12987 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0282, (cst_val *)&val_0417},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0283, (cst_val *)&val_0032},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0284, (cst_val *)&val_1627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12990 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0288, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0289, (cst_val *)&val_12991},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12993 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0292, (cst_val *)&val_12994},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0293, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0294, (cst_val *)&val_12995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12998 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0298, (cst_val *)&val_10115},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0299, (cst_val *)&val_2744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_12999 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_single_mcep_pau_142_NO_0301, (cst_val *)&val_13000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_13001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_13002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_13003 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_single_mcep_pau_142_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_single_mcep_pau_142_cart = {
  cmu_us_rms_single_mcep_pau_142_cart_nodes,
  cmu_us_rms_single_mcep_pau_142_feat_table
};


const cst_cart * const cmu_us_rms_single_mcep_carts[] = {
 &cmu_us_rms_single_mcep_zh_204_cart,
 &cmu_us_rms_single_mcep_zh_205_cart,
 &cmu_us_rms_single_mcep_zh_206_cart,
 &cmu_us_rms_single_mcep_oy_131_cart,
 &cmu_us_rms_single_mcep_oy_132_cart,
 &cmu_us_rms_single_mcep_oy_133_cart,
 &cmu_us_rms_single_mcep_ch_41_cart,
 &cmu_us_rms_single_mcep_ch_42_cart,
 &cmu_us_rms_single_mcep_ch_43_cart,
 &cmu_us_rms_single_mcep_aw_21_cart,
 &cmu_us_rms_single_mcep_aw_22_cart,
 &cmu_us_rms_single_mcep_aw_23_cart,
 &cmu_us_rms_single_mcep_ow_126_cart,
 &cmu_us_rms_single_mcep_ow_127_cart,
 &cmu_us_rms_single_mcep_ow_128_cart,
 &cmu_us_rms_single_mcep_b_36_cart,
 &cmu_us_rms_single_mcep_b_37_cart,
 &cmu_us_rms_single_mcep_b_38_cart,
 &cmu_us_rms_single_mcep_g_76_cart,
 &cmu_us_rms_single_mcep_g_77_cart,
 &cmu_us_rms_single_mcep_g_78_cart,
 &cmu_us_rms_single_mcep_ng_121_cart,
 &cmu_us_rms_single_mcep_ng_122_cart,
 &cmu_us_rms_single_mcep_ng_123_cart,
 &cmu_us_rms_single_mcep_uw_179_cart,
 &cmu_us_rms_single_mcep_uw_180_cart,
 &cmu_us_rms_single_mcep_uw_181_cart,
 &cmu_us_rms_single_mcep_sh_156_cart,
 &cmu_us_rms_single_mcep_sh_157_cart,
 &cmu_us_rms_single_mcep_sh_158_cart,
 &cmu_us_rms_single_mcep_uh_174_cart,
 &cmu_us_rms_single_mcep_uh_175_cart,
 &cmu_us_rms_single_mcep_uh_176_cart,
 &cmu_us_rms_single_mcep_hh_81_cart,
 &cmu_us_rms_single_mcep_hh_82_cart,
 &cmu_us_rms_single_mcep_hh_83_cart,
 &cmu_us_rms_single_mcep_ae_6_cart,
 &cmu_us_rms_single_mcep_ae_7_cart,
 &cmu_us_rms_single_mcep_ae_8_cart,
 &cmu_us_rms_single_mcep_y_194_cart,
 &cmu_us_rms_single_mcep_y_195_cart,
 &cmu_us_rms_single_mcep_y_196_cart,
 &cmu_us_rms_single_mcep_k_101_cart,
 &cmu_us_rms_single_mcep_k_102_cart,
 &cmu_us_rms_single_mcep_k_103_cart,
 &cmu_us_rms_single_mcep_aa_1_cart,
 &cmu_us_rms_single_mcep_aa_2_cart,
 &cmu_us_rms_single_mcep_aa_3_cart,
 &cmu_us_rms_single_mcep_ay_31_cart,
 &cmu_us_rms_single_mcep_ay_32_cart,
 &cmu_us_rms_single_mcep_ay_33_cart,
 &cmu_us_rms_single_mcep_w_189_cart,
 &cmu_us_rms_single_mcep_w_190_cart,
 &cmu_us_rms_single_mcep_w_191_cart,
 &cmu_us_rms_single_mcep_m_111_cart,
 &cmu_us_rms_single_mcep_m_112_cart,
 &cmu_us_rms_single_mcep_m_113_cart,
 &cmu_us_rms_single_mcep_pau_143_cart,
 &cmu_us_rms_single_mcep_ao_16_cart,
 &cmu_us_rms_single_mcep_ao_17_cart,
 &cmu_us_rms_single_mcep_ao_18_cart,
 &cmu_us_rms_single_mcep_th_169_cart,
 &cmu_us_rms_single_mcep_th_170_cart,
 &cmu_us_rms_single_mcep_th_171_cart,
 &cmu_us_rms_single_mcep_ah_11_cart,
 &cmu_us_rms_single_mcep_ah_12_cart,
 &cmu_us_rms_single_mcep_ah_13_cart,
 &cmu_us_rms_single_mcep_v_184_cart,
 &cmu_us_rms_single_mcep_v_185_cart,
 &cmu_us_rms_single_mcep_v_186_cart,
 &cmu_us_rms_single_mcep_dh_51_cart,
 &cmu_us_rms_single_mcep_dh_52_cart,
 &cmu_us_rms_single_mcep_dh_53_cart,
 &cmu_us_rms_single_mcep_d_46_cart,
 &cmu_us_rms_single_mcep_d_47_cart,
 &cmu_us_rms_single_mcep_d_48_cart,
 &cmu_us_rms_single_mcep_n_116_cart,
 &cmu_us_rms_single_mcep_n_117_cart,
 &cmu_us_rms_single_mcep_n_118_cart,
 &cmu_us_rms_single_mcep_jh_96_cart,
 &cmu_us_rms_single_mcep_jh_97_cart,
 &cmu_us_rms_single_mcep_jh_98_cart,
 &cmu_us_rms_single_mcep_r_146_cart,
 &cmu_us_rms_single_mcep_r_147_cart,
 &cmu_us_rms_single_mcep_r_148_cart,
 &cmu_us_rms_single_mcep_ey_66_cart,
 &cmu_us_rms_single_mcep_ey_67_cart,
 &cmu_us_rms_single_mcep_ey_68_cart,
 &cmu_us_rms_single_mcep_f_71_cart,
 &cmu_us_rms_single_mcep_f_72_cart,
 &cmu_us_rms_single_mcep_f_73_cart,
 &cmu_us_rms_single_mcep_ih_86_cart,
 &cmu_us_rms_single_mcep_ih_87_cart,
 &cmu_us_rms_single_mcep_ih_88_cart,
 &cmu_us_rms_single_mcep_p_136_cart,
 &cmu_us_rms_single_mcep_p_137_cart,
 &cmu_us_rms_single_mcep_p_138_cart,
 &cmu_us_rms_single_mcep_iy_91_cart,
 &cmu_us_rms_single_mcep_iy_92_cart,
 &cmu_us_rms_single_mcep_iy_93_cart,
 &cmu_us_rms_single_mcep_l_106_cart,
 &cmu_us_rms_single_mcep_l_107_cart,
 &cmu_us_rms_single_mcep_l_108_cart,
 &cmu_us_rms_single_mcep_z_199_cart,
 &cmu_us_rms_single_mcep_z_200_cart,
 &cmu_us_rms_single_mcep_z_201_cart,
 &cmu_us_rms_single_mcep_pau_161_cart,
 &cmu_us_rms_single_mcep_s_151_cart,
 &cmu_us_rms_single_mcep_s_152_cart,
 &cmu_us_rms_single_mcep_s_153_cart,
 &cmu_us_rms_single_mcep_eh_56_cart,
 &cmu_us_rms_single_mcep_eh_57_cart,
 &cmu_us_rms_single_mcep_eh_58_cart,
 &cmu_us_rms_single_mcep_t_164_cart,
 &cmu_us_rms_single_mcep_t_165_cart,
 &cmu_us_rms_single_mcep_t_166_cart,
 &cmu_us_rms_single_mcep_er_61_cart,
 &cmu_us_rms_single_mcep_er_62_cart,
 &cmu_us_rms_single_mcep_er_63_cart,
 &cmu_us_rms_single_mcep_ax_26_cart,
 &cmu_us_rms_single_mcep_ax_27_cart,
 &cmu_us_rms_single_mcep_ax_28_cart,
 &cmu_us_rms_single_mcep_pau_141_cart,
 &cmu_us_rms_single_mcep_pau_142_cart,
 0 };
