DEF_STATIC_CONST_VAL_STRING(val_0000,"pau");
DEF_STATIC_CONST_VAL_STRING(val_0001,"BB");
DEF_STATIC_CONST_VAL_FLOAT(val_0002,2.000000);
#define CTNODE_cmu_us_rms_dur_NO_0001 3
DEF_STATIC_CONST_VAL_FLOAT(val_0003,0.000000);
#define CTNODE_cmu_us_rms_dur_NO_0000 4
DEF_STATIC_CONST_VAL_STRING(val_0004,"0");
DEF_STATIC_CONST_VAL_STRING(val_0005,"pau_143");
DEF_STATIC_CONST_VAL_STRING(val_0006,"f");
DEF_STATIC_CONST_VAL_STRING(val_0007,"s");
DEF_STATIC_CONST_VAL_STRING(val_0008,"-");
DEF_STATIC_CONST_VAL_FLOAT(val_0009,0.586565);
#define CTNODE_cmu_us_rms_dur_NO_0008 10
DEF_STATIC_CONST_VAL_FLOAT(val_0010,0.230541);
#define CTNODE_cmu_us_rms_dur_NO_0007 11
DEF_STATIC_CONST_VAL_STRING(val_0011,"z");
DEF_STATIC_CONST_VAL_STRING(val_0012,"+");
DEF_STATIC_CONST_VAL_FLOAT(val_0013,0.575770);
#define CTNODE_cmu_us_rms_dur_NO_0012 14
DEF_STATIC_CONST_VAL_FLOAT(val_0014,0.750541);
#define CTNODE_cmu_us_rms_dur_NO_0011 15
DEF_STATIC_CONST_VAL_FLOAT(val_0015,0.932118);
#define CTNODE_cmu_us_rms_dur_NO_0006 16
DEF_STATIC_CONST_VAL_FLOAT(val_0016,1.415230);
#define CTNODE_cmu_us_rms_dur_NO_0018 20
DEF_STATIC_CONST_VAL_FLOAT(val_0017,1.092560);
#define CTNODE_cmu_us_rms_dur_NO_0017 21
DEF_STATIC_CONST_VAL_FLOAT(val_0018,0.651116);
#define CTNODE_cmu_us_rms_dur_NO_0016 22
DEF_STATIC_CONST_VAL_STRING(val_0019,"1");
DEF_STATIC_CONST_VAL_FLOAT(val_0020,1.090410);
#define CTNODE_cmu_us_rms_dur_NO_0022 24
DEF_STATIC_CONST_VAL_FLOAT(val_0021,3.054800);
#define CTNODE_cmu_us_rms_dur_NO_0024 26
DEF_STATIC_CONST_VAL_STRING(val_0022,"l_108");
DEF_STATIC_CONST_VAL_FLOAT(val_0023,2.735160);
#define CTNODE_cmu_us_rms_dur_NO_0026 28
DEF_STATIC_CONST_VAL_STRING(val_0024,"r");
DEF_STATIC_CONST_VAL_FLOAT(val_0025,2.691710);
#define CTNODE_cmu_us_rms_dur_NO_0029 31
DEF_STATIC_CONST_VAL_FLOAT(val_0026,2.230620);
#define CTNODE_cmu_us_rms_dur_NO_0028 32
DEF_STATIC_CONST_VAL_FLOAT(val_0027,2.337170);
#define CTNODE_cmu_us_rms_dur_NO_0032 34
DEF_STATIC_CONST_VAL_STRING(val_0028,"2");
DEF_STATIC_CONST_VAL_FLOAT(val_0029,2.074540);
#define CTNODE_cmu_us_rms_dur_NO_0034 36
DEF_STATIC_CONST_VAL_FLOAT(val_0030,1.643970);
#define CTNODE_cmu_us_rms_dur_NO_0005 37
DEF_STATIC_CONST_VAL_FLOAT(val_0031,0.481673);
#define CTNODE_cmu_us_rms_dur_NO_0039 41
DEF_STATIC_CONST_VAL_FLOAT(val_0032,0.213566);
#define CTNODE_cmu_us_rms_dur_NO_0041 43
DEF_STATIC_CONST_VAL_FLOAT(val_0033,0.158476);
#define CTNODE_cmu_us_rms_dur_NO_0043 45
DEF_STATIC_CONST_VAL_FLOAT(val_0034,-0.249188);
#define CTNODE_cmu_us_rms_dur_NO_0038 46
DEF_STATIC_CONST_VAL_FLOAT(val_0035,-0.092660);
#define CTNODE_cmu_us_rms_dur_NO_0047 49
DEF_STATIC_CONST_VAL_FLOAT(val_0036,-0.097152);
#define CTNODE_cmu_us_rms_dur_NO_0046 50
DEF_STATIC_CONST_VAL_STRING(val_0037,"iy");
DEF_STATIC_CONST_VAL_FLOAT(val_0038,-0.163777);
#define CTNODE_cmu_us_rms_dur_NO_0050 52
DEF_STATIC_CONST_VAL_FLOAT(val_0039,-1.125300);
#define CTNODE_cmu_us_rms_dur_NO_0052 54
DEF_STATIC_CONST_VAL_STRING(val_0040,"l");
DEF_STATIC_CONST_VAL_FLOAT(val_0041,-1.070890);
#define CTNODE_cmu_us_rms_dur_NO_0054 56
DEF_STATIC_CONST_VAL_STRING(val_0042,"n");
DEF_STATIC_CONST_VAL_FLOAT(val_0043,-0.807427);
#define CTNODE_cmu_us_rms_dur_NO_0056 58
DEF_STATIC_CONST_VAL_FLOAT(val_0044,-0.793795);
#define CTNODE_cmu_us_rms_dur_NO_0059 61
DEF_STATIC_CONST_VAL_FLOAT(val_0045,-0.599203);
#define CTNODE_cmu_us_rms_dur_NO_0058 62
DEF_STATIC_CONST_VAL_FLOAT(val_0046,-0.658563);
#define CTNODE_cmu_us_rms_dur_NO_0062 64
DEF_STATIC_CONST_VAL_FLOAT(val_0047,0.128521);
#define CTNODE_cmu_us_rms_dur_NO_0037 65
DEF_STATIC_CONST_VAL_STRING(val_0048,"pau_141");
DEF_STATIC_CONST_VAL_STRING(val_0049,"t_166");
DEF_STATIC_CONST_VAL_FLOAT(val_0050,-0.396800);
#define CTNODE_cmu_us_rms_dur_NO_0067 69
DEF_STATIC_CONST_VAL_STRING(val_0051,"a");
DEF_STATIC_CONST_VAL_FLOAT(val_0052,-0.378869);
#define CTNODE_cmu_us_rms_dur_NO_0069 71
DEF_STATIC_CONST_VAL_FLOAT(val_0053,-0.306811);
#define CTNODE_cmu_us_rms_dur_NO_0071 73
DEF_STATIC_CONST_VAL_FLOAT(val_0054,-0.190320);
#define CTNODE_cmu_us_rms_dur_NO_0066 74
DEF_STATIC_CONST_VAL_STRING(val_0055,"n_118");
DEF_STATIC_CONST_VAL_FLOAT(val_0056,-0.019879);
#define CTNODE_cmu_us_rms_dur_NO_0075 77
DEF_STATIC_CONST_VAL_FLOAT(val_0057,-0.173445);
#define CTNODE_cmu_us_rms_dur_NO_0074 78
DEF_STATIC_CONST_VAL_FLOAT(val_0058,0.116037);
#define CTNODE_cmu_us_rms_dur_NO_0078 80
DEF_STATIC_CONST_VAL_FLOAT(val_0059,0.513169);
#define CTNODE_cmu_us_rms_dur_NO_0065 81
DEF_STATIC_CONST_VAL_STRING(val_0060,"iy_93");
DEF_STATIC_CONST_VAL_FLOAT(val_0061,1.261170);
#define CTNODE_cmu_us_rms_dur_NO_0082 84
DEF_STATIC_CONST_VAL_FLOAT(val_0062,2.275980);
#define CTNODE_cmu_us_rms_dur_NO_0081 85
DEF_STATIC_CONST_VAL_STRING(val_0063,"z_200");
DEF_STATIC_CONST_VAL_FLOAT(val_0064,1.985290);
#define CTNODE_cmu_us_rms_dur_NO_0086 88
DEF_STATIC_CONST_VAL_FLOAT(val_0065,1.238300);
#define CTNODE_cmu_us_rms_dur_NO_0085 89
DEF_STATIC_CONST_VAL_FLOAT(val_0066,-0.420004);
#define CTNODE_cmu_us_rms_dur_NO_0090 92
DEF_STATIC_CONST_VAL_STRING(val_0067,"coda");
DEF_STATIC_CONST_VAL_FLOAT(val_0068,2.397750);
#define CTNODE_cmu_us_rms_dur_NO_0093 95
DEF_STATIC_CONST_VAL_FLOAT(val_0069,1.189650);
#define CTNODE_cmu_us_rms_dur_NO_0092 96
DEF_STATIC_CONST_VAL_STRING(val_0070,"p");
DEF_STATIC_CONST_VAL_FLOAT(val_0071,1.537390);
#define CTNODE_cmu_us_rms_dur_NO_0096 98
DEF_STATIC_CONST_VAL_FLOAT(val_0072,0.817087);
#define CTNODE_cmu_us_rms_dur_NO_0099 101
DEF_STATIC_CONST_VAL_FLOAT(val_0073,2.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0074,1.078840);
#define CTNODE_cmu_us_rms_dur_NO_0101 103
DEF_STATIC_CONST_VAL_FLOAT(val_0075,1.390930);
#define CTNODE_cmu_us_rms_dur_NO_0098 104
DEF_STATIC_CONST_VAL_STRING(val_0076,"ng_123");
DEF_STATIC_CONST_VAL_FLOAT(val_0077,0.004705);
#define CTNODE_cmu_us_rms_dur_NO_0105 107
DEF_STATIC_CONST_VAL_FLOAT(val_0078,3.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0079,1.518090);
#define CTNODE_cmu_us_rms_dur_NO_0108 110
DEF_STATIC_CONST_VAL_FLOAT(val_0080,0.838156);
#define CTNODE_cmu_us_rms_dur_NO_0107 111
DEF_STATIC_CONST_VAL_FLOAT(val_0081,12.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0082,1.220040);
#define CTNODE_cmu_us_rms_dur_NO_0112 114
DEF_STATIC_CONST_VAL_FLOAT(val_0083,0.741612);
#define CTNODE_cmu_us_rms_dur_NO_0111 115
DEF_STATIC_CONST_VAL_FLOAT(val_0084,-0.018900);
#define CTNODE_cmu_us_rms_dur_NO_0115 117
DEF_STATIC_CONST_VAL_FLOAT(val_0085,13.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0086,6.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0087,0.815331);
#define CTNODE_cmu_us_rms_dur_NO_0119 121
DEF_STATIC_CONST_VAL_FLOAT(val_0088,0.464698);
#define CTNODE_cmu_us_rms_dur_NO_0118 122
DEF_STATIC_CONST_VAL_FLOAT(val_0089,1.064650);
#define CTNODE_cmu_us_rms_dur_NO_0117 123
DEF_STATIC_CONST_VAL_FLOAT(val_0090,0.296282);
#define CTNODE_cmu_us_rms_dur_NO_0104 124
DEF_STATIC_CONST_VAL_FLOAT(val_0091,14.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0092,1.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0093,9.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0094,0.433128);
#define CTNODE_cmu_us_rms_dur_NO_0126 128
DEF_STATIC_CONST_VAL_FLOAT(val_0095,0.203678);
#define CTNODE_cmu_us_rms_dur_NO_0125 129
DEF_STATIC_CONST_VAL_STRING(val_0096,"3");
DEF_STATIC_CONST_VAL_FLOAT(val_0097,0.997380);
#define CTNODE_cmu_us_rms_dur_NO_0129 131
DEF_STATIC_CONST_VAL_FLOAT(val_0098,0.474837);
#define CTNODE_cmu_us_rms_dur_NO_0124 132
DEF_STATIC_CONST_VAL_FLOAT(val_0099,0.105431);
#define CTNODE_cmu_us_rms_dur_NO_0089 133
DEF_STATIC_CONST_VAL_STRING(val_0100,"n_117");
DEF_STATIC_CONST_VAL_FLOAT(val_0101,1.780560);
#define CTNODE_cmu_us_rms_dur_NO_0134 136
DEF_STATIC_CONST_VAL_FLOAT(val_0102,0.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0103,1.461320);
#define CTNODE_cmu_us_rms_dur_NO_0136 138
DEF_STATIC_CONST_VAL_FLOAT(val_0104,0.852101);
#define CTNODE_cmu_us_rms_dur_NO_0133 139
DEF_STATIC_CONST_VAL_STRING(val_0105,"pau_142");
DEF_STATIC_CONST_VAL_FLOAT(val_0106,2.090780);
#define CTNODE_cmu_us_rms_dur_NO_0141 143
DEF_STATIC_CONST_VAL_FLOAT(val_0107,1.800530);
#define CTNODE_cmu_us_rms_dur_NO_0140 144
DEF_STATIC_CONST_VAL_FLOAT(val_0108,0.728364);
#define CTNODE_cmu_us_rms_dur_NO_0144 146
DEF_STATIC_CONST_VAL_FLOAT(val_0109,6.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0110,0.413656);
#define CTNODE_cmu_us_rms_dur_NO_0147 149
DEF_STATIC_CONST_VAL_FLOAT(val_0111,0.353463);
#define CTNODE_cmu_us_rms_dur_NO_0146 150
DEF_STATIC_CONST_VAL_FLOAT(val_0112,-0.203313);
#define CTNODE_cmu_us_rms_dur_NO_0150 152
DEF_STATIC_CONST_VAL_FLOAT(val_0113,1.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0114,0.315884);
#define CTNODE_cmu_us_rms_dur_NO_0152 154
DEF_STATIC_CONST_VAL_FLOAT(val_0115,-0.141241);
#define CTNODE_cmu_us_rms_dur_NO_0139 155
DEF_STATIC_CONST_VAL_STRING(val_0116,"m_111");
DEF_STATIC_CONST_VAL_FLOAT(val_0117,1.338860);
#define CTNODE_cmu_us_rms_dur_NO_0155 157
DEF_STATIC_CONST_VAL_STRING(val_0118,"l_106");
DEF_STATIC_CONST_VAL_FLOAT(val_0119,1.437800);
#define CTNODE_cmu_us_rms_dur_NO_0157 159
DEF_STATIC_CONST_VAL_STRING(val_0120,"s_152");
DEF_STATIC_CONST_VAL_FLOAT(val_0121,0.711627);
#define CTNODE_cmu_us_rms_dur_NO_0160 162
DEF_STATIC_CONST_VAL_FLOAT(val_0122,1.250200);
#define CTNODE_cmu_us_rms_dur_NO_0159 163
DEF_STATIC_CONST_VAL_STRING(val_0123,"d_47");
DEF_STATIC_CONST_VAL_FLOAT(val_0124,1.223490);
#define CTNODE_cmu_us_rms_dur_NO_0164 166
DEF_STATIC_CONST_VAL_FLOAT(val_0125,0.273227);
#define CTNODE_cmu_us_rms_dur_NO_0163 167
DEF_STATIC_CONST_VAL_STRING(val_0126,"ng_122");
DEF_STATIC_CONST_VAL_FLOAT(val_0127,0.826785);
#define CTNODE_cmu_us_rms_dur_NO_0168 170
DEF_STATIC_CONST_VAL_STRING(val_0128,"l_107");
DEF_STATIC_CONST_VAL_FLOAT(val_0129,-0.687814);
#define CTNODE_cmu_us_rms_dur_NO_0170 172
DEF_STATIC_CONST_VAL_FLOAT(val_0130,0.433086);
#define CTNODE_cmu_us_rms_dur_NO_0173 175
DEF_STATIC_CONST_VAL_FLOAT(val_0131,0.343900);
#define CTNODE_cmu_us_rms_dur_NO_0172 176
DEF_STATIC_CONST_VAL_FLOAT(val_0132,-0.743901);
#define CTNODE_cmu_us_rms_dur_NO_0176 178
DEF_STATIC_CONST_VAL_FLOAT(val_0133,-0.663328);
#define CTNODE_cmu_us_rms_dur_NO_0178 180
DEF_STATIC_CONST_VAL_FLOAT(val_0134,10.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0135,-0.340197);
#define CTNODE_cmu_us_rms_dur_NO_0182 184
DEF_STATIC_CONST_VAL_FLOAT(val_0136,-0.561975);
#define CTNODE_cmu_us_rms_dur_NO_0181 185
DEF_STATIC_CONST_VAL_FLOAT(val_0137,-0.029288);
#define CTNODE_cmu_us_rms_dur_NO_0185 187
DEF_STATIC_CONST_VAL_FLOAT(val_0138,-0.396912);
#define CTNODE_cmu_us_rms_dur_NO_0180 188
DEF_STATIC_CONST_VAL_FLOAT(val_0139,3.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0140,10.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0141,0.136570);
#define CTNODE_cmu_us_rms_dur_NO_0189 191
DEF_STATIC_CONST_VAL_FLOAT(val_0142,0.537867);
#define CTNODE_cmu_us_rms_dur_NO_0188 192
DEF_STATIC_CONST_VAL_FLOAT(val_0143,-0.242295);
#define CTNODE_cmu_us_rms_dur_NO_0167 193
DEF_STATIC_CONST_VAL_STRING(val_0144,"iy_92");
DEF_STATIC_CONST_VAL_FLOAT(val_0145,-0.473445);
#define CTNODE_cmu_us_rms_dur_NO_0194 196
DEF_STATIC_CONST_VAL_STRING(val_0146,"er_61");
DEF_STATIC_CONST_VAL_FLOAT(val_0147,-0.316703);
#define CTNODE_cmu_us_rms_dur_NO_0196 198
DEF_STATIC_CONST_VAL_STRING(val_0148,"d");
DEF_STATIC_CONST_VAL_FLOAT(val_0149,0.169886);
#define CTNODE_cmu_us_rms_dur_NO_0199 201
DEF_STATIC_CONST_VAL_FLOAT(val_0150,0.482833);
#define CTNODE_cmu_us_rms_dur_NO_0201 203
DEF_STATIC_CONST_VAL_FLOAT(val_0151,0.535685);
#define CTNODE_cmu_us_rms_dur_NO_0198 204
DEF_STATIC_CONST_VAL_STRING(val_0152,"t");
DEF_STATIC_CONST_VAL_FLOAT(val_0153,0.190187);
#define CTNODE_cmu_us_rms_dur_NO_0205 207
DEF_STATIC_CONST_VAL_FLOAT(val_0154,-0.264958);
#define CTNODE_cmu_us_rms_dur_NO_0207 209
DEF_STATIC_CONST_VAL_FLOAT(val_0155,-0.178805);
#define CTNODE_cmu_us_rms_dur_NO_0209 211
DEF_STATIC_CONST_VAL_FLOAT(val_0156,0.139422);
#define CTNODE_cmu_us_rms_dur_NO_0204 212
DEF_STATIC_CONST_VAL_STRING(val_0157,"final");
DEF_STATIC_CONST_VAL_FLOAT(val_0158,-0.022270);
#define CTNODE_cmu_us_rms_dur_NO_0213 215
DEF_STATIC_CONST_VAL_FLOAT(val_0159,0.668162);
#define CTNODE_cmu_us_rms_dur_NO_0215 217
DEF_STATIC_CONST_VAL_FLOAT(val_0160,0.525248);
#define CTNODE_cmu_us_rms_dur_NO_0217 219
DEF_STATIC_CONST_VAL_FLOAT(val_0161,0.094391);
#define CTNODE_cmu_us_rms_dur_NO_0212 220
DEF_STATIC_CONST_VAL_FLOAT(val_0162,0.124864);
#define CTNODE_cmu_us_rms_dur_NO_0220 222
DEF_STATIC_CONST_VAL_FLOAT(val_0163,-0.136776);
#define CTNODE_cmu_us_rms_dur_NO_0193 223
DEF_STATIC_CONST_VAL_FLOAT(val_0164,0.370776);
#define CTNODE_cmu_us_rms_dur_NO_0224 226
DEF_STATIC_CONST_VAL_FLOAT(val_0165,8.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0166,-0.277749);
#define CTNODE_cmu_us_rms_dur_NO_0226 228
DEF_STATIC_CONST_VAL_STRING(val_0167,"t_164");
DEF_STATIC_CONST_VAL_FLOAT(val_0168,0.253781);
#define CTNODE_cmu_us_rms_dur_NO_0228 230
DEF_STATIC_CONST_VAL_FLOAT(val_0169,-0.209656);
#define CTNODE_cmu_us_rms_dur_NO_0223 231
DEF_STATIC_CONST_VAL_FLOAT(val_0170,0.842281);
#define CTNODE_cmu_us_rms_dur_NO_0233 235
DEF_STATIC_CONST_VAL_FLOAT(val_0171,11.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0172,1.384860);
#define CTNODE_cmu_us_rms_dur_NO_0235 237
DEF_STATIC_CONST_VAL_FLOAT(val_0173,1.120110);
#define CTNODE_cmu_us_rms_dur_NO_0232 238
DEF_STATIC_CONST_VAL_FLOAT(val_0174,2.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0175,0.974878);
#define CTNODE_cmu_us_rms_dur_NO_0239 241
DEF_STATIC_CONST_VAL_FLOAT(val_0176,0.661682);
#define CTNODE_cmu_us_rms_dur_NO_0238 242
DEF_STATIC_CONST_VAL_FLOAT(val_0177,0.358512);
#define CTNODE_cmu_us_rms_dur_NO_0231 243
DEF_STATIC_CONST_VAL_FLOAT(val_0178,0.082065);
#define CTNODE_cmu_us_rms_dur_NO_0004 244
DEF_STATIC_CONST_VAL_FLOAT(val_0179,-1.251650);
#define CTNODE_cmu_us_rms_dur_NO_0249 251
DEF_STATIC_CONST_VAL_STRING(val_0180,"ay");
DEF_STATIC_CONST_VAL_FLOAT(val_0181,-0.175191);
#define CTNODE_cmu_us_rms_dur_NO_0252 254
DEF_STATIC_CONST_VAL_FLOAT(val_0182,-0.470202);
#define CTNODE_cmu_us_rms_dur_NO_0254 256
DEF_STATIC_CONST_VAL_FLOAT(val_0183,-0.413469);
#define CTNODE_cmu_us_rms_dur_NO_0251 257
DEF_STATIC_CONST_VAL_STRING(val_0184,"ay_31");
DEF_STATIC_CONST_VAL_FLOAT(val_0185,-0.583887);
#define CTNODE_cmu_us_rms_dur_NO_0258 260
DEF_STATIC_CONST_VAL_FLOAT(val_0186,-0.514238);
#define CTNODE_cmu_us_rms_dur_NO_0257 261
DEF_STATIC_CONST_VAL_FLOAT(val_0187,-0.578046);
#define CTNODE_cmu_us_rms_dur_NO_0261 263
DEF_STATIC_CONST_VAL_FLOAT(val_0188,-0.621706);
#define CTNODE_cmu_us_rms_dur_NO_0248 264
DEF_STATIC_CONST_VAL_FLOAT(val_0189,0.226873);
#define CTNODE_cmu_us_rms_dur_NO_0264 266
DEF_STATIC_CONST_VAL_FLOAT(val_0190,-0.437188);
#define CTNODE_cmu_us_rms_dur_NO_0266 268
DEF_STATIC_CONST_VAL_FLOAT(val_0191,-0.469598);
#define CTNODE_cmu_us_rms_dur_NO_0268 270
DEF_STATIC_CONST_VAL_FLOAT(val_0192,0.128562);
#define CTNODE_cmu_us_rms_dur_NO_0270 272
DEF_STATIC_CONST_VAL_FLOAT(val_0193,-0.153323);
#define CTNODE_cmu_us_rms_dur_NO_0247 273
DEF_STATIC_CONST_VAL_STRING(val_0194,"ae_8");
DEF_STATIC_CONST_VAL_STRING(val_0195,"in");
DEF_STATIC_CONST_VAL_FLOAT(val_0196,-0.264332);
#define CTNODE_cmu_us_rms_dur_NO_0274 276
DEF_STATIC_CONST_VAL_FLOAT(val_0197,5.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0198,-0.557048);
#define CTNODE_cmu_us_rms_dur_NO_0277 279
DEF_STATIC_CONST_VAL_FLOAT(val_0199,-0.413834);
#define CTNODE_cmu_us_rms_dur_NO_0276 280
DEF_STATIC_CONST_VAL_FLOAT(val_0200,0.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0201,-0.608481);
#define CTNODE_cmu_us_rms_dur_NO_0280 282
DEF_STATIC_CONST_VAL_FLOAT(val_0202,8.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0203,-0.885086);
#define CTNODE_cmu_us_rms_dur_NO_0283 285
DEF_STATIC_CONST_VAL_FLOAT(val_0204,-0.564419);
#define CTNODE_cmu_us_rms_dur_NO_0282 286
DEF_STATIC_CONST_VAL_FLOAT(val_0205,-0.867120);
#define CTNODE_cmu_us_rms_dur_NO_0273 287
DEF_STATIC_CONST_VAL_STRING(val_0206,"ih_86");
DEF_STATIC_CONST_VAL_FLOAT(val_0207,1.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0208,-0.048178);
#define CTNODE_cmu_us_rms_dur_NO_0288 290
DEF_STATIC_CONST_VAL_FLOAT(val_0209,1.562750);
#define CTNODE_cmu_us_rms_dur_NO_0291 293
DEF_STATIC_CONST_VAL_FLOAT(val_0210,1.759660);
#define CTNODE_cmu_us_rms_dur_NO_0290 294
DEF_STATIC_CONST_VAL_FLOAT(val_0211,1.013350);
#define CTNODE_cmu_us_rms_dur_NO_0287 295
DEF_STATIC_CONST_VAL_STRING(val_0212,"t_165");
DEF_STATIC_CONST_VAL_FLOAT(val_0213,0.597915);
#define CTNODE_cmu_us_rms_dur_NO_0296 298
DEF_STATIC_CONST_VAL_FLOAT(val_0214,1.328890);
#define CTNODE_cmu_us_rms_dur_NO_0298 300
DEF_STATIC_CONST_VAL_FLOAT(val_0215,0.865987);
#define CTNODE_cmu_us_rms_dur_NO_0295 301
DEF_STATIC_CONST_VAL_FLOAT(val_0216,1.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0217,0.904971);
#define CTNODE_cmu_us_rms_dur_NO_0303 305
DEF_STATIC_CONST_VAL_FLOAT(val_0218,1.270480);
#define CTNODE_cmu_us_rms_dur_NO_0302 306
DEF_STATIC_CONST_VAL_STRING(val_0219,"hh_81");
DEF_STATIC_CONST_VAL_FLOAT(val_0220,-0.055824);
#define CTNODE_cmu_us_rms_dur_NO_0307 309
DEF_STATIC_CONST_VAL_FLOAT(val_0221,-0.506297);
#define CTNODE_cmu_us_rms_dur_NO_0306 310
DEF_STATIC_CONST_VAL_FLOAT(val_0222,0.708950);
#define CTNODE_cmu_us_rms_dur_NO_0311 313
DEF_STATIC_CONST_VAL_STRING(val_0223,"ax");
DEF_STATIC_CONST_VAL_FLOAT(val_0224,-0.242606);
#define CTNODE_cmu_us_rms_dur_NO_0313 315
DEF_STATIC_CONST_VAL_FLOAT(val_0225,4.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0226,-0.352953);
#define CTNODE_cmu_us_rms_dur_NO_0316 318
DEF_STATIC_CONST_VAL_FLOAT(val_0227,0.310095);
#define CTNODE_cmu_us_rms_dur_NO_0315 319
DEF_STATIC_CONST_VAL_FLOAT(val_0228,0.076514);
#define CTNODE_cmu_us_rms_dur_NO_0319 321
DEF_STATIC_CONST_VAL_FLOAT(val_0229,0.582637);
#define CTNODE_cmu_us_rms_dur_NO_0310 322
DEF_STATIC_CONST_VAL_FLOAT(val_0230,2.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0231,0.605425);
#define CTNODE_cmu_us_rms_dur_NO_0323 325
DEF_STATIC_CONST_VAL_FLOAT(val_0232,-0.021326);
#define CTNODE_cmu_us_rms_dur_NO_0322 326
DEF_STATIC_CONST_VAL_FLOAT(val_0233,0.526825);
#define CTNODE_cmu_us_rms_dur_NO_0328 330
DEF_STATIC_CONST_VAL_FLOAT(val_0234,4.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0235,0.953477);
#define CTNODE_cmu_us_rms_dur_NO_0330 332
DEF_STATIC_CONST_VAL_FLOAT(val_0236,0.653336);
#define CTNODE_cmu_us_rms_dur_NO_0327 333
DEF_STATIC_CONST_VAL_FLOAT(val_0237,3.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0238,1.234690);
#define CTNODE_cmu_us_rms_dur_NO_0333 335
DEF_STATIC_CONST_VAL_FLOAT(val_0239,0.872680);
#define CTNODE_cmu_us_rms_dur_NO_0326 336
DEF_STATIC_CONST_VAL_FLOAT(val_0240,0.170317);
#define CTNODE_cmu_us_rms_dur_NO_0301 337
DEF_STATIC_CONST_VAL_FLOAT(val_0241,6.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0242,6.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0243,-0.430501);
#define CTNODE_cmu_us_rms_dur_NO_0340 342
DEF_STATIC_CONST_VAL_FLOAT(val_0244,-0.436974);
#define CTNODE_cmu_us_rms_dur_NO_0339 343
DEF_STATIC_CONST_VAL_FLOAT(val_0245,-0.050292);
#define CTNODE_cmu_us_rms_dur_NO_0338 344
DEF_STATIC_CONST_VAL_STRING(val_0246,"ae_7");
DEF_STATIC_CONST_VAL_FLOAT(val_0247,1.721280);
#define CTNODE_cmu_us_rms_dur_NO_0344 346
DEF_STATIC_CONST_VAL_STRING(val_0248,"dh_52");
DEF_STATIC_CONST_VAL_FLOAT(val_0249,0.897038);
#define CTNODE_cmu_us_rms_dur_NO_0347 349
DEF_STATIC_CONST_VAL_FLOAT(val_0250,1.307840);
#define CTNODE_cmu_us_rms_dur_NO_0346 350
DEF_STATIC_CONST_VAL_FLOAT(val_0251,-0.110520);
#define CTNODE_cmu_us_rms_dur_NO_0350 352
DEF_STATIC_CONST_VAL_FLOAT(val_0252,9.700000);
DEF_STATIC_CONST_VAL_STRING(val_0253,"dh_53");
DEF_STATIC_CONST_VAL_FLOAT(val_0254,1.395740);
#define CTNODE_cmu_us_rms_dur_NO_0353 355
DEF_STATIC_CONST_VAL_FLOAT(val_0255,0.385642);
#define CTNODE_cmu_us_rms_dur_NO_0352 356
DEF_STATIC_CONST_VAL_FLOAT(val_0256,0.870275);
#define CTNODE_cmu_us_rms_dur_NO_0356 358
DEF_STATIC_CONST_VAL_FLOAT(val_0257,9.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0258,7.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0259,0.383862);
#define CTNODE_cmu_us_rms_dur_NO_0360 362
DEF_STATIC_CONST_VAL_FLOAT(val_0260,5.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0261,-0.085089);
#define CTNODE_cmu_us_rms_dur_NO_0362 364
DEF_STATIC_CONST_VAL_FLOAT(val_0262,0.034752);
#define CTNODE_cmu_us_rms_dur_NO_0359 365
DEF_STATIC_CONST_VAL_FLOAT(val_0263,0.480915);
#define CTNODE_cmu_us_rms_dur_NO_0358 366
DEF_STATIC_CONST_VAL_FLOAT(val_0264,-0.005180);
#define CTNODE_cmu_us_rms_dur_NO_0337 367
DEF_STATIC_CONST_VAL_STRING(val_0265,"ax_26");
DEF_STATIC_CONST_VAL_FLOAT(val_0266,0.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0267,-0.365020);
#define CTNODE_cmu_us_rms_dur_NO_0369 371
DEF_STATIC_CONST_VAL_FLOAT(val_0268,-0.636091);
#define CTNODE_cmu_us_rms_dur_NO_0371 373
DEF_STATIC_CONST_VAL_FLOAT(val_0269,-0.454283);
#define CTNODE_cmu_us_rms_dur_NO_0368 374
DEF_STATIC_CONST_VAL_FLOAT(val_0270,-0.494766);
#define CTNODE_cmu_us_rms_dur_NO_0375 377
DEF_STATIC_CONST_VAL_FLOAT(val_0271,-0.286263);
#define CTNODE_cmu_us_rms_dur_NO_0374 378
DEF_STATIC_CONST_VAL_FLOAT(val_0272,-0.087903);
#define CTNODE_cmu_us_rms_dur_NO_0367 379
DEF_STATIC_CONST_VAL_FLOAT(val_0273,0.874661);
#define CTNODE_cmu_us_rms_dur_NO_0379 381
DEF_STATIC_CONST_VAL_STRING(val_0274,"aa_1");
DEF_STATIC_CONST_VAL_FLOAT(val_0275,1.046220);
#define CTNODE_cmu_us_rms_dur_NO_0381 383
DEF_STATIC_CONST_VAL_STRING(val_0276,"ae_6");
DEF_STATIC_CONST_VAL_FLOAT(val_0277,2.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0278,1.087880);
#define CTNODE_cmu_us_rms_dur_NO_0384 386
DEF_STATIC_CONST_VAL_FLOAT(val_0279,0.394384);
#define CTNODE_cmu_us_rms_dur_NO_0383 387
DEF_STATIC_CONST_VAL_STRING(val_0280,"ah_12");
DEF_STATIC_CONST_VAL_FLOAT(val_0281,-0.060294);
#define CTNODE_cmu_us_rms_dur_NO_0388 390
DEF_STATIC_CONST_VAL_FLOAT(val_0282,-0.300363);
#define CTNODE_cmu_us_rms_dur_NO_0390 392
DEF_STATIC_CONST_VAL_FLOAT(val_0283,-0.603215);
#define CTNODE_cmu_us_rms_dur_NO_0387 393
DEF_STATIC_CONST_VAL_FLOAT(val_0284,1.265440);
#define CTNODE_cmu_us_rms_dur_NO_0394 396
DEF_STATIC_CONST_VAL_STRING(val_0285,"ao_18");
DEF_STATIC_CONST_VAL_FLOAT(val_0286,-0.523151);
#define CTNODE_cmu_us_rms_dur_NO_0396 398
DEF_STATIC_CONST_VAL_FLOAT(val_0287,1.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0288,0.424744);
#define CTNODE_cmu_us_rms_dur_NO_0400 402
DEF_STATIC_CONST_VAL_FLOAT(val_0289,0.879963);
#define CTNODE_cmu_us_rms_dur_NO_0399 403
DEF_STATIC_CONST_VAL_FLOAT(val_0290,0.776527);
#define CTNODE_cmu_us_rms_dur_NO_0404 406
DEF_STATIC_CONST_VAL_FLOAT(val_0291,0.301786);
#define CTNODE_cmu_us_rms_dur_NO_0403 407
DEF_STATIC_CONST_VAL_FLOAT(val_0292,0.380664);
#define CTNODE_cmu_us_rms_dur_NO_0407 409
DEF_STATIC_CONST_VAL_FLOAT(val_0293,-0.084118);
#define CTNODE_cmu_us_rms_dur_NO_0409 411
DEF_STATIC_CONST_VAL_FLOAT(val_0294,0.238686);
#define CTNODE_cmu_us_rms_dur_NO_0398 412
DEF_STATIC_CONST_VAL_FLOAT(val_0295,0.649616);
#define CTNODE_cmu_us_rms_dur_NO_0412 414
DEF_STATIC_CONST_VAL_FLOAT(val_0296,6.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0297,0.096587);
#define CTNODE_cmu_us_rms_dur_NO_0417 419
DEF_STATIC_CONST_VAL_FLOAT(val_0298,-0.102179);
#define CTNODE_cmu_us_rms_dur_NO_0416 420
DEF_STATIC_CONST_VAL_FLOAT(val_0299,0.331697);
#define CTNODE_cmu_us_rms_dur_NO_0415 421
DEF_STATIC_CONST_VAL_FLOAT(val_0300,-0.496438);
#define CTNODE_cmu_us_rms_dur_NO_0421 423
DEF_STATIC_CONST_VAL_FLOAT(val_0301,-0.285812);
#define CTNODE_cmu_us_rms_dur_NO_0423 425
DEF_STATIC_CONST_VAL_FLOAT(val_0302,0.009670);
#define CTNODE_cmu_us_rms_dur_NO_0414 426
DEF_STATIC_CONST_VAL_FLOAT(val_0303,1.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0304,0.388630);
#define CTNODE_cmu_us_rms_dur_NO_0428 430
DEF_STATIC_CONST_VAL_FLOAT(val_0305,-0.063506);
#define CTNODE_cmu_us_rms_dur_NO_0427 431
DEF_STATIC_CONST_VAL_FLOAT(val_0306,-0.262333);
#define CTNODE_cmu_us_rms_dur_NO_0426 432
DEF_STATIC_CONST_VAL_FLOAT(val_0307,0.543910);
#define CTNODE_cmu_us_rms_dur_NO_0432 434
DEF_STATIC_CONST_VAL_FLOAT(val_0308,0.640147);
#define CTNODE_cmu_us_rms_dur_NO_0435 437
DEF_STATIC_CONST_VAL_FLOAT(val_0309,0.228053);
#define CTNODE_cmu_us_rms_dur_NO_0434 438
DEF_STATIC_CONST_VAL_FLOAT(val_0310,7.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0311,0.404953);
#define CTNODE_cmu_us_rms_dur_NO_0439 441
DEF_STATIC_CONST_VAL_FLOAT(val_0312,-0.049997);
#define CTNODE_cmu_us_rms_dur_NO_0441 443
DEF_STATIC_CONST_VAL_FLOAT(val_0313,0.175368);
#define CTNODE_cmu_us_rms_dur_NO_0438 444
DEF_STATIC_CONST_VAL_FLOAT(val_0314,-0.065582);
#define CTNODE_cmu_us_rms_dur_NO_0393 445
DEF_STATIC_CONST_VAL_FLOAT(val_0315,2.300000);
DEF_STATIC_CONST_VAL_STRING(val_0316,"hh");
DEF_STATIC_CONST_VAL_FLOAT(val_0317,-0.482911);
#define CTNODE_cmu_us_rms_dur_NO_0446 448
DEF_STATIC_CONST_VAL_STRING(val_0318,"m");
DEF_STATIC_CONST_VAL_FLOAT(val_0319,-0.522708);
#define CTNODE_cmu_us_rms_dur_NO_0448 450
DEF_STATIC_CONST_VAL_STRING(val_0320,"w_190");
DEF_STATIC_CONST_VAL_FLOAT(val_0321,-0.455802);
#define CTNODE_cmu_us_rms_dur_NO_0450 452
DEF_STATIC_CONST_VAL_STRING(val_0322,"pau_161");
DEF_STATIC_CONST_VAL_FLOAT(val_0323,0.017005);
#define CTNODE_cmu_us_rms_dur_NO_0453 455
DEF_STATIC_CONST_VAL_FLOAT(val_0324,-0.526863);
#define CTNODE_cmu_us_rms_dur_NO_0452 456
DEF_STATIC_CONST_VAL_FLOAT(val_0325,6.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0326,-0.145186);
#define CTNODE_cmu_us_rms_dur_NO_0460 462
DEF_STATIC_CONST_VAL_FLOAT(val_0327,0.212857);
#define CTNODE_cmu_us_rms_dur_NO_0459 463
DEF_STATIC_CONST_VAL_FLOAT(val_0328,0.337337);
#define CTNODE_cmu_us_rms_dur_NO_0458 464
DEF_STATIC_CONST_VAL_FLOAT(val_0329,-0.324786);
#define CTNODE_cmu_us_rms_dur_NO_0457 465
DEF_STATIC_CONST_VAL_FLOAT(val_0330,0.375411);
#define CTNODE_cmu_us_rms_dur_NO_0456 466
DEF_STATIC_CONST_VAL_FLOAT(val_0331,0.317269);
#define CTNODE_cmu_us_rms_dur_NO_0466 468
DEF_STATIC_CONST_VAL_FLOAT(val_0332,-0.388768);
#define CTNODE_cmu_us_rms_dur_NO_0468 470
DEF_STATIC_CONST_VAL_FLOAT(val_0333,-0.128788);
#define CTNODE_cmu_us_rms_dur_NO_0445 471
DEF_STATIC_CONST_VAL_STRING(val_0334,"w_191");
DEF_STATIC_CONST_VAL_FLOAT(val_0335,-0.023205);
#define CTNODE_cmu_us_rms_dur_NO_0472 474
DEF_STATIC_CONST_VAL_FLOAT(val_0336,-0.623490);
#define CTNODE_cmu_us_rms_dur_NO_0475 477
DEF_STATIC_CONST_VAL_FLOAT(val_0337,-0.269660);
#define CTNODE_cmu_us_rms_dur_NO_0474 478
DEF_STATIC_CONST_VAL_FLOAT(val_0338,-0.213656);
#define CTNODE_cmu_us_rms_dur_NO_0471 479
DEF_STATIC_CONST_VAL_STRING(val_0339,"r_148");
DEF_STATIC_CONST_VAL_FLOAT(val_0340,-0.501605);
#define CTNODE_cmu_us_rms_dur_NO_0479 481
DEF_STATIC_CONST_VAL_STRING(val_0341,"uw");
DEF_STATIC_CONST_VAL_FLOAT(val_0342,-0.361355);
#define CTNODE_cmu_us_rms_dur_NO_0481 483
DEF_STATIC_CONST_VAL_FLOAT(val_0343,-0.136190);
#define CTNODE_cmu_us_rms_dur_NO_0484 486
DEF_STATIC_CONST_VAL_FLOAT(val_0344,-0.425518);
#define CTNODE_cmu_us_rms_dur_NO_0483 487
DEF_STATIC_CONST_VAL_FLOAT(val_0345,-0.399557);
#define CTNODE_cmu_us_rms_dur_NO_0487 489
DEF_STATIC_CONST_VAL_STRING(val_0346,"r_147");
DEF_STATIC_CONST_VAL_FLOAT(val_0347,-0.405293);
#define CTNODE_cmu_us_rms_dur_NO_0489 491
DEF_STATIC_CONST_VAL_FLOAT(val_0348,-0.295829);
#define CTNODE_cmu_us_rms_dur_NO_0491 493
DEF_STATIC_CONST_VAL_FLOAT(val_0349,1.182560);
#define CTNODE_cmu_us_rms_dur_NO_0494 496
DEF_STATIC_CONST_VAL_STRING(val_0350,"b");
DEF_STATIC_CONST_VAL_STRING(val_0351,"b_37");
DEF_STATIC_CONST_VAL_FLOAT(val_0352,0.357777);
#define CTNODE_cmu_us_rms_dur_NO_0497 499
DEF_STATIC_CONST_VAL_FLOAT(val_0353,-0.316556);
#define CTNODE_cmu_us_rms_dur_NO_0496 500
DEF_STATIC_CONST_VAL_FLOAT(val_0354,2.700000);
DEF_STATIC_CONST_VAL_STRING(val_0355,"content");
DEF_STATIC_CONST_VAL_FLOAT(val_0356,0.994399);
#define CTNODE_cmu_us_rms_dur_NO_0503 505
DEF_STATIC_CONST_VAL_FLOAT(val_0357,0.386286);
#define CTNODE_cmu_us_rms_dur_NO_0502 506
DEF_STATIC_CONST_VAL_FLOAT(val_0358,0.151836);
#define CTNODE_cmu_us_rms_dur_NO_0501 507
DEF_STATIC_CONST_VAL_FLOAT(val_0359,0.534797);
#define CTNODE_cmu_us_rms_dur_NO_0507 509
DEF_STATIC_CONST_VAL_FLOAT(val_0360,4.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0361,-0.117594);
#define CTNODE_cmu_us_rms_dur_NO_0509 511
DEF_STATIC_CONST_VAL_FLOAT(val_0362,0.089095);
#define CTNODE_cmu_us_rms_dur_NO_0511 513
DEF_STATIC_CONST_VAL_FLOAT(val_0363,0.509020);
#define CTNODE_cmu_us_rms_dur_NO_0513 515
DEF_STATIC_CONST_VAL_FLOAT(val_0364,0.167479);
#define CTNODE_cmu_us_rms_dur_NO_0500 516
DEF_STATIC_CONST_VAL_FLOAT(val_0365,-0.097171);
#define CTNODE_cmu_us_rms_dur_NO_0516 518
DEF_STATIC_CONST_VAL_FLOAT(val_0366,0.119311);
#define CTNODE_cmu_us_rms_dur_NO_0493 519
DEF_STATIC_CONST_VAL_FLOAT(val_0367,-0.439871);
#define CTNODE_cmu_us_rms_dur_NO_0519 521
DEF_STATIC_CONST_VAL_FLOAT(val_0368,-0.098382);
#define CTNODE_cmu_us_rms_dur_NO_0523 525
DEF_STATIC_CONST_VAL_FLOAT(val_0369,0.583417);
#define CTNODE_cmu_us_rms_dur_NO_0522 526
DEF_STATIC_CONST_VAL_FLOAT(val_0370,5.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0371,0.171874);
#define CTNODE_cmu_us_rms_dur_NO_0526 528
DEF_STATIC_CONST_VAL_FLOAT(val_0372,-0.074586);
#define CTNODE_cmu_us_rms_dur_NO_0528 530
DEF_STATIC_CONST_VAL_FLOAT(val_0373,-0.466981);
#define CTNODE_cmu_us_rms_dur_NO_0530 532
DEF_STATIC_CONST_VAL_FLOAT(val_0374,-0.677711);
#define CTNODE_cmu_us_rms_dur_NO_0521 533
DEF_STATIC_CONST_VAL_FLOAT(val_0375,-0.187348);
#define CTNODE_cmu_us_rms_dur_NO_0534 536
DEF_STATIC_CONST_VAL_FLOAT(val_0376,4.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0377,0.075770);
#define CTNODE_cmu_us_rms_dur_NO_0538 540
DEF_STATIC_CONST_VAL_FLOAT(val_0378,-0.141914);
#define CTNODE_cmu_us_rms_dur_NO_0537 541
DEF_STATIC_CONST_VAL_STRING(val_0379,"ae");
DEF_STATIC_CONST_VAL_FLOAT(val_0380,0.274102);
#define CTNODE_cmu_us_rms_dur_NO_0542 544
DEF_STATIC_CONST_VAL_FLOAT(val_0381,0.135791);
#define CTNODE_cmu_us_rms_dur_NO_0544 546
DEF_STATIC_CONST_VAL_FLOAT(val_0382,-0.293972);
#define CTNODE_cmu_us_rms_dur_NO_0541 547
DEF_STATIC_CONST_VAL_FLOAT(val_0383,-0.085102);
#define CTNODE_cmu_us_rms_dur_NO_0548 550
DEF_STATIC_CONST_VAL_FLOAT(val_0384,-0.122622);
#define CTNODE_cmu_us_rms_dur_NO_0551 553
DEF_STATIC_CONST_VAL_FLOAT(val_0385,0.445712);
#define CTNODE_cmu_us_rms_dur_NO_0553 555
DEF_STATIC_CONST_VAL_FLOAT(val_0386,0.040805);
#define CTNODE_cmu_us_rms_dur_NO_0550 556
DEF_STATIC_CONST_VAL_FLOAT(val_0387,0.669607);
#define CTNODE_cmu_us_rms_dur_NO_0556 558
DEF_STATIC_CONST_VAL_FLOAT(val_0388,0.109555);
#define CTNODE_cmu_us_rms_dur_NO_0547 559
DEF_STATIC_CONST_VAL_FLOAT(val_0389,1.181850);
#define CTNODE_cmu_us_rms_dur_NO_0560 562
DEF_STATIC_CONST_VAL_FLOAT(val_0390,0.569717);
#define CTNODE_cmu_us_rms_dur_NO_0562 564
DEF_STATIC_CONST_VAL_FLOAT(val_0391,0.160441);
#define CTNODE_cmu_us_rms_dur_NO_0559 565
DEF_STATIC_CONST_VAL_FLOAT(val_0392,0.366337);
#define CTNODE_cmu_us_rms_dur_NO_0565 567
DEF_STATIC_CONST_VAL_FLOAT(val_0393,-0.028417);
#define CTNODE_cmu_us_rms_dur_NO_0536 568
DEF_STATIC_CONST_VAL_FLOAT(val_0394,-0.084196);
#define CTNODE_cmu_us_rms_dur_NO_0533 569
DEF_STATIC_CONST_VAL_STRING(val_0395,"aux");
DEF_STATIC_CONST_VAL_FLOAT(val_0396,0.057826);
#define CTNODE_cmu_us_rms_dur_NO_0569 571
DEF_STATIC_CONST_VAL_FLOAT(val_0397,5.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0398,1.043510);
#define CTNODE_cmu_us_rms_dur_NO_0571 573
DEF_STATIC_CONST_VAL_FLOAT(val_0399,0.363103);
#define CTNODE_cmu_us_rms_dur_NO_0246 574
DEF_STATIC_CONST_VAL_FLOAT(val_0400,-0.559966);
#define CTNODE_cmu_us_rms_dur_NO_0577 579
DEF_STATIC_CONST_VAL_FLOAT(val_0401,-0.576104);
#define CTNODE_cmu_us_rms_dur_NO_0576 580
DEF_STATIC_CONST_VAL_FLOAT(val_0402,-0.476432);
#define CTNODE_cmu_us_rms_dur_NO_0575 581
DEF_STATIC_CONST_VAL_FLOAT(val_0403,-0.543096);
#define CTNODE_cmu_us_rms_dur_NO_0582 584
#define CTNODE_cmu_us_rms_dur_NO_0584 586
#define CTNODE_cmu_us_rms_dur_NO_0586 588
DEF_STATIC_CONST_VAL_FLOAT(val_0404,-0.563136);
#define CTNODE_cmu_us_rms_dur_NO_0589 591
DEF_STATIC_CONST_VAL_FLOAT(val_0405,-0.553691);
#define CTNODE_cmu_us_rms_dur_NO_0591 593
DEF_STATIC_CONST_VAL_FLOAT(val_0406,-0.567459);
#define CTNODE_cmu_us_rms_dur_NO_0588 594
DEF_STATIC_CONST_VAL_FLOAT(val_0407,-0.565730);
#define CTNODE_cmu_us_rms_dur_NO_0581 595
#define CTNODE_cmu_us_rms_dur_NO_0574 596
DEF_STATIC_CONST_VAL_FLOAT(val_0408,1.235110);
#define CTNODE_cmu_us_rms_dur_NO_0600 602
DEF_STATIC_CONST_VAL_FLOAT(val_0409,0.439014);
#define CTNODE_cmu_us_rms_dur_NO_0602 604
DEF_STATIC_CONST_VAL_FLOAT(val_0410,0.986000);
#define CTNODE_cmu_us_rms_dur_NO_0599 605
DEF_STATIC_CONST_VAL_FLOAT(val_0411,0.090561);
#define CTNODE_cmu_us_rms_dur_NO_0598 606
DEF_STATIC_CONST_VAL_FLOAT(val_0412,0.380991);
#define CTNODE_cmu_us_rms_dur_NO_0608 610
DEF_STATIC_CONST_VAL_FLOAT(val_0413,-0.520095);
#define CTNODE_cmu_us_rms_dur_NO_0610 612
DEF_STATIC_CONST_VAL_STRING(val_0414,"ax_28");
DEF_STATIC_CONST_VAL_FLOAT(val_0415,-0.377653);
#define CTNODE_cmu_us_rms_dur_NO_0613 615
DEF_STATIC_CONST_VAL_FLOAT(val_0416,-0.093768);
#define CTNODE_cmu_us_rms_dur_NO_0615 617
DEF_STATIC_CONST_VAL_FLOAT(val_0417,0.639192);
#define CTNODE_cmu_us_rms_dur_NO_0617 619
DEF_STATIC_CONST_VAL_FLOAT(val_0418,0.299035);
#define CTNODE_cmu_us_rms_dur_NO_0612 620
DEF_STATIC_CONST_VAL_FLOAT(val_0419,0.270910);
#define CTNODE_cmu_us_rms_dur_NO_0621 623
DEF_STATIC_CONST_VAL_FLOAT(val_0420,0.040891);
#define CTNODE_cmu_us_rms_dur_NO_0620 624
DEF_STATIC_CONST_VAL_FLOAT(val_0421,0.200000);
DEF_STATIC_CONST_VAL_STRING(val_0422,"initial");
DEF_STATIC_CONST_VAL_FLOAT(val_0423,-0.373419);
#define CTNODE_cmu_us_rms_dur_NO_0626 628
DEF_STATIC_CONST_VAL_FLOAT(val_0424,0.163236);
#define CTNODE_cmu_us_rms_dur_NO_0625 629
DEF_STATIC_CONST_VAL_FLOAT(val_0425,-0.408794);
#define CTNODE_cmu_us_rms_dur_NO_0630 632
DEF_STATIC_CONST_VAL_FLOAT(val_0426,-0.514458);
#define CTNODE_cmu_us_rms_dur_NO_0629 633
DEF_STATIC_CONST_VAL_FLOAT(val_0427,-0.293502);
#define CTNODE_cmu_us_rms_dur_NO_0624 634
DEF_STATIC_CONST_VAL_FLOAT(val_0428,-0.430984);
#define CTNODE_cmu_us_rms_dur_NO_0634 636
DEF_STATIC_CONST_VAL_FLOAT(val_0429,8.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0430,-0.445449);
#define CTNODE_cmu_us_rms_dur_NO_0637 639
DEF_STATIC_CONST_VAL_FLOAT(val_0431,-0.189046);
#define CTNODE_cmu_us_rms_dur_NO_0636 640
DEF_STATIC_CONST_VAL_FLOAT(val_0432,-0.275839);
#define CTNODE_cmu_us_rms_dur_NO_0641 643
DEF_STATIC_CONST_VAL_FLOAT(val_0433,0.427499);
#define CTNODE_cmu_us_rms_dur_NO_0643 645
DEF_STATIC_CONST_VAL_FLOAT(val_0434,0.100085);
#define CTNODE_cmu_us_rms_dur_NO_0640 646
DEF_STATIC_CONST_VAL_FLOAT(val_0435,0.140340);
#define CTNODE_cmu_us_rms_dur_NO_0647 649
DEF_STATIC_CONST_VAL_FLOAT(val_0436,-0.104723);
#define CTNODE_cmu_us_rms_dur_NO_0649 651
DEF_STATIC_CONST_VAL_FLOAT(val_0437,-0.201257);
#define CTNODE_cmu_us_rms_dur_NO_0653 655
DEF_STATIC_CONST_VAL_FLOAT(val_0438,-0.464136);
#define CTNODE_cmu_us_rms_dur_NO_0652 656
DEF_STATIC_CONST_VAL_FLOAT(val_0439,-0.119502);
#define CTNODE_cmu_us_rms_dur_NO_0651 657
DEF_STATIC_CONST_VAL_FLOAT(val_0440,-0.608244);
#define CTNODE_cmu_us_rms_dur_NO_0657 659
DEF_STATIC_CONST_VAL_FLOAT(val_0441,-0.332783);
#define CTNODE_cmu_us_rms_dur_NO_0646 660
DEF_STATIC_CONST_VAL_FLOAT(val_0442,-0.314097);
#define CTNODE_cmu_us_rms_dur_NO_0660 662
DEF_STATIC_CONST_VAL_FLOAT(val_0443,1.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0444,-0.328534);
#define CTNODE_cmu_us_rms_dur_NO_0663 665
DEF_STATIC_CONST_VAL_FLOAT(val_0445,0.208703);
#define CTNODE_cmu_us_rms_dur_NO_0666 668
DEF_STATIC_CONST_VAL_FLOAT(val_0446,-0.047727);
#define CTNODE_cmu_us_rms_dur_NO_0665 669
DEF_STATIC_CONST_VAL_FLOAT(val_0447,-0.196463);
#define CTNODE_cmu_us_rms_dur_NO_0662 670
DEF_STATIC_CONST_VAL_FLOAT(val_0448,0.319807);
#define CTNODE_cmu_us_rms_dur_NO_0670 672
DEF_STATIC_CONST_VAL_FLOAT(val_0449,-0.187254);
#define CTNODE_cmu_us_rms_dur_NO_0672 674
DEF_STATIC_CONST_VAL_FLOAT(val_0450,0.176567);
#define CTNODE_cmu_us_rms_dur_NO_0607 675
DEF_STATIC_CONST_VAL_FLOAT(val_0451,0.223271);
#define CTNODE_cmu_us_rms_dur_NO_0677 679
DEF_STATIC_CONST_VAL_FLOAT(val_0452,-0.056050);
#define CTNODE_cmu_us_rms_dur_NO_0680 682
DEF_STATIC_CONST_VAL_FLOAT(val_0453,-0.315445);
#define CTNODE_cmu_us_rms_dur_NO_0679 683
DEF_STATIC_CONST_VAL_FLOAT(val_0454,-0.605187);
#define CTNODE_cmu_us_rms_dur_NO_0683 685
DEF_STATIC_CONST_VAL_FLOAT(val_0455,-0.301440);
#define CTNODE_cmu_us_rms_dur_NO_0676 686
DEF_STATIC_CONST_VAL_FLOAT(val_0456,0.661787);
#define CTNODE_cmu_us_rms_dur_NO_0687 689
DEF_STATIC_CONST_VAL_STRING(val_0457,"m_112");
DEF_STATIC_CONST_VAL_FLOAT(val_0458,0.668548);
#define CTNODE_cmu_us_rms_dur_NO_0689 691
DEF_STATIC_CONST_VAL_STRING(val_0459,"ao");
DEF_STATIC_CONST_VAL_FLOAT(val_0460,-0.319836);
#define CTNODE_cmu_us_rms_dur_NO_0691 693
DEF_STATIC_CONST_VAL_FLOAT(val_0461,0.209583);
#define CTNODE_cmu_us_rms_dur_NO_0696 698
DEF_STATIC_CONST_VAL_FLOAT(val_0462,0.587245);
#define CTNODE_cmu_us_rms_dur_NO_0695 699
DEF_STATIC_CONST_VAL_FLOAT(val_0463,2.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0464,0.395502);
#define CTNODE_cmu_us_rms_dur_NO_0701 703
DEF_STATIC_CONST_VAL_FLOAT(val_0465,0.176480);
#define CTNODE_cmu_us_rms_dur_NO_0700 704
DEF_STATIC_CONST_VAL_FLOAT(val_0466,-0.093590);
#define CTNODE_cmu_us_rms_dur_NO_0704 706
DEF_STATIC_CONST_VAL_FLOAT(val_0467,0.218732);
#define CTNODE_cmu_us_rms_dur_NO_0699 707
DEF_STATIC_CONST_VAL_FLOAT(val_0468,-0.065635);
#define CTNODE_cmu_us_rms_dur_NO_0708 710
DEF_STATIC_CONST_VAL_FLOAT(val_0469,0.145012);
#define CTNODE_cmu_us_rms_dur_NO_0707 711
DEF_STATIC_CONST_VAL_FLOAT(val_0470,9.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0471,-0.256342);
#define CTNODE_cmu_us_rms_dur_NO_0711 713
DEF_STATIC_CONST_VAL_FLOAT(val_0472,-0.114391);
#define CTNODE_cmu_us_rms_dur_NO_0713 715
DEF_STATIC_CONST_VAL_FLOAT(val_0473,0.042018);
#define CTNODE_cmu_us_rms_dur_NO_0694 716
DEF_STATIC_CONST_VAL_FLOAT(val_0474,0.628683);
#define CTNODE_cmu_us_rms_dur_NO_0716 718
DEF_STATIC_CONST_VAL_FLOAT(val_0475,0.233692);
#define CTNODE_cmu_us_rms_dur_NO_0693 719
DEF_STATIC_CONST_VAL_FLOAT(val_0476,0.017692);
#define CTNODE_cmu_us_rms_dur_NO_0721 723
DEF_STATIC_CONST_VAL_FLOAT(val_0477,-0.282204);
#define CTNODE_cmu_us_rms_dur_NO_0720 724
DEF_STATIC_CONST_VAL_FLOAT(val_0478,0.246877);
#define CTNODE_cmu_us_rms_dur_NO_0724 726
DEF_STATIC_CONST_VAL_FLOAT(val_0479,-0.077731);
#define CTNODE_cmu_us_rms_dur_NO_0719 727
DEF_STATIC_CONST_VAL_FLOAT(val_0480,-0.253561);
#define CTNODE_cmu_us_rms_dur_NO_0686 728
DEF_STATIC_CONST_VAL_FLOAT(val_0481,-0.145110);
#define CTNODE_cmu_us_rms_dur_NO_0729 731
DEF_STATIC_CONST_VAL_FLOAT(val_0482,0.882674);
#define CTNODE_cmu_us_rms_dur_NO_0732 734
DEF_STATIC_CONST_VAL_FLOAT(val_0483,0.425017);
#define CTNODE_cmu_us_rms_dur_NO_0731 735
DEF_STATIC_CONST_VAL_FLOAT(val_0484,1.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0485,0.354155);
#define CTNODE_cmu_us_rms_dur_NO_0735 737
DEF_STATIC_CONST_VAL_FLOAT(val_0486,0.225448);
#define CTNODE_cmu_us_rms_dur_NO_0737 739
DEF_STATIC_CONST_VAL_FLOAT(val_0487,-0.079206);
#define CTNODE_cmu_us_rms_dur_NO_0728 740
DEF_STATIC_CONST_VAL_FLOAT(val_0488,0.931676);
#define CTNODE_cmu_us_rms_dur_NO_0740 742
DEF_STATIC_CONST_VAL_FLOAT(val_0489,7.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_0490,0.452572);
#define CTNODE_cmu_us_rms_dur_NO_0743 745
DEF_STATIC_CONST_VAL_FLOAT(val_0491,0.930494);
#define CTNODE_cmu_us_rms_dur_NO_0742 746
DEF_STATIC_CONST_VAL_FLOAT(val_0492,0.258672);
#define CTNODE_cmu_us_rms_dur_NO_0675 747
DEF_STATIC_CONST_VAL_FLOAT(val_0493,0.735001);
#define CTNODE_cmu_us_rms_dur_NO_0747 749
DEF_STATIC_CONST_VAL_FLOAT(val_0494,0.554528);
#define CTNODE_cmu_us_rms_dur_NO_0749 751
DEF_STATIC_CONST_VAL_STRING(val_0495,"ey_68");
DEF_STATIC_CONST_VAL_FLOAT(val_0496,0.512546);
#define CTNODE_cmu_us_rms_dur_NO_0751 753
DEF_STATIC_CONST_VAL_FLOAT(val_0497,-0.339399);
#define CTNODE_cmu_us_rms_dur_NO_0754 756
DEF_STATIC_CONST_VAL_FLOAT(val_0498,-0.674106);
#define CTNODE_cmu_us_rms_dur_NO_0753 757
DEF_STATIC_CONST_VAL_FLOAT(val_0499,0.638103);
#define CTNODE_cmu_us_rms_dur_NO_0757 759
DEF_STATIC_CONST_VAL_FLOAT(val_0500,0.558124);
#define CTNODE_cmu_us_rms_dur_NO_0760 762
DEF_STATIC_CONST_VAL_FLOAT(val_0501,0.019760);
#define CTNODE_cmu_us_rms_dur_NO_0762 764
DEF_STATIC_CONST_VAL_FLOAT(val_0502,0.301742);
#define CTNODE_cmu_us_rms_dur_NO_0759 765
DEF_STATIC_CONST_VAL_FLOAT(val_0503,-0.252154);
#define CTNODE_cmu_us_rms_dur_NO_0766 768
DEF_STATIC_CONST_VAL_FLOAT(val_0504,-0.499658);
#define CTNODE_cmu_us_rms_dur_NO_0765 769
DEF_STATIC_CONST_VAL_STRING(val_0505,"eh_58");
DEF_STATIC_CONST_VAL_FLOAT(val_0506,-0.418207);
#define CTNODE_cmu_us_rms_dur_NO_0770 772
DEF_STATIC_CONST_VAL_FLOAT(val_0507,0.226559);
#define CTNODE_cmu_us_rms_dur_NO_0774 776
DEF_STATIC_CONST_VAL_FLOAT(val_0508,-0.211345);
#define CTNODE_cmu_us_rms_dur_NO_0773 777
DEF_STATIC_CONST_VAL_FLOAT(val_0509,-0.491067);
#define CTNODE_cmu_us_rms_dur_NO_0777 779
DEF_STATIC_CONST_VAL_FLOAT(val_0510,-0.213020);
#define CTNODE_cmu_us_rms_dur_NO_0772 780
DEF_STATIC_CONST_VAL_STRING(val_0511,"ey_66");
DEF_STATIC_CONST_VAL_FLOAT(val_0512,-0.451451);
#define CTNODE_cmu_us_rms_dur_NO_0780 782
DEF_STATIC_CONST_VAL_STRING(val_0513,"g");
DEF_STATIC_CONST_VAL_FLOAT(val_0514,0.612599);
#define CTNODE_cmu_us_rms_dur_NO_0782 784
DEF_STATIC_CONST_VAL_STRING(val_0515,"n_116");
DEF_STATIC_CONST_VAL_FLOAT(val_0516,-0.320504);
#define CTNODE_cmu_us_rms_dur_NO_0785 787
DEF_STATIC_CONST_VAL_FLOAT(val_0517,0.747738);
#define CTNODE_cmu_us_rms_dur_NO_0788 790
DEF_STATIC_CONST_VAL_FLOAT(val_0518,0.462220);
#define CTNODE_cmu_us_rms_dur_NO_0787 791
DEF_STATIC_CONST_VAL_FLOAT(val_0519,-0.170373);
#define CTNODE_cmu_us_rms_dur_NO_0791 793
DEF_STATIC_CONST_VAL_FLOAT(val_0520,0.058174);
#define CTNODE_cmu_us_rms_dur_NO_0794 796
DEF_STATIC_CONST_VAL_FLOAT(val_0521,0.563529);
#define CTNODE_cmu_us_rms_dur_NO_0793 797
DEF_STATIC_CONST_VAL_FLOAT(val_0522,0.411222);
#define CTNODE_cmu_us_rms_dur_NO_0798 800
DEF_STATIC_CONST_VAL_FLOAT(val_0523,0.092043);
#define CTNODE_cmu_us_rms_dur_NO_0797 801
DEF_STATIC_CONST_VAL_FLOAT(val_0524,-0.172351);
#define CTNODE_cmu_us_rms_dur_NO_0784 802
DEF_STATIC_CONST_VAL_FLOAT(val_0525,-0.539852);
#define CTNODE_cmu_us_rms_dur_NO_0803 805
DEF_STATIC_CONST_VAL_FLOAT(val_0526,0.034416);
#define CTNODE_cmu_us_rms_dur_NO_0802 806
DEF_STATIC_CONST_VAL_FLOAT(val_0527,0.239679);
#define CTNODE_cmu_us_rms_dur_NO_0807 809
DEF_STATIC_CONST_VAL_FLOAT(val_0528,-0.009395);
#define CTNODE_cmu_us_rms_dur_NO_0806 810
DEF_STATIC_CONST_VAL_FLOAT(val_0529,-0.178348);
#define CTNODE_cmu_us_rms_dur_NO_0769 811
DEF_STATIC_CONST_VAL_STRING(val_0530,"er_63");
DEF_STATIC_CONST_VAL_FLOAT(val_0531,-0.558815);
#define CTNODE_cmu_us_rms_dur_NO_0812 814
DEF_STATIC_CONST_VAL_FLOAT(val_0532,-0.453880);
#define CTNODE_cmu_us_rms_dur_NO_0815 817
DEF_STATIC_CONST_VAL_FLOAT(val_0533,-0.011145);
#define CTNODE_cmu_us_rms_dur_NO_0818 820
DEF_STATIC_CONST_VAL_FLOAT(val_0534,0.327123);
#define CTNODE_cmu_us_rms_dur_NO_0817 821
DEF_STATIC_CONST_VAL_FLOAT(val_0535,0.017524);
#define CTNODE_cmu_us_rms_dur_NO_0821 823
DEF_STATIC_CONST_VAL_FLOAT(val_0536,-0.154979);
#define CTNODE_cmu_us_rms_dur_NO_0823 825
DEF_STATIC_CONST_VAL_FLOAT(val_0537,-0.434521);
#define CTNODE_cmu_us_rms_dur_NO_0814 826
DEF_STATIC_CONST_VAL_FLOAT(val_0538,-0.328840);
#define CTNODE_cmu_us_rms_dur_NO_0826 828
DEF_STATIC_CONST_VAL_FLOAT(val_0539,-0.150741);
#define CTNODE_cmu_us_rms_dur_NO_0828 830
DEF_STATIC_CONST_VAL_FLOAT(val_0540,5.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0541,-0.062014);
#define CTNODE_cmu_us_rms_dur_NO_0831 833
DEF_STATIC_CONST_VAL_FLOAT(val_0542,0.477425);
#define CTNODE_cmu_us_rms_dur_NO_0833 835
DEF_STATIC_CONST_VAL_FLOAT(val_0543,-0.123627);
#define CTNODE_cmu_us_rms_dur_NO_0835 837
DEF_STATIC_CONST_VAL_FLOAT(val_0544,0.368475);
#define CTNODE_cmu_us_rms_dur_NO_0830 838
DEF_STATIC_CONST_VAL_FLOAT(val_0545,0.645845);
#define CTNODE_cmu_us_rms_dur_NO_0811 839
DEF_STATIC_CONST_VAL_FLOAT(val_0546,0.220057);
#define CTNODE_cmu_us_rms_dur_NO_0839 841
DEF_STATIC_CONST_VAL_STRING(val_0547,"eh");
DEF_STATIC_CONST_VAL_FLOAT(val_0548,3.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_0549,0.108764);
#define CTNODE_cmu_us_rms_dur_NO_0842 844
DEF_STATIC_CONST_VAL_FLOAT(val_0550,-0.034318);
#define CTNODE_cmu_us_rms_dur_NO_0841 845
DEF_STATIC_CONST_VAL_FLOAT(val_0551,-0.146559);
#define CTNODE_cmu_us_rms_dur_NO_0846 848
DEF_STATIC_CONST_VAL_FLOAT(val_0552,0.095152);
#define CTNODE_cmu_us_rms_dur_NO_0845 849
DEF_STATIC_CONST_VAL_FLOAT(val_0553,-0.526398);
#define CTNODE_cmu_us_rms_dur_NO_0850 852
DEF_STATIC_CONST_VAL_FLOAT(val_0554,-0.401457);
#define CTNODE_cmu_us_rms_dur_NO_0854 856
DEF_STATIC_CONST_VAL_FLOAT(val_0555,-0.055850);
#define CTNODE_cmu_us_rms_dur_NO_0856 858
DEF_STATIC_CONST_VAL_FLOAT(val_0556,-0.318918);
#define CTNODE_cmu_us_rms_dur_NO_0853 859
DEF_STATIC_CONST_VAL_FLOAT(val_0557,-0.264654);
#define CTNODE_cmu_us_rms_dur_NO_0859 861
DEF_STATIC_CONST_VAL_FLOAT(val_0558,-0.581687);
#define CTNODE_cmu_us_rms_dur_NO_0852 862
DEF_STATIC_CONST_VAL_FLOAT(val_0559,-0.234009);
#define CTNODE_cmu_us_rms_dur_NO_0862 864
DEF_STATIC_CONST_VAL_FLOAT(val_0560,0.084350);
#define CTNODE_cmu_us_rms_dur_NO_0849 865
DEF_STATIC_CONST_VAL_FLOAT(val_0561,-0.355035);
#define CTNODE_cmu_us_rms_dur_NO_0865 867
DEF_STATIC_CONST_VAL_FLOAT(val_0562,-0.555527);
#define CTNODE_cmu_us_rms_dur_NO_0606 868
DEF_STATIC_CONST_VAL_FLOAT(val_0563,1.254940);
#define CTNODE_cmu_us_rms_dur_NO_0869 871
DEF_STATIC_CONST_VAL_FLOAT(val_0564,0.984931);
#define CTNODE_cmu_us_rms_dur_NO_0871 873
DEF_STATIC_CONST_VAL_FLOAT(val_0565,-0.510497);
#define CTNODE_cmu_us_rms_dur_NO_0873 875
DEF_STATIC_CONST_VAL_FLOAT(val_0566,0.249240);
#define CTNODE_cmu_us_rms_dur_NO_0875 877
DEF_STATIC_CONST_VAL_FLOAT(val_0567,-0.302299);
#define CTNODE_cmu_us_rms_dur_NO_0877 879
DEF_STATIC_CONST_VAL_STRING(val_0568,"b_38");
DEF_STATIC_CONST_VAL_FLOAT(val_0569,-0.300833);
#define CTNODE_cmu_us_rms_dur_NO_0879 881
DEF_STATIC_CONST_VAL_FLOAT(val_0570,-0.237496);
#define CTNODE_cmu_us_rms_dur_NO_0881 883
DEF_STATIC_CONST_VAL_FLOAT(val_0571,6.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0572,-0.055974);
#define CTNODE_cmu_us_rms_dur_NO_0883 885
DEF_STATIC_CONST_VAL_FLOAT(val_0573,0.273395);
#define CTNODE_cmu_us_rms_dur_NO_0868 886
DEF_STATIC_CONST_VAL_STRING(val_0574,"hh_83");
DEF_STATIC_CONST_VAL_FLOAT(val_0575,0.498936);
#define CTNODE_cmu_us_rms_dur_NO_0886 888
DEF_STATIC_CONST_VAL_STRING(val_0576,"ih_87");
DEF_STATIC_CONST_VAL_FLOAT(val_0577,0.472601);
#define CTNODE_cmu_us_rms_dur_NO_0889 891
DEF_STATIC_CONST_VAL_FLOAT(val_0578,1.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0579,7.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0580,0.093072);
#define CTNODE_cmu_us_rms_dur_NO_0893 895
DEF_STATIC_CONST_VAL_FLOAT(val_0581,-0.277603);
#define CTNODE_cmu_us_rms_dur_NO_0892 896
DEF_STATIC_CONST_VAL_FLOAT(val_0582,-0.313055);
#define CTNODE_cmu_us_rms_dur_NO_0897 899
DEF_STATIC_CONST_VAL_FLOAT(val_0583,-0.537872);
#define CTNODE_cmu_us_rms_dur_NO_0896 900
DEF_STATIC_CONST_VAL_FLOAT(val_0584,-0.423817);
#define CTNODE_cmu_us_rms_dur_NO_0900 902
DEF_STATIC_CONST_VAL_FLOAT(val_0585,-0.064045);
#define CTNODE_cmu_us_rms_dur_NO_0903 905
DEF_STATIC_CONST_VAL_FLOAT(val_0586,-0.250813);
#define CTNODE_cmu_us_rms_dur_NO_0902 906
DEF_STATIC_CONST_VAL_FLOAT(val_0587,-0.239545);
#define CTNODE_cmu_us_rms_dur_NO_0906 908
DEF_STATIC_CONST_VAL_FLOAT(val_0588,-0.396295);
#define CTNODE_cmu_us_rms_dur_NO_0891 909
DEF_STATIC_CONST_VAL_FLOAT(val_0589,0.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0590,0.026706);
#define CTNODE_cmu_us_rms_dur_NO_0910 912
DEF_STATIC_CONST_VAL_FLOAT(val_0591,0.515420);
#define CTNODE_cmu_us_rms_dur_NO_0909 913
DEF_STATIC_CONST_VAL_FLOAT(val_0592,-0.044298);
#define CTNODE_cmu_us_rms_dur_NO_0914 916
DEF_STATIC_CONST_VAL_FLOAT(val_0593,0.355681);
#define CTNODE_cmu_us_rms_dur_NO_0913 917
DEF_STATIC_CONST_VAL_FLOAT(val_0594,0.133699);
#define CTNODE_cmu_us_rms_dur_NO_0917 919
DEF_STATIC_CONST_VAL_FLOAT(val_0595,0.302173);
#define CTNODE_cmu_us_rms_dur_NO_0920 922
DEF_STATIC_CONST_VAL_FLOAT(val_0596,-0.148804);
#define CTNODE_cmu_us_rms_dur_NO_0919 923
DEF_STATIC_CONST_VAL_STRING(val_0597,"th");
DEF_STATIC_CONST_VAL_FLOAT(val_0598,-0.469023);
#define CTNODE_cmu_us_rms_dur_NO_0923 925
DEF_STATIC_CONST_VAL_FLOAT(val_0599,7.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0600,-0.434157);
#define CTNODE_cmu_us_rms_dur_NO_0926 928
DEF_STATIC_CONST_VAL_FLOAT(val_0601,-0.163220);
#define CTNODE_cmu_us_rms_dur_NO_0925 929
DEF_STATIC_CONST_VAL_FLOAT(val_0602,-0.338445);
#define CTNODE_cmu_us_rms_dur_NO_0930 932
DEF_STATIC_CONST_VAL_FLOAT(val_0603,-0.204866);
#define CTNODE_cmu_us_rms_dur_NO_0934 936
DEF_STATIC_CONST_VAL_FLOAT(val_0604,0.012846);
#define CTNODE_cmu_us_rms_dur_NO_0933 937
DEF_STATIC_CONST_VAL_FLOAT(val_0605,-0.075243);
#define CTNODE_cmu_us_rms_dur_NO_0937 939
DEF_STATIC_CONST_VAL_FLOAT(val_0606,-0.475952);
#define CTNODE_cmu_us_rms_dur_NO_0939 941
DEF_STATIC_CONST_VAL_FLOAT(val_0607,-0.284755);
#define CTNODE_cmu_us_rms_dur_NO_0932 942
DEF_STATIC_CONST_VAL_FLOAT(val_0608,0.331605);
#define CTNODE_cmu_us_rms_dur_NO_0929 943
DEF_STATIC_CONST_VAL_FLOAT(val_0609,0.139994);
#define CTNODE_cmu_us_rms_dur_NO_0888 944
DEF_STATIC_CONST_VAL_FLOAT(val_0610,-0.218494);
#define CTNODE_cmu_us_rms_dur_NO_0945 947
DEF_STATIC_CONST_VAL_FLOAT(val_0611,-0.426453);
#define CTNODE_cmu_us_rms_dur_NO_0947 949
DEF_STATIC_CONST_VAL_FLOAT(val_0612,-0.844093);
#define CTNODE_cmu_us_rms_dur_NO_0949 951
DEF_STATIC_CONST_VAL_FLOAT(val_0613,-0.626273);
#define CTNODE_cmu_us_rms_dur_NO_0944 952
DEF_STATIC_CONST_VAL_FLOAT(val_0614,-0.139621);
#define CTNODE_cmu_us_rms_dur_NO_0954 956
DEF_STATIC_CONST_VAL_FLOAT(val_0615,0.135325);
#define CTNODE_cmu_us_rms_dur_NO_0953 957
DEF_STATIC_CONST_VAL_FLOAT(val_0616,0.291445);
#define CTNODE_cmu_us_rms_dur_NO_0952 958
DEF_STATIC_CONST_VAL_FLOAT(val_0617,0.264196);
#define CTNODE_cmu_us_rms_dur_NO_0961 963
DEF_STATIC_CONST_VAL_FLOAT(val_0618,-0.131808);
#define CTNODE_cmu_us_rms_dur_NO_0960 964
DEF_STATIC_CONST_VAL_FLOAT(val_0619,-0.164547);
#define CTNODE_cmu_us_rms_dur_NO_0964 966
DEF_STATIC_CONST_VAL_FLOAT(val_0620,-0.379714);
#define CTNODE_cmu_us_rms_dur_NO_0959 967
DEF_STATIC_CONST_VAL_STRING(val_0621,"d_46");
DEF_STATIC_CONST_VAL_FLOAT(val_0622,-0.116993);
#define CTNODE_cmu_us_rms_dur_NO_0967 969
DEF_STATIC_CONST_VAL_FLOAT(val_0623,-0.223158);
#define CTNODE_cmu_us_rms_dur_NO_0970 972
DEF_STATIC_CONST_VAL_FLOAT(val_0624,-0.394199);
#define CTNODE_cmu_us_rms_dur_NO_0973 975
DEF_STATIC_CONST_VAL_FLOAT(val_0625,-0.299456);
#define CTNODE_cmu_us_rms_dur_NO_0972 976
DEF_STATIC_CONST_VAL_FLOAT(val_0626,-0.498049);
#define CTNODE_cmu_us_rms_dur_NO_0976 978
DEF_STATIC_CONST_VAL_FLOAT(val_0627,-0.651480);
#define CTNODE_cmu_us_rms_dur_NO_0969 979
DEF_STATIC_CONST_VAL_FLOAT(val_0628,-0.063838);
#define CTNODE_cmu_us_rms_dur_NO_0979 981
DEF_STATIC_CONST_VAL_FLOAT(val_0629,-0.558912);
#define CTNODE_cmu_us_rms_dur_NO_0981 983
DEF_STATIC_CONST_VAL_FLOAT(val_0630,-0.083159);
#define CTNODE_cmu_us_rms_dur_NO_0958 984
DEF_STATIC_CONST_VAL_STRING(val_0631,"dh_51");
DEF_STATIC_CONST_VAL_FLOAT(val_0632,-0.733144);
#define CTNODE_cmu_us_rms_dur_NO_0984 986
DEF_STATIC_CONST_VAL_FLOAT(val_0633,-0.656910);
#define CTNODE_cmu_us_rms_dur_NO_0986 988
DEF_STATIC_CONST_VAL_FLOAT(val_0634,-0.579019);
#define CTNODE_cmu_us_rms_dur_NO_0988 990
DEF_STATIC_CONST_VAL_FLOAT(val_0635,-0.419596);
#define CTNODE_cmu_us_rms_dur_NO_0990 992
DEF_STATIC_CONST_VAL_FLOAT(val_0636,-0.076468);
#define CTNODE_cmu_us_rms_dur_NO_0992 994
DEF_STATIC_CONST_VAL_FLOAT(val_0637,-0.307213);
#define CTNODE_cmu_us_rms_dur_NO_0597 995
DEF_STATIC_CONST_VAL_STRING(val_0638,"v_184");
DEF_STATIC_CONST_VAL_FLOAT(val_0639,1.237510);
#define CTNODE_cmu_us_rms_dur_NO_0996 998
DEF_STATIC_CONST_VAL_FLOAT(val_0640,0.234022);
#define CTNODE_cmu_us_rms_dur_NO_0995 999
DEF_STATIC_CONST_VAL_STRING(val_0641,"z_199");
DEF_STATIC_CONST_VAL_FLOAT(val_0642,0.710101);
#define CTNODE_cmu_us_rms_dur_NO_1001 1003
DEF_STATIC_CONST_VAL_FLOAT(val_0643,0.400896);
#define CTNODE_cmu_us_rms_dur_NO_1003 1005
DEF_STATIC_CONST_VAL_FLOAT(val_0644,0.250691);
#define CTNODE_cmu_us_rms_dur_NO_1005 1007
DEF_STATIC_CONST_VAL_FLOAT(val_0645,-0.031907);
#define CTNODE_cmu_us_rms_dur_NO_1000 1008
DEF_STATIC_CONST_VAL_FLOAT(val_0646,-0.391286);
#define CTNODE_cmu_us_rms_dur_NO_1009 1011
DEF_STATIC_CONST_VAL_FLOAT(val_0647,-0.024268);
#define CTNODE_cmu_us_rms_dur_NO_1008 1012
DEF_STATIC_CONST_VAL_FLOAT(val_0648,0.251394);
#define CTNODE_cmu_us_rms_dur_NO_1012 1014
DEF_STATIC_CONST_VAL_FLOAT(val_0649,0.420532);
#define CTNODE_cmu_us_rms_dur_NO_0999 1015
DEF_STATIC_CONST_VAL_STRING(val_0650,"aa_2");
DEF_STATIC_CONST_VAL_FLOAT(val_0651,-0.808224);
#define CTNODE_cmu_us_rms_dur_NO_1017 1019
DEF_STATIC_CONST_VAL_FLOAT(val_0652,-0.709576);
#define CTNODE_cmu_us_rms_dur_NO_1020 1022
DEF_STATIC_CONST_VAL_FLOAT(val_0653,-0.655479);
#define CTNODE_cmu_us_rms_dur_NO_1022 1024
DEF_STATIC_CONST_VAL_FLOAT(val_0654,-0.520172);
#define CTNODE_cmu_us_rms_dur_NO_1019 1025
DEF_STATIC_CONST_VAL_FLOAT(val_0655,-0.762737);
#define CTNODE_cmu_us_rms_dur_NO_1016 1026
DEF_STATIC_CONST_VAL_FLOAT(val_0656,0.273123);
#define CTNODE_cmu_us_rms_dur_NO_1026 1028
DEF_STATIC_CONST_VAL_FLOAT(val_0657,-0.110031);
#define CTNODE_cmu_us_rms_dur_NO_1030 1032
DEF_STATIC_CONST_VAL_FLOAT(val_0658,0.073835);
#define CTNODE_cmu_us_rms_dur_NO_1032 1034
DEF_STATIC_CONST_VAL_FLOAT(val_0659,0.298925);
#define CTNODE_cmu_us_rms_dur_NO_1029 1035
DEF_STATIC_CONST_VAL_FLOAT(val_0660,0.171043);
#define CTNODE_cmu_us_rms_dur_NO_1035 1037
DEF_STATIC_CONST_VAL_FLOAT(val_0661,-0.813507);
#define CTNODE_cmu_us_rms_dur_NO_1037 1039
DEF_STATIC_CONST_VAL_FLOAT(val_0662,-0.529101);
#define CTNODE_cmu_us_rms_dur_NO_1040 1042
DEF_STATIC_CONST_VAL_FLOAT(val_0663,-0.739163);
#define CTNODE_cmu_us_rms_dur_NO_1039 1043
DEF_STATIC_CONST_VAL_FLOAT(val_0664,-0.260501);
#define CTNODE_cmu_us_rms_dur_NO_1044 1046
DEF_STATIC_CONST_VAL_FLOAT(val_0665,0.172614);
#define CTNODE_cmu_us_rms_dur_NO_1043 1047
DEF_STATIC_CONST_VAL_STRING(val_0666,"dh");
DEF_STATIC_CONST_VAL_FLOAT(val_0667,-0.396884);
#define CTNODE_cmu_us_rms_dur_NO_1048 1050
DEF_STATIC_CONST_VAL_FLOAT(val_0668,-0.493307);
#define CTNODE_cmu_us_rms_dur_NO_1050 1052
DEF_STATIC_CONST_VAL_FLOAT(val_0669,-0.570313);
#define CTNODE_cmu_us_rms_dur_NO_1047 1053
DEF_STATIC_CONST_VAL_STRING(val_0670,"er");
DEF_STATIC_CONST_VAL_FLOAT(val_0671,-0.545542);
#define CTNODE_cmu_us_rms_dur_NO_1053 1055
DEF_STATIC_CONST_VAL_STRING(val_0672,"wp");
DEF_STATIC_CONST_VAL_FLOAT(val_0673,-0.431061);
#define CTNODE_cmu_us_rms_dur_NO_1056 1058
DEF_STATIC_CONST_VAL_FLOAT(val_0674,-0.510666);
#define CTNODE_cmu_us_rms_dur_NO_1055 1059
DEF_STATIC_CONST_VAL_FLOAT(val_0675,-0.515352);
#define CTNODE_cmu_us_rms_dur_NO_1059 1061
DEF_STATIC_CONST_VAL_FLOAT(val_0676,0.045341);
#define CTNODE_cmu_us_rms_dur_NO_1061 1063
DEF_STATIC_CONST_VAL_FLOAT(val_0677,-0.188298);
#define CTNODE_cmu_us_rms_dur_NO_1065 1067
DEF_STATIC_CONST_VAL_FLOAT(val_0678,0.136314);
#define CTNODE_cmu_us_rms_dur_NO_1064 1068
DEF_STATIC_CONST_VAL_FLOAT(val_0679,-0.334742);
#define CTNODE_cmu_us_rms_dur_NO_1063 1069
DEF_STATIC_CONST_VAL_FLOAT(val_0680,-0.042733);
#define CTNODE_cmu_us_rms_dur_NO_1069 1071
DEF_STATIC_CONST_VAL_STRING(val_0681,"v");
DEF_STATIC_CONST_VAL_FLOAT(val_0682,-0.326036);
#define CTNODE_cmu_us_rms_dur_NO_1072 1074
DEF_STATIC_CONST_VAL_FLOAT(val_0683,-0.668373);
#define CTNODE_cmu_us_rms_dur_NO_1071 1075
DEF_STATIC_CONST_VAL_FLOAT(val_0684,-0.068345);
#define CTNODE_cmu_us_rms_dur_NO_1077 1079
DEF_STATIC_CONST_VAL_FLOAT(val_0685,-0.371705);
#define CTNODE_cmu_us_rms_dur_NO_1080 1082
DEF_STATIC_CONST_VAL_FLOAT(val_0686,-0.090722);
#define CTNODE_cmu_us_rms_dur_NO_1079 1083
DEF_STATIC_CONST_VAL_FLOAT(val_0687,-0.439782);
#define CTNODE_cmu_us_rms_dur_NO_1076 1084
DEF_STATIC_CONST_VAL_FLOAT(val_0688,0.022775);
#define CTNODE_cmu_us_rms_dur_NO_1075 1085
DEF_STATIC_CONST_VAL_FLOAT(val_0689,0.050642);
#define CTNODE_cmu_us_rms_dur_NO_1086 1088
DEF_STATIC_CONST_VAL_FLOAT(val_0690,-0.313127);
#define CTNODE_cmu_us_rms_dur_NO_1090 1092
DEF_STATIC_CONST_VAL_FLOAT(val_0691,-0.377211);
#define CTNODE_cmu_us_rms_dur_NO_1089 1093
DEF_STATIC_CONST_VAL_FLOAT(val_0692,-0.030213);
#define CTNODE_cmu_us_rms_dur_NO_1088 1094
DEF_STATIC_CONST_VAL_STRING(val_0693,"aa");
DEF_STATIC_CONST_VAL_FLOAT(val_0694,-0.297013);
#define CTNODE_cmu_us_rms_dur_NO_1095 1097
DEF_STATIC_CONST_VAL_FLOAT(val_0695,-0.564290);
#define CTNODE_cmu_us_rms_dur_NO_1097 1099
DEF_STATIC_CONST_VAL_FLOAT(val_0696,-0.409818);
#define CTNODE_cmu_us_rms_dur_NO_1094 1100
DEF_STATIC_CONST_VAL_FLOAT(val_0697,-0.172714);
#define CTNODE_cmu_us_rms_dur_NO_1100 1102
DEF_STATIC_CONST_VAL_FLOAT(val_0698,-0.339986);
#define CTNODE_cmu_us_rms_dur_NO_1085 1103
DEF_STATIC_CONST_VAL_FLOAT(val_0699,-0.534381);
#define CTNODE_cmu_us_rms_dur_NO_1105 1107
DEF_STATIC_CONST_VAL_FLOAT(val_0700,-0.339018);
#define CTNODE_cmu_us_rms_dur_NO_1104 1108
DEF_STATIC_CONST_VAL_FLOAT(val_0701,-0.679831);
#define CTNODE_cmu_us_rms_dur_NO_1103 1109
DEF_STATIC_CONST_VAL_FLOAT(val_0702,-0.181097);
#define CTNODE_cmu_us_rms_dur_NO_1028 1110
DEF_STATIC_CONST_VAL_FLOAT(val_0703,-0.605315);
#define CTNODE_cmu_us_rms_dur_NO_1111 1113
DEF_STATIC_CONST_VAL_FLOAT(val_0704,-0.746718);
#define CTNODE_cmu_us_rms_dur_NO_1110 1114
DEF_STATIC_CONST_VAL_FLOAT(val_0705,-0.250501);
#define CTNODE_cmu_us_rms_dur_NO_1015 1115
DEF_STATIC_CONST_VAL_FLOAT(val_0706,0.854948);
#define CTNODE_cmu_us_rms_dur_NO_1117 1119
DEF_STATIC_CONST_VAL_FLOAT(val_0707,-0.597331);
#define CTNODE_cmu_us_rms_dur_NO_1119 1121
DEF_STATIC_CONST_VAL_FLOAT(val_0708,0.377649);
#define CTNODE_cmu_us_rms_dur_NO_1123 1125
DEF_STATIC_CONST_VAL_FLOAT(val_0709,-0.042819);
#define CTNODE_cmu_us_rms_dur_NO_1122 1126
DEF_STATIC_CONST_VAL_FLOAT(val_0710,-0.296821);
#define CTNODE_cmu_us_rms_dur_NO_1126 1128
DEF_STATIC_CONST_VAL_FLOAT(val_0711,-0.185565);
#define CTNODE_cmu_us_rms_dur_NO_1128 1130
DEF_STATIC_CONST_VAL_FLOAT(val_0712,-0.031485);
#define CTNODE_cmu_us_rms_dur_NO_1121 1131
DEF_STATIC_CONST_VAL_FLOAT(val_0713,3.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0714,0.128875);
#define CTNODE_cmu_us_rms_dur_NO_1132 1134
DEF_STATIC_CONST_VAL_FLOAT(val_0715,0.622411);
#define CTNODE_cmu_us_rms_dur_NO_1131 1135
DEF_STATIC_CONST_VAL_FLOAT(val_0716,0.102811);
#define CTNODE_cmu_us_rms_dur_NO_1136 1138
DEF_STATIC_CONST_VAL_FLOAT(val_0717,0.451782);
#define CTNODE_cmu_us_rms_dur_NO_1135 1139
DEF_STATIC_CONST_VAL_FLOAT(val_0718,0.222605);
#define CTNODE_cmu_us_rms_dur_NO_1141 1143
DEF_STATIC_CONST_VAL_FLOAT(val_0719,-0.112666);
#define CTNODE_cmu_us_rms_dur_NO_1140 1144
DEF_STATIC_CONST_VAL_FLOAT(val_0720,0.418797);
#define CTNODE_cmu_us_rms_dur_NO_1139 1145
DEF_STATIC_CONST_VAL_FLOAT(val_0721,-0.218701);
#define CTNODE_cmu_us_rms_dur_NO_1116 1146
DEF_STATIC_CONST_VAL_STRING(val_0722,"single");
DEF_STATIC_CONST_VAL_FLOAT(val_0723,0.931839);
#define CTNODE_cmu_us_rms_dur_NO_1149 1151
DEF_STATIC_CONST_VAL_FLOAT(val_0724,0.622807);
#define CTNODE_cmu_us_rms_dur_NO_1151 1153
DEF_STATIC_CONST_VAL_FLOAT(val_0725,-0.323003);
#define CTNODE_cmu_us_rms_dur_NO_1154 1156
DEF_STATIC_CONST_VAL_FLOAT(val_0726,0.013427);
#define CTNODE_cmu_us_rms_dur_NO_1153 1157
DEF_STATIC_CONST_VAL_FLOAT(val_0727,0.627169);
#define CTNODE_cmu_us_rms_dur_NO_1157 1159
DEF_STATIC_CONST_VAL_FLOAT(val_0728,0.068380);
#define CTNODE_cmu_us_rms_dur_NO_1160 1162
DEF_STATIC_CONST_VAL_FLOAT(val_0729,0.618604);
#define CTNODE_cmu_us_rms_dur_NO_1159 1163
DEF_STATIC_CONST_VAL_FLOAT(val_0730,-0.316745);
#define CTNODE_cmu_us_rms_dur_NO_1164 1166
DEF_STATIC_CONST_VAL_FLOAT(val_0731,-0.076566);
#define CTNODE_cmu_us_rms_dur_NO_1163 1167
DEF_STATIC_CONST_VAL_FLOAT(val_0732,0.336636);
#define CTNODE_cmu_us_rms_dur_NO_1148 1168
DEF_STATIC_CONST_VAL_FLOAT(val_0733,0.597521);
#define CTNODE_cmu_us_rms_dur_NO_1168 1170
DEF_STATIC_CONST_VAL_FLOAT(val_0734,0.064054);
#define CTNODE_cmu_us_rms_dur_NO_1172 1174
DEF_STATIC_CONST_VAL_FLOAT(val_0735,0.672647);
#define CTNODE_cmu_us_rms_dur_NO_1171 1175
DEF_STATIC_CONST_VAL_STRING(val_0736,"ih_88");
DEF_STATIC_CONST_VAL_FLOAT(val_0737,0.199820);
#define CTNODE_cmu_us_rms_dur_NO_1175 1177
DEF_STATIC_CONST_VAL_FLOAT(val_0738,13.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0739,-0.419609);
#define CTNODE_cmu_us_rms_dur_NO_1179 1181
DEF_STATIC_CONST_VAL_FLOAT(val_0740,-0.480337);
#define CTNODE_cmu_us_rms_dur_NO_1181 1183
DEF_STATIC_CONST_VAL_FLOAT(val_0741,-0.281872);
#define CTNODE_cmu_us_rms_dur_NO_1184 1186
DEF_STATIC_CONST_VAL_FLOAT(val_0742,0.261583);
#define CTNODE_cmu_us_rms_dur_NO_1186 1188
DEF_STATIC_CONST_VAL_FLOAT(val_0743,-0.002389);
#define CTNODE_cmu_us_rms_dur_NO_1183 1189
DEF_STATIC_CONST_VAL_FLOAT(val_0744,-0.283002);
#define CTNODE_cmu_us_rms_dur_NO_1178 1190
DEF_STATIC_CONST_VAL_FLOAT(val_0745,0.065942);
#define CTNODE_cmu_us_rms_dur_NO_1177 1191
DEF_STATIC_CONST_VAL_FLOAT(val_0746,0.228966);
#define CTNODE_cmu_us_rms_dur_NO_1170 1192
DEF_STATIC_CONST_VAL_FLOAT(val_0747,-0.540820);
#define CTNODE_cmu_us_rms_dur_NO_1192 1194
DEF_STATIC_CONST_VAL_FLOAT(val_0748,-0.457549);
#define CTNODE_cmu_us_rms_dur_NO_1147 1195
DEF_STATIC_CONST_VAL_FLOAT(val_0749,-0.065713);
#define CTNODE_cmu_us_rms_dur_NO_1197 1199
DEF_STATIC_CONST_VAL_FLOAT(val_0750,-0.305734);
#define CTNODE_cmu_us_rms_dur_NO_1196 1200
DEF_STATIC_CONST_VAL_FLOAT(val_0751,0.384729);
#define CTNODE_cmu_us_rms_dur_NO_1200 1202
DEF_STATIC_CONST_VAL_FLOAT(val_0752,-0.271463);
#define CTNODE_cmu_us_rms_dur_NO_1202 1204
DEF_STATIC_CONST_VAL_FLOAT(val_0753,0.181556);
#define CTNODE_cmu_us_rms_dur_NO_1195 1205
DEF_STATIC_CONST_VAL_FLOAT(val_0754,4.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_0755,0.059931);
#define CTNODE_cmu_us_rms_dur_NO_1206 1208
DEF_STATIC_CONST_VAL_FLOAT(val_0756,0.022002);
#define CTNODE_cmu_us_rms_dur_NO_1208 1210
DEF_STATIC_CONST_VAL_FLOAT(val_0757,-0.340536);
#define CTNODE_cmu_us_rms_dur_NO_1205 1211
DEF_STATIC_CONST_VAL_STRING(val_0758,"ax_27");
DEF_STATIC_CONST_VAL_FLOAT(val_0759,-0.544948);
#define CTNODE_cmu_us_rms_dur_NO_1212 1214
DEF_STATIC_CONST_VAL_FLOAT(val_0760,-0.105726);
#define CTNODE_cmu_us_rms_dur_NO_1216 1218
DEF_STATIC_CONST_VAL_FLOAT(val_0761,3.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_0762,-0.483207);
#define CTNODE_cmu_us_rms_dur_NO_1218 1220
DEF_STATIC_CONST_VAL_FLOAT(val_0763,-0.131878);
#define CTNODE_cmu_us_rms_dur_NO_1215 1221
DEF_STATIC_CONST_VAL_FLOAT(val_0764,0.173647);
#define CTNODE_cmu_us_rms_dur_NO_1214 1222
DEF_STATIC_CONST_VAL_FLOAT(val_0765,-0.503444);
#define CTNODE_cmu_us_rms_dur_NO_1211 1223
DEF_STATIC_CONST_VAL_FLOAT(val_0766,-0.632442);
#define CTNODE_cmu_us_rms_dur_NO_1146 1224
DEF_STATIC_CONST_VAL_FLOAT(val_0767,-0.413502);
#define CTNODE_cmu_us_rms_dur_NO_1226 1228
DEF_STATIC_CONST_VAL_FLOAT(val_0768,-0.647048);
#define CTNODE_cmu_us_rms_dur_NO_1229 1231
DEF_STATIC_CONST_VAL_FLOAT(val_0769,6.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0770,-0.406240);
#define CTNODE_cmu_us_rms_dur_NO_1231 1233
DEF_STATIC_CONST_VAL_FLOAT(val_0771,-0.536433);
#define CTNODE_cmu_us_rms_dur_NO_1228 1234
DEF_STATIC_CONST_VAL_FLOAT(val_0772,-0.690598);
#define CTNODE_cmu_us_rms_dur_NO_1225 1235
DEF_STATIC_CONST_VAL_FLOAT(val_0773,0.078942);
#define CTNODE_cmu_us_rms_dur_NO_1224 1236
DEF_STATIC_CONST_VAL_FLOAT(val_0774,0.098539);
#define CTNODE_cmu_us_rms_dur_NO_1238 1240
DEF_STATIC_CONST_VAL_FLOAT(val_0775,-0.046383);
#define CTNODE_cmu_us_rms_dur_NO_1241 1243
DEF_STATIC_CONST_VAL_FLOAT(val_0776,-0.388064);
#define CTNODE_cmu_us_rms_dur_NO_1240 1244
DEF_STATIC_CONST_VAL_FLOAT(val_0777,-0.636319);
#define CTNODE_cmu_us_rms_dur_NO_1246 1248
DEF_STATIC_CONST_VAL_FLOAT(val_0778,-0.565568);
#define CTNODE_cmu_us_rms_dur_NO_1245 1249
DEF_STATIC_CONST_VAL_FLOAT(val_0779,-0.413427);
#define CTNODE_cmu_us_rms_dur_NO_1249 1251
DEF_STATIC_CONST_VAL_FLOAT(val_0780,-0.555608);
#define CTNODE_cmu_us_rms_dur_NO_1244 1252
DEF_STATIC_CONST_VAL_FLOAT(val_0781,-0.203316);
#define CTNODE_cmu_us_rms_dur_NO_1237 1253
DEF_STATIC_CONST_VAL_STRING(val_0782,"ow_128");
DEF_STATIC_CONST_VAL_FLOAT(val_0783,0.487972);
#define CTNODE_cmu_us_rms_dur_NO_1253 1255
DEF_STATIC_CONST_VAL_FLOAT(val_0784,0.126008);
#define CTNODE_cmu_us_rms_dur_NO_1257 1259
DEF_STATIC_CONST_VAL_FLOAT(val_0785,-0.221427);
#define CTNODE_cmu_us_rms_dur_NO_1256 1260
DEF_STATIC_CONST_VAL_FLOAT(val_0786,-0.219171);
#define CTNODE_cmu_us_rms_dur_NO_1260 1262
DEF_STATIC_CONST_VAL_FLOAT(val_0787,-0.700052);
#define CTNODE_cmu_us_rms_dur_NO_1262 1264
DEF_STATIC_CONST_VAL_FLOAT(val_0788,-0.582053);
#define CTNODE_cmu_us_rms_dur_NO_1255 1265
DEF_STATIC_CONST_VAL_FLOAT(val_0789,-0.546415);
#define CTNODE_cmu_us_rms_dur_NO_1267 1269
DEF_STATIC_CONST_VAL_FLOAT(val_0790,-0.703580);
#define CTNODE_cmu_us_rms_dur_NO_1270 1272
DEF_STATIC_CONST_VAL_FLOAT(val_0791,-0.294361);
#define CTNODE_cmu_us_rms_dur_NO_1269 1273
DEF_STATIC_CONST_VAL_FLOAT(val_0792,0.779262);
#define CTNODE_cmu_us_rms_dur_NO_1274 1276
DEF_STATIC_CONST_VAL_FLOAT(val_0793,-0.012872);
#define CTNODE_cmu_us_rms_dur_NO_1273 1277
DEF_STATIC_CONST_VAL_FLOAT(val_0794,-0.479273);
#define CTNODE_cmu_us_rms_dur_NO_1278 1280
DEF_STATIC_CONST_VAL_FLOAT(val_0795,-0.179017);
#define CTNODE_cmu_us_rms_dur_NO_1277 1281
DEF_STATIC_CONST_VAL_FLOAT(val_0796,-0.062983);
#define CTNODE_cmu_us_rms_dur_NO_1281 1283
DEF_STATIC_CONST_VAL_FLOAT(val_0797,0.325721);
#define CTNODE_cmu_us_rms_dur_NO_1266 1284
DEF_STATIC_CONST_VAL_STRING(val_0798,"ah");
DEF_STATIC_CONST_VAL_FLOAT(val_0799,-0.553933);
#define CTNODE_cmu_us_rms_dur_NO_1285 1287
DEF_STATIC_CONST_VAL_FLOAT(val_0800,-0.067956);
#define CTNODE_cmu_us_rms_dur_NO_1284 1288
DEF_STATIC_CONST_VAL_FLOAT(val_0801,0.296726);
#define CTNODE_cmu_us_rms_dur_NO_1290 1292
DEF_STATIC_CONST_VAL_FLOAT(val_0802,-0.060788);
#define CTNODE_cmu_us_rms_dur_NO_1289 1293
DEF_STATIC_CONST_VAL_FLOAT(val_0803,0.872817);
#define CTNODE_cmu_us_rms_dur_NO_1288 1294
DEF_STATIC_CONST_VAL_FLOAT(val_0804,-0.242878);
#define CTNODE_cmu_us_rms_dur_NO_1294 1296
DEF_STATIC_CONST_VAL_FLOAT(val_0805,0.010669);
#define CTNODE_cmu_us_rms_dur_NO_1297 1299
DEF_STATIC_CONST_VAL_FLOAT(val_0806,-0.431732);
#define CTNODE_cmu_us_rms_dur_NO_1296 1300
DEF_STATIC_CONST_VAL_FLOAT(val_0807,0.747547);
#define CTNODE_cmu_us_rms_dur_NO_1302 1304
DEF_STATIC_CONST_VAL_FLOAT(val_0808,0.084295);
#define CTNODE_cmu_us_rms_dur_NO_1304 1306
DEF_STATIC_CONST_VAL_FLOAT(val_0809,0.491451);
#define CTNODE_cmu_us_rms_dur_NO_1301 1307
DEF_STATIC_CONST_VAL_FLOAT(val_0810,0.030488);
#define CTNODE_cmu_us_rms_dur_NO_1308 1310
DEF_STATIC_CONST_VAL_FLOAT(val_0811,0.346141);
#define CTNODE_cmu_us_rms_dur_NO_1307 1311
DEF_STATIC_CONST_VAL_FLOAT(val_0812,-0.173885);
#define CTNODE_cmu_us_rms_dur_NO_1300 1312
DEF_STATIC_CONST_VAL_FLOAT(val_0813,-0.197381);
#define CTNODE_cmu_us_rms_dur_NO_1265 1313
DEF_STATIC_CONST_VAL_FLOAT(val_0814,-0.705297);
#define CTNODE_cmu_us_rms_dur_NO_1314 1316
DEF_STATIC_CONST_VAL_FLOAT(val_0815,-0.280838);
#define CTNODE_cmu_us_rms_dur_NO_1316 1318
DEF_STATIC_CONST_VAL_FLOAT(val_0816,-0.633535);
#define CTNODE_cmu_us_rms_dur_NO_1313 1319
DEF_STATIC_CONST_VAL_FLOAT(val_0817,-0.453555);
#define CTNODE_cmu_us_rms_dur_NO_1320 1322
DEF_STATIC_CONST_VAL_FLOAT(val_0818,8.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0819,0.053348);
#define CTNODE_cmu_us_rms_dur_NO_1324 1326
DEF_STATIC_CONST_VAL_FLOAT(val_0820,-0.344530);
#define CTNODE_cmu_us_rms_dur_NO_1323 1327
DEF_STATIC_CONST_VAL_FLOAT(val_0821,0.452516);
#define CTNODE_cmu_us_rms_dur_NO_1328 1330
DEF_STATIC_CONST_VAL_FLOAT(val_0822,0.065310);
#define CTNODE_cmu_us_rms_dur_NO_1327 1331
DEF_STATIC_CONST_VAL_FLOAT(val_0823,-0.163155);
#define CTNODE_cmu_us_rms_dur_NO_1322 1332
DEF_STATIC_CONST_VAL_FLOAT(val_0824,3.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0825,-0.427340);
#define CTNODE_cmu_us_rms_dur_NO_1333 1335
DEF_STATIC_CONST_VAL_FLOAT(val_0826,-0.173719);
#define CTNODE_cmu_us_rms_dur_NO_1332 1336
DEF_STATIC_CONST_VAL_FLOAT(val_0827,0.041466);
#define CTNODE_cmu_us_rms_dur_NO_1319 1337
DEF_STATIC_CONST_VAL_FLOAT(val_0828,-0.280507);
#define CTNODE_cmu_us_rms_dur_NO_1338 1340
DEF_STATIC_CONST_VAL_FLOAT(val_0829,0.113146);
#define CTNODE_cmu_us_rms_dur_NO_1337 1341
DEF_STATIC_CONST_VAL_FLOAT(val_0830,-0.519725);
#define CTNODE_cmu_us_rms_dur_NO_1341 1343
DEF_STATIC_CONST_VAL_FLOAT(val_0831,-0.507461);
#define CTNODE_cmu_us_rms_dur_NO_1344 1346
DEF_STATIC_CONST_VAL_FLOAT(val_0832,-0.320820);
#define CTNODE_cmu_us_rms_dur_NO_1343 1347
DEF_STATIC_CONST_VAL_FLOAT(val_0833,11.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_0834,-0.509800);
#define CTNODE_cmu_us_rms_dur_NO_1349 1351
DEF_STATIC_CONST_VAL_FLOAT(val_0835,-0.317461);
#define CTNODE_cmu_us_rms_dur_NO_1348 1352
DEF_STATIC_CONST_VAL_FLOAT(val_0836,-0.112608);
#define CTNODE_cmu_us_rms_dur_NO_1347 1353
DEF_STATIC_CONST_VAL_FLOAT(val_0837,0.133664);
#define CTNODE_cmu_us_rms_dur_NO_1236 1354
DEF_STATIC_CONST_VAL_FLOAT(val_0838,0.618380);
#define CTNODE_cmu_us_rms_dur_NO_1115 1355
DEF_STATIC_CONST_VAL_FLOAT(val_0839,4.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_0840,0.520238);
#define CTNODE_cmu_us_rms_dur_NO_1357 1359
DEF_STATIC_CONST_VAL_FLOAT(val_0841,0.181483);
#define CTNODE_cmu_us_rms_dur_NO_1356 1360
DEF_STATIC_CONST_VAL_FLOAT(val_0842,0.382838);
#define CTNODE_cmu_us_rms_dur_NO_1361 1363
DEF_STATIC_CONST_VAL_STRING(val_0843,"w");
DEF_STATIC_CONST_VAL_FLOAT(val_0844,-0.422214);
#define CTNODE_cmu_us_rms_dur_NO_1363 1365
DEF_STATIC_CONST_VAL_FLOAT(val_0845,-0.148356);
#define CTNODE_cmu_us_rms_dur_NO_1367 1369
DEF_STATIC_CONST_VAL_FLOAT(val_0846,0.078710);
#define CTNODE_cmu_us_rms_dur_NO_1366 1370
DEF_STATIC_CONST_VAL_FLOAT(val_0847,0.479397);
#define CTNODE_cmu_us_rms_dur_NO_1365 1371
DEF_STATIC_CONST_VAL_FLOAT(val_0848,-0.168786);
#define CTNODE_cmu_us_rms_dur_NO_1372 1374
DEF_STATIC_CONST_VAL_FLOAT(val_0849,0.389487);
#define CTNODE_cmu_us_rms_dur_NO_1374 1376
DEF_STATIC_CONST_VAL_FLOAT(val_0850,0.078352);
#define CTNODE_cmu_us_rms_dur_NO_1371 1377
DEF_STATIC_CONST_VAL_STRING(val_0851,"ow_126");
DEF_STATIC_CONST_VAL_FLOAT(val_0852,-0.372753);
#define CTNODE_cmu_us_rms_dur_NO_1377 1379
DEF_STATIC_CONST_VAL_FLOAT(val_0853,-0.430677);
#define CTNODE_cmu_us_rms_dur_NO_1381 1383
DEF_STATIC_CONST_VAL_FLOAT(val_0854,0.059010);
#define CTNODE_cmu_us_rms_dur_NO_1383 1385
DEF_STATIC_CONST_VAL_FLOAT(val_0855,-0.195813);
#define CTNODE_cmu_us_rms_dur_NO_1380 1386
DEF_STATIC_CONST_VAL_FLOAT(val_0856,-0.092356);
#define CTNODE_cmu_us_rms_dur_NO_1387 1389
DEF_STATIC_CONST_VAL_FLOAT(val_0857,0.330555);
#define CTNODE_cmu_us_rms_dur_NO_1386 1390
DEF_STATIC_CONST_VAL_FLOAT(val_0858,4.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_0859,0.120252);
#define CTNODE_cmu_us_rms_dur_NO_1391 1393
DEF_STATIC_CONST_VAL_FLOAT(val_0860,-0.110122);
#define CTNODE_cmu_us_rms_dur_NO_1390 1394
DEF_STATIC_CONST_VAL_FLOAT(val_0861,-0.051679);
#define CTNODE_cmu_us_rms_dur_NO_1394 1396
DEF_STATIC_CONST_VAL_FLOAT(val_0862,-0.446360);
#define CTNODE_cmu_us_rms_dur_NO_1379 1397
DEF_STATIC_CONST_VAL_FLOAT(val_0863,-0.392504);
#define CTNODE_cmu_us_rms_dur_NO_1360 1398
DEF_STATIC_CONST_VAL_FLOAT(val_0864,0.695067);
#define CTNODE_cmu_us_rms_dur_NO_1398 1400
DEF_STATIC_CONST_VAL_FLOAT(val_0865,0.001916);
#define CTNODE_cmu_us_rms_dur_NO_1355 1401
DEF_STATIC_CONST_VAL_FLOAT(val_0866,0.956404);
#define CTNODE_cmu_us_rms_dur_NO_1402 1404
DEF_STATIC_CONST_VAL_FLOAT(val_0867,0.406251);
#define CTNODE_cmu_us_rms_dur_NO_1405 1407
DEF_STATIC_CONST_VAL_FLOAT(val_0868,-0.163795);
#define CTNODE_cmu_us_rms_dur_NO_1404 1408
DEF_STATIC_CONST_VAL_FLOAT(val_0869,-0.439522);
#define CTNODE_cmu_us_rms_dur_NO_1408 1410
DEF_STATIC_CONST_VAL_FLOAT(val_0870,-0.015425);
#define CTNODE_cmu_us_rms_dur_NO_1401 1411
DEF_STATIC_CONST_VAL_STRING(val_0871,"to");
DEF_STATIC_CONST_VAL_FLOAT(val_0872,-0.442155);
#define CTNODE_cmu_us_rms_dur_NO_1412 1414
DEF_STATIC_CONST_VAL_FLOAT(val_0873,0.226222);
#define CTNODE_cmu_us_rms_dur_NO_1414 1416
DEF_STATIC_CONST_VAL_FLOAT(val_0874,0.846873);
#define CTNODE_cmu_us_rms_dur_NO_1411 1417
DEF_STATIC_CONST_VAL_FLOAT(val_0875,0.042025);
#define CTNODE_cmu_us_rms_dur_NO_1419 1421
DEF_STATIC_CONST_VAL_FLOAT(val_0876,-0.144955);
#define CTNODE_cmu_us_rms_dur_NO_1421 1423
DEF_STATIC_CONST_VAL_STRING(val_0877,"d_48");
DEF_STATIC_CONST_VAL_FLOAT(val_0878,-0.137286);
#define CTNODE_cmu_us_rms_dur_NO_1423 1425
DEF_STATIC_CONST_VAL_FLOAT(val_0879,-0.180432);
#define CTNODE_cmu_us_rms_dur_NO_1426 1428
DEF_STATIC_CONST_VAL_FLOAT(val_0880,-0.379953);
#define CTNODE_cmu_us_rms_dur_NO_1425 1429
DEF_STATIC_CONST_VAL_FLOAT(val_0881,-0.644498);
#define CTNODE_cmu_us_rms_dur_NO_1433 1435
DEF_STATIC_CONST_VAL_FLOAT(val_0882,-0.408259);
#define CTNODE_cmu_us_rms_dur_NO_1432 1436
DEF_STATIC_CONST_VAL_FLOAT(val_0883,-0.298670);
#define CTNODE_cmu_us_rms_dur_NO_1431 1437
DEF_STATIC_CONST_VAL_FLOAT(val_0884,-0.697770);
#define CTNODE_cmu_us_rms_dur_NO_1430 1438
DEF_STATIC_CONST_VAL_FLOAT(val_0885,2.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_0886,-0.228084);
#define CTNODE_cmu_us_rms_dur_NO_1438 1440
DEF_STATIC_CONST_VAL_FLOAT(val_0887,-0.332215);
#define CTNODE_cmu_us_rms_dur_NO_1440 1442
DEF_STATIC_CONST_VAL_FLOAT(val_0888,-0.564725);
#define CTNODE_cmu_us_rms_dur_NO_1429 1443
DEF_STATIC_CONST_VAL_FLOAT(val_0889,-0.486034);
#define CTNODE_cmu_us_rms_dur_NO_1443 1445
DEF_STATIC_CONST_VAL_FLOAT(val_0890,-0.711773);
#define CTNODE_cmu_us_rms_dur_NO_1446 1448
DEF_STATIC_CONST_VAL_FLOAT(val_0891,-0.769811);
#define CTNODE_cmu_us_rms_dur_NO_1445 1449
DEF_STATIC_CONST_VAL_FLOAT(val_0892,-0.565555);
#define CTNODE_cmu_us_rms_dur_NO_1449 1451
DEF_STATIC_CONST_VAL_FLOAT(val_0893,-0.670226);
#define CTNODE_cmu_us_rms_dur_NO_1418 1452
DEF_STATIC_CONST_VAL_FLOAT(val_0894,-0.734685);
#define CTNODE_cmu_us_rms_dur_NO_1453 1455
DEF_STATIC_CONST_VAL_FLOAT(val_0895,-0.349663);
#define CTNODE_cmu_us_rms_dur_NO_1455 1457
DEF_STATIC_CONST_VAL_FLOAT(val_0896,-0.558711);
#define CTNODE_cmu_us_rms_dur_NO_1458 1460
DEF_STATIC_CONST_VAL_FLOAT(val_0897,-0.447020);
#define CTNODE_cmu_us_rms_dur_NO_1457 1461
DEF_STATIC_CONST_VAL_FLOAT(val_0898,-0.624915);
#define CTNODE_cmu_us_rms_dur_NO_1452 1462
DEF_STATIC_CONST_VAL_FLOAT(val_0899,-0.828837);
#define CTNODE_cmu_us_rms_dur_NO_1462 1464
DEF_STATIC_CONST_VAL_FLOAT(val_0900,0.393704);
#define CTNODE_cmu_us_rms_dur_NO_1464 1466
DEF_STATIC_CONST_VAL_FLOAT(val_0901,0.746488);
#define CTNODE_cmu_us_rms_dur_NO_1468 1470
DEF_STATIC_CONST_VAL_FLOAT(val_0902,3.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_0903,-0.044117);
#define CTNODE_cmu_us_rms_dur_NO_1470 1472
DEF_STATIC_CONST_VAL_FLOAT(val_0904,0.099428);
#define CTNODE_cmu_us_rms_dur_NO_1467 1473
DEF_STATIC_CONST_VAL_FLOAT(val_0905,-0.656141);
#define CTNODE_cmu_us_rms_dur_NO_1474 1476
DEF_STATIC_CONST_VAL_FLOAT(val_0906,-0.604628);
#define CTNODE_cmu_us_rms_dur_NO_1476 1478
DEF_STATIC_CONST_VAL_FLOAT(val_0907,-0.250210);
#define CTNODE_cmu_us_rms_dur_NO_1473 1479
DEF_STATIC_CONST_VAL_FLOAT(val_0908,-0.319155);
#define CTNODE_cmu_us_rms_dur_NO_1481 1483
DEF_STATIC_CONST_VAL_FLOAT(val_0909,-0.425090);
#define CTNODE_cmu_us_rms_dur_NO_1483 1485
DEF_STATIC_CONST_VAL_FLOAT(val_0910,-0.636514);
#define CTNODE_cmu_us_rms_dur_NO_1485 1487
DEF_STATIC_CONST_VAL_FLOAT(val_0911,-0.734667);
#define CTNODE_cmu_us_rms_dur_NO_1480 1488
DEF_STATIC_CONST_VAL_FLOAT(val_0912,0.020742);
#define CTNODE_cmu_us_rms_dur_NO_1479 1489
DEF_STATIC_CONST_VAL_FLOAT(val_0913,0.545299);
#define CTNODE_cmu_us_rms_dur_NO_1490 1492
DEF_STATIC_CONST_VAL_STRING(val_0914,"z_201");
DEF_STATIC_CONST_VAL_FLOAT(val_0915,0.327511);
#define CTNODE_cmu_us_rms_dur_NO_1492 1494
DEF_STATIC_CONST_VAL_FLOAT(val_0916,-0.409782);
#define CTNODE_cmu_us_rms_dur_NO_1494 1496
DEF_STATIC_CONST_VAL_FLOAT(val_0917,0.205173);
#define CTNODE_cmu_us_rms_dur_NO_1496 1498
DEF_STATIC_CONST_VAL_FLOAT(val_0918,-0.127791);
#define CTNODE_cmu_us_rms_dur_NO_1498 1500
DEF_STATIC_CONST_VAL_FLOAT(val_0919,-0.375530);
#define CTNODE_cmu_us_rms_dur_NO_1489 1501
DEF_STATIC_CONST_VAL_FLOAT(val_0920,0.429383);
#define CTNODE_cmu_us_rms_dur_NO_1503 1505
DEF_STATIC_CONST_VAL_FLOAT(val_0921,-0.048525);
#define CTNODE_cmu_us_rms_dur_NO_1502 1506
DEF_STATIC_CONST_VAL_FLOAT(val_0922,0.214875);
#define CTNODE_cmu_us_rms_dur_NO_1506 1508
DEF_STATIC_CONST_VAL_STRING(val_0923,"v_185");
DEF_STATIC_CONST_VAL_FLOAT(val_0924,0.307042);
#define CTNODE_cmu_us_rms_dur_NO_1509 1511
DEF_STATIC_CONST_VAL_FLOAT(val_0925,-0.184503);
#define CTNODE_cmu_us_rms_dur_NO_1508 1512
DEF_STATIC_CONST_VAL_FLOAT(val_0926,-0.669057);
#define CTNODE_cmu_us_rms_dur_NO_1513 1515
DEF_STATIC_CONST_VAL_FLOAT(val_0927,-0.165541);
#define CTNODE_cmu_us_rms_dur_NO_1515 1517
DEF_STATIC_CONST_VAL_FLOAT(val_0928,-0.469351);
#define CTNODE_cmu_us_rms_dur_NO_1512 1518
DEF_STATIC_CONST_VAL_FLOAT(val_0929,0.180833);
#define CTNODE_cmu_us_rms_dur_NO_1520 1522
DEF_STATIC_CONST_VAL_FLOAT(val_0930,-0.291725);
#define CTNODE_cmu_us_rms_dur_NO_1519 1523
DEF_STATIC_CONST_VAL_FLOAT(val_0931,-0.260463);
#define CTNODE_cmu_us_rms_dur_NO_1525 1527
DEF_STATIC_CONST_VAL_FLOAT(val_0932,-0.009861);
#define CTNODE_cmu_us_rms_dur_NO_1524 1528
DEF_STATIC_CONST_VAL_FLOAT(val_0933,0.043547);
#define CTNODE_cmu_us_rms_dur_NO_1530 1532
DEF_STATIC_CONST_VAL_FLOAT(val_0934,-0.335634);
#define CTNODE_cmu_us_rms_dur_NO_1529 1533
DEF_STATIC_CONST_VAL_FLOAT(val_0935,-0.384787);
#define CTNODE_cmu_us_rms_dur_NO_1528 1534
DEF_STATIC_CONST_VAL_FLOAT(val_0936,4.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_0937,-0.632538);
#define CTNODE_cmu_us_rms_dur_NO_1535 1537
DEF_STATIC_CONST_VAL_FLOAT(val_0938,-0.586234);
#define CTNODE_cmu_us_rms_dur_NO_1537 1539
DEF_STATIC_CONST_VAL_FLOAT(val_0939,-0.206453);
#define CTNODE_cmu_us_rms_dur_NO_1539 1541
DEF_STATIC_CONST_VAL_FLOAT(val_0940,-0.395906);
#define CTNODE_cmu_us_rms_dur_NO_1542 1544
DEF_STATIC_CONST_VAL_FLOAT(val_0941,-0.571073);
#define CTNODE_cmu_us_rms_dur_NO_1541 1545
DEF_STATIC_CONST_VAL_FLOAT(val_0942,-0.274870);
#define CTNODE_cmu_us_rms_dur_NO_1534 1546
DEF_STATIC_CONST_VAL_FLOAT(val_0943,-0.409759);
#define CTNODE_cmu_us_rms_dur_NO_1546 1548
DEF_STATIC_CONST_VAL_FLOAT(val_0944,-0.073918);
#define CTNODE_cmu_us_rms_dur_NO_1523 1549
DEF_STATIC_CONST_VAL_FLOAT(val_0945,0.277935);
#define CTNODE_cmu_us_rms_dur_NO_1550 1552
DEF_STATIC_CONST_VAL_FLOAT(val_0946,-0.076386);
#define CTNODE_cmu_us_rms_dur_NO_1552 1554
DEF_STATIC_CONST_VAL_FLOAT(val_0947,-0.300795);
#define CTNODE_cmu_us_rms_dur_NO_1549 1555
DEF_STATIC_CONST_VAL_FLOAT(val_0948,0.309098);
#define CTNODE_cmu_us_rms_dur_NO_1557 1559
DEF_STATIC_CONST_VAL_FLOAT(val_0949,-0.104794);
#define CTNODE_cmu_us_rms_dur_NO_1556 1560
DEF_STATIC_CONST_VAL_FLOAT(val_0950,-0.355957);
#define CTNODE_cmu_us_rms_dur_NO_1555 1561
DEF_STATIC_CONST_VAL_FLOAT(val_0951,0.068947);
#define CTNODE_cmu_us_rms_dur_NO_1562 1564
DEF_STATIC_CONST_VAL_FLOAT(val_0952,0.103967);
#define CTNODE_cmu_us_rms_dur_NO_1565 1567
DEF_STATIC_CONST_VAL_FLOAT(val_0953,-0.235162);
#define CTNODE_cmu_us_rms_dur_NO_1568 1570
DEF_STATIC_CONST_VAL_FLOAT(val_0954,0.066229);
#define CTNODE_cmu_us_rms_dur_NO_1567 1571
DEF_STATIC_CONST_VAL_FLOAT(val_0955,-0.455368);
#define CTNODE_cmu_us_rms_dur_NO_1571 1573
DEF_STATIC_CONST_VAL_FLOAT(val_0956,-0.313753);
#define CTNODE_cmu_us_rms_dur_NO_1573 1575
DEF_STATIC_CONST_VAL_FLOAT(val_0957,-0.092656);
#define CTNODE_cmu_us_rms_dur_NO_1564 1576
DEF_STATIC_CONST_VAL_FLOAT(val_0958,-0.306749);
#define CTNODE_cmu_us_rms_dur_NO_1577 1579
DEF_STATIC_CONST_VAL_FLOAT(val_0959,-0.605768);
#define CTNODE_cmu_us_rms_dur_NO_1576 1580
DEF_STATIC_CONST_VAL_FLOAT(val_0960,-0.100008);
#define CTNODE_cmu_us_rms_dur_NO_1580 1582
DEF_STATIC_CONST_VAL_FLOAT(val_0961,-0.363139);
#define CTNODE_cmu_us_rms_dur_NO_1583 1585
DEF_STATIC_CONST_VAL_FLOAT(val_0962,-0.212236);
#define CTNODE_cmu_us_rms_dur_NO_1582 1586
DEF_STATIC_CONST_VAL_FLOAT(val_0963,-0.451542);
#define CTNODE_cmu_us_rms_dur_NO_1561 1587
DEF_STATIC_CONST_VAL_FLOAT(val_0964,-0.572049);
#define CTNODE_cmu_us_rms_dur_NO_1518 1588
DEF_STATIC_CONST_VAL_FLOAT(val_0965,-0.341265);
#define CTNODE_cmu_us_rms_dur_NO_1589 1591
DEF_STATIC_CONST_VAL_FLOAT(val_0966,-0.037719);
#define CTNODE_cmu_us_rms_dur_NO_1588 1592
DEF_STATIC_CONST_VAL_FLOAT(val_0967,0.434889);
#define CTNODE_cmu_us_rms_dur_NO_1501 1593
DEF_STATIC_CONST_VAL_FLOAT(val_0968,-0.298318);
#define CTNODE_cmu_us_rms_dur_NO_1593 1595
DEF_STATIC_CONST_VAL_FLOAT(val_0969,-0.661470);
#define CTNODE_cmu_us_rms_dur_NO_1466 1596
DEF_STATIC_CONST_VAL_FLOAT(val_0970,-0.004959);
#define CTNODE_cmu_us_rms_dur_NO_1597 1599
DEF_STATIC_CONST_VAL_FLOAT(val_0971,0.116499);
#define CTNODE_cmu_us_rms_dur_NO_1596 1600
DEF_STATIC_CONST_VAL_FLOAT(val_0972,0.108823);
#define CTNODE_cmu_us_rms_dur_NO_1600 1602
DEF_STATIC_CONST_VAL_FLOAT(val_0973,0.012036);
#define CTNODE_cmu_us_rms_dur_NO_1602 1604
DEF_STATIC_CONST_VAL_STRING(val_0974,"k");
DEF_STATIC_CONST_VAL_FLOAT(val_0975,0.230025);
#define CTNODE_cmu_us_rms_dur_NO_1605 1607
DEF_STATIC_CONST_VAL_STRING(val_0976,"k_102");
DEF_STATIC_CONST_VAL_FLOAT(val_0977,-0.029124);
#define CTNODE_cmu_us_rms_dur_NO_1607 1609
DEF_STATIC_CONST_VAL_FLOAT(val_0978,-0.157380);
#define CTNODE_cmu_us_rms_dur_NO_1609 1611
DEF_STATIC_CONST_VAL_FLOAT(val_0979,-0.458563);
#define CTNODE_cmu_us_rms_dur_NO_1604 1612
DEF_STATIC_CONST_VAL_FLOAT(val_0980,-0.863763);
#define CTNODE_cmu_us_rms_dur_NO_1613 1615
DEF_STATIC_CONST_VAL_FLOAT(val_0981,-0.231869);
#define CTNODE_cmu_us_rms_dur_NO_1616 1618
DEF_STATIC_CONST_VAL_FLOAT(val_0982,-0.537671);
#define CTNODE_cmu_us_rms_dur_NO_1615 1619
DEF_STATIC_CONST_VAL_FLOAT(val_0983,-0.630451);
#define CTNODE_cmu_us_rms_dur_NO_1612 1620
DEF_STATIC_CONST_VAL_FLOAT(val_0984,-0.704530);
#define CTNODE_cmu_us_rms_dur_NO_1621 1623
DEF_STATIC_CONST_VAL_FLOAT(val_0985,-0.313085);
#define CTNODE_cmu_us_rms_dur_NO_1623 1625
DEF_STATIC_CONST_VAL_FLOAT(val_0986,-0.577376);
#define CTNODE_cmu_us_rms_dur_NO_1620 1626
DEF_STATIC_CONST_VAL_FLOAT(val_0987,0.044454);
#define CTNODE_cmu_us_rms_dur_NO_1628 1630
DEF_STATIC_CONST_VAL_FLOAT(val_0988,-0.068029);
#define CTNODE_cmu_us_rms_dur_NO_1630 1632
DEF_STATIC_CONST_VAL_FLOAT(val_0989,0.084606);
#define CTNODE_cmu_us_rms_dur_NO_1633 1635
DEF_STATIC_CONST_VAL_FLOAT(val_0990,-0.387465);
#define CTNODE_cmu_us_rms_dur_NO_1632 1636
DEF_STATIC_CONST_VAL_FLOAT(val_0991,-0.112111);
#define CTNODE_cmu_us_rms_dur_NO_1637 1639
DEF_STATIC_CONST_VAL_FLOAT(val_0992,-0.348033);
#define CTNODE_cmu_us_rms_dur_NO_1642 1644
DEF_STATIC_CONST_VAL_FLOAT(val_0993,-0.383331);
#define CTNODE_cmu_us_rms_dur_NO_1641 1645
DEF_STATIC_CONST_VAL_FLOAT(val_0994,-0.595044);
#define CTNODE_cmu_us_rms_dur_NO_1640 1646
DEF_STATIC_CONST_VAL_FLOAT(val_0995,-0.265627);
#define CTNODE_cmu_us_rms_dur_NO_1647 1649
DEF_STATIC_CONST_VAL_FLOAT(val_0996,-0.376119);
#define CTNODE_cmu_us_rms_dur_NO_1646 1650
DEF_STATIC_CONST_VAL_FLOAT(val_0997,-0.116808);
#define CTNODE_cmu_us_rms_dur_NO_1639 1651
DEF_STATIC_CONST_VAL_FLOAT(val_0998,-0.421523);
#define CTNODE_cmu_us_rms_dur_NO_1652 1654
DEF_STATIC_CONST_VAL_FLOAT(val_0999,-0.694989);
#define CTNODE_cmu_us_rms_dur_NO_1651 1655
DEF_STATIC_CONST_VAL_FLOAT(val_1000,-0.795143);
#define CTNODE_cmu_us_rms_dur_NO_1636 1656
DEF_STATIC_CONST_VAL_FLOAT(val_1001,-0.494204);
#define CTNODE_cmu_us_rms_dur_NO_1657 1659
DEF_STATIC_CONST_VAL_FLOAT(val_1002,-0.253975);
#define CTNODE_cmu_us_rms_dur_NO_1656 1660
DEF_STATIC_CONST_VAL_FLOAT(val_1003,0.058545);
#define CTNODE_cmu_us_rms_dur_NO_1660 1662
DEF_STATIC_CONST_VAL_FLOAT(val_1004,-0.050633);
#define CTNODE_cmu_us_rms_dur_NO_1662 1664
DEF_STATIC_CONST_VAL_FLOAT(val_1005,-0.547029);
#define CTNODE_cmu_us_rms_dur_NO_1627 1665
DEF_STATIC_CONST_VAL_FLOAT(val_1006,0.258917);
#define CTNODE_cmu_us_rms_dur_NO_1665 1667
DEF_STATIC_CONST_VAL_FLOAT(val_1007,-0.347840);
#define CTNODE_cmu_us_rms_dur_NO_1626 1668
DEF_STATIC_CONST_VAL_FLOAT(val_1008,-0.560932);
#define CTNODE_cmu_us_rms_dur_NO_1417 1669
DEF_STATIC_CONST_VAL_FLOAT(val_1009,-0.029317);
#define CTNODE_cmu_us_rms_dur_NO_1672 1674
DEF_STATIC_CONST_VAL_FLOAT(val_1010,0.015808);
#define CTNODE_cmu_us_rms_dur_NO_1674 1676
DEF_STATIC_CONST_VAL_FLOAT(val_1011,0.104861);
#define CTNODE_cmu_us_rms_dur_NO_1676 1678
DEF_STATIC_CONST_VAL_FLOAT(val_1012,0.349365);
#define CTNODE_cmu_us_rms_dur_NO_1678 1680
DEF_STATIC_CONST_VAL_FLOAT(val_1013,0.730983);
#define CTNODE_cmu_us_rms_dur_NO_1671 1681
DEF_STATIC_CONST_VAL_FLOAT(val_1014,-0.435412);
#define CTNODE_cmu_us_rms_dur_NO_1683 1685
DEF_STATIC_CONST_VAL_FLOAT(val_1015,-0.053258);
#define CTNODE_cmu_us_rms_dur_NO_1682 1686
DEF_STATIC_CONST_VAL_FLOAT(val_1016,0.139690);
#define CTNODE_cmu_us_rms_dur_NO_1688 1690
DEF_STATIC_CONST_VAL_FLOAT(val_1017,0.587534);
#define CTNODE_cmu_us_rms_dur_NO_1687 1691
DEF_STATIC_CONST_VAL_FLOAT(val_1018,-0.036684);
#define CTNODE_cmu_us_rms_dur_NO_1686 1692
DEF_STATIC_CONST_VAL_FLOAT(val_1019,9.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_1020,-0.030406);
#define CTNODE_cmu_us_rms_dur_NO_1694 1696
DEF_STATIC_CONST_VAL_FLOAT(val_1021,0.101881);
#define CTNODE_cmu_us_rms_dur_NO_1696 1698
DEF_STATIC_CONST_VAL_FLOAT(val_1022,0.404414);
#define CTNODE_cmu_us_rms_dur_NO_1693 1699
DEF_STATIC_CONST_VAL_FLOAT(val_1023,-0.193925);
#define CTNODE_cmu_us_rms_dur_NO_1692 1700
DEF_STATIC_CONST_VAL_FLOAT(val_1024,-0.230992);
#define CTNODE_cmu_us_rms_dur_NO_1700 1702
DEF_STATIC_CONST_VAL_FLOAT(val_1025,-0.070036);
#define CTNODE_cmu_us_rms_dur_NO_1681 1703
DEF_STATIC_CONST_VAL_FLOAT(val_1026,0.158691);
#define CTNODE_cmu_us_rms_dur_NO_1703 1705
DEF_STATIC_CONST_VAL_FLOAT(val_1027,-0.464075);
#define CTNODE_cmu_us_rms_dur_NO_1705 1707
DEF_STATIC_CONST_VAL_FLOAT(val_1028,-0.131755);
#define CTNODE_cmu_us_rms_dur_NO_1707 1709
DEF_STATIC_CONST_VAL_FLOAT(val_1029,-0.309296);
#define CTNODE_cmu_us_rms_dur_NO_1670 1710
DEF_STATIC_CONST_VAL_FLOAT(val_1030,0.338296);
#define CTNODE_cmu_us_rms_dur_NO_1713 1715
DEF_STATIC_CONST_VAL_FLOAT(val_1031,-0.206353);
#define CTNODE_cmu_us_rms_dur_NO_1712 1716
DEF_STATIC_CONST_VAL_FLOAT(val_1032,-0.481516);
#define CTNODE_cmu_us_rms_dur_NO_1716 1718
DEF_STATIC_CONST_VAL_FLOAT(val_1033,-0.296638);
#define CTNODE_cmu_us_rms_dur_NO_1718 1720
DEF_STATIC_CONST_VAL_FLOAT(val_1034,-0.224178);
#define CTNODE_cmu_us_rms_dur_NO_1720 1722
DEF_STATIC_CONST_VAL_FLOAT(val_1035,0.040045);
#define CTNODE_cmu_us_rms_dur_NO_1711 1723
DEF_STATIC_CONST_VAL_FLOAT(val_1036,-0.579318);
#define CTNODE_cmu_us_rms_dur_NO_1723 1725
DEF_STATIC_CONST_VAL_FLOAT(val_1037,-0.473028);
#define CTNODE_cmu_us_rms_dur_NO_1725 1727
DEF_STATIC_CONST_VAL_FLOAT(val_1038,-0.407308);
#define CTNODE_cmu_us_rms_dur_NO_1728 1730
DEF_STATIC_CONST_VAL_FLOAT(val_1039,-0.262907);
#define CTNODE_cmu_us_rms_dur_NO_1730 1732
DEF_STATIC_CONST_VAL_FLOAT(val_1040,-0.015019);
#define CTNODE_cmu_us_rms_dur_NO_1727 1733
DEF_STATIC_CONST_VAL_FLOAT(val_1041,-0.431743);
#define CTNODE_cmu_us_rms_dur_NO_1710 1734
DEF_STATIC_CONST_VAL_FLOAT(val_1042,0.427149);
#define CTNODE_cmu_us_rms_dur_NO_1734 1736
DEF_STATIC_CONST_VAL_FLOAT(val_1043,0.368033);
#define CTNODE_cmu_us_rms_dur_NO_1736 1738
DEF_STATIC_CONST_VAL_FLOAT(val_1044,-0.184220);
#define CTNODE_cmu_us_rms_dur_NO_1739 1741
DEF_STATIC_CONST_VAL_FLOAT(val_1045,-0.063834);
#define CTNODE_cmu_us_rms_dur_NO_1741 1743
DEF_STATIC_CONST_VAL_FLOAT(val_1046,0.488069);
#define CTNODE_cmu_us_rms_dur_NO_1738 1744
DEF_STATIC_CONST_VAL_FLOAT(val_1047,1.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_1048,0.304905);
#define CTNODE_cmu_us_rms_dur_NO_1745 1747
DEF_STATIC_CONST_VAL_FLOAT(val_1049,-0.182969);
#define CTNODE_cmu_us_rms_dur_NO_1744 1748
DEF_STATIC_CONST_VAL_FLOAT(val_1050,-0.309720);
#define CTNODE_cmu_us_rms_dur_NO_1749 1751
DEF_STATIC_CONST_VAL_FLOAT(val_1051,0.188145);
#define CTNODE_cmu_us_rms_dur_NO_1748 1752
DEF_STATIC_CONST_VAL_FLOAT(val_1052,0.011664);
#define CTNODE_cmu_us_rms_dur_NO_1752 1754
DEF_STATIC_CONST_VAL_FLOAT(val_1053,0.069917);
#define CTNODE_cmu_us_rms_dur_NO_1754 1756
DEF_STATIC_CONST_VAL_FLOAT(val_1054,-0.094403);
#define CTNODE_cmu_us_rms_dur_NO_1756 1758
DEF_STATIC_CONST_VAL_FLOAT(val_1055,-0.098742);
#define CTNODE_cmu_us_rms_dur_NO_1759 1761
DEF_STATIC_CONST_VAL_FLOAT(val_1056,-0.585880);
#define CTNODE_cmu_us_rms_dur_NO_1761 1763
DEF_STATIC_CONST_VAL_FLOAT(val_1057,-0.238065);
#define CTNODE_cmu_us_rms_dur_NO_1758 1764
DEF_STATIC_CONST_VAL_FLOAT(val_1058,-0.538258);
#define CTNODE_cmu_us_rms_dur_NO_1764 1766
DEF_STATIC_CONST_VAL_FLOAT(val_1059,-0.727905);
#define CTNODE_cmu_us_rms_dur_NO_1669 1767
DEF_STATIC_CONST_VAL_STRING(val_1060,"ow");
DEF_STATIC_CONST_VAL_FLOAT(val_1061,0.227978);
#define CTNODE_cmu_us_rms_dur_NO_1767 1769
DEF_STATIC_CONST_VAL_FLOAT(val_1062,-0.324058);
#define CTNODE_cmu_us_rms_dur_NO_1770 1772
DEF_STATIC_CONST_VAL_FLOAT(val_1063,-0.476640);
#define CTNODE_cmu_us_rms_dur_NO_1772 1774
DEF_STATIC_CONST_VAL_FLOAT(val_1064,-0.635983);
#define CTNODE_cmu_us_rms_dur_NO_1769 1775
DEF_STATIC_CONST_VAL_STRING(val_1065,"r_146");
DEF_STATIC_CONST_VAL_FLOAT(val_1066,-0.229532);
#define CTNODE_cmu_us_rms_dur_NO_1776 1778
DEF_STATIC_CONST_VAL_FLOAT(val_1067,-0.525847);
#define CTNODE_cmu_us_rms_dur_NO_1778 1780
DEF_STATIC_CONST_VAL_FLOAT(val_1068,-0.197443);
#define CTNODE_cmu_us_rms_dur_NO_1780 1782
DEF_STATIC_CONST_VAL_FLOAT(val_1069,-0.608164);
#define CTNODE_cmu_us_rms_dur_NO_1782 1784
DEF_STATIC_CONST_VAL_FLOAT(val_1070,-0.351159);
#define CTNODE_cmu_us_rms_dur_NO_1775 1785
DEF_STATIC_CONST_VAL_FLOAT(val_1071,0.221886);
#define CTNODE_cmu_us_rms_dur_NO_1785 1787
DEF_STATIC_CONST_VAL_FLOAT(val_1072,-0.523862);
#define CTNODE_cmu_us_rms_dur_NO_1788 1790
DEF_STATIC_CONST_VAL_FLOAT(val_1073,-0.340845);
#define CTNODE_cmu_us_rms_dur_NO_1787 1791
DEF_STATIC_CONST_VAL_FLOAT(val_1074,-0.559090);
#define CTNODE_cmu_us_rms_dur_NO_1793 1795
DEF_STATIC_CONST_VAL_FLOAT(val_1075,-0.258999);
#define CTNODE_cmu_us_rms_dur_NO_1792 1796
DEF_STATIC_CONST_VAL_FLOAT(val_1076,-0.130230);
#define CTNODE_cmu_us_rms_dur_NO_1791 1797
DEF_STATIC_CONST_VAL_FLOAT(val_1077,-0.394531);
#define CTNODE_cmu_us_rms_dur_NO_1798 1800
DEF_STATIC_CONST_VAL_FLOAT(val_1078,-0.470442);
#define CTNODE_cmu_us_rms_dur_NO_1801 1803
DEF_STATIC_CONST_VAL_FLOAT(val_1079,-0.031488);
#define CTNODE_cmu_us_rms_dur_NO_1800 1804
DEF_STATIC_CONST_VAL_FLOAT(val_1080,0.462935);
#define CTNODE_cmu_us_rms_dur_NO_1805 1807
DEF_STATIC_CONST_VAL_FLOAT(val_1081,0.010646);
#define CTNODE_cmu_us_rms_dur_NO_1804 1808
DEF_STATIC_CONST_VAL_FLOAT(val_1082,-0.187795);
#define CTNODE_cmu_us_rms_dur_NO_1797 1809
DEF_STATIC_CONST_VAL_FLOAT(val_1083,-0.448270);
#define CTNODE_cmu_us_rms_dur_NO_1810 1812
DEF_STATIC_CONST_VAL_FLOAT(val_1084,-0.278204);
#define CTNODE_cmu_us_rms_dur_NO_1813 1815
DEF_STATIC_CONST_VAL_FLOAT(val_1085,-0.184297);
#define CTNODE_cmu_us_rms_dur_NO_1812 1816
DEF_STATIC_CONST_VAL_FLOAT(val_1086,0.050949);
#define CTNODE_cmu_us_rms_dur_NO_1809 1817
DEF_STATIC_CONST_VAL_FLOAT(val_1087,-0.508645);
#define CTNODE_cmu_us_rms_dur_NO_0596 1818
DEF_STATIC_CONST_VAL_FLOAT(val_1088,2.628700);
#define CTNODE_cmu_us_rms_dur_NO_1820 1822
DEF_STATIC_CONST_VAL_FLOAT(val_1089,4.387630);
#define CTNODE_cmu_us_rms_dur_NO_1819 1823
DEF_STATIC_CONST_VAL_FLOAT(val_1090,6.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_1091,0.208192);
#define CTNODE_cmu_us_rms_dur_NO_1823 1825
DEF_STATIC_CONST_VAL_FLOAT(val_1092,-0.077128);
#define CTNODE_cmu_us_rms_dur_NO_1818 1826
DEF_STATIC_CONST_VAL_FLOAT(val_1093,0.539159);
#define CTNODE_cmu_us_rms_dur_NO_1831 1833
DEF_STATIC_CONST_VAL_FLOAT(val_1094,0.021701);
#define CTNODE_cmu_us_rms_dur_NO_1830 1834
DEF_STATIC_CONST_VAL_FLOAT(val_1095,0.706359);
#define CTNODE_cmu_us_rms_dur_NO_1829 1835
DEF_STATIC_CONST_VAL_FLOAT(val_1096,0.728352);
#define CTNODE_cmu_us_rms_dur_NO_1835 1837
DEF_STATIC_CONST_VAL_FLOAT(val_1097,-0.183877);
#define CTNODE_cmu_us_rms_dur_NO_1838 1840
DEF_STATIC_CONST_VAL_FLOAT(val_1098,-0.469282);
#define CTNODE_cmu_us_rms_dur_NO_1837 1841
DEF_STATIC_CONST_VAL_FLOAT(val_1099,-0.269038);
#define CTNODE_cmu_us_rms_dur_NO_1843 1845
DEF_STATIC_CONST_VAL_FLOAT(val_1100,-0.452516);
#define CTNODE_cmu_us_rms_dur_NO_1842 1846
DEF_STATIC_CONST_VAL_FLOAT(val_1101,0.160789);
#define CTNODE_cmu_us_rms_dur_NO_1846 1848
DEF_STATIC_CONST_VAL_FLOAT(val_1102,0.047443);
#define CTNODE_cmu_us_rms_dur_NO_1848 1850
DEF_STATIC_CONST_VAL_FLOAT(val_1103,-0.327529);
#define CTNODE_cmu_us_rms_dur_NO_1841 1851
DEF_STATIC_CONST_VAL_FLOAT(val_1104,-0.335667);
#define CTNODE_cmu_us_rms_dur_NO_1851 1853
DEF_STATIC_CONST_VAL_FLOAT(val_1105,0.764344);
#define CTNODE_cmu_us_rms_dur_NO_1853 1855
DEF_STATIC_CONST_VAL_FLOAT(val_1106,0.266855);
#define CTNODE_cmu_us_rms_dur_NO_1858 1860
DEF_STATIC_CONST_VAL_FLOAT(val_1107,-0.504541);
#define CTNODE_cmu_us_rms_dur_NO_1860 1862
DEF_STATIC_CONST_VAL_FLOAT(val_1108,-0.232515);
#define CTNODE_cmu_us_rms_dur_NO_1857 1863
DEF_STATIC_CONST_VAL_FLOAT(val_1109,0.072447);
#define CTNODE_cmu_us_rms_dur_NO_1864 1866
DEF_STATIC_CONST_VAL_FLOAT(val_1110,-0.179663);
#define CTNODE_cmu_us_rms_dur_NO_1863 1867
DEF_STATIC_CONST_VAL_FLOAT(val_1111,3.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_1112,0.654439);
#define CTNODE_cmu_us_rms_dur_NO_1869 1871
DEF_STATIC_CONST_VAL_FLOAT(val_1113,0.330730);
#define CTNODE_cmu_us_rms_dur_NO_1871 1873
DEF_STATIC_CONST_VAL_FLOAT(val_1114,0.112682);
#define CTNODE_cmu_us_rms_dur_NO_1868 1874
DEF_STATIC_CONST_VAL_FLOAT(val_1115,0.486442);
#define CTNODE_cmu_us_rms_dur_NO_1874 1876
DEF_STATIC_CONST_VAL_FLOAT(val_1116,-0.176416);
#define CTNODE_cmu_us_rms_dur_NO_1876 1878
DEF_STATIC_CONST_VAL_FLOAT(val_1117,0.279573);
#define CTNODE_cmu_us_rms_dur_NO_1878 1880
DEF_STATIC_CONST_VAL_FLOAT(val_1118,-0.066551);
#define CTNODE_cmu_us_rms_dur_NO_1867 1881
DEF_STATIC_CONST_VAL_FLOAT(val_1119,0.632478);
#define CTNODE_cmu_us_rms_dur_NO_1856 1882
DEF_STATIC_CONST_VAL_FLOAT(val_1120,0.355233);
#define CTNODE_cmu_us_rms_dur_NO_1882 1884
DEF_STATIC_CONST_VAL_FLOAT(val_1121,0.717424);
#define CTNODE_cmu_us_rms_dur_NO_1855 1885
DEF_STATIC_CONST_VAL_FLOAT(val_1122,-0.408346);
#define CTNODE_cmu_us_rms_dur_NO_1885 1887
DEF_STATIC_CONST_VAL_FLOAT(val_1123,-0.121809);
#define CTNODE_cmu_us_rms_dur_NO_1889 1891
DEF_STATIC_CONST_VAL_FLOAT(val_1124,0.202780);
#define CTNODE_cmu_us_rms_dur_NO_1888 1892
DEF_STATIC_CONST_VAL_FLOAT(val_1125,-0.217020);
#define CTNODE_cmu_us_rms_dur_NO_1887 1893
DEF_STATIC_CONST_VAL_FLOAT(val_1126,0.386741);
#define CTNODE_cmu_us_rms_dur_NO_1828 1894
DEF_STATIC_CONST_VAL_FLOAT(val_1127,0.059268);
#define CTNODE_cmu_us_rms_dur_NO_1895 1897
DEF_STATIC_CONST_VAL_FLOAT(val_1128,-0.137750);
#define CTNODE_cmu_us_rms_dur_NO_1897 1899
DEF_STATIC_CONST_VAL_FLOAT(val_1129,-0.492908);
#define CTNODE_cmu_us_rms_dur_NO_1900 1902
DEF_STATIC_CONST_VAL_FLOAT(val_1130,-0.316582);
#define CTNODE_cmu_us_rms_dur_NO_1902 1904
DEF_STATIC_CONST_VAL_FLOAT(val_1131,-0.094958);
#define CTNODE_cmu_us_rms_dur_NO_1899 1905
DEF_STATIC_CONST_VAL_FLOAT(val_1132,-0.622832);
#define CTNODE_cmu_us_rms_dur_NO_1894 1906
DEF_STATIC_CONST_VAL_FLOAT(val_1133,-0.214697);
#define CTNODE_cmu_us_rms_dur_NO_1907 1909
DEF_STATIC_CONST_VAL_FLOAT(val_1134,0.032880);
#define CTNODE_cmu_us_rms_dur_NO_1906 1910
DEF_STATIC_CONST_VAL_FLOAT(val_1135,0.290804);
#define CTNODE_cmu_us_rms_dur_NO_1827 1911
DEF_STATIC_CONST_VAL_FLOAT(val_1136,-0.864752);
#define CTNODE_cmu_us_rms_dur_NO_1912 1914
DEF_STATIC_CONST_VAL_FLOAT(val_1137,0.052843);
#define CTNODE_cmu_us_rms_dur_NO_1915 1917
DEF_STATIC_CONST_VAL_FLOAT(val_1138,-0.222385);
#define CTNODE_cmu_us_rms_dur_NO_1914 1918
DEF_STATIC_CONST_VAL_FLOAT(val_1139,-0.541890);
#define CTNODE_cmu_us_rms_dur_NO_1911 1919
DEF_STATIC_CONST_VAL_FLOAT(val_1140,-0.628124);
#define CTNODE_cmu_us_rms_dur_NO_1922 1924
DEF_STATIC_CONST_VAL_FLOAT(val_1141,-0.550848);
#define CTNODE_cmu_us_rms_dur_NO_1924 1926
DEF_STATIC_CONST_VAL_FLOAT(val_1142,-0.355593);
#define CTNODE_cmu_us_rms_dur_NO_1921 1927
DEF_STATIC_CONST_VAL_FLOAT(val_1143,-0.313307);
#define CTNODE_cmu_us_rms_dur_NO_1920 1928
DEF_STATIC_CONST_VAL_FLOAT(val_1144,-0.117949);
#define CTNODE_cmu_us_rms_dur_NO_1919 1929
DEF_STATIC_CONST_VAL_FLOAT(val_1145,0.303991);
#define CTNODE_cmu_us_rms_dur_NO_1932 1934
DEF_STATIC_CONST_VAL_FLOAT(val_1146,-0.499651);
#define CTNODE_cmu_us_rms_dur_NO_1935 1937
DEF_STATIC_CONST_VAL_FLOAT(val_1147,-0.255614);
#define CTNODE_cmu_us_rms_dur_NO_1934 1938
DEF_STATIC_CONST_VAL_FLOAT(val_1148,0.244452);
#define CTNODE_cmu_us_rms_dur_NO_1938 1940
DEF_STATIC_CONST_VAL_FLOAT(val_1149,0.028984);
#define CTNODE_cmu_us_rms_dur_NO_1940 1942
DEF_STATIC_CONST_VAL_FLOAT(val_1150,-0.273814);
#define CTNODE_cmu_us_rms_dur_NO_1931 1943
DEF_STATIC_CONST_VAL_FLOAT(val_1151,0.398732);
#define CTNODE_cmu_us_rms_dur_NO_1930 1944
DEF_STATIC_CONST_VAL_FLOAT(val_1152,0.237432);
#define CTNODE_cmu_us_rms_dur_NO_1944 1946
DEF_STATIC_CONST_VAL_FLOAT(val_1153,-0.744894);
#define CTNODE_cmu_us_rms_dur_NO_1947 1949
DEF_STATIC_CONST_VAL_FLOAT(val_1154,-0.182909);
#define CTNODE_cmu_us_rms_dur_NO_1949 1951
DEF_STATIC_CONST_VAL_FLOAT(val_1155,-0.574389);
#define CTNODE_cmu_us_rms_dur_NO_1946 1952
DEF_STATIC_CONST_VAL_FLOAT(val_1156,-0.179060);
#define CTNODE_cmu_us_rms_dur_NO_1954 1956
DEF_STATIC_CONST_VAL_FLOAT(val_1157,-0.482871);
#define CTNODE_cmu_us_rms_dur_NO_1953 1957
DEF_STATIC_CONST_VAL_FLOAT(val_1158,-0.384153);
#define CTNODE_cmu_us_rms_dur_NO_1957 1959
DEF_STATIC_CONST_VAL_FLOAT(val_1159,0.432390);
#define CTNODE_cmu_us_rms_dur_NO_1960 1962
DEF_STATIC_CONST_VAL_FLOAT(val_1160,-0.281426);
#define CTNODE_cmu_us_rms_dur_NO_1963 1965
DEF_STATIC_CONST_VAL_FLOAT(val_1161,0.021791);
#define CTNODE_cmu_us_rms_dur_NO_1962 1966
DEF_STATIC_CONST_VAL_FLOAT(val_1162,0.194337);
#define CTNODE_cmu_us_rms_dur_NO_1959 1967
DEF_STATIC_CONST_VAL_FLOAT(val_1163,-0.315251);
#define CTNODE_cmu_us_rms_dur_NO_1952 1968
DEF_STATIC_CONST_VAL_FLOAT(val_1164,-0.577475);
#define CTNODE_cmu_us_rms_dur_NO_1970 1972
DEF_STATIC_CONST_VAL_FLOAT(val_1165,-0.355953);
#define CTNODE_cmu_us_rms_dur_NO_1972 1974
DEF_STATIC_CONST_VAL_FLOAT(val_1166,-0.080726);
#define CTNODE_cmu_us_rms_dur_NO_1969 1975
DEF_STATIC_CONST_VAL_FLOAT(val_1167,-0.699958);
#define CTNODE_cmu_us_rms_dur_NO_1968 1976
DEF_STATIC_CONST_VAL_FLOAT(val_1168,-0.517532);
#define CTNODE_cmu_us_rms_dur_NO_1976 1978
DEF_STATIC_CONST_VAL_FLOAT(val_1169,0.117712);
#define CTNODE_cmu_us_rms_dur_NO_1978 1980
DEF_STATIC_CONST_VAL_FLOAT(val_1170,0.046371);
#define CTNODE_cmu_us_rms_dur_NO_1980 1982
DEF_STATIC_CONST_VAL_FLOAT(val_1171,-0.475704);
#define CTNODE_cmu_us_rms_dur_NO_1982 1984
DEF_STATIC_CONST_VAL_FLOAT(val_1172,-0.477770);
#define CTNODE_cmu_us_rms_dur_NO_1985 1987
DEF_STATIC_CONST_VAL_FLOAT(val_1173,-0.317472);
#define CTNODE_cmu_us_rms_dur_NO_1984 1988
DEF_STATIC_CONST_VAL_FLOAT(val_1174,-0.423105);
#define CTNODE_cmu_us_rms_dur_NO_1988 1990
DEF_STATIC_CONST_VAL_FLOAT(val_1175,-0.358310);
#define CTNODE_cmu_us_rms_dur_NO_1991 1993
DEF_STATIC_CONST_VAL_FLOAT(val_1176,-0.025979);
#define CTNODE_cmu_us_rms_dur_NO_1990 1994
DEF_STATIC_CONST_VAL_FLOAT(val_1177,0.063818);
#define CTNODE_cmu_us_rms_dur_NO_1929 1995
DEF_STATIC_CONST_VAL_FLOAT(val_1178,-0.429952);
#define CTNODE_cmu_us_rms_dur_NO_1996 1998
DEF_STATIC_CONST_VAL_STRING(val_1179,"v_186");
DEF_STATIC_CONST_VAL_FLOAT(val_1180,0.125860);
#define CTNODE_cmu_us_rms_dur_NO_1998 2000
DEF_STATIC_CONST_VAL_FLOAT(val_1181,5.100000);
DEF_STATIC_CONST_VAL_FLOAT(val_1182,-0.391018);
#define CTNODE_cmu_us_rms_dur_NO_2000 2002
DEF_STATIC_CONST_VAL_FLOAT(val_1183,-0.339223);
#define CTNODE_cmu_us_rms_dur_NO_2002 2004
DEF_STATIC_CONST_VAL_FLOAT(val_1184,0.085865);
#define CTNODE_cmu_us_rms_dur_NO_1995 2005
DEF_STATIC_CONST_VAL_FLOAT(val_1185,-0.325985);
#define CTNODE_cmu_us_rms_dur_NO_2007 2009
DEF_STATIC_CONST_VAL_FLOAT(val_1186,-0.217650);
#define CTNODE_cmu_us_rms_dur_NO_2009 2011
DEF_STATIC_CONST_VAL_FLOAT(val_1187,0.277557);
#define CTNODE_cmu_us_rms_dur_NO_2006 2012
DEF_STATIC_CONST_VAL_FLOAT(val_1188,-0.383293);
#define CTNODE_cmu_us_rms_dur_NO_2005 2013
DEF_STATIC_CONST_VAL_FLOAT(val_1189,0.653707);
#define CTNODE_cmu_us_rms_dur_NO_2013 2015
DEF_STATIC_CONST_VAL_FLOAT(val_1190,5.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_1191,-0.532639);
#define CTNODE_cmu_us_rms_dur_NO_2016 2018
DEF_STATIC_CONST_VAL_FLOAT(val_1192,0.049716);
#define CTNODE_cmu_us_rms_dur_NO_2015 2019
DEF_STATIC_CONST_VAL_FLOAT(val_1193,-0.359580);
#define CTNODE_cmu_us_rms_dur_NO_2020 2022
DEF_STATIC_CONST_VAL_FLOAT(val_1194,0.117754);
#define CTNODE_cmu_us_rms_dur_NO_2019 2023
DEF_STATIC_CONST_VAL_FLOAT(val_1195,0.399988);
#define CTNODE_cmu_us_rms_dur_NO_2025 2027
DEF_STATIC_CONST_VAL_FLOAT(val_1196,0.874376);
#define CTNODE_cmu_us_rms_dur_NO_2024 2028
DEF_STATIC_CONST_VAL_FLOAT(val_1197,0.611580);
#define CTNODE_cmu_us_rms_dur_NO_2028 2030
DEF_STATIC_CONST_VAL_FLOAT(val_1198,-0.137344);
#define CTNODE_cmu_us_rms_dur_NO_2031 2033
DEF_STATIC_CONST_VAL_FLOAT(val_1199,0.556271);
#define CTNODE_cmu_us_rms_dur_NO_2030 2034
DEF_STATIC_CONST_VAL_FLOAT(val_1200,0.029431);
#define CTNODE_cmu_us_rms_dur_NO_2034 2036
DEF_STATIC_CONST_VAL_FLOAT(val_1201,-0.326713);
#define CTNODE_cmu_us_rms_dur_NO_2023 2037
DEF_STATIC_CONST_VAL_FLOAT(val_1202,0.388527);
#define CTNODE_cmu_us_rms_dur_NO_2037 2039
DEF_STATIC_CONST_VAL_FLOAT(val_1203,0.152413);
#define CTNODE_cmu_us_rms_dur_NO_2039 2041
DEF_STATIC_CONST_VAL_FLOAT(val_1204,0.136242);
#define CTNODE_cmu_us_rms_dur_NO_2042 2044
DEF_STATIC_CONST_VAL_FLOAT(val_1205,-0.250108);
#define CTNODE_cmu_us_rms_dur_NO_2041 2045
DEF_STATIC_CONST_VAL_FLOAT(val_1206,-0.148299);
#define CTNODE_cmu_us_rms_dur_NO_2045 2047
DEF_STATIC_CONST_VAL_FLOAT(val_1207,-0.394894);
#define CTNODE_cmu_us_rms_dur_NO_1826 2048
DEF_STATIC_CONST_VAL_FLOAT(val_1208,1.350820);
#define CTNODE_cmu_us_rms_dur_NO_2050 2052
DEF_STATIC_CONST_VAL_FLOAT(val_1209,0.570309);
#define CTNODE_cmu_us_rms_dur_NO_2049 2053
DEF_STATIC_CONST_VAL_FLOAT(val_1210,-0.321856);
#define CTNODE_cmu_us_rms_dur_NO_2054 2056
DEF_STATIC_CONST_VAL_FLOAT(val_1211,-0.046686);
#define CTNODE_cmu_us_rms_dur_NO_2053 2057
DEF_STATIC_CONST_VAL_FLOAT(val_1212,1.221090);
#define CTNODE_cmu_us_rms_dur_NO_2058 2060
DEF_STATIC_CONST_VAL_FLOAT(val_1213,0.315785);
#define CTNODE_cmu_us_rms_dur_NO_2057 2061
DEF_STATIC_CONST_VAL_FLOAT(val_1214,-0.133001);
#define CTNODE_cmu_us_rms_dur_NO_2061 2063
DEF_STATIC_CONST_VAL_FLOAT(val_1215,0.268977);
#define CTNODE_cmu_us_rms_dur_NO_2048 2064
DEF_STATIC_CONST_VAL_FLOAT(val_1216,-0.513205);
#define CTNODE_cmu_us_rms_dur_NO_2065 2067
DEF_STATIC_CONST_VAL_FLOAT(val_1217,-0.340118);
#define CTNODE_cmu_us_rms_dur_NO_2064 2068
DEF_STATIC_CONST_VAL_FLOAT(val_1218,0.699766);
#define CTNODE_cmu_us_rms_dur_NO_2068 2070
DEF_STATIC_CONST_VAL_FLOAT(val_1219,-0.826511);
#define CTNODE_cmu_us_rms_dur_NO_2073 2075
DEF_STATIC_CONST_VAL_FLOAT(val_1220,-0.171192);
#define CTNODE_cmu_us_rms_dur_NO_2075 2077
DEF_STATIC_CONST_VAL_FLOAT(val_1221,-0.144902);
#define CTNODE_cmu_us_rms_dur_NO_2077 2079
DEF_STATIC_CONST_VAL_FLOAT(val_1222,0.047627);
#define CTNODE_cmu_us_rms_dur_NO_2072 2080
DEF_STATIC_CONST_VAL_FLOAT(val_1223,0.501620);
#define CTNODE_cmu_us_rms_dur_NO_2080 2082
DEF_STATIC_CONST_VAL_FLOAT(val_1224,-0.185516);
#define CTNODE_cmu_us_rms_dur_NO_2082 2084
DEF_STATIC_CONST_VAL_FLOAT(val_1225,0.370395);
#define CTNODE_cmu_us_rms_dur_NO_2084 2086
DEF_STATIC_CONST_VAL_FLOAT(val_1226,0.042479);
#define CTNODE_cmu_us_rms_dur_NO_2086 2088
DEF_STATIC_CONST_VAL_FLOAT(val_1227,0.063956);
#define CTNODE_cmu_us_rms_dur_NO_2088 2090
DEF_STATIC_CONST_VAL_FLOAT(val_1228,0.062308);
#define CTNODE_cmu_us_rms_dur_NO_2090 2092
DEF_STATIC_CONST_VAL_FLOAT(val_1229,0.526457);
#define CTNODE_cmu_us_rms_dur_NO_2071 2093
DEF_STATIC_CONST_VAL_FLOAT(val_1230,0.904896);
#define CTNODE_cmu_us_rms_dur_NO_2093 2095
DEF_STATIC_CONST_VAL_FLOAT(val_1231,0.787540);
#define CTNODE_cmu_us_rms_dur_NO_2095 2097
DEF_STATIC_CONST_VAL_FLOAT(val_1232,0.862688);
#define CTNODE_cmu_us_rms_dur_NO_2070 2098
DEF_STATIC_CONST_VAL_FLOAT(val_1233,1.219330);
#define CTNODE_cmu_us_rms_dur_NO_2099 2101
DEF_STATIC_CONST_VAL_FLOAT(val_1234,0.075482);
#define CTNODE_cmu_us_rms_dur_NO_2102 2104
DEF_STATIC_CONST_VAL_FLOAT(val_1235,0.672371);
#define CTNODE_cmu_us_rms_dur_NO_2101 2105
DEF_STATIC_CONST_VAL_FLOAT(val_1236,-0.227251);
#define CTNODE_cmu_us_rms_dur_NO_2098 2106
DEF_STATIC_CONST_VAL_STRING(val_1237,"iy_91");
DEF_STATIC_CONST_VAL_FLOAT(val_1238,0.841200);
#define CTNODE_cmu_us_rms_dur_NO_2108 2110
DEF_STATIC_CONST_VAL_FLOAT(val_1239,0.403254);
#define CTNODE_cmu_us_rms_dur_NO_2107 2111
DEF_STATIC_CONST_VAL_FLOAT(val_1240,0.077340);
#define CTNODE_cmu_us_rms_dur_NO_2106 2112
DEF_STATIC_CONST_VAL_FLOAT(val_1241,-0.389134);
#define CTNODE_cmu_us_rms_dur_NO_2114 2116
DEF_STATIC_CONST_VAL_FLOAT(val_1242,-0.150090);
#define CTNODE_cmu_us_rms_dur_NO_2116 2118
DEF_STATIC_CONST_VAL_FLOAT(val_1243,-0.042781);
#define CTNODE_cmu_us_rms_dur_NO_2113 2119
DEF_STATIC_CONST_VAL_FLOAT(val_1244,-0.581929);
#define CTNODE_cmu_us_rms_dur_NO_2112 2120
DEF_STATIC_CONST_VAL_FLOAT(val_1245,0.692072);
#define CTNODE_cmu_us_rms_dur_NO_2121 2123
DEF_STATIC_CONST_VAL_FLOAT(val_1246,0.085145);
#define CTNODE_cmu_us_rms_dur_NO_2123 2125
DEF_STATIC_CONST_VAL_FLOAT(val_1247,0.335549);
#define CTNODE_cmu_us_rms_dur_NO_2120 2126
DEF_STATIC_CONST_VAL_FLOAT(val_1248,0.807804);
#define CTNODE_cmu_us_rms_dur_NO_2128 2130
DEF_STATIC_CONST_VAL_FLOAT(val_1249,0.138433);
#define CTNODE_cmu_us_rms_dur_NO_2127 2131
DEF_STATIC_CONST_VAL_STRING(val_1250,"ih");
DEF_STATIC_CONST_VAL_FLOAT(val_1251,-0.255917);
#define CTNODE_cmu_us_rms_dur_NO_2132 2134
DEF_STATIC_CONST_VAL_FLOAT(val_1252,0.416856);
#define CTNODE_cmu_us_rms_dur_NO_2136 2138
DEF_STATIC_CONST_VAL_FLOAT(val_1253,-0.148218);
#define CTNODE_cmu_us_rms_dur_NO_2135 2139
DEF_STATIC_CONST_VAL_FLOAT(val_1254,0.101572);
#define CTNODE_cmu_us_rms_dur_NO_2139 2141
DEF_STATIC_CONST_VAL_FLOAT(val_1255,0.173860);
#define CTNODE_cmu_us_rms_dur_NO_2141 2143
DEF_STATIC_CONST_VAL_FLOAT(val_1256,0.415388);
#define CTNODE_cmu_us_rms_dur_NO_2143 2145
DEF_STATIC_CONST_VAL_FLOAT(val_1257,0.855102);
#define CTNODE_cmu_us_rms_dur_NO_2134 2146
DEF_STATIC_CONST_VAL_FLOAT(val_1258,-0.142985);
#define CTNODE_cmu_us_rms_dur_NO_2131 2147
DEF_STATIC_CONST_VAL_FLOAT(val_1259,0.453191);
#define CTNODE_cmu_us_rms_dur_NO_2148 2150
DEF_STATIC_CONST_VAL_FLOAT(val_1260,0.171221);
#define CTNODE_cmu_us_rms_dur_NO_2147 2151
DEF_STATIC_CONST_VAL_FLOAT(val_1261,-0.168932);
#define CTNODE_cmu_us_rms_dur_NO_2152 2154
DEF_STATIC_CONST_VAL_STRING(val_1262,"er_62");
DEF_STATIC_CONST_VAL_FLOAT(val_1263,-0.702981);
#define CTNODE_cmu_us_rms_dur_NO_2154 2156
DEF_STATIC_CONST_VAL_FLOAT(val_1264,-0.370741);
#define CTNODE_cmu_us_rms_dur_NO_2151 2157
DEF_STATIC_CONST_VAL_FLOAT(val_1265,0.075935);
#define CTNODE_cmu_us_rms_dur_NO_2159 2161
DEF_STATIC_CONST_VAL_FLOAT(val_1266,-0.311721);
#define CTNODE_cmu_us_rms_dur_NO_2158 2162
DEF_STATIC_CONST_VAL_FLOAT(val_1267,-0.511026);
#define CTNODE_cmu_us_rms_dur_NO_2157 2163
DEF_STATIC_CONST_VAL_FLOAT(val_1268,-0.387998);
#define CTNODE_cmu_us_rms_dur_NO_2164 2166
DEF_STATIC_CONST_VAL_FLOAT(val_1269,-0.273722);
#define CTNODE_cmu_us_rms_dur_NO_2166 2168
DEF_STATIC_CONST_VAL_FLOAT(val_1270,0.006162);
#define CTNODE_cmu_us_rms_dur_NO_2163 2169
DEF_STATIC_CONST_VAL_FLOAT(val_1271,0.645818);
#define CTNODE_cmu_us_rms_dur_NO_2171 2173
DEF_STATIC_CONST_VAL_FLOAT(val_1272,0.073773);
#define CTNODE_cmu_us_rms_dur_NO_2170 2174
DEF_STATIC_CONST_VAL_FLOAT(val_1273,0.405267);
#define CTNODE_cmu_us_rms_dur_NO_2174 2176
DEF_STATIC_CONST_VAL_FLOAT(val_1274,0.744081);
#define CTNODE_cmu_us_rms_dur_NO_2177 2179
DEF_STATIC_CONST_VAL_FLOAT(val_1275,0.388259);
#define CTNODE_cmu_us_rms_dur_NO_2179 2181
DEF_STATIC_CONST_VAL_FLOAT(val_1276,7.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_1277,-0.267562);
#define CTNODE_cmu_us_rms_dur_NO_2181 2183
DEF_STATIC_CONST_VAL_FLOAT(val_1278,0.016339);
#define CTNODE_cmu_us_rms_dur_NO_2176 2184
DEF_STATIC_CONST_VAL_FLOAT(val_1279,0.464757);
#define CTNODE_cmu_us_rms_dur_NO_2185 2187
DEF_STATIC_CONST_VAL_FLOAT(val_1280,-0.041844);
#define CTNODE_cmu_us_rms_dur_NO_2189 2191
DEF_STATIC_CONST_VAL_FLOAT(val_1281,0.143003);
#define CTNODE_cmu_us_rms_dur_NO_2188 2192
DEF_STATIC_CONST_VAL_FLOAT(val_1282,0.002010);
#define CTNODE_cmu_us_rms_dur_NO_2193 2195
DEF_STATIC_CONST_VAL_FLOAT(val_1283,-0.078813);
#define CTNODE_cmu_us_rms_dur_NO_2192 2196
DEF_STATIC_CONST_VAL_FLOAT(val_1284,-0.092122);
#define CTNODE_cmu_us_rms_dur_NO_2196 2198
DEF_STATIC_CONST_VAL_FLOAT(val_1285,-0.351939);
#define CTNODE_cmu_us_rms_dur_NO_2187 2199
DEF_STATIC_CONST_VAL_FLOAT(val_1286,0.125751);
#define CTNODE_cmu_us_rms_dur_NO_2200 2202
DEF_STATIC_CONST_VAL_FLOAT(val_1287,-0.116331);
#define CTNODE_cmu_us_rms_dur_NO_2199 2203
DEF_STATIC_CONST_VAL_FLOAT(val_1288,0.223328);
#define CTNODE_cmu_us_rms_dur_NO_2184 2204
DEF_STATIC_CONST_VAL_FLOAT(val_1289,-0.528374);
#define CTNODE_cmu_us_rms_dur_NO_2204 2206
DEF_STATIC_CONST_VAL_FLOAT(val_1290,0.335409);
#define CTNODE_cmu_us_rms_dur_NO_2207 2209
DEF_STATIC_CONST_VAL_FLOAT(val_1291,-0.089796);
#define CTNODE_cmu_us_rms_dur_NO_2206 2210
DEF_STATIC_CONST_VAL_FLOAT(val_1292,0.249968);
#define CTNODE_cmu_us_rms_dur_NO_2210 2212
DEF_STATIC_CONST_VAL_FLOAT(val_1293,-0.313893);
#define CTNODE_cmu_us_rms_dur_NO_2213 2215
DEF_STATIC_CONST_VAL_FLOAT(val_1294,-0.217600);
#define CTNODE_cmu_us_rms_dur_NO_2217 2219
DEF_STATIC_CONST_VAL_FLOAT(val_1295,-0.430793);
#define CTNODE_cmu_us_rms_dur_NO_2216 2220
DEF_STATIC_CONST_VAL_FLOAT(val_1296,-0.028581);
#define CTNODE_cmu_us_rms_dur_NO_2215 2221
DEF_STATIC_CONST_VAL_FLOAT(val_1297,-0.225753);
#define CTNODE_cmu_us_rms_dur_NO_2221 2223
DEF_STATIC_CONST_VAL_FLOAT(val_1298,0.056033);
#define CTNODE_cmu_us_rms_dur_NO_2212 2224
DEF_STATIC_CONST_VAL_FLOAT(val_1299,0.002505);
#define CTNODE_cmu_us_rms_dur_NO_2169 2225
DEF_STATIC_CONST_VAL_FLOAT(val_1300,-0.209265);
#define CTNODE_cmu_us_rms_dur_NO_2228 2230
DEF_STATIC_CONST_VAL_FLOAT(val_1301,0.060333);
#define CTNODE_cmu_us_rms_dur_NO_2227 2231
DEF_STATIC_CONST_VAL_FLOAT(val_1302,-0.383805);
#define CTNODE_cmu_us_rms_dur_NO_2226 2232
DEF_STATIC_CONST_VAL_FLOAT(val_1303,0.262687);
#define CTNODE_cmu_us_rms_dur_NO_2225 2233
DEF_STATIC_CONST_VAL_FLOAT(val_1304,-0.110128);
#define CTNODE_cmu_us_rms_dur_NO_2233 2235
DEF_STATIC_CONST_VAL_FLOAT(val_1305,-0.645905);
#define CTNODE_cmu_us_rms_dur_NO_2235 2237
DEF_STATIC_CONST_VAL_FLOAT(val_1306,-0.327443);
#define CTNODE_cmu_us_rms_dur_NO_2126 2238
DEF_STATIC_CONST_VAL_FLOAT(val_1307,-0.439796);
#define CTNODE_cmu_us_rms_dur_NO_2241 2243
DEF_STATIC_CONST_VAL_FLOAT(val_1308,0.046920);
#define CTNODE_cmu_us_rms_dur_NO_2243 2245
DEF_STATIC_CONST_VAL_FLOAT(val_1309,-0.242874);
#define CTNODE_cmu_us_rms_dur_NO_2240 2246
DEF_STATIC_CONST_VAL_FLOAT(val_1310,-0.080699);
#define CTNODE_cmu_us_rms_dur_NO_2246 2248
DEF_STATIC_CONST_VAL_FLOAT(val_1311,0.430657);
#define CTNODE_cmu_us_rms_dur_NO_2239 2249
DEF_STATIC_CONST_VAL_FLOAT(val_1312,7.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_1313,-0.168625);
#define CTNODE_cmu_us_rms_dur_NO_2251 2253
DEF_STATIC_CONST_VAL_FLOAT(val_1314,-0.387072);
#define CTNODE_cmu_us_rms_dur_NO_2250 2254
DEF_STATIC_CONST_VAL_FLOAT(val_1315,0.311002);
#define CTNODE_cmu_us_rms_dur_NO_2254 2256
DEF_STATIC_CONST_VAL_FLOAT(val_1316,-0.128733);
#define CTNODE_cmu_us_rms_dur_NO_2249 2257
DEF_STATIC_CONST_VAL_FLOAT(val_1317,1.019960);
#define CTNODE_cmu_us_rms_dur_NO_2258 2260
DEF_STATIC_CONST_VAL_FLOAT(val_1318,0.005028);
#define CTNODE_cmu_us_rms_dur_NO_2260 2262
DEF_STATIC_CONST_VAL_FLOAT(val_1319,0.501118);
#define CTNODE_cmu_us_rms_dur_NO_2257 2263
DEF_STATIC_CONST_VAL_FLOAT(val_1320,0.748510);
#define CTNODE_cmu_us_rms_dur_NO_2264 2266
DEF_STATIC_CONST_VAL_FLOAT(val_1321,0.173364);
#define CTNODE_cmu_us_rms_dur_NO_2267 2269
DEF_STATIC_CONST_VAL_FLOAT(val_1322,0.471730);
#define CTNODE_cmu_us_rms_dur_NO_2266 2270
DEF_STATIC_CONST_VAL_FLOAT(val_1323,-0.139351);
#define CTNODE_cmu_us_rms_dur_NO_2263 2271
DEF_STATIC_CONST_VAL_FLOAT(val_1324,0.567645);
#define CTNODE_cmu_us_rms_dur_NO_2272 2274
DEF_STATIC_CONST_VAL_FLOAT(val_1325,-0.010858);
#define CTNODE_cmu_us_rms_dur_NO_2271 2275
DEF_STATIC_CONST_VAL_FLOAT(val_1326,-0.356539);
#define CTNODE_cmu_us_rms_dur_NO_2275 2277
DEF_STATIC_CONST_VAL_FLOAT(val_1327,-0.048193);
#define CTNODE_cmu_us_rms_dur_NO_2238 2278
DEF_STATIC_CONST_VAL_FLOAT(val_1328,0.896730);
#define CTNODE_cmu_us_rms_dur_NO_2278 2280
DEF_STATIC_CONST_VAL_FLOAT(val_1329,0.023379);
#define CTNODE_cmu_us_rms_dur_NO_0245 2281
DEF_STATIC_CONST_VAL_FLOAT(val_1330,1.935660);
#define CTNODE_cmu_us_rms_dur_NO_2283 2285
DEF_STATIC_CONST_VAL_FLOAT(val_1331,1.666940);
#define CTNODE_cmu_us_rms_dur_NO_2286 2288
DEF_STATIC_CONST_VAL_FLOAT(val_1332,1.354330);
#define CTNODE_cmu_us_rms_dur_NO_2285 2289
DEF_STATIC_CONST_VAL_FLOAT(val_1333,-0.247153);
#define CTNODE_cmu_us_rms_dur_NO_2290 2292
DEF_STATIC_CONST_VAL_FLOAT(val_1334,-0.698624);
#define CTNODE_cmu_us_rms_dur_NO_2289 2293
DEF_STATIC_CONST_VAL_FLOAT(val_1335,1.556960);
#define CTNODE_cmu_us_rms_dur_NO_2294 2296
DEF_STATIC_CONST_VAL_FLOAT(val_1336,0.498329);
#define CTNODE_cmu_us_rms_dur_NO_2293 2297
DEF_STATIC_CONST_VAL_FLOAT(val_1337,0.684830);
#define CTNODE_cmu_us_rms_dur_NO_2299 2301
DEF_STATIC_CONST_VAL_FLOAT(val_1338,0.082796);
#define CTNODE_cmu_us_rms_dur_NO_2303 2305
DEF_STATIC_CONST_VAL_FLOAT(val_1339,-0.219632);
#define CTNODE_cmu_us_rms_dur_NO_2302 2306
DEF_STATIC_CONST_VAL_FLOAT(val_1340,0.370028);
#define CTNODE_cmu_us_rms_dur_NO_2301 2307
DEF_STATIC_CONST_VAL_FLOAT(val_1341,-0.635169);
#define CTNODE_cmu_us_rms_dur_NO_2298 2308
DEF_STATIC_CONST_VAL_FLOAT(val_1342,1.112130);
#define CTNODE_cmu_us_rms_dur_NO_2308 2310
DEF_STATIC_CONST_VAL_STRING(val_1343,"hh_82");
DEF_STATIC_CONST_VAL_FLOAT(val_1344,1.030370);
#define CTNODE_cmu_us_rms_dur_NO_2311 2313
DEF_STATIC_CONST_VAL_FLOAT(val_1345,14.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_1346,0.446828);
#define CTNODE_cmu_us_rms_dur_NO_2313 2315
DEF_STATIC_CONST_VAL_FLOAT(val_1347,0.653778);
#define CTNODE_cmu_us_rms_dur_NO_2310 2316
DEF_STATIC_CONST_VAL_FLOAT(val_1348,0.819922);
#define CTNODE_cmu_us_rms_dur_NO_2317 2319
DEF_STATIC_CONST_VAL_FLOAT(val_1349,0.026159);
#define CTNODE_cmu_us_rms_dur_NO_2320 2322
DEF_STATIC_CONST_VAL_FLOAT(val_1350,0.480135);
#define CTNODE_cmu_us_rms_dur_NO_2323 2325
DEF_STATIC_CONST_VAL_FLOAT(val_1351,0.037359);
#define CTNODE_cmu_us_rms_dur_NO_2325 2327
DEF_STATIC_CONST_VAL_FLOAT(val_1352,0.405228);
#define CTNODE_cmu_us_rms_dur_NO_2322 2328
DEF_STATIC_CONST_VAL_FLOAT(val_1353,0.086180);
#define CTNODE_cmu_us_rms_dur_NO_2319 2329
DEF_STATIC_CONST_VAL_FLOAT(val_1354,0.862262);
#define CTNODE_cmu_us_rms_dur_NO_2329 2331
DEF_STATIC_CONST_VAL_FLOAT(val_1355,0.315754);
#define CTNODE_cmu_us_rms_dur_NO_2316 2332
DEF_STATIC_CONST_VAL_FLOAT(val_1356,-0.118462);
#define CTNODE_cmu_us_rms_dur_NO_2297 2333
DEF_STATIC_CONST_VAL_FLOAT(val_1357,-0.413074);
#define CTNODE_cmu_us_rms_dur_NO_2282 2334
DEF_STATIC_CONST_VAL_FLOAT(val_1358,0.287315);
#define CTNODE_cmu_us_rms_dur_NO_2337 2339
DEF_STATIC_CONST_VAL_FLOAT(val_1359,-0.359987);
#define CTNODE_cmu_us_rms_dur_NO_2340 2342
DEF_STATIC_CONST_VAL_FLOAT(val_1360,-0.376999);
#define CTNODE_cmu_us_rms_dur_NO_2339 2343
DEF_STATIC_CONST_VAL_FLOAT(val_1361,0.218442);
#define CTNODE_cmu_us_rms_dur_NO_2343 2345
DEF_STATIC_CONST_VAL_FLOAT(val_1362,-0.428238);
#define CTNODE_cmu_us_rms_dur_NO_2346 2348
DEF_STATIC_CONST_VAL_FLOAT(val_1363,-0.021596);
#define CTNODE_cmu_us_rms_dur_NO_2345 2349
DEF_STATIC_CONST_VAL_FLOAT(val_1364,0.073656);
#define CTNODE_cmu_us_rms_dur_NO_2336 2350
DEF_STATIC_CONST_VAL_FLOAT(val_1365,-0.443015);
#define CTNODE_cmu_us_rms_dur_NO_2351 2353
DEF_STATIC_CONST_VAL_FLOAT(val_1366,-0.156333);
#define CTNODE_cmu_us_rms_dur_NO_2350 2354
DEF_STATIC_CONST_VAL_FLOAT(val_1367,-0.007043);
#define CTNODE_cmu_us_rms_dur_NO_2355 2357
DEF_STATIC_CONST_VAL_FLOAT(val_1368,0.858148);
#define CTNODE_cmu_us_rms_dur_NO_2359 2361
DEF_STATIC_CONST_VAL_FLOAT(val_1369,1.825310);
#define CTNODE_cmu_us_rms_dur_NO_2361 2363
DEF_STATIC_CONST_VAL_FLOAT(val_1370,1.270570);
#define CTNODE_cmu_us_rms_dur_NO_2358 2364
DEF_STATIC_CONST_VAL_FLOAT(val_1371,0.770972);
#define CTNODE_cmu_us_rms_dur_NO_2364 2366
DEF_STATIC_CONST_VAL_FLOAT(val_1372,0.262786);
#define CTNODE_cmu_us_rms_dur_NO_2357 2367
DEF_STATIC_CONST_VAL_FLOAT(val_1373,0.452144);
#define CTNODE_cmu_us_rms_dur_NO_2368 2370
DEF_STATIC_CONST_VAL_FLOAT(val_1374,0.022446);
#define CTNODE_cmu_us_rms_dur_NO_2367 2371
DEF_STATIC_CONST_VAL_FLOAT(val_1375,0.764966);
#define CTNODE_cmu_us_rms_dur_NO_2354 2372
DEF_STATIC_CONST_VAL_FLOAT(val_1376,-0.420572);
#define CTNODE_cmu_us_rms_dur_NO_2373 2375
DEF_STATIC_CONST_VAL_FLOAT(val_1377,0.161374);
#define CTNODE_cmu_us_rms_dur_NO_2375 2377
DEF_STATIC_CONST_VAL_FLOAT(val_1378,-0.134619);
#define CTNODE_cmu_us_rms_dur_NO_2372 2378
DEF_STATIC_CONST_VAL_FLOAT(val_1379,-0.158214);
#define CTNODE_cmu_us_rms_dur_NO_2380 2382
DEF_STATIC_CONST_VAL_FLOAT(val_1380,-0.586807);
#define CTNODE_cmu_us_rms_dur_NO_2379 2383
DEF_STATIC_CONST_VAL_FLOAT(val_1381,0.784368);
#define CTNODE_cmu_us_rms_dur_NO_2384 2386
DEF_STATIC_CONST_VAL_FLOAT(val_1382,1.205080);
#define CTNODE_cmu_us_rms_dur_NO_2383 2387
DEF_STATIC_CONST_VAL_STRING(val_1383,"sh_158");
DEF_STATIC_CONST_VAL_FLOAT(val_1384,0.904678);
#define CTNODE_cmu_us_rms_dur_NO_2387 2389
DEF_STATIC_CONST_VAL_FLOAT(val_1385,0.819351);
#define CTNODE_cmu_us_rms_dur_NO_2389 2391
DEF_STATIC_CONST_VAL_FLOAT(val_1386,-0.050982);
#define CTNODE_cmu_us_rms_dur_NO_2392 2394
DEF_STATIC_CONST_VAL_FLOAT(val_1387,-0.455854);
#define CTNODE_cmu_us_rms_dur_NO_2391 2395
DEF_STATIC_CONST_VAL_FLOAT(val_1388,11.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_1389,-0.263696);
#define CTNODE_cmu_us_rms_dur_NO_2398 2400
DEF_STATIC_CONST_VAL_FLOAT(val_1390,-0.326513);
#define CTNODE_cmu_us_rms_dur_NO_2397 2401
DEF_STATIC_CONST_VAL_FLOAT(val_1391,-0.151802);
#define CTNODE_cmu_us_rms_dur_NO_2396 2402
DEF_STATIC_CONST_VAL_FLOAT(val_1392,0.024030);
#define CTNODE_cmu_us_rms_dur_NO_2395 2403
DEF_STATIC_CONST_VAL_FLOAT(val_1393,0.879095);
#define CTNODE_cmu_us_rms_dur_NO_2403 2405
DEF_STATIC_CONST_VAL_FLOAT(val_1394,-0.159779);
#define CTNODE_cmu_us_rms_dur_NO_2405 2407
DEF_STATIC_CONST_VAL_STRING(val_1395,"sh");
DEF_STATIC_CONST_VAL_FLOAT(val_1396,-0.152287);
#define CTNODE_cmu_us_rms_dur_NO_2407 2409
DEF_STATIC_CONST_VAL_FLOAT(val_1397,0.077460);
#define CTNODE_cmu_us_rms_dur_NO_2411 2413
DEF_STATIC_CONST_VAL_FLOAT(val_1398,8.600000);
DEF_STATIC_CONST_VAL_FLOAT(val_1399,0.729940);
#define CTNODE_cmu_us_rms_dur_NO_2414 2416
DEF_STATIC_CONST_VAL_FLOAT(val_1400,0.368877);
#define CTNODE_cmu_us_rms_dur_NO_2413 2417
DEF_STATIC_CONST_VAL_FLOAT(val_1401,0.390942);
#define CTNODE_cmu_us_rms_dur_NO_2417 2419
DEF_STATIC_CONST_VAL_FLOAT(val_1402,0.145267);
#define CTNODE_cmu_us_rms_dur_NO_2410 2420
DEF_STATIC_CONST_VAL_FLOAT(val_1403,0.934150);
#define CTNODE_cmu_us_rms_dur_NO_2409 2421
DEF_STATIC_CONST_VAL_FLOAT(val_1404,-0.149907);
#define CTNODE_cmu_us_rms_dur_NO_2378 2422
DEF_STATIC_CONST_VAL_STRING(val_1405,"eh_56");
DEF_STATIC_CONST_VAL_FLOAT(val_1406,0.573985);
#define CTNODE_cmu_us_rms_dur_NO_2425 2427
DEF_STATIC_CONST_VAL_FLOAT(val_1407,-0.510151);
#define CTNODE_cmu_us_rms_dur_NO_2427 2429
DEF_STATIC_CONST_VAL_FLOAT(val_1408,0.093517);
#define CTNODE_cmu_us_rms_dur_NO_2424 2430
DEF_STATIC_CONST_VAL_FLOAT(val_1409,0.001292);
#define CTNODE_cmu_us_rms_dur_NO_2430 2432
DEF_STATIC_CONST_VAL_FLOAT(val_1410,1.285260);
#define CTNODE_cmu_us_rms_dur_NO_2433 2435
DEF_STATIC_CONST_VAL_FLOAT(val_1411,0.454841);
#define CTNODE_cmu_us_rms_dur_NO_2432 2436
DEF_STATIC_CONST_VAL_FLOAT(val_1412,0.139680);
#define CTNODE_cmu_us_rms_dur_NO_2439 2441
DEF_STATIC_CONST_VAL_FLOAT(val_1413,0.713656);
#define CTNODE_cmu_us_rms_dur_NO_2438 2442
DEF_STATIC_CONST_VAL_FLOAT(val_1414,-0.019452);
#define CTNODE_cmu_us_rms_dur_NO_2437 2443
DEF_STATIC_CONST_VAL_FLOAT(val_1415,0.157190);
#define CTNODE_cmu_us_rms_dur_NO_2443 2445
DEF_STATIC_CONST_VAL_FLOAT(val_1416,0.310141);
#define CTNODE_cmu_us_rms_dur_NO_2446 2448
DEF_STATIC_CONST_VAL_FLOAT(val_1417,1.305960);
#define CTNODE_cmu_us_rms_dur_NO_2449 2451
DEF_STATIC_CONST_VAL_FLOAT(val_1418,0.473098);
#define CTNODE_cmu_us_rms_dur_NO_2451 2453
DEF_STATIC_CONST_VAL_FLOAT(val_1419,0.947254);
#define CTNODE_cmu_us_rms_dur_NO_2454 2456
DEF_STATIC_CONST_VAL_FLOAT(val_1420,0.393444);
#define CTNODE_cmu_us_rms_dur_NO_2453 2457
DEF_STATIC_CONST_VAL_FLOAT(val_1421,1.251140);
#define CTNODE_cmu_us_rms_dur_NO_2457 2459
DEF_STATIC_CONST_VAL_FLOAT(val_1422,0.820499);
#define CTNODE_cmu_us_rms_dur_NO_2448 2460
DEF_STATIC_CONST_VAL_FLOAT(val_1423,0.663213);
#define CTNODE_cmu_us_rms_dur_NO_2460 2462
DEF_STATIC_CONST_VAL_FLOAT(val_1424,0.254231);
#define CTNODE_cmu_us_rms_dur_NO_2445 2463
DEF_STATIC_CONST_VAL_FLOAT(val_1425,-0.119979);
#define CTNODE_cmu_us_rms_dur_NO_2463 2465
DEF_STATIC_CONST_VAL_FLOAT(val_1426,0.730526);
#define CTNODE_cmu_us_rms_dur_NO_2436 2466
DEF_STATIC_CONST_VAL_FLOAT(val_1427,-0.135007);
#define CTNODE_cmu_us_rms_dur_NO_2423 2467
DEF_STATIC_CONST_VAL_FLOAT(val_1428,0.185851);
#define CTNODE_cmu_us_rms_dur_NO_2469 2471
DEF_STATIC_CONST_VAL_FLOAT(val_1429,-0.035455);
#define CTNODE_cmu_us_rms_dur_NO_2468 2472
DEF_STATIC_CONST_VAL_FLOAT(val_1430,-0.383455);
#define CTNODE_cmu_us_rms_dur_NO_2472 2474
DEF_STATIC_CONST_VAL_FLOAT(val_1431,-0.176251);
#define CTNODE_cmu_us_rms_dur_NO_2474 2476
DEF_STATIC_CONST_VAL_FLOAT(val_1432,0.069407);
#define CTNODE_cmu_us_rms_dur_NO_2467 2477
DEF_STATIC_CONST_VAL_FLOAT(val_1433,0.915610);
#define CTNODE_cmu_us_rms_dur_NO_2478 2480
DEF_STATIC_CONST_VAL_FLOAT(val_1434,0.130956);
#define CTNODE_cmu_us_rms_dur_NO_2480 2482
DEF_STATIC_CONST_VAL_FLOAT(val_1435,0.194281);
#define CTNODE_cmu_us_rms_dur_NO_2483 2485
DEF_STATIC_CONST_VAL_FLOAT(val_1436,1.069320);
#define CTNODE_cmu_us_rms_dur_NO_2485 2487
DEF_STATIC_CONST_VAL_FLOAT(val_1437,0.373078);
#define CTNODE_cmu_us_rms_dur_NO_2482 2488
DEF_STATIC_CONST_VAL_FLOAT(val_1438,0.533671);
#define CTNODE_cmu_us_rms_dur_NO_2490 2492
DEF_STATIC_CONST_VAL_FLOAT(val_1439,0.113068);
#define CTNODE_cmu_us_rms_dur_NO_2489 2493
DEF_STATIC_CONST_VAL_FLOAT(val_1440,0.576852);
#define CTNODE_cmu_us_rms_dur_NO_2488 2494
DEF_STATIC_CONST_VAL_FLOAT(val_1441,0.036448);
#define CTNODE_cmu_us_rms_dur_NO_2477 2495
DEF_STATIC_CONST_VAL_FLOAT(val_1442,-0.057465);
#define CTNODE_cmu_us_rms_dur_NO_2422 2496
DEF_STATIC_CONST_VAL_FLOAT(val_1443,2.183300);
#define CTNODE_cmu_us_rms_dur_NO_2496 2498
DEF_STATIC_CONST_VAL_FLOAT(val_1444,1.428710);
#define CTNODE_cmu_us_rms_dur_NO_2498 2500
DEF_STATIC_CONST_VAL_FLOAT(val_1445,0.378145);
#define CTNODE_cmu_us_rms_dur_NO_2501 2503
DEF_STATIC_CONST_VAL_FLOAT(val_1446,-0.289340);
#define CTNODE_cmu_us_rms_dur_NO_2500 2504
DEF_STATIC_CONST_VAL_FLOAT(val_1447,0.139951);
#define CTNODE_cmu_us_rms_dur_NO_2505 2507
DEF_STATIC_CONST_VAL_FLOAT(val_1448,1.317630);
#define CTNODE_cmu_us_rms_dur_NO_2508 2510
DEF_STATIC_CONST_VAL_FLOAT(val_1449,0.035363);
#define CTNODE_cmu_us_rms_dur_NO_2510 2512
DEF_STATIC_CONST_VAL_FLOAT(val_1450,0.255476);
#define CTNODE_cmu_us_rms_dur_NO_2512 2514
DEF_STATIC_CONST_VAL_FLOAT(val_1451,0.879067);
#define CTNODE_cmu_us_rms_dur_NO_2507 2515
DEF_STATIC_CONST_VAL_FLOAT(val_1452,0.891376);
#define CTNODE_cmu_us_rms_dur_NO_2516 2518
DEF_STATIC_CONST_VAL_FLOAT(val_1453,1.152230);
#define CTNODE_cmu_us_rms_dur_NO_2518 2520
DEF_STATIC_CONST_VAL_FLOAT(val_1454,1.642060);
#define CTNODE_cmu_us_rms_dur_NO_2515 2521
DEF_STATIC_CONST_VAL_FLOAT(val_1455,0.639573);
#define CTNODE_cmu_us_rms_dur_NO_2504 2522
DEF_STATIC_CONST_VAL_FLOAT(val_1456,0.696111);
#define CTNODE_cmu_us_rms_dur_NO_2522 2524
DEF_STATIC_CONST_VAL_FLOAT(val_1457,0.655000);
#define CTNODE_cmu_us_rms_dur_NO_2525 2527
DEF_STATIC_CONST_VAL_FLOAT(val_1458,0.274823);
#define CTNODE_cmu_us_rms_dur_NO_2524 2528
DEF_STATIC_CONST_VAL_FLOAT(val_1459,0.274341);
#define CTNODE_cmu_us_rms_dur_NO_2528 2530
DEF_STATIC_CONST_VAL_FLOAT(val_1460,-0.482268);
#define CTNODE_cmu_us_rms_dur_NO_2530 2532
DEF_STATIC_CONST_VAL_FLOAT(val_1461,0.172418);
#define CTNODE_cmu_us_rms_dur_NO_2335 2533
DEF_STATIC_CONST_VAL_FLOAT(val_1462,0.394282);
#define CTNODE_cmu_us_rms_dur_NO_2536 2538
DEF_STATIC_CONST_VAL_FLOAT(val_1463,-0.012245);
#define CTNODE_cmu_us_rms_dur_NO_2538 2540
DEF_STATIC_CONST_VAL_FLOAT(val_1464,-0.130908);
#define CTNODE_cmu_us_rms_dur_NO_2541 2543
DEF_STATIC_CONST_VAL_FLOAT(val_1465,-0.319766);
#define CTNODE_cmu_us_rms_dur_NO_2540 2544
DEF_STATIC_CONST_VAL_FLOAT(val_1466,-0.526458);
#define CTNODE_cmu_us_rms_dur_NO_2535 2545
DEF_STATIC_CONST_VAL_FLOAT(val_1467,1.142090);
#define CTNODE_cmu_us_rms_dur_NO_2545 2547
DEF_STATIC_CONST_VAL_FLOAT(val_1468,1.016430);
#define CTNODE_cmu_us_rms_dur_NO_2548 2550
DEF_STATIC_CONST_VAL_FLOAT(val_1469,0.453481);
#define CTNODE_cmu_us_rms_dur_NO_2547 2551
DEF_STATIC_CONST_VAL_FLOAT(val_1470,-0.344434);
#define CTNODE_cmu_us_rms_dur_NO_2551 2553
DEF_STATIC_CONST_VAL_FLOAT(val_1471,-0.266542);
#define CTNODE_cmu_us_rms_dur_NO_2553 2555
DEF_STATIC_CONST_VAL_STRING(val_1472,"s_153");
DEF_STATIC_CONST_VAL_FLOAT(val_1473,-0.299015);
#define CTNODE_cmu_us_rms_dur_NO_2555 2557
DEF_STATIC_CONST_VAL_FLOAT(val_1474,0.522409);
#define CTNODE_cmu_us_rms_dur_NO_2559 2561
DEF_STATIC_CONST_VAL_FLOAT(val_1475,-0.013142);
#define CTNODE_cmu_us_rms_dur_NO_2562 2564
DEF_STATIC_CONST_VAL_FLOAT(val_1476,0.357976);
#define CTNODE_cmu_us_rms_dur_NO_2561 2565
DEF_STATIC_CONST_VAL_FLOAT(val_1477,-0.179717);
#define CTNODE_cmu_us_rms_dur_NO_2558 2566
DEF_STATIC_CONST_VAL_FLOAT(val_1478,1.344490);
#define CTNODE_cmu_us_rms_dur_NO_2566 2568
DEF_STATIC_CONST_VAL_FLOAT(val_1479,0.718923);
#define CTNODE_cmu_us_rms_dur_NO_2569 2571
DEF_STATIC_CONST_VAL_FLOAT(val_1480,0.333567);
#define CTNODE_cmu_us_rms_dur_NO_2571 2573
DEF_STATIC_CONST_VAL_FLOAT(val_1481,-0.154460);
#define CTNODE_cmu_us_rms_dur_NO_2568 2574
DEF_STATIC_CONST_VAL_FLOAT(val_1482,0.600601);
#define CTNODE_cmu_us_rms_dur_NO_2574 2576
DEF_STATIC_CONST_VAL_FLOAT(val_1483,0.979833);
#define CTNODE_cmu_us_rms_dur_NO_2557 2577
DEF_STATIC_CONST_VAL_FLOAT(val_1484,0.407236);
#define CTNODE_cmu_us_rms_dur_NO_2579 2581
DEF_STATIC_CONST_VAL_FLOAT(val_1485,0.078419);
#define CTNODE_cmu_us_rms_dur_NO_2578 2582
DEF_STATIC_CONST_VAL_FLOAT(val_1486,-0.290932);
#define CTNODE_cmu_us_rms_dur_NO_2582 2584
DEF_STATIC_CONST_VAL_FLOAT(val_1487,-0.037352);
#define CTNODE_cmu_us_rms_dur_NO_2584 2586
DEF_STATIC_CONST_VAL_FLOAT(val_1488,0.178408);
#define CTNODE_cmu_us_rms_dur_NO_2577 2587
DEF_STATIC_CONST_VAL_FLOAT(val_1489,-0.166057);
#define CTNODE_cmu_us_rms_dur_NO_2587 2589
DEF_STATIC_CONST_VAL_FLOAT(val_1490,0.697661);
#define CTNODE_cmu_us_rms_dur_NO_2591 2593
DEF_STATIC_CONST_VAL_FLOAT(val_1491,0.285227);
#define CTNODE_cmu_us_rms_dur_NO_2593 2595
DEF_STATIC_CONST_VAL_FLOAT(val_1492,0.112337);
#define CTNODE_cmu_us_rms_dur_NO_2590 2596
DEF_STATIC_CONST_VAL_FLOAT(val_1493,-0.331950);
#define CTNODE_cmu_us_rms_dur_NO_2596 2598
DEF_STATIC_CONST_VAL_FLOAT(val_1494,-0.026197);
#define CTNODE_cmu_us_rms_dur_NO_2598 2600
DEF_STATIC_CONST_VAL_FLOAT(val_1495,0.326684);
#define CTNODE_cmu_us_rms_dur_NO_2589 2601
DEF_STATIC_CONST_VAL_FLOAT(val_1496,0.358440);
#define CTNODE_cmu_us_rms_dur_NO_2602 2604
DEF_STATIC_CONST_VAL_FLOAT(val_1497,-0.186867);
#define CTNODE_cmu_us_rms_dur_NO_2601 2605
DEF_STATIC_CONST_VAL_FLOAT(val_1498,0.048693);
#define CTNODE_cmu_us_rms_dur_NO_2605 2607
DEF_STATIC_CONST_VAL_FLOAT(val_1499,0.790219);
#define CTNODE_cmu_us_rms_dur_NO_2607 2609
DEF_STATIC_CONST_VAL_FLOAT(val_1500,0.846662);
#define CTNODE_cmu_us_rms_dur_NO_2609 2611
DEF_STATIC_CONST_VAL_FLOAT(val_1501,0.099680);
#define CTNODE_cmu_us_rms_dur_NO_2611 2613
DEF_STATIC_CONST_VAL_FLOAT(val_1502,11.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_1503,0.452765);
#define CTNODE_cmu_us_rms_dur_NO_2615 2617
DEF_STATIC_CONST_VAL_FLOAT(val_1504,0.257182);
#define CTNODE_cmu_us_rms_dur_NO_2617 2619
DEF_STATIC_CONST_VAL_FLOAT(val_1505,0.036033);
#define CTNODE_cmu_us_rms_dur_NO_2614 2620
DEF_STATIC_CONST_VAL_FLOAT(val_1506,0.785935);
#define CTNODE_cmu_us_rms_dur_NO_2620 2622
DEF_STATIC_CONST_VAL_FLOAT(val_1507,0.442817);
#define CTNODE_cmu_us_rms_dur_NO_2613 2623
DEF_STATIC_CONST_VAL_FLOAT(val_1508,0.821220);
#define CTNODE_cmu_us_rms_dur_NO_2534 2624
DEF_STATIC_CONST_VAL_FLOAT(val_1509,0.788183);
#define CTNODE_cmu_us_rms_dur_NO_2624 2626
DEF_STATIC_CONST_VAL_FLOAT(val_1510,0.963623);
#define CTNODE_cmu_us_rms_dur_NO_2627 2629
DEF_STATIC_CONST_VAL_FLOAT(val_1511,-0.076020);
#define CTNODE_cmu_us_rms_dur_NO_2631 2633
DEF_STATIC_CONST_VAL_FLOAT(val_1512,0.225499);
#define CTNODE_cmu_us_rms_dur_NO_2630 2634
DEF_STATIC_CONST_VAL_FLOAT(val_1513,-0.361906);
#define CTNODE_cmu_us_rms_dur_NO_2629 2635
DEF_STATIC_CONST_VAL_FLOAT(val_1514,0.286795);
#define CTNODE_cmu_us_rms_dur_NO_2636 2638
DEF_STATIC_CONST_VAL_FLOAT(val_1515,-0.151081);
#define CTNODE_cmu_us_rms_dur_NO_2635 2639
DEF_STATIC_CONST_VAL_FLOAT(val_1516,0.343189);
#define CTNODE_cmu_us_rms_dur_NO_2639 2641
DEF_STATIC_CONST_VAL_FLOAT(val_1517,0.653756);
#define CTNODE_cmu_us_rms_dur_NO_2626 2642
DEF_STATIC_CONST_VAL_STRING(val_1518,"s_151");
DEF_STATIC_CONST_VAL_FLOAT(val_1519,-0.604063);
#define CTNODE_cmu_us_rms_dur_NO_2642 2644
DEF_STATIC_CONST_VAL_FLOAT(val_1520,-0.132818);
#define CTNODE_cmu_us_rms_dur_NO_2646 2648
DEF_STATIC_CONST_VAL_FLOAT(val_1521,-0.562525);
#define CTNODE_cmu_us_rms_dur_NO_2649 2651
DEF_STATIC_CONST_VAL_FLOAT(val_1522,-0.393772);
#define CTNODE_cmu_us_rms_dur_NO_2648 2652
DEF_STATIC_CONST_VAL_FLOAT(val_1523,-0.381385);
#define CTNODE_cmu_us_rms_dur_NO_2652 2654
DEF_STATIC_CONST_VAL_FLOAT(val_1524,-0.178268);
#define CTNODE_cmu_us_rms_dur_NO_2645 2655
DEF_STATIC_CONST_VAL_FLOAT(val_1525,0.305214);
#define CTNODE_cmu_us_rms_dur_NO_2655 2657
DEF_STATIC_CONST_VAL_FLOAT(val_1526,-0.205897);
#define CTNODE_cmu_us_rms_dur_NO_2644 2658
DEF_STATIC_CONST_VAL_FLOAT(val_1527,-0.540143);
#define CTNODE_cmu_us_rms_dur_NO_2659 2661
DEF_STATIC_CONST_VAL_FLOAT(val_1528,-0.118870);
#define CTNODE_cmu_us_rms_dur_NO_2658 2662
DEF_STATIC_CONST_VAL_FLOAT(val_1529,0.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_1530,-0.364265);
#define CTNODE_cmu_us_rms_dur_NO_2663 2665
DEF_STATIC_CONST_VAL_FLOAT(val_1531,0.449654);
#define CTNODE_cmu_us_rms_dur_NO_2666 2668
DEF_STATIC_CONST_VAL_FLOAT(val_1532,0.140442);
#define CTNODE_cmu_us_rms_dur_NO_2665 2669
DEF_STATIC_CONST_VAL_FLOAT(val_1533,0.139176);
#define CTNODE_cmu_us_rms_dur_NO_2669 2671
DEF_STATIC_CONST_VAL_FLOAT(val_1534,-0.291343);
#define CTNODE_cmu_us_rms_dur_NO_2662 2672
DEF_STATIC_CONST_VAL_FLOAT(val_1535,0.565502);
#define CTNODE_cmu_us_rms_dur_NO_2533 2673
DEF_STATIC_CONST_VAL_FLOAT(val_1536,0.478099);
#define CTNODE_cmu_us_rms_dur_NO_2674 2676
DEF_STATIC_CONST_VAL_FLOAT(val_1537,0.283405);
#define CTNODE_cmu_us_rms_dur_NO_2678 2680
DEF_STATIC_CONST_VAL_FLOAT(val_1538,-0.022182);
#define CTNODE_cmu_us_rms_dur_NO_2677 2681
DEF_STATIC_CONST_VAL_FLOAT(val_1539,0.544632);
#define CTNODE_cmu_us_rms_dur_NO_2676 2682
DEF_STATIC_CONST_VAL_FLOAT(val_1540,0.407936);
#define CTNODE_cmu_us_rms_dur_NO_2683 2685
DEF_STATIC_CONST_VAL_FLOAT(val_1541,-0.436343);
#define CTNODE_cmu_us_rms_dur_NO_2687 2689
DEF_STATIC_CONST_VAL_FLOAT(val_1542,-0.149347);
#define CTNODE_cmu_us_rms_dur_NO_2686 2690
DEF_STATIC_CONST_VAL_FLOAT(val_1543,0.084088);
#define CTNODE_cmu_us_rms_dur_NO_2685 2691
DEF_STATIC_CONST_VAL_FLOAT(val_1544,-0.186105);
#define CTNODE_cmu_us_rms_dur_NO_2691 2693
DEF_STATIC_CONST_VAL_FLOAT(val_1545,0.624612);
#define CTNODE_cmu_us_rms_dur_NO_2694 2696
DEF_STATIC_CONST_VAL_FLOAT(val_1546,0.437845);
#define CTNODE_cmu_us_rms_dur_NO_2696 2698
DEF_STATIC_CONST_VAL_FLOAT(val_1547,-0.021702);
#define CTNODE_cmu_us_rms_dur_NO_2693 2699
DEF_STATIC_CONST_VAL_FLOAT(val_1548,-0.192881);
#define CTNODE_cmu_us_rms_dur_NO_2682 2700
DEF_STATIC_CONST_VAL_FLOAT(val_1549,-0.367165);
#define CTNODE_cmu_us_rms_dur_NO_2701 2703
DEF_STATIC_CONST_VAL_FLOAT(val_1550,-0.223442);
#define CTNODE_cmu_us_rms_dur_NO_2703 2705
DEF_STATIC_CONST_VAL_FLOAT(val_1551,0.335155);
#define CTNODE_cmu_us_rms_dur_NO_2705 2707
DEF_STATIC_CONST_VAL_FLOAT(val_1552,-0.015743);
#define CTNODE_cmu_us_rms_dur_NO_2700 2708
DEF_STATIC_CONST_VAL_FLOAT(val_1553,-0.392682);
#define CTNODE_cmu_us_rms_dur_NO_2673 2709
DEF_STATIC_CONST_VAL_FLOAT(val_1554,-0.736196);
#define CTNODE_cmu_us_rms_dur_NO_2710 2712
DEF_STATIC_CONST_VAL_FLOAT(val_1555,-0.564109);
#define CTNODE_cmu_us_rms_dur_NO_2709 2713
DEF_STATIC_CONST_VAL_FLOAT(val_1556,-0.628736);
#define CTNODE_cmu_us_rms_dur_NO_2713 2715
DEF_STATIC_CONST_VAL_FLOAT(val_1557,-0.525248);
#define CTNODE_cmu_us_rms_dur_NO_2716 2718
DEF_STATIC_CONST_VAL_FLOAT(val_1558,-0.210741);
#define CTNODE_cmu_us_rms_dur_NO_2715 2719
DEF_STATIC_CONST_VAL_FLOAT(val_1559,-0.193845);
#define CTNODE_cmu_us_rms_dur_NO_2720 2722
DEF_STATIC_CONST_VAL_FLOAT(val_1560,-0.431719);
#define CTNODE_cmu_us_rms_dur_NO_2719 2723
DEF_STATIC_CONST_VAL_FLOAT(val_1561,0.384372);
#define CTNODE_cmu_us_rms_dur_NO_2724 2726
DEF_STATIC_CONST_VAL_FLOAT(val_1562,0.140527);
#define CTNODE_cmu_us_rms_dur_NO_2723 2727
DEF_STATIC_CONST_VAL_FLOAT(val_1563,-0.187464);
#define CTNODE_cmu_us_rms_dur_NO_2334 2728
DEF_STATIC_CONST_VAL_FLOAT(val_1564,1.968710);
#define CTNODE_cmu_us_rms_dur_NO_2730 2732
DEF_STATIC_CONST_VAL_FLOAT(val_1565,1.565510);
#define CTNODE_cmu_us_rms_dur_NO_2732 2734
DEF_STATIC_CONST_VAL_FLOAT(val_1566,1.057700);
#define CTNODE_cmu_us_rms_dur_NO_2729 2735
DEF_STATIC_CONST_VAL_FLOAT(val_1567,0.231727);
#define CTNODE_cmu_us_rms_dur_NO_2735 2737
DEF_STATIC_CONST_VAL_FLOAT(val_1568,-0.478697);
#define CTNODE_cmu_us_rms_dur_NO_2728 2738
DEF_STATIC_CONST_VAL_FLOAT(val_1569,-1.161760);
#define CTNODE_cmu_us_rms_dur_NO_2740 2742
DEF_STATIC_CONST_VAL_FLOAT(val_1570,-0.529674);
#define CTNODE_cmu_us_rms_dur_NO_2742 2744
DEF_STATIC_CONST_VAL_FLOAT(val_1571,-0.053964);
#define CTNODE_cmu_us_rms_dur_NO_2739 2745
DEF_STATIC_CONST_VAL_FLOAT(val_1572,-0.303965);
#define CTNODE_cmu_us_rms_dur_NO_2750 2752
DEF_STATIC_CONST_VAL_FLOAT(val_1573,-0.183728);
#define CTNODE_cmu_us_rms_dur_NO_2749 2753
DEF_STATIC_CONST_VAL_FLOAT(val_1574,-0.449049);
#define CTNODE_cmu_us_rms_dur_NO_2748 2754
DEF_STATIC_CONST_VAL_FLOAT(val_1575,-0.151583);
#define CTNODE_cmu_us_rms_dur_NO_2756 2758
DEF_STATIC_CONST_VAL_FLOAT(val_1576,0.133828);
#define CTNODE_cmu_us_rms_dur_NO_2755 2759
DEF_STATIC_CONST_VAL_FLOAT(val_1577,0.758936);
#define CTNODE_cmu_us_rms_dur_NO_2760 2762
DEF_STATIC_CONST_VAL_FLOAT(val_1578,0.298451);
#define CTNODE_cmu_us_rms_dur_NO_2759 2763
DEF_STATIC_CONST_VAL_FLOAT(val_1579,0.362074);
#define CTNODE_cmu_us_rms_dur_NO_2763 2765
DEF_STATIC_CONST_VAL_FLOAT(val_1580,-0.031270);
#define CTNODE_cmu_us_rms_dur_NO_2754 2766
DEF_STATIC_CONST_VAL_FLOAT(val_1581,-0.034203);
#define CTNODE_cmu_us_rms_dur_NO_2766 2768
DEF_STATIC_CONST_VAL_FLOAT(val_1582,-0.434162);
#define CTNODE_cmu_us_rms_dur_NO_2768 2770
DEF_STATIC_CONST_VAL_FLOAT(val_1583,-0.266411);
#define CTNODE_cmu_us_rms_dur_NO_2747 2771
DEF_STATIC_CONST_VAL_FLOAT(val_1584,-0.352620);
#define CTNODE_cmu_us_rms_dur_NO_2771 2773
DEF_STATIC_CONST_VAL_FLOAT(val_1585,0.477820);
#define CTNODE_cmu_us_rms_dur_NO_2774 2776
DEF_STATIC_CONST_VAL_FLOAT(val_1586,1.056180);
#define CTNODE_cmu_us_rms_dur_NO_2773 2777
DEF_STATIC_CONST_VAL_FLOAT(val_1587,-0.038827);
#define CTNODE_cmu_us_rms_dur_NO_2778 2780
DEF_STATIC_CONST_VAL_FLOAT(val_1588,1.115790);
#define CTNODE_cmu_us_rms_dur_NO_2781 2783
DEF_STATIC_CONST_VAL_FLOAT(val_1589,0.540331);
#define CTNODE_cmu_us_rms_dur_NO_2780 2784
DEF_STATIC_CONST_VAL_FLOAT(val_1590,0.590791);
#define CTNODE_cmu_us_rms_dur_NO_2784 2786
DEF_STATIC_CONST_VAL_FLOAT(val_1591,0.456764);
#define CTNODE_cmu_us_rms_dur_NO_2786 2788
DEF_STATIC_CONST_VAL_FLOAT(val_1592,0.013500);
#define CTNODE_cmu_us_rms_dur_NO_2777 2789
DEF_STATIC_CONST_VAL_FLOAT(val_1593,-0.196127);
#define CTNODE_cmu_us_rms_dur_NO_2789 2791
DEF_STATIC_CONST_VAL_FLOAT(val_1594,-0.121338);
#define CTNODE_cmu_us_rms_dur_NO_2791 2793
DEF_STATIC_CONST_VAL_FLOAT(val_1595,0.797523);
#define CTNODE_cmu_us_rms_dur_NO_2793 2795
DEF_STATIC_CONST_VAL_FLOAT(val_1596,0.314021);
#define CTNODE_cmu_us_rms_dur_NO_2797 2799
DEF_STATIC_CONST_VAL_FLOAT(val_1597,0.850171);
#define CTNODE_cmu_us_rms_dur_NO_2796 2800
DEF_STATIC_CONST_VAL_FLOAT(val_1598,-0.388363);
#define CTNODE_cmu_us_rms_dur_NO_2800 2802
DEF_STATIC_CONST_VAL_FLOAT(val_1599,0.364534);
#define CTNODE_cmu_us_rms_dur_NO_2795 2803
DEF_STATIC_CONST_VAL_FLOAT(val_1600,0.469077);
#define CTNODE_cmu_us_rms_dur_NO_2804 2806
DEF_STATIC_CONST_VAL_FLOAT(val_1601,0.136247);
#define CTNODE_cmu_us_rms_dur_NO_2803 2807
DEF_STATIC_CONST_VAL_FLOAT(val_1602,0.286398);
#define CTNODE_cmu_us_rms_dur_NO_2808 2810
DEF_STATIC_CONST_VAL_FLOAT(val_1603,-0.138765);
#define CTNODE_cmu_us_rms_dur_NO_2807 2811
DEF_STATIC_CONST_VAL_FLOAT(val_1604,-0.262775);
#define CTNODE_cmu_us_rms_dur_NO_2746 2812
DEF_STATIC_CONST_VAL_FLOAT(val_1605,1.520890);
#define CTNODE_cmu_us_rms_dur_NO_2813 2815
DEF_STATIC_CONST_VAL_FLOAT(val_1606,0.830625);
#define CTNODE_cmu_us_rms_dur_NO_2812 2816
DEF_STATIC_CONST_VAL_FLOAT(val_1607,0.913658);
#define CTNODE_cmu_us_rms_dur_NO_2816 2818
DEF_STATIC_CONST_VAL_FLOAT(val_1608,0.121337);
#define CTNODE_cmu_us_rms_dur_NO_2745 2819
DEF_STATIC_CONST_VAL_FLOAT(val_1609,-0.711139);
#define CTNODE_cmu_us_rms_dur_NO_2820 2822
DEF_STATIC_CONST_VAL_FLOAT(val_1610,-0.422501);
#define CTNODE_cmu_us_rms_dur_NO_2823 2825
DEF_STATIC_CONST_VAL_FLOAT(val_1611,-0.607130);
#define CTNODE_cmu_us_rms_dur_NO_2822 2826
DEF_STATIC_CONST_VAL_FLOAT(val_1612,-0.302777);
#define CTNODE_cmu_us_rms_dur_NO_2827 2829
DEF_STATIC_CONST_VAL_FLOAT(val_1613,-0.514922);
#define CTNODE_cmu_us_rms_dur_NO_2826 2830
DEF_STATIC_CONST_VAL_FLOAT(val_1614,-0.241500);
#define CTNODE_cmu_us_rms_dur_NO_2830 2832
DEF_STATIC_CONST_VAL_FLOAT(val_1615,-0.012264);
#define CTNODE_cmu_us_rms_dur_NO_2819 2833
DEF_STATIC_CONST_VAL_FLOAT(val_1616,-0.197371);
#define CTNODE_cmu_us_rms_dur_NO_2834 2836
DEF_STATIC_CONST_VAL_FLOAT(val_1617,1.044370);
#define CTNODE_cmu_us_rms_dur_NO_2837 2839
DEF_STATIC_CONST_VAL_FLOAT(val_1618,0.835981);
#define CTNODE_cmu_us_rms_dur_NO_2839 2841
DEF_STATIC_CONST_VAL_FLOAT(val_1619,0.378539);
#define CTNODE_cmu_us_rms_dur_NO_2836 2842
DEF_STATIC_CONST_VAL_FLOAT(val_1620,-0.008850);
#define CTNODE_cmu_us_rms_dur_NO_2842 2844
DEF_STATIC_CONST_VAL_FLOAT(val_1621,0.238804);
#define CTNODE_cmu_us_rms_dur_NO_2844 2846
DEF_STATIC_CONST_VAL_FLOAT(val_1622,0.581519);
#define CTNODE_cmu_us_rms_dur_NO_2833 2847
DEF_STATIC_CONST_VAL_FLOAT(val_1623,1.210810);
#define CTNODE_cmu_us_rms_dur_NO_2849 2851
DEF_STATIC_CONST_VAL_FLOAT(val_1624,0.675239);
#define CTNODE_cmu_us_rms_dur_NO_2848 2852
DEF_STATIC_CONST_VAL_FLOAT(val_1625,1.536390);
#define CTNODE_cmu_us_rms_dur_NO_2853 2855
DEF_STATIC_CONST_VAL_FLOAT(val_1626,1.148470);
#define CTNODE_cmu_us_rms_dur_NO_2856 2858
DEF_STATIC_CONST_VAL_FLOAT(val_1627,0.524137);
#define CTNODE_cmu_us_rms_dur_NO_2855 2859
DEF_STATIC_CONST_VAL_STRING(val_1628,"f_71");
DEF_STATIC_CONST_VAL_FLOAT(val_1629,0.624454);
#define CTNODE_cmu_us_rms_dur_NO_2860 2862
DEF_STATIC_CONST_VAL_FLOAT(val_1630,-0.405244);
#define CTNODE_cmu_us_rms_dur_NO_2862 2864
DEF_STATIC_CONST_VAL_FLOAT(val_1631,0.310985);
#define CTNODE_cmu_us_rms_dur_NO_2864 2866
DEF_STATIC_CONST_VAL_FLOAT(val_1632,0.084517);
#define CTNODE_cmu_us_rms_dur_NO_2868 2870
DEF_STATIC_CONST_VAL_FLOAT(val_1633,-0.210102);
#define CTNODE_cmu_us_rms_dur_NO_2867 2871
DEF_STATIC_CONST_VAL_FLOAT(val_1634,-0.402655);
#define CTNODE_cmu_us_rms_dur_NO_2866 2872
DEF_STATIC_CONST_VAL_FLOAT(val_1635,-0.198107);
#define CTNODE_cmu_us_rms_dur_NO_2872 2874
DEF_STATIC_CONST_VAL_FLOAT(val_1636,-0.181732);
#define CTNODE_cmu_us_rms_dur_NO_2874 2876
DEF_STATIC_CONST_VAL_FLOAT(val_1637,-0.098421);
#define CTNODE_cmu_us_rms_dur_NO_2876 2878
DEF_STATIC_CONST_VAL_FLOAT(val_1638,0.238578);
#define CTNODE_cmu_us_rms_dur_NO_2878 2880
DEF_STATIC_CONST_VAL_FLOAT(val_1639,0.217644);
#define CTNODE_cmu_us_rms_dur_NO_2880 2882
DEF_STATIC_CONST_VAL_FLOAT(val_1640,0.160968);
#define CTNODE_cmu_us_rms_dur_NO_2882 2884
DEF_STATIC_CONST_VAL_FLOAT(val_1641,0.075400);
#define CTNODE_cmu_us_rms_dur_NO_2884 2886
DEF_STATIC_CONST_VAL_FLOAT(val_1642,-0.200748);
#define CTNODE_cmu_us_rms_dur_NO_2859 2887
DEF_STATIC_CONST_VAL_FLOAT(val_1643,-0.366576);
#define CTNODE_cmu_us_rms_dur_NO_2888 2890
DEF_STATIC_CONST_VAL_FLOAT(val_1644,0.404720);
#define CTNODE_cmu_us_rms_dur_NO_2890 2892
DEF_STATIC_CONST_VAL_FLOAT(val_1645,-0.241142);
#define CTNODE_cmu_us_rms_dur_NO_2892 2894
DEF_STATIC_CONST_VAL_FLOAT(val_1646,0.204651);
#define CTNODE_cmu_us_rms_dur_NO_2887 2895
DEF_STATIC_CONST_VAL_FLOAT(val_1647,-0.386133);
#define CTNODE_cmu_us_rms_dur_NO_2897 2899
DEF_STATIC_CONST_VAL_FLOAT(val_1648,0.172103);
#define CTNODE_cmu_us_rms_dur_NO_2896 2900
DEF_STATIC_CONST_VAL_FLOAT(val_1649,0.512170);
#define CTNODE_cmu_us_rms_dur_NO_2900 2902
DEF_STATIC_CONST_VAL_FLOAT(val_1650,0.334172);
#define CTNODE_cmu_us_rms_dur_NO_2902 2904
DEF_STATIC_CONST_VAL_FLOAT(val_1651,-0.155135);
#define CTNODE_cmu_us_rms_dur_NO_2904 2906
DEF_STATIC_CONST_VAL_FLOAT(val_1652,0.012701);
#define CTNODE_cmu_us_rms_dur_NO_2906 2908
DEF_STATIC_CONST_VAL_FLOAT(val_1653,0.374878);
#define CTNODE_cmu_us_rms_dur_NO_2895 2909
DEF_STATIC_CONST_VAL_FLOAT(val_1654,0.375202);
#define CTNODE_cmu_us_rms_dur_NO_2910 2912
DEF_STATIC_CONST_VAL_FLOAT(val_1655,0.062280);
#define CTNODE_cmu_us_rms_dur_NO_2912 2914
DEF_STATIC_CONST_VAL_FLOAT(val_1656,-0.314257);
#define CTNODE_cmu_us_rms_dur_NO_2909 2915
DEF_STATIC_CONST_VAL_FLOAT(val_1657,0.447195);
#define CTNODE_cmu_us_rms_dur_NO_2916 2918
DEF_STATIC_CONST_VAL_FLOAT(val_1658,1.373130);
#define CTNODE_cmu_us_rms_dur_NO_2918 2920
DEF_STATIC_CONST_VAL_FLOAT(val_1659,0.777321);
#define CTNODE_cmu_us_rms_dur_NO_2915 2921
DEF_STATIC_CONST_VAL_FLOAT(val_1660,-0.012609);
#define CTNODE_cmu_us_rms_dur_NO_2852 2922
DEF_STATIC_CONST_VAL_FLOAT(val_1661,-0.162354);
#define CTNODE_cmu_us_rms_dur_NO_2924 2926
DEF_STATIC_CONST_VAL_FLOAT(val_1662,-0.585203);
#define CTNODE_cmu_us_rms_dur_NO_2923 2927
DEF_STATIC_CONST_VAL_FLOAT(val_1663,0.143345);
#define CTNODE_cmu_us_rms_dur_NO_2930 2932
DEF_STATIC_CONST_VAL_FLOAT(val_1664,0.602066);
#define CTNODE_cmu_us_rms_dur_NO_2929 2933
DEF_STATIC_CONST_VAL_FLOAT(val_1665,0.073596);
#define CTNODE_cmu_us_rms_dur_NO_2928 2934
DEF_STATIC_CONST_VAL_STRING(val_1666,"eh_57");
DEF_STATIC_CONST_VAL_FLOAT(val_1667,0.374017);
#define CTNODE_cmu_us_rms_dur_NO_2934 2936
DEF_STATIC_CONST_VAL_FLOAT(val_1668,1.464540);
#define CTNODE_cmu_us_rms_dur_NO_2927 2937
DEF_STATIC_CONST_VAL_FLOAT(val_1669,1.069390);
#define CTNODE_cmu_us_rms_dur_NO_2938 2940
DEF_STATIC_CONST_VAL_FLOAT(val_1670,-0.210763);
#define CTNODE_cmu_us_rms_dur_NO_2943 2945
DEF_STATIC_CONST_VAL_FLOAT(val_1671,0.145490);
#define CTNODE_cmu_us_rms_dur_NO_2942 2946
DEF_STATIC_CONST_VAL_FLOAT(val_1672,-0.574990);
#define CTNODE_cmu_us_rms_dur_NO_2946 2948
DEF_STATIC_CONST_VAL_FLOAT(val_1673,-0.212410);
#define CTNODE_cmu_us_rms_dur_NO_2941 2949
DEF_STATIC_CONST_VAL_STRING(val_1674,"ey");
DEF_STATIC_CONST_VAL_STRING(val_1675,"ey_67");
DEF_STATIC_CONST_VAL_FLOAT(val_1676,-0.071902);
#define CTNODE_cmu_us_rms_dur_NO_2950 2952
DEF_STATIC_CONST_VAL_FLOAT(val_1677,-0.289605);
#define CTNODE_cmu_us_rms_dur_NO_2949 2953
DEF_STATIC_CONST_VAL_FLOAT(val_1678,0.158205);
#define CTNODE_cmu_us_rms_dur_NO_2954 2956
DEF_STATIC_CONST_VAL_FLOAT(val_1679,-0.046705);
#define CTNODE_cmu_us_rms_dur_NO_2956 2958
DEF_STATIC_CONST_VAL_FLOAT(val_1680,-0.392514);
#define CTNODE_cmu_us_rms_dur_NO_2953 2959
DEF_STATIC_CONST_VAL_FLOAT(val_1681,-0.225998);
#define CTNODE_cmu_us_rms_dur_NO_2960 2962
DEF_STATIC_CONST_VAL_FLOAT(val_1682,0.000074);
#define CTNODE_cmu_us_rms_dur_NO_2959 2963
DEF_STATIC_CONST_VAL_FLOAT(val_1683,-0.146434);
#define CTNODE_cmu_us_rms_dur_NO_2963 2965
DEF_STATIC_CONST_VAL_FLOAT(val_1684,0.103641);
#define CTNODE_cmu_us_rms_dur_NO_2966 2968
DEF_STATIC_CONST_VAL_FLOAT(val_1685,-0.384402);
#define CTNODE_cmu_us_rms_dur_NO_2965 2969
DEF_STATIC_CONST_VAL_FLOAT(val_1686,0.863031);
#define CTNODE_cmu_us_rms_dur_NO_2973 2975
DEF_STATIC_CONST_VAL_FLOAT(val_1687,0.364595);
#define CTNODE_cmu_us_rms_dur_NO_2972 2976
DEF_STATIC_CONST_VAL_FLOAT(val_1688,0.142186);
#define CTNODE_cmu_us_rms_dur_NO_2971 2977
DEF_STATIC_CONST_VAL_FLOAT(val_1689,-0.050705);
#define CTNODE_cmu_us_rms_dur_NO_2970 2978
DEF_STATIC_CONST_VAL_FLOAT(val_1690,0.559059);
#define CTNODE_cmu_us_rms_dur_NO_2978 2980
DEF_STATIC_CONST_VAL_FLOAT(val_1691,1.012970);
#define CTNODE_cmu_us_rms_dur_NO_2969 2981
DEF_STATIC_CONST_VAL_FLOAT(val_1692,0.973913);
#define CTNODE_cmu_us_rms_dur_NO_2982 2984
DEF_STATIC_CONST_VAL_FLOAT(val_1693,0.203677);
#define CTNODE_cmu_us_rms_dur_NO_2981 2985
DEF_STATIC_CONST_VAL_FLOAT(val_1694,0.658832);
#define CTNODE_cmu_us_rms_dur_NO_2985 2987
DEF_STATIC_CONST_VAL_FLOAT(val_1695,-0.283430);
#define CTNODE_cmu_us_rms_dur_NO_2988 2990
DEF_STATIC_CONST_VAL_FLOAT(val_1696,-0.172847);
#define CTNODE_cmu_us_rms_dur_NO_2987 2991
DEF_STATIC_CONST_VAL_FLOAT(val_1697,0.299039);
#define CTNODE_cmu_us_rms_dur_NO_2992 2994
DEF_STATIC_CONST_VAL_FLOAT(val_1698,0.568659);
#define CTNODE_cmu_us_rms_dur_NO_2991 2995
DEF_STATIC_CONST_VAL_FLOAT(val_1699,0.349813);
#define CTNODE_cmu_us_rms_dur_NO_2995 2997
DEF_STATIC_CONST_VAL_FLOAT(val_1700,-0.008977);
#define CTNODE_cmu_us_rms_dur_NO_2998 3000
DEF_STATIC_CONST_VAL_FLOAT(val_1701,-0.213634);
#define CTNODE_cmu_us_rms_dur_NO_2997 3001
DEF_STATIC_CONST_VAL_FLOAT(val_1702,0.251086);
#define CTNODE_cmu_us_rms_dur_NO_3002 3004
DEF_STATIC_CONST_VAL_FLOAT(val_1703,-0.013506);
#define CTNODE_cmu_us_rms_dur_NO_3001 3005
DEF_STATIC_CONST_VAL_FLOAT(val_1704,-0.102483);
#define CTNODE_cmu_us_rms_dur_NO_2940 3006
DEF_STATIC_CONST_VAL_FLOAT(val_1705,0.746079);
#define CTNODE_cmu_us_rms_dur_NO_3006 3008
DEF_STATIC_CONST_VAL_FLOAT(val_1706,0.615029);
#define CTNODE_cmu_us_rms_dur_NO_3008 3010
DEF_STATIC_CONST_VAL_FLOAT(val_1707,0.166833);
#define CTNODE_cmu_us_rms_dur_NO_2937 3011
DEF_STATIC_CONST_VAL_FLOAT(val_1708,0.661443);
#define CTNODE_cmu_us_rms_dur_NO_3011 3013
DEF_STATIC_CONST_VAL_FLOAT(val_1709,0.276578);
#define CTNODE_cmu_us_rms_dur_NO_3013 3015
DEF_STATIC_CONST_VAL_FLOAT(val_1710,-0.649835);
#define CTNODE_cmu_us_rms_dur_NO_3015 3017
DEF_STATIC_CONST_VAL_FLOAT(val_1711,-0.025658);
#define CTNODE_cmu_us_rms_dur_NO_3017 3019
DEF_STATIC_CONST_VAL_FLOAT(val_1712,-0.620784);
#define CTNODE_cmu_us_rms_dur_NO_3020 3022
DEF_STATIC_CONST_VAL_FLOAT(val_1713,-0.341263);
#define CTNODE_cmu_us_rms_dur_NO_3019 3023
DEF_STATIC_CONST_VAL_FLOAT(val_1714,-0.141837);
#define CTNODE_cmu_us_rms_dur_NO_3023 3025
DEF_STATIC_CONST_VAL_FLOAT(val_1715,-0.469569);
#define CTNODE_cmu_us_rms_dur_NO_2922 3026
DEF_STATIC_CONST_VAL_STRING(val_1716,"f_72");
DEF_STATIC_CONST_VAL_FLOAT(val_1717,0.522831);
#define CTNODE_cmu_us_rms_dur_NO_3028 3030
DEF_STATIC_CONST_VAL_FLOAT(val_1718,0.760434);
#define CTNODE_cmu_us_rms_dur_NO_3027 3031
DEF_STATIC_CONST_VAL_FLOAT(val_1719,0.709735);
#define CTNODE_cmu_us_rms_dur_NO_3031 3033
DEF_STATIC_CONST_VAL_FLOAT(val_1720,0.538455);
#define CTNODE_cmu_us_rms_dur_NO_3033 3035
DEF_STATIC_CONST_VAL_FLOAT(val_1721,11.000000);
DEF_STATIC_CONST_VAL_FLOAT(val_1722,0.380180);
#define CTNODE_cmu_us_rms_dur_NO_3037 3039
DEF_STATIC_CONST_VAL_FLOAT(val_1723,0.141394);
#define CTNODE_cmu_us_rms_dur_NO_3041 3043
DEF_STATIC_CONST_VAL_FLOAT(val_1724,-0.192255);
#define CTNODE_cmu_us_rms_dur_NO_3040 3044
DEF_STATIC_CONST_VAL_FLOAT(val_1725,0.570916);
#define CTNODE_cmu_us_rms_dur_NO_3044 3046
DEF_STATIC_CONST_VAL_FLOAT(val_1726,-0.172176);
#define CTNODE_cmu_us_rms_dur_NO_3046 3048
DEF_STATIC_CONST_VAL_FLOAT(val_1727,0.178117);
#define CTNODE_cmu_us_rms_dur_NO_3039 3049
DEF_STATIC_CONST_VAL_FLOAT(val_1728,0.226249);
#define CTNODE_cmu_us_rms_dur_NO_3050 3052
DEF_STATIC_CONST_VAL_FLOAT(val_1729,-0.059652);
#define CTNODE_cmu_us_rms_dur_NO_3049 3053
DEF_STATIC_CONST_VAL_FLOAT(val_1730,-0.126386);
#define CTNODE_cmu_us_rms_dur_NO_3055 3057
DEF_STATIC_CONST_VAL_FLOAT(val_1731,-0.278872);
#define CTNODE_cmu_us_rms_dur_NO_3054 3058
DEF_STATIC_CONST_VAL_FLOAT(val_1732,0.105884);
#define CTNODE_cmu_us_rms_dur_NO_3053 3059
DEF_STATIC_CONST_VAL_FLOAT(val_1733,-0.417159);
#define CTNODE_cmu_us_rms_dur_NO_3036 3060
DEF_STATIC_CONST_VAL_FLOAT(val_1734,0.266984);
#define CTNODE_cmu_us_rms_dur_NO_3062 3064
DEF_STATIC_CONST_VAL_FLOAT(val_1735,0.786356);
#define CTNODE_cmu_us_rms_dur_NO_3061 3065
DEF_STATIC_CONST_VAL_FLOAT(val_1736,-0.032100);
#define CTNODE_cmu_us_rms_dur_NO_3065 3067
DEF_STATIC_CONST_VAL_FLOAT(val_1737,0.534554);
#define CTNODE_cmu_us_rms_dur_NO_3067 3069
DEF_STATIC_CONST_VAL_FLOAT(val_1738,-0.001665);
#define CTNODE_cmu_us_rms_dur_NO_3060 3070
DEF_STATIC_CONST_VAL_FLOAT(val_1739,-0.311555);
#define CTNODE_cmu_us_rms_dur_NO_3070 3072
DEF_STATIC_CONST_VAL_FLOAT(val_1740,0.296595);
#define CTNODE_cmu_us_rms_dur_NO_3072 3074
DEF_STATIC_CONST_VAL_FLOAT(val_1741,-0.070275);
#define CTNODE_cmu_us_rms_dur_NO_3035 3075
DEF_STATIC_CONST_VAL_FLOAT(val_1742,0.082133);
#define CTNODE_cmu_us_rms_dur_NO_3075 3077
DEF_STATIC_CONST_VAL_FLOAT(val_1743,-0.092783);
#define CTNODE_cmu_us_rms_dur_NO_3077 3079
DEF_STATIC_CONST_VAL_FLOAT(val_1744,-0.486948);
#define CTNODE_cmu_us_rms_dur_NO_3079 3081
DEF_STATIC_CONST_VAL_FLOAT(val_1745,-0.294728);
#define CTNODE_cmu_us_rms_dur_NO_3026 3082
DEF_STATIC_CONST_VAL_FLOAT(val_1746,-0.108121);
#define CTNODE_cmu_us_rms_dur_NO_3083 3085
DEF_STATIC_CONST_VAL_FLOAT(val_1747,-0.714989);
#define CTNODE_cmu_us_rms_dur_NO_3085 3087
DEF_STATIC_CONST_VAL_FLOAT(val_1748,-0.267529);
#define CTNODE_cmu_us_rms_dur_NO_3082 3088
DEF_STATIC_CONST_VAL_FLOAT(val_1749,0.552541);
#define CTNODE_cmu_us_rms_dur_NO_3088 3090
DEF_STATIC_CONST_VAL_FLOAT(val_1750,0.754926);
#define CTNODE_cmu_us_rms_dur_NO_3092 3094
DEF_STATIC_CONST_VAL_FLOAT(val_1751,0.362351);
#define CTNODE_cmu_us_rms_dur_NO_3091 3095
DEF_STATIC_CONST_VAL_FLOAT(val_1752,0.374786);
#define CTNODE_cmu_us_rms_dur_NO_3095 3097
DEF_STATIC_CONST_VAL_FLOAT(val_1753,0.138530);
#define CTNODE_cmu_us_rms_dur_NO_3097 3099
DEF_STATIC_CONST_VAL_FLOAT(val_1754,-0.507756);
#define CTNODE_cmu_us_rms_dur_NO_3090 3100
DEF_STATIC_CONST_VAL_FLOAT(val_1755,-0.516796);
#define CTNODE_cmu_us_rms_dur_NO_3101 3103
DEF_STATIC_CONST_VAL_FLOAT(val_1756,-0.128271);
#define CTNODE_cmu_us_rms_dur_NO_3100 3104
DEF_STATIC_CONST_VAL_STRING(val_1757,"sh_157");
DEF_STATIC_CONST_VAL_FLOAT(val_1758,-0.469594);
#define CTNODE_cmu_us_rms_dur_NO_3105 3107
DEF_STATIC_CONST_VAL_STRING(val_1759,"sh_156");
DEF_STATIC_CONST_VAL_FLOAT(val_1760,-0.326288);
#define CTNODE_cmu_us_rms_dur_NO_3108 3110
DEF_STATIC_CONST_VAL_FLOAT(val_1761,8.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_1762,0.188396);
#define CTNODE_cmu_us_rms_dur_NO_3112 3114
DEF_STATIC_CONST_VAL_FLOAT(val_1763,0.442344);
#define CTNODE_cmu_us_rms_dur_NO_3111 3115
DEF_STATIC_CONST_VAL_FLOAT(val_1764,0.080643);
#define CTNODE_cmu_us_rms_dur_NO_3115 3117
DEF_STATIC_CONST_VAL_FLOAT(val_1765,-0.213216);
#define CTNODE_cmu_us_rms_dur_NO_3110 3118
DEF_STATIC_CONST_VAL_FLOAT(val_1766,-0.206487);
#define CTNODE_cmu_us_rms_dur_NO_3107 3119
DEF_STATIC_CONST_VAL_FLOAT(val_1767,-0.449722);
#define CTNODE_cmu_us_rms_dur_NO_3119 3121
DEF_STATIC_CONST_VAL_FLOAT(val_1768,0.118448);
#define CTNODE_cmu_us_rms_dur_NO_3122 3124
DEF_STATIC_CONST_VAL_FLOAT(val_1769,-0.314397);
#define CTNODE_cmu_us_rms_dur_NO_3121 3125
DEF_STATIC_CONST_VAL_FLOAT(val_1770,-0.386023);
#define CTNODE_cmu_us_rms_dur_NO_3104 3126
DEF_STATIC_CONST_VAL_FLOAT(val_1771,0.563912);
#define CTNODE_cmu_us_rms_dur_NO_3126 3128
DEF_STATIC_CONST_VAL_FLOAT(val_1772,0.500000);
DEF_STATIC_CONST_VAL_FLOAT(val_1773,-0.414475);
#define CTNODE_cmu_us_rms_dur_NO_3130 3132
DEF_STATIC_CONST_VAL_FLOAT(val_1774,-0.581211);
#define CTNODE_cmu_us_rms_dur_NO_3129 3133
DEF_STATIC_CONST_VAL_FLOAT(val_1775,0.396540);
#define CTNODE_cmu_us_rms_dur_NO_3134 3136
DEF_STATIC_CONST_VAL_FLOAT(val_1776,0.209831);
#define CTNODE_cmu_us_rms_dur_NO_3136 3138
DEF_STATIC_CONST_VAL_FLOAT(val_1777,-0.322929);
#define CTNODE_cmu_us_rms_dur_NO_3138 3140
DEF_STATIC_CONST_VAL_FLOAT(val_1778,-0.083024);
#define CTNODE_cmu_us_rms_dur_NO_3133 3141
DEF_STATIC_CONST_VAL_FLOAT(val_1779,-0.434900);
#define CTNODE_cmu_us_rms_dur_NO_3142 3144
DEF_STATIC_CONST_VAL_FLOAT(val_1780,-0.203464);
#define CTNODE_cmu_us_rms_dur_NO_3144 3146
DEF_STATIC_CONST_VAL_FLOAT(val_1781,0.278462);
#define CTNODE_cmu_us_rms_dur_NO_3147 3149
DEF_STATIC_CONST_VAL_FLOAT(val_1782,0.068716);
#define CTNODE_cmu_us_rms_dur_NO_3146 3150
DEF_STATIC_CONST_VAL_FLOAT(val_1783,-0.170117);
#define CTNODE_cmu_us_rms_dur_NO_3141 3151
DEF_STATIC_CONST_VAL_FLOAT(val_1784,-0.282611);
#define CTNODE_cmu_us_rms_dur_NO_3151 3153
DEF_STATIC_CONST_VAL_FLOAT(val_1785,-0.620918);
#define CTNODE_cmu_us_rms_dur_NO_3128 3154
DEF_STATIC_CONST_VAL_FLOAT(val_1786,-0.432077);
#define CTNODE_cmu_us_rms_dur_NO_3154 3156
DEF_STATIC_CONST_VAL_STRING(val_1787,"ao_17");
DEF_STATIC_CONST_VAL_FLOAT(val_1788,-0.347720);
#define CTNODE_cmu_us_rms_dur_NO_3156 3158
DEF_STATIC_CONST_VAL_FLOAT(val_1789,0.085154);
#define CTNODE_cmu_us_rms_dur_NO_3161 3163
DEF_STATIC_CONST_VAL_FLOAT(val_1790,-0.105181);
#define CTNODE_cmu_us_rms_dur_NO_3163 3165
DEF_STATIC_CONST_VAL_FLOAT(val_1791,-0.305898);
#define CTNODE_cmu_us_rms_dur_NO_3160 3166
DEF_STATIC_CONST_VAL_FLOAT(val_1792,-0.629175);
#define CTNODE_cmu_us_rms_dur_NO_3166 3168
DEF_STATIC_CONST_VAL_FLOAT(val_1793,-0.277631);
#define CTNODE_cmu_us_rms_dur_NO_3159 3169
DEF_STATIC_CONST_VAL_FLOAT(val_1794,0.341739);
#define CTNODE_cmu_us_rms_dur_NO_3158 3170
DEF_STATIC_CONST_VAL_FLOAT(val_1795,-0.474163);
#define CTNODE_cmu_us_rms_dur_NO_3171 3173
DEF_STATIC_CONST_VAL_FLOAT(val_1796,-0.102534);
#define CTNODE_cmu_us_rms_dur_NO_3170 3174
DEF_STATIC_CONST_VAL_FLOAT(val_1797,-0.345323);
#define CTNODE_cmu_us_rms_dur_NO_3174 3176
DEF_STATIC_CONST_VAL_FLOAT(val_1798,-0.154907);
#define CTNODE_cmu_us_rms_dur_NO_3177 3179
DEF_STATIC_CONST_VAL_FLOAT(val_1799,0.811095);
#define CTNODE_cmu_us_rms_dur_NO_3176 3180
DEF_STATIC_CONST_VAL_FLOAT(val_1800,7.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_1801,-0.209532);
#define CTNODE_cmu_us_rms_dur_NO_3181 3183
DEF_STATIC_CONST_VAL_STRING(val_1802,"m_113");
DEF_STATIC_CONST_VAL_FLOAT(val_1803,0.061415);
#define CTNODE_cmu_us_rms_dur_NO_3184 3186
DEF_STATIC_CONST_VAL_FLOAT(val_1804,-0.362668);
#define CTNODE_cmu_us_rms_dur_NO_3183 3187
DEF_STATIC_CONST_VAL_FLOAT(val_1805,-0.280477);
#define CTNODE_cmu_us_rms_dur_NO_3188 3190
DEF_STATIC_CONST_VAL_FLOAT(val_1806,-0.262293);
#define CTNODE_cmu_us_rms_dur_NO_3192 3194
DEF_STATIC_CONST_VAL_FLOAT(val_1807,0.005457);
#define CTNODE_cmu_us_rms_dur_NO_3196 3198
DEF_STATIC_CONST_VAL_FLOAT(val_1808,0.404325);
#define CTNODE_cmu_us_rms_dur_NO_3198 3200
DEF_STATIC_CONST_VAL_FLOAT(val_1809,0.936440);
#define CTNODE_cmu_us_rms_dur_NO_3200 3202
DEF_STATIC_CONST_VAL_FLOAT(val_1810,0.459125);
#define CTNODE_cmu_us_rms_dur_NO_3195 3203
DEF_STATIC_CONST_VAL_FLOAT(val_1811,0.011990);
#define CTNODE_cmu_us_rms_dur_NO_3194 3204
DEF_STATIC_CONST_VAL_FLOAT(val_1812,-0.230071);
#define CTNODE_cmu_us_rms_dur_NO_3204 3206
DEF_STATIC_CONST_VAL_FLOAT(val_1813,0.380504);
#define CTNODE_cmu_us_rms_dur_NO_3206 3208
DEF_STATIC_CONST_VAL_FLOAT(val_1814,0.094437);
#define CTNODE_cmu_us_rms_dur_NO_3191 3209
DEF_STATIC_CONST_VAL_FLOAT(val_1815,-0.259310);
#define CTNODE_cmu_us_rms_dur_NO_3209 3211
DEF_STATIC_CONST_VAL_FLOAT(val_1816,0.011498);
#define CTNODE_cmu_us_rms_dur_NO_3211 3213
DEF_STATIC_CONST_VAL_FLOAT(val_1817,0.230712);
#define CTNODE_cmu_us_rms_dur_NO_3190 3214
DEF_STATIC_CONST_VAL_FLOAT(val_1818,0.617636);
#define CTNODE_cmu_us_rms_dur_NO_3215 3217
DEF_STATIC_CONST_VAL_FLOAT(val_1819,-0.382253);
#define CTNODE_cmu_us_rms_dur_NO_3217 3219
DEF_STATIC_CONST_VAL_FLOAT(val_1820,-0.280581);
#define CTNODE_cmu_us_rms_dur_NO_3219 3221
DEF_STATIC_CONST_VAL_FLOAT(val_1821,-0.194985);
#define CTNODE_cmu_us_rms_dur_NO_3222 3224
DEF_STATIC_CONST_VAL_FLOAT(val_1822,0.460069);
#define CTNODE_cmu_us_rms_dur_NO_3225 3227
DEF_STATIC_CONST_VAL_FLOAT(val_1823,0.428837);
#define CTNODE_cmu_us_rms_dur_NO_3228 3230
DEF_STATIC_CONST_VAL_FLOAT(val_1824,0.125562);
#define CTNODE_cmu_us_rms_dur_NO_3227 3231
DEF_STATIC_CONST_VAL_FLOAT(val_1825,-0.093531);
#define CTNODE_cmu_us_rms_dur_NO_3224 3232
DEF_STATIC_CONST_VAL_FLOAT(val_1826,0.081081);
#define CTNODE_cmu_us_rms_dur_NO_3232 3234
DEF_STATIC_CONST_VAL_FLOAT(val_1827,-0.208854);
#define CTNODE_cmu_us_rms_dur_NO_3221 3235
DEF_STATIC_CONST_VAL_FLOAT(val_1828,-0.221117);
#define CTNODE_cmu_us_rms_dur_NO_3214 3236
DEF_STATIC_CONST_VAL_FLOAT(val_1829,3.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_1830,-0.165312);
#define CTNODE_cmu_us_rms_dur_NO_3237 3239
DEF_STATIC_CONST_VAL_FLOAT(val_1831,0.100346);
#define CTNODE_cmu_us_rms_dur_NO_3236 3240
DEF_STATIC_CONST_VAL_FLOAT(val_1832,0.610772);
#define CTNODE_cmu_us_rms_dur_NO_3187 3241
DEF_STATIC_CONST_VAL_FLOAT(val_1833,-0.044626);
#define CTNODE_cmu_us_rms_dur_NO_3241 3243
DEF_STATIC_CONST_VAL_FLOAT(val_1834,0.421033);
#define CTNODE_cmu_us_rms_dur_NO_3244 3246
DEF_STATIC_CONST_VAL_FLOAT(val_1835,0.069182);
#define CTNODE_cmu_us_rms_dur_NO_3243 3247
DEF_STATIC_CONST_VAL_FLOAT(val_1836,0.687973);
#define CTNODE_cmu_us_rms_dur_NO_3180 3248
DEF_STATIC_CONST_VAL_FLOAT(val_1837,-0.076600);
#define CTNODE_cmu_us_rms_dur_NO_3249 3251
DEF_STATIC_CONST_VAL_FLOAT(val_1838,-0.374136);
#define CTNODE_cmu_us_rms_dur_NO_3248 3252
DEF_STATIC_CONST_VAL_FLOAT(val_1839,0.150533);
#define CTNODE_cmu_us_rms_dur_NO_3252 3254
DEF_STATIC_CONST_VAL_FLOAT(val_1840,-0.189827);
#define CTNODE_cmu_us_rms_dur_NO_2847 3255
DEF_STATIC_CONST_VAL_FLOAT(val_1841,0.765629);
#define CTNODE_cmu_us_rms_dur_NO_3256 3258
DEF_STATIC_CONST_VAL_FLOAT(val_1842,0.131855);
#define CTNODE_cmu_us_rms_dur_NO_3259 3261
DEF_STATIC_CONST_VAL_FLOAT(val_1843,0.532765);
#define CTNODE_cmu_us_rms_dur_NO_3258 3262
DEF_STATIC_CONST_VAL_FLOAT(val_1844,-0.099761);
#define CTNODE_cmu_us_rms_dur_NO_3255 3263
DEF_STATIC_CONST_VAL_FLOAT(val_1845,0.923980);
#define CTNODE_cmu_us_rms_dur_NO_3265 3267
DEF_STATIC_CONST_VAL_FLOAT(val_1846,0.213869);
#define CTNODE_cmu_us_rms_dur_NO_3264 3268
DEF_STATIC_CONST_VAL_FLOAT(val_1847,0.519469);
#define CTNODE_cmu_us_rms_dur_NO_3268 3270
DEF_STATIC_CONST_VAL_FLOAT(val_1848,0.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_1849,0.027785);
#define CTNODE_cmu_us_rms_dur_NO_3270 3272
DEF_STATIC_CONST_VAL_FLOAT(val_1850,-0.330960);
#define CTNODE_cmu_us_rms_dur_NO_3263 3273
DEF_STATIC_CONST_VAL_FLOAT(val_1851,-0.261662);
#define CTNODE_cmu_us_rms_dur_NO_3276 3278
DEF_STATIC_CONST_VAL_FLOAT(val_1852,-0.453114);
#define CTNODE_cmu_us_rms_dur_NO_3275 3279
DEF_STATIC_CONST_VAL_FLOAT(val_1853,-0.556572);
#define CTNODE_cmu_us_rms_dur_NO_3274 3280
DEF_STATIC_CONST_VAL_FLOAT(val_1854,0.254348);
#define CTNODE_cmu_us_rms_dur_NO_3281 3283
DEF_STATIC_CONST_VAL_FLOAT(val_1855,-0.129627);
#define CTNODE_cmu_us_rms_dur_NO_3280 3284
DEF_STATIC_CONST_VAL_FLOAT(val_1856,-0.486505);
#define CTNODE_cmu_us_rms_dur_NO_3286 3288
DEF_STATIC_CONST_VAL_FLOAT(val_1857,-0.577260);
#define CTNODE_cmu_us_rms_dur_NO_3285 3289
DEF_STATIC_CONST_VAL_FLOAT(val_1858,-0.415095);
#define CTNODE_cmu_us_rms_dur_NO_3289 3291
DEF_STATIC_CONST_VAL_FLOAT(val_1859,-0.145745);
#define CTNODE_cmu_us_rms_dur_NO_3284 3292
DEF_STATIC_CONST_VAL_FLOAT(val_1860,-0.414252);
#define CTNODE_cmu_us_rms_dur_NO_3292 3294
DEF_STATIC_CONST_VAL_FLOAT(val_1861,0.135772);
#define CTNODE_cmu_us_rms_dur_NO_3294 3296
DEF_STATIC_CONST_VAL_FLOAT(val_1862,-0.182493);
#define CTNODE_cmu_us_rms_dur_NO_3297 3299
DEF_STATIC_CONST_VAL_FLOAT(val_1863,-0.339518);
#define CTNODE_cmu_us_rms_dur_NO_3296 3300
DEF_STATIC_CONST_VAL_FLOAT(val_1864,-0.067763);
#define CTNODE_cmu_us_rms_dur_NO_3273 3301
DEF_STATIC_CONST_VAL_FLOAT(val_1865,-0.216367);
#define CTNODE_cmu_us_rms_dur_NO_3302 3304
DEF_STATIC_CONST_VAL_FLOAT(val_1866,-0.591035);
#define CTNODE_cmu_us_rms_dur_NO_3301 3305
DEF_STATIC_CONST_VAL_FLOAT(val_1867,-0.309981);
#define CTNODE_cmu_us_rms_dur_NO_3307 3309
DEF_STATIC_CONST_VAL_FLOAT(val_1868,-0.538846);
#define CTNODE_cmu_us_rms_dur_NO_3306 3310
DEF_STATIC_CONST_VAL_FLOAT(val_1869,0.013055);
#define CTNODE_cmu_us_rms_dur_NO_3305 3311
DEF_STATIC_CONST_VAL_FLOAT(val_1870,0.632054);
#define CTNODE_cmu_us_rms_dur_NO_3313 3315
DEF_STATIC_CONST_VAL_FLOAT(val_1871,0.384512);
#define CTNODE_cmu_us_rms_dur_NO_3312 3316
DEF_STATIC_CONST_VAL_FLOAT(val_1872,-0.006643);
#define CTNODE_cmu_us_rms_dur_NO_3311 3317
DEF_STATIC_CONST_VAL_FLOAT(val_1873,0.152333);
#define CTNODE_cmu_us_rms_dur_NO_3320 3322
DEF_STATIC_CONST_VAL_FLOAT(val_1874,0.801243);
#define CTNODE_cmu_us_rms_dur_NO_3319 3323
DEF_STATIC_CONST_VAL_FLOAT(val_1875,0.273324);
#define CTNODE_cmu_us_rms_dur_NO_3323 3325
DEF_STATIC_CONST_VAL_FLOAT(val_1876,11.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_1877,-0.091043);
#define CTNODE_cmu_us_rms_dur_NO_3325 3327
DEF_STATIC_CONST_VAL_FLOAT(val_1878,-0.100222);
#define CTNODE_cmu_us_rms_dur_NO_3318 3328
DEF_STATIC_CONST_VAL_STRING(val_1879,"w_189");
DEF_STATIC_CONST_VAL_FLOAT(val_1880,-0.575832);
#define CTNODE_cmu_us_rms_dur_NO_3329 3331
DEF_STATIC_CONST_VAL_FLOAT(val_1881,-0.160490);
#define CTNODE_cmu_us_rms_dur_NO_3328 3332
DEF_STATIC_CONST_VAL_FLOAT(val_1882,-0.063083);
#define CTNODE_cmu_us_rms_dur_NO_3332 3334
DEF_STATIC_CONST_VAL_FLOAT(val_1883,0.262636);
#define CTNODE_cmu_us_rms_dur_NO_3317 3335
DEF_STATIC_CONST_VAL_FLOAT(val_1884,0.417491);
#define CTNODE_cmu_us_rms_dur_NO_3338 3340
DEF_STATIC_CONST_VAL_FLOAT(val_1885,-0.184566);
#define CTNODE_cmu_us_rms_dur_NO_3337 3341
DEF_STATIC_CONST_VAL_FLOAT(val_1886,-0.157241);
#define CTNODE_cmu_us_rms_dur_NO_3342 3344
DEF_STATIC_CONST_VAL_FLOAT(val_1887,0.242974);
#define CTNODE_cmu_us_rms_dur_NO_3341 3345
DEF_STATIC_CONST_VAL_FLOAT(val_1888,-0.446668);
#define CTNODE_cmu_us_rms_dur_NO_3345 3347
DEF_STATIC_CONST_VAL_FLOAT(val_1889,0.150850);
#define CTNODE_cmu_us_rms_dur_NO_3347 3349
DEF_STATIC_CONST_VAL_FLOAT(val_1890,-0.584799);
#define CTNODE_cmu_us_rms_dur_NO_3351 3353
DEF_STATIC_CONST_VAL_FLOAT(val_1891,-0.045425);
#define CTNODE_cmu_us_rms_dur_NO_3353 3355
DEF_STATIC_CONST_VAL_FLOAT(val_1892,-0.442701);
#define CTNODE_cmu_us_rms_dur_NO_3355 3357
DEF_STATIC_CONST_VAL_FLOAT(val_1893,-0.270352);
#define CTNODE_cmu_us_rms_dur_NO_3350 3358
DEF_STATIC_CONST_VAL_FLOAT(val_1894,0.086137);
#define CTNODE_cmu_us_rms_dur_NO_3349 3359
DEF_STATIC_CONST_VAL_FLOAT(val_1895,-0.331173);
#define CTNODE_cmu_us_rms_dur_NO_3359 3361
DEF_STATIC_CONST_VAL_FLOAT(val_1896,-0.586922);
#define CTNODE_cmu_us_rms_dur_NO_3336 3362
DEF_STATIC_CONST_VAL_FLOAT(val_1897,0.344084);
#define CTNODE_cmu_us_rms_dur_NO_3363 3365
DEF_STATIC_CONST_VAL_FLOAT(val_1898,0.182809);
#define CTNODE_cmu_us_rms_dur_NO_3362 3366
DEF_STATIC_CONST_VAL_FLOAT(val_1899,-0.166042);
#define CTNODE_cmu_us_rms_dur_NO_3335 3367
DEF_STATIC_CONST_VAL_FLOAT(val_1900,-0.574250);
#define CTNODE_cmu_us_rms_dur_NO_2738 3368
DEF_STATIC_CONST_VAL_STRING(val_1901,"k_103");
DEF_STATIC_CONST_VAL_FLOAT(val_1902,0.332446);
#define CTNODE_cmu_us_rms_dur_NO_3369 3371
DEF_STATIC_CONST_VAL_FLOAT(val_1903,1.040390);
#define CTNODE_cmu_us_rms_dur_NO_3371 3373
DEF_STATIC_CONST_VAL_FLOAT(val_1904,0.885718);
#define CTNODE_cmu_us_rms_dur_NO_3373 3375
DEF_STATIC_CONST_VAL_FLOAT(val_1905,0.659754);
#define CTNODE_cmu_us_rms_dur_NO_3368 3376
DEF_STATIC_CONST_VAL_FLOAT(val_1906,-0.619923);
#define CTNODE_cmu_us_rms_dur_NO_3378 3380
DEF_STATIC_CONST_VAL_FLOAT(val_1907,-0.681286);
#define CTNODE_cmu_us_rms_dur_NO_3381 3383
DEF_STATIC_CONST_VAL_FLOAT(val_1908,-0.295200);
#define CTNODE_cmu_us_rms_dur_NO_3380 3384
DEF_STATIC_CONST_VAL_FLOAT(val_1909,0.087436);
#define CTNODE_cmu_us_rms_dur_NO_3385 3387
DEF_STATIC_CONST_VAL_FLOAT(val_1910,-0.425453);
#define CTNODE_cmu_us_rms_dur_NO_3387 3389
DEF_STATIC_CONST_VAL_FLOAT(val_1911,-0.212205);
#define CTNODE_cmu_us_rms_dur_NO_3389 3391
DEF_STATIC_CONST_VAL_FLOAT(val_1912,-0.002115);
#define CTNODE_cmu_us_rms_dur_NO_3384 3392
DEF_STATIC_CONST_VAL_FLOAT(val_1913,-0.454607);
#define CTNODE_cmu_us_rms_dur_NO_3393 3395
DEF_STATIC_CONST_VAL_FLOAT(val_1914,-0.148700);
#define CTNODE_cmu_us_rms_dur_NO_3392 3396
DEF_STATIC_CONST_VAL_FLOAT(val_1915,-0.542918);
#define CTNODE_cmu_us_rms_dur_NO_3377 3397
DEF_STATIC_CONST_VAL_FLOAT(val_1916,0.608403);
#define CTNODE_cmu_us_rms_dur_NO_3398 3400
DEF_STATIC_CONST_VAL_FLOAT(val_1917,0.458753);
#define CTNODE_cmu_us_rms_dur_NO_3400 3402
DEF_STATIC_CONST_VAL_FLOAT(val_1918,0.235119);
#define CTNODE_cmu_us_rms_dur_NO_3402 3404
DEF_STATIC_CONST_VAL_FLOAT(val_1919,-0.193920);
#define CTNODE_cmu_us_rms_dur_NO_3397 3405
DEF_STATIC_CONST_VAL_FLOAT(val_1920,0.702782);
#define CTNODE_cmu_us_rms_dur_NO_3376 3406
DEF_STATIC_CONST_VAL_FLOAT(val_1921,1.600480);
#define CTNODE_cmu_us_rms_dur_NO_3407 3409
DEF_STATIC_CONST_VAL_FLOAT(val_1922,1.026730);
#define CTNODE_cmu_us_rms_dur_NO_3409 3411
DEF_STATIC_CONST_VAL_FLOAT(val_1923,0.676937);
#define CTNODE_cmu_us_rms_dur_NO_3411 3413
DEF_STATIC_CONST_VAL_FLOAT(val_1924,0.171197);
#define CTNODE_cmu_us_rms_dur_NO_3406 3414
DEF_STATIC_CONST_VAL_FLOAT(val_1925,0.084745);
#define CTNODE_cmu_us_rms_dur_NO_3417 3419
DEF_STATIC_CONST_VAL_FLOAT(val_1926,-0.190786);
#define CTNODE_cmu_us_rms_dur_NO_3416 3420
DEF_STATIC_CONST_VAL_FLOAT(val_1927,-0.355620);
#define CTNODE_cmu_us_rms_dur_NO_3415 3421
DEF_STATIC_CONST_VAL_FLOAT(val_1928,0.198962);
#define CTNODE_cmu_us_rms_dur_NO_3423 3425
DEF_STATIC_CONST_VAL_FLOAT(val_1929,1.302790);
#define CTNODE_cmu_us_rms_dur_NO_3425 3427
DEF_STATIC_CONST_VAL_FLOAT(val_1930,0.864670);
#define CTNODE_cmu_us_rms_dur_NO_3427 3429
DEF_STATIC_CONST_VAL_FLOAT(val_1931,0.548149);
#define CTNODE_cmu_us_rms_dur_NO_3422 3430
DEF_STATIC_CONST_VAL_FLOAT(val_1932,-0.268462);
#define CTNODE_cmu_us_rms_dur_NO_3430 3432
DEF_STATIC_CONST_VAL_FLOAT(val_1933,0.023997);
#define CTNODE_cmu_us_rms_dur_NO_3434 3436
DEF_STATIC_CONST_VAL_FLOAT(val_1934,0.089060);
#define CTNODE_cmu_us_rms_dur_NO_3436 3438
DEF_STATIC_CONST_VAL_FLOAT(val_1935,0.255586);
#define CTNODE_cmu_us_rms_dur_NO_3438 3440
DEF_STATIC_CONST_VAL_FLOAT(val_1936,0.644640);
#define CTNODE_cmu_us_rms_dur_NO_3433 3441
DEF_STATIC_CONST_VAL_FLOAT(val_1937,-0.108497);
#define CTNODE_cmu_us_rms_dur_NO_3432 3442
DEF_STATIC_CONST_VAL_FLOAT(val_1938,1.034670);
#define CTNODE_cmu_us_rms_dur_NO_3442 3444
DEF_STATIC_CONST_VAL_FLOAT(val_1939,0.729843);
#define CTNODE_cmu_us_rms_dur_NO_3445 3447
DEF_STATIC_CONST_VAL_FLOAT(val_1940,0.155163);
#define CTNODE_cmu_us_rms_dur_NO_3444 3448
DEF_STATIC_CONST_VAL_FLOAT(val_1941,-0.025913);
#define CTNODE_cmu_us_rms_dur_NO_3421 3449
DEF_STATIC_CONST_VAL_STRING(val_1942,"g_76");
DEF_STATIC_CONST_VAL_FLOAT(val_1943,-0.502292);
#define CTNODE_cmu_us_rms_dur_NO_3450 3452
DEF_STATIC_CONST_VAL_FLOAT(val_1944,0.022496);
#define CTNODE_cmu_us_rms_dur_NO_3449 3453
DEF_STATIC_CONST_VAL_FLOAT(val_1945,0.512044);
#define CTNODE_cmu_us_rms_dur_NO_3455 3457
DEF_STATIC_CONST_VAL_FLOAT(val_1946,1.050810);
#define CTNODE_cmu_us_rms_dur_NO_3454 3458
DEF_STATIC_CONST_VAL_FLOAT(val_1947,0.207811);
#define CTNODE_cmu_us_rms_dur_NO_3453 3459
DEF_STATIC_CONST_VAL_FLOAT(val_1948,0.632124);
#define CTNODE_cmu_us_rms_dur_NO_3459 3461
DEF_STATIC_CONST_VAL_FLOAT(val_1949,0.792035);
#define CTNODE_cmu_us_rms_dur_NO_3462 3464
DEF_STATIC_CONST_VAL_FLOAT(val_1950,0.633762);
#define CTNODE_cmu_us_rms_dur_NO_3465 3467
DEF_STATIC_CONST_VAL_FLOAT(val_1951,0.315677);
#define CTNODE_cmu_us_rms_dur_NO_3468 3470
DEF_STATIC_CONST_VAL_FLOAT(val_1952,-0.035449);
#define CTNODE_cmu_us_rms_dur_NO_3467 3471
DEF_STATIC_CONST_VAL_FLOAT(val_1953,0.499178);
#define CTNODE_cmu_us_rms_dur_NO_3464 3472
DEF_STATIC_CONST_VAL_FLOAT(val_1954,0.315551);
#define CTNODE_cmu_us_rms_dur_NO_3472 3474
DEF_STATIC_CONST_VAL_FLOAT(val_1955,0.003789);
#define CTNODE_cmu_us_rms_dur_NO_3474 3476
DEF_STATIC_CONST_VAL_FLOAT(val_1956,-0.000587);
#define CTNODE_cmu_us_rms_dur_NO_3476 3478
DEF_STATIC_CONST_VAL_FLOAT(val_1957,0.286821);
#define CTNODE_cmu_us_rms_dur_NO_3461 3479
DEF_STATIC_CONST_VAL_FLOAT(val_1958,-0.345996);
#define CTNODE_cmu_us_rms_dur_NO_3479 3481
DEF_STATIC_CONST_VAL_FLOAT(val_1959,-0.057170);
#define CTNODE_cmu_us_rms_dur_NO_3482 3484
DEF_STATIC_CONST_VAL_FLOAT(val_1960,0.446591);
#define CTNODE_cmu_us_rms_dur_NO_3484 3486
DEF_STATIC_CONST_VAL_FLOAT(val_1961,0.825755);
#define CTNODE_cmu_us_rms_dur_NO_3481 3487
DEF_STATIC_CONST_VAL_STRING(val_1962,"g_78");
DEF_STATIC_CONST_VAL_FLOAT(val_1963,0.523017);
#define CTNODE_cmu_us_rms_dur_NO_3487 3489
DEF_STATIC_CONST_VAL_FLOAT(val_1964,-0.284489);
#define CTNODE_cmu_us_rms_dur_NO_3490 3492
DEF_STATIC_CONST_VAL_FLOAT(val_1965,-0.104932);
#define CTNODE_cmu_us_rms_dur_NO_3492 3494
DEF_STATIC_CONST_VAL_FLOAT(val_1966,0.094548);
#define CTNODE_cmu_us_rms_dur_NO_3494 3496
DEF_STATIC_CONST_VAL_FLOAT(val_1967,0.203058);
#define CTNODE_cmu_us_rms_dur_NO_3489 3497
DEF_STATIC_CONST_VAL_FLOAT(val_1968,-0.413237);
#define CTNODE_cmu_us_rms_dur_NO_3498 3500
DEF_STATIC_CONST_VAL_FLOAT(val_1969,0.351045);
#define CTNODE_cmu_us_rms_dur_NO_3497 3501
DEF_STATIC_CONST_VAL_FLOAT(val_1970,0.378285);
#define CTNODE_cmu_us_rms_dur_NO_3503 3505
DEF_STATIC_CONST_VAL_FLOAT(val_1971,9.800000);
DEF_STATIC_CONST_VAL_FLOAT(val_1972,0.103438);
#define CTNODE_cmu_us_rms_dur_NO_3505 3507
DEF_STATIC_CONST_VAL_FLOAT(val_1973,-0.048132);
#define CTNODE_cmu_us_rms_dur_NO_3502 3508
DEF_STATIC_CONST_VAL_FLOAT(val_1974,0.094495);
#define CTNODE_cmu_us_rms_dur_NO_3508 3510
DEF_STATIC_CONST_VAL_FLOAT(val_1975,-0.093513);
#define CTNODE_cmu_us_rms_dur_NO_3510 3512
DEF_STATIC_CONST_VAL_FLOAT(val_1976,-0.292560);
#define CTNODE_cmu_us_rms_dur_NO_3501 3513
DEF_STATIC_CONST_VAL_FLOAT(val_1977,0.065199);
#define CTNODE_cmu_us_rms_dur_NO_3513 3515
DEF_STATIC_CONST_VAL_FLOAT(val_1978,0.351063);
#define CTNODE_cmu_us_rms_dur_NO_3516 3518
DEF_STATIC_CONST_VAL_FLOAT(val_1979,0.143468);
#define CTNODE_cmu_us_rms_dur_NO_3515 3519
DEF_STATIC_CONST_VAL_FLOAT(val_1980,0.618969);
#define CTNODE_cmu_us_rms_dur_NO_3414 3520
DEF_STATIC_CONST_VAL_FLOAT(val_1981,-0.410445);
#define CTNODE_cmu_us_rms_dur_NO_3520 3522
DEF_STATIC_CONST_VAL_FLOAT(val_1982,0.229532);
#define CTNODE_cmu_us_rms_dur_NO_3525 3527
DEF_STATIC_CONST_VAL_FLOAT(val_1983,0.729766);
#define CTNODE_cmu_us_rms_dur_NO_3524 3528
DEF_STATIC_CONST_VAL_FLOAT(val_1984,-0.296589);
#define CTNODE_cmu_us_rms_dur_NO_3528 3530
DEF_STATIC_CONST_VAL_FLOAT(val_1985,0.423227);
#define CTNODE_cmu_us_rms_dur_NO_3530 3532
DEF_STATIC_CONST_VAL_FLOAT(val_1986,-0.244033);
#define CTNODE_cmu_us_rms_dur_NO_3532 3534
DEF_STATIC_CONST_VAL_FLOAT(val_1987,-0.236967);
#define CTNODE_cmu_us_rms_dur_NO_3534 3536
DEF_STATIC_CONST_VAL_FLOAT(val_1988,0.134231);
#define CTNODE_cmu_us_rms_dur_NO_3540 3542
DEF_STATIC_CONST_VAL_FLOAT(val_1989,-0.015101);
#define CTNODE_cmu_us_rms_dur_NO_3539 3543
DEF_STATIC_CONST_VAL_FLOAT(val_1990,-0.150678);
#define CTNODE_cmu_us_rms_dur_NO_3538 3544
DEF_STATIC_CONST_VAL_FLOAT(val_1991,0.163185);
#define CTNODE_cmu_us_rms_dur_NO_3537 3545
DEF_STATIC_CONST_VAL_FLOAT(val_1992,0.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_1993,-0.094291);
#define CTNODE_cmu_us_rms_dur_NO_3545 3547
DEF_STATIC_CONST_VAL_FLOAT(val_1994,0.324655);
#define CTNODE_cmu_us_rms_dur_NO_3549 3551
DEF_STATIC_CONST_VAL_FLOAT(val_1995,0.193440);
#define CTNODE_cmu_us_rms_dur_NO_3551 3553
DEF_STATIC_CONST_VAL_FLOAT(val_1996,-0.170947);
#define CTNODE_cmu_us_rms_dur_NO_3548 3554
DEF_STATIC_CONST_VAL_FLOAT(val_1997,0.187390);
#define CTNODE_cmu_us_rms_dur_NO_3554 3556
DEF_STATIC_CONST_VAL_FLOAT(val_1998,0.529907);
#define CTNODE_cmu_us_rms_dur_NO_3547 3557
DEF_STATIC_CONST_VAL_FLOAT(val_1999,0.577209);
#define CTNODE_cmu_us_rms_dur_NO_3536 3558
DEF_STATIC_CONST_VAL_FLOAT(val_2000,-0.217934);
#define CTNODE_cmu_us_rms_dur_NO_3523 3559
DEF_STATIC_CONST_VAL_FLOAT(val_2001,0.247054);
#define CTNODE_cmu_us_rms_dur_NO_3559 3561
DEF_STATIC_CONST_VAL_FLOAT(val_2002,0.649726);
#define CTNODE_cmu_us_rms_dur_NO_3522 3562
DEF_STATIC_CONST_VAL_FLOAT(val_2003,-0.383934);
#define CTNODE_cmu_us_rms_dur_NO_3562 3564
DEF_STATIC_CONST_VAL_FLOAT(val_2004,-0.365698);
#define CTNODE_cmu_us_rms_dur_NO_3564 3566
DEF_STATIC_CONST_VAL_FLOAT(val_2005,-0.039944);
#define CTNODE_cmu_us_rms_dur_NO_3567 3569
DEF_STATIC_CONST_VAL_FLOAT(val_2006,-0.364510);
#define CTNODE_cmu_us_rms_dur_NO_3566 3570
DEF_STATIC_CONST_VAL_FLOAT(val_2007,-0.131058);
#define CTNODE_cmu_us_rms_dur_NO_3570 3572
DEF_STATIC_CONST_VAL_FLOAT(val_2008,0.470060);
#define CTNODE_cmu_us_rms_dur_NO_3573 3575
DEF_STATIC_CONST_VAL_FLOAT(val_2009,0.171021);
#define CTNODE_cmu_us_rms_dur_NO_3572 3576
DEF_STATIC_CONST_VAL_FLOAT(val_2010,0.003158);
#define CTNODE_cmu_us_rms_dur_NO_3576 3578
DEF_STATIC_CONST_VAL_FLOAT(val_2011,0.054542);
#define CTNODE_cmu_us_rms_dur_NO_2281 3579
DEF_STATIC_CONST_VAL_FLOAT(val_2012,-0.566463);
#define CTNODE_cmu_us_rms_dur_NO_3582 3584
DEF_STATIC_CONST_VAL_FLOAT(val_2013,-0.718057);
#define CTNODE_cmu_us_rms_dur_NO_3581 3585
DEF_STATIC_CONST_VAL_FLOAT(val_2014,-0.337290);
#define CTNODE_cmu_us_rms_dur_NO_3586 3588
DEF_STATIC_CONST_VAL_FLOAT(val_2015,-0.729162);
#define CTNODE_cmu_us_rms_dur_NO_3588 3590
DEF_STATIC_CONST_VAL_FLOAT(val_2016,-0.580050);
#define CTNODE_cmu_us_rms_dur_NO_3585 3591
DEF_STATIC_CONST_VAL_FLOAT(val_2017,-0.596255);
#define CTNODE_cmu_us_rms_dur_NO_3592 3594
DEF_STATIC_CONST_VAL_FLOAT(val_2018,-0.426784);
#define CTNODE_cmu_us_rms_dur_NO_3594 3596
DEF_STATIC_CONST_VAL_FLOAT(val_2019,-0.243766);
#define CTNODE_cmu_us_rms_dur_NO_3591 3597
DEF_STATIC_CONST_VAL_FLOAT(val_2020,-0.114054);
#define CTNODE_cmu_us_rms_dur_NO_3597 3599
DEF_STATIC_CONST_VAL_FLOAT(val_2021,-0.073979);
#define CTNODE_cmu_us_rms_dur_NO_3580 3600
DEF_STATIC_CONST_VAL_FLOAT(val_2022,-0.875180);
#define CTNODE_cmu_us_rms_dur_NO_3600 3602
DEF_STATIC_CONST_VAL_FLOAT(val_2023,-0.530998);
#define CTNODE_cmu_us_rms_dur_NO_3604 3606
DEF_STATIC_CONST_VAL_FLOAT(val_2024,-0.644036);
#define CTNODE_cmu_us_rms_dur_NO_3603 3607
DEF_STATIC_CONST_VAL_FLOAT(val_2025,-0.469048);
#define CTNODE_cmu_us_rms_dur_NO_3602 3608
DEF_STATIC_CONST_VAL_FLOAT(val_2026,-0.643941);
#define CTNODE_cmu_us_rms_dur_NO_3608 3610
DEF_STATIC_CONST_VAL_FLOAT(val_2027,-0.631746);
#define CTNODE_cmu_us_rms_dur_NO_3611 3613
DEF_STATIC_CONST_VAL_FLOAT(val_2028,-0.477448);
#define CTNODE_cmu_us_rms_dur_NO_3614 3616
DEF_STATIC_CONST_VAL_FLOAT(val_2029,-0.406969);
#define CTNODE_cmu_us_rms_dur_NO_3616 3618
DEF_STATIC_CONST_VAL_FLOAT(val_2030,-0.195141);
#define CTNODE_cmu_us_rms_dur_NO_3613 3619
DEF_STATIC_CONST_VAL_FLOAT(val_2031,-0.040307);
#define CTNODE_cmu_us_rms_dur_NO_3610 3620
DEF_STATIC_CONST_VAL_FLOAT(val_2032,0.513888);
#define CTNODE_cmu_us_rms_dur_NO_3621 3623
DEF_STATIC_CONST_VAL_FLOAT(val_2033,0.146480);
#define CTNODE_cmu_us_rms_dur_NO_3620 3624
DEF_STATIC_CONST_VAL_FLOAT(val_2034,0.378176);
#define CTNODE_cmu_us_rms_dur_NO_3624 3626
DEF_STATIC_CONST_VAL_FLOAT(val_2035,0.284232);
#define CTNODE_cmu_us_rms_dur_NO_3626 3628
DEF_STATIC_CONST_VAL_FLOAT(val_2036,0.004419);
#define CTNODE_cmu_us_rms_dur_NO_3629 3631
DEF_STATIC_CONST_VAL_FLOAT(val_2037,0.358325);
#define CTNODE_cmu_us_rms_dur_NO_3628 3632
DEF_STATIC_CONST_VAL_FLOAT(val_2038,-0.064162);
#define CTNODE_cmu_us_rms_dur_NO_3633 3635
DEF_STATIC_CONST_VAL_FLOAT(val_2039,0.452618);
#define CTNODE_cmu_us_rms_dur_NO_3632 3636
DEF_STATIC_CONST_VAL_FLOAT(val_2040,-0.210254);
#define CTNODE_cmu_us_rms_dur_NO_3638 3640
DEF_STATIC_CONST_VAL_FLOAT(val_2041,-0.168332);
#define CTNODE_cmu_us_rms_dur_NO_3641 3643
DEF_STATIC_CONST_VAL_FLOAT(val_2042,-0.113154);
#define CTNODE_cmu_us_rms_dur_NO_3643 3645
DEF_STATIC_CONST_VAL_FLOAT(val_2043,0.292725);
#define CTNODE_cmu_us_rms_dur_NO_3645 3647
DEF_STATIC_CONST_VAL_FLOAT(val_2044,-0.009258);
#define CTNODE_cmu_us_rms_dur_NO_3640 3648
DEF_STATIC_CONST_VAL_FLOAT(val_2045,-0.223613);
#define CTNODE_cmu_us_rms_dur_NO_3637 3649
DEF_STATIC_CONST_VAL_FLOAT(val_2046,-0.157424);
#define CTNODE_cmu_us_rms_dur_NO_3649 3651
DEF_STATIC_CONST_VAL_FLOAT(val_2047,-0.594750);
#define CTNODE_cmu_us_rms_dur_NO_3636 3652
DEF_STATIC_CONST_VAL_FLOAT(val_2048,-0.096631);
#define CTNODE_cmu_us_rms_dur_NO_3652 3654
DEF_STATIC_CONST_VAL_FLOAT(val_2049,-0.473396);
#define CTNODE_cmu_us_rms_dur_NO_3654 3656
DEF_STATIC_CONST_VAL_FLOAT(val_2050,-0.184855);
#define CTNODE_cmu_us_rms_dur_NO_3656 3658
DEF_STATIC_CONST_VAL_FLOAT(val_2051,-0.441486);
#define CTNODE_cmu_us_rms_dur_NO_3659 3661
DEF_STATIC_CONST_VAL_FLOAT(val_2052,-0.079866);
#define CTNODE_cmu_us_rms_dur_NO_3661 3663
DEF_STATIC_CONST_VAL_FLOAT(val_2053,-0.359176);
#define CTNODE_cmu_us_rms_dur_NO_3658 3664
DEF_STATIC_CONST_VAL_FLOAT(val_2054,-0.463717);
#define CTNODE_cmu_us_rms_dur_NO_3579 3665
DEF_STATIC_CONST_VAL_FLOAT(val_2055,0.275603);
#define CTNODE_cmu_us_rms_dur_NO_3668 3670
DEF_STATIC_CONST_VAL_FLOAT(val_2056,-0.082109);
#define CTNODE_cmu_us_rms_dur_NO_3667 3671
DEF_STATIC_CONST_VAL_FLOAT(val_2057,-0.201508);
#define CTNODE_cmu_us_rms_dur_NO_3666 3672
DEF_STATIC_CONST_VAL_FLOAT(val_2058,-0.396383);
#define CTNODE_cmu_us_rms_dur_NO_3673 3675
DEF_STATIC_CONST_VAL_FLOAT(val_2059,-0.088618);
#define CTNODE_cmu_us_rms_dur_NO_3672 3676
DEF_STATIC_CONST_VAL_FLOAT(val_2060,-0.242026);
#define CTNODE_cmu_us_rms_dur_NO_3676 3678
DEF_STATIC_CONST_VAL_FLOAT(val_2061,-0.587231);
#define CTNODE_cmu_us_rms_dur_NO_3678 3680
DEF_STATIC_CONST_VAL_FLOAT(val_2062,-0.298312);
#define CTNODE_cmu_us_rms_dur_NO_3680 3682
DEF_STATIC_CONST_VAL_FLOAT(val_2063,-0.469748);
#define CTNODE_cmu_us_rms_dur_NO_3665 3683
DEF_STATIC_CONST_VAL_FLOAT(val_2064,0.907133);
#define CTNODE_cmu_us_rms_dur_NO_3683 3685
DEF_STATIC_CONST_VAL_FLOAT(val_2065,-0.524385);
#define CTNODE_cmu_us_rms_dur_NO_3685 3687
DEF_STATIC_CONST_VAL_FLOAT(val_2066,0.843964);
#define CTNODE_cmu_us_rms_dur_NO_3687 3689
DEF_STATIC_CONST_VAL_FLOAT(val_2067,0.551814);
#define CTNODE_cmu_us_rms_dur_NO_3691 3693
DEF_STATIC_CONST_VAL_FLOAT(val_2068,-0.368712);
#define CTNODE_cmu_us_rms_dur_NO_3693 3695
DEF_STATIC_CONST_VAL_FLOAT(val_2069,-0.120781);
#define CTNODE_cmu_us_rms_dur_NO_3695 3697
DEF_STATIC_CONST_VAL_FLOAT(val_2070,0.133097);
#define CTNODE_cmu_us_rms_dur_NO_3690 3698
DEF_STATIC_CONST_VAL_FLOAT(val_2071,-0.605673);
#define CTNODE_cmu_us_rms_dur_NO_3698 3700
DEF_STATIC_CONST_VAL_FLOAT(val_2072,-0.050647);
#define CTNODE_cmu_us_rms_dur_NO_3700 3702
DEF_STATIC_CONST_VAL_FLOAT(val_2073,-0.343025);
#define CTNODE_cmu_us_rms_dur_NO_3689 3703
DEF_STATIC_CONST_VAL_FLOAT(val_2074,-0.526246);
#define CTNODE_cmu_us_rms_dur_NO_3704 3706
DEF_STATIC_CONST_VAL_FLOAT(val_2075,0.063776);
#define CTNODE_cmu_us_rms_dur_NO_3706 3708
DEF_STATIC_CONST_VAL_FLOAT(val_2076,-0.391539);
#define CTNODE_cmu_us_rms_dur_NO_3703 3709
DEF_STATIC_CONST_VAL_FLOAT(val_2077,-0.515556);
#define CTNODE_cmu_us_rms_dur_NO_3709 3711
DEF_STATIC_CONST_VAL_FLOAT(val_2078,-0.339868);
#define CTNODE_cmu_us_rms_dur_NO_3711 3713
DEF_STATIC_CONST_VAL_FLOAT(val_2079,0.813516);
#define CTNODE_cmu_us_rms_dur_NO_3714 3716
DEF_STATIC_CONST_VAL_FLOAT(val_2080,0.503630);
#define CTNODE_cmu_us_rms_dur_NO_3716 3718
DEF_STATIC_CONST_VAL_FLOAT(val_2081,0.145584);
#define CTNODE_cmu_us_rms_dur_NO_3713 3719
DEF_STATIC_CONST_VAL_FLOAT(val_2082,-0.225151);
#define CTNODE_cmu_us_rms_dur_NO_3720 3722
DEF_STATIC_CONST_VAL_FLOAT(val_2083,0.477910);
#define CTNODE_cmu_us_rms_dur_NO_3724 3726
DEF_STATIC_CONST_VAL_FLOAT(val_2084,0.839986);
#define CTNODE_cmu_us_rms_dur_NO_3723 3727
DEF_STATIC_CONST_VAL_FLOAT(val_2085,0.127699);
#define CTNODE_cmu_us_rms_dur_NO_3728 3730
DEF_STATIC_CONST_VAL_FLOAT(val_2086,0.070464);
#define CTNODE_cmu_us_rms_dur_NO_3727 3731
DEF_STATIC_CONST_VAL_FLOAT(val_2087,0.423087);
#define CTNODE_cmu_us_rms_dur_NO_3722 3732
DEF_STATIC_CONST_VAL_FLOAT(val_2088,0.048461);
#define CTNODE_cmu_us_rms_dur_NO_3733 3735
DEF_STATIC_CONST_VAL_FLOAT(val_2089,0.161092);
#define CTNODE_cmu_us_rms_dur_NO_3736 3738
DEF_STATIC_CONST_VAL_FLOAT(val_2090,0.776297);
#define CTNODE_cmu_us_rms_dur_NO_3738 3740
DEF_STATIC_CONST_VAL_FLOAT(val_2091,0.440331);
#define CTNODE_cmu_us_rms_dur_NO_3735 3741
DEF_STATIC_CONST_VAL_FLOAT(val_2092,0.067339);
#define CTNODE_cmu_us_rms_dur_NO_3732 3742
DEF_STATIC_CONST_VAL_FLOAT(val_2093,-0.043518);
#define CTNODE_cmu_us_rms_dur_NO_3743 3745
DEF_STATIC_CONST_VAL_FLOAT(val_2094,0.565194);
#define CTNODE_cmu_us_rms_dur_NO_3742 3746
DEF_STATIC_CONST_VAL_FLOAT(val_2095,-0.351795);
#define CTNODE_cmu_us_rms_dur_NO_3746 3748
DEF_STATIC_CONST_VAL_FLOAT(val_2096,-0.096919);
#define CTNODE_cmu_us_rms_dur_NO_3748 3750
DEF_STATIC_CONST_VAL_FLOAT(val_2097,0.139707);
#define CTNODE_cmu_us_rms_dur_NO_3719 3751
DEF_STATIC_CONST_VAL_FLOAT(val_2098,0.494646);
#define CTNODE_cmu_us_rms_dur_NO_3751 3753
DEF_STATIC_CONST_VAL_FLOAT(val_2099,-0.196334);
#define CTNODE_cmu_us_rms_dur_NO_3754 3756
DEF_STATIC_CONST_VAL_FLOAT(val_2100,-0.055661);
#define CTNODE_cmu_us_rms_dur_NO_3757 3759
DEF_STATIC_CONST_VAL_FLOAT(val_2101,0.243018);
#define CTNODE_cmu_us_rms_dur_NO_3756 3760
DEF_STATIC_CONST_VAL_FLOAT(val_2102,0.568502);
#define CTNODE_cmu_us_rms_dur_NO_3753 3761
DEF_STATIC_CONST_VAL_FLOAT(val_2103,-0.059666);
#define CTNODE_cmu_us_rms_dur_NO_3764 3766
DEF_STATIC_CONST_VAL_FLOAT(val_2104,-0.328078);
#define CTNODE_cmu_us_rms_dur_NO_3763 3767
DEF_STATIC_CONST_VAL_FLOAT(val_2105,0.099060);
#define CTNODE_cmu_us_rms_dur_NO_3762 3768
DEF_STATIC_CONST_VAL_FLOAT(val_2106,0.390580);
#define CTNODE_cmu_us_rms_dur_NO_3761 3769
DEF_STATIC_CONST_VAL_FLOAT(val_2107,-0.414532);
#define CTNODE_cmu_us_rms_dur_NO_3769 3771
DEF_STATIC_CONST_VAL_FLOAT(val_2108,-0.257669);
#define CTNODE_cmu_us_rms_dur_NO_3771 3773
DEF_STATIC_CONST_VAL_FLOAT(val_2109,0.168029);
#define CTNODE_cmu_us_rms_dur_NO_3773 3775
DEF_STATIC_CONST_VAL_FLOAT(val_2110,-0.201224);
#define CTNODE_cmu_us_rms_dur_NO_0244 3776
DEF_STATIC_CONST_VAL_FLOAT(val_2111,2.970600);
#define CTNODE_cmu_us_rms_dur_NO_3778 3780
DEF_STATIC_CONST_VAL_FLOAT(val_2112,1.513110);
#define CTNODE_cmu_us_rms_dur_NO_3777 3781
DEF_STATIC_CONST_VAL_STRING(val_2113,"th_171");
DEF_STATIC_CONST_VAL_FLOAT(val_2114,1.390700);
#define CTNODE_cmu_us_rms_dur_NO_3782 3784
DEF_STATIC_CONST_VAL_FLOAT(val_2115,1.125100);
#define CTNODE_cmu_us_rms_dur_NO_3785 3787
DEF_STATIC_CONST_VAL_FLOAT(val_2116,0.343149);
#define CTNODE_cmu_us_rms_dur_NO_3787 3789
DEF_STATIC_CONST_VAL_FLOAT(val_2117,0.695772);
#define CTNODE_cmu_us_rms_dur_NO_3784 3790
DEF_STATIC_CONST_VAL_FLOAT(val_2118,0.600618);
#define CTNODE_cmu_us_rms_dur_NO_3791 3793
DEF_STATIC_CONST_VAL_FLOAT(val_2119,-0.076973);
#define CTNODE_cmu_us_rms_dur_NO_3794 3796
DEF_STATIC_CONST_VAL_FLOAT(val_2120,0.124344);
#define CTNODE_cmu_us_rms_dur_NO_3793 3797
DEF_STATIC_CONST_VAL_FLOAT(val_2121,0.641022);
#define CTNODE_cmu_us_rms_dur_NO_3790 3798
DEF_STATIC_CONST_VAL_FLOAT(val_2122,0.085883);
#define CTNODE_cmu_us_rms_dur_NO_3798 3800
DEF_STATIC_CONST_VAL_FLOAT(val_2123,-0.293121);
#define CTNODE_cmu_us_rms_dur_NO_3781 3801
DEF_STATIC_CONST_VAL_FLOAT(val_2124,0.356021);
#define CTNODE_cmu_us_rms_dur_NO_3801 3803
DEF_STATIC_CONST_VAL_FLOAT(val_2125,0.002604);
#define CTNODE_cmu_us_rms_dur_NO_3805 3807
DEF_STATIC_CONST_VAL_FLOAT(val_2126,0.207334);
#define CTNODE_cmu_us_rms_dur_NO_3804 3808
DEF_STATIC_CONST_VAL_FLOAT(val_2127,-0.160284);
#define CTNODE_cmu_us_rms_dur_NO_3808 3810
DEF_STATIC_CONST_VAL_FLOAT(val_2128,-0.394020);
#define CTNODE_cmu_us_rms_dur_NO_3803 3811
DEF_STATIC_CONST_VAL_FLOAT(val_2129,-0.752646);
#define CTNODE_cmu_us_rms_dur_NO_3811 3813
DEF_STATIC_CONST_VAL_FLOAT(val_2130,-0.527343);
#define CTNODE_cmu_us_rms_dur_NO_3813 3815
DEF_STATIC_CONST_VAL_FLOAT(val_2131,-0.168454);
#define CTNODE_cmu_us_rms_dur_NO_3776 3816
DEF_STATIC_CONST_VAL_STRING(val_2132,"y");
DEF_STATIC_CONST_VAL_FLOAT(val_2133,-0.580791);
#define CTNODE_cmu_us_rms_dur_NO_3819 3821
#define CTNODE_cmu_us_rms_dur_NO_3821 3823
#define CTNODE_cmu_us_rms_dur_NO_3824 3826
#define CTNODE_cmu_us_rms_dur_NO_3826 3828
#define CTNODE_cmu_us_rms_dur_NO_3823 3829
#define CTNODE_cmu_us_rms_dur_NO_3829 3831
DEF_STATIC_CONST_VAL_FLOAT(val_2134,-0.576386);
#define CTNODE_cmu_us_rms_dur_NO_3831 3833
DEF_STATIC_CONST_VAL_FLOAT(val_2135,-0.571930);
#define CTNODE_cmu_us_rms_dur_NO_3833 3835
DEF_STATIC_CONST_VAL_FLOAT(val_2136,-0.567840);
#define CTNODE_cmu_us_rms_dur_NO_3818 3836
DEF_STATIC_CONST_VAL_FLOAT(val_2137,-0.376669);
#define CTNODE_cmu_us_rms_dur_NO_3817 3837
DEF_STATIC_CONST_VAL_FLOAT(val_2138,-0.201146);
#define CTNODE_cmu_us_rms_dur_NO_3838 3840
DEF_STATIC_CONST_VAL_FLOAT(val_2139,0.680625);
#define CTNODE_cmu_us_rms_dur_NO_3841 3843
DEF_STATIC_CONST_VAL_FLOAT(val_2140,0.871445);
#define CTNODE_cmu_us_rms_dur_NO_3843 3845
DEF_STATIC_CONST_VAL_FLOAT(val_2141,0.829606);
#define CTNODE_cmu_us_rms_dur_NO_3840 3846
DEF_STATIC_CONST_VAL_FLOAT(val_2142,0.368165);
#define CTNODE_cmu_us_rms_dur_NO_3847 3849
DEF_STATIC_CONST_VAL_FLOAT(val_2143,0.497011);
#define CTNODE_cmu_us_rms_dur_NO_3849 3851
DEF_STATIC_CONST_VAL_FLOAT(val_2144,0.788522);
#define CTNODE_cmu_us_rms_dur_NO_3846 3852
DEF_STATIC_CONST_VAL_FLOAT(val_2145,0.288121);
#define CTNODE_cmu_us_rms_dur_NO_3837 3853
DEF_STATIC_CONST_VAL_FLOAT(val_2146,-0.105815);
#define CTNODE_cmu_us_rms_dur_NO_3855 3857
DEF_STATIC_CONST_VAL_FLOAT(val_2147,1.438370);
#define CTNODE_cmu_us_rms_dur_NO_3857 3859
DEF_STATIC_CONST_VAL_FLOAT(val_2148,0.973187);
#define CTNODE_cmu_us_rms_dur_NO_3859 3861
DEF_STATIC_CONST_VAL_FLOAT(val_2149,0.487348);
#define CTNODE_cmu_us_rms_dur_NO_3861 3863
DEF_STATIC_CONST_VAL_FLOAT(val_2150,-0.077170);
#define CTNODE_cmu_us_rms_dur_NO_3854 3864
DEF_STATIC_CONST_VAL_FLOAT(val_2151,-1.358630);
#define CTNODE_cmu_us_rms_dur_NO_3865 3867
DEF_STATIC_CONST_VAL_FLOAT(val_2152,-0.559320);
#define CTNODE_cmu_us_rms_dur_NO_3864 3868
DEF_STATIC_CONST_VAL_FLOAT(val_2153,1.110480);
#define CTNODE_cmu_us_rms_dur_NO_3870 3872
DEF_STATIC_CONST_VAL_FLOAT(val_2154,0.734093);
#define CTNODE_cmu_us_rms_dur_NO_3872 3874
DEF_STATIC_CONST_VAL_FLOAT(val_2155,-0.257826);
#define CTNODE_cmu_us_rms_dur_NO_3869 3875
DEF_STATIC_CONST_VAL_FLOAT(val_2156,-0.661763);
#define CTNODE_cmu_us_rms_dur_NO_3868 3876
DEF_STATIC_CONST_VAL_FLOAT(val_2157,0.487115);
#define CTNODE_cmu_us_rms_dur_NO_3877 3879
DEF_STATIC_CONST_VAL_FLOAT(val_2158,0.159837);
#define CTNODE_cmu_us_rms_dur_NO_3879 3881
DEF_STATIC_CONST_VAL_FLOAT(val_2159,-0.488376);
#define CTNODE_cmu_us_rms_dur_NO_3881 3883
DEF_STATIC_CONST_VAL_FLOAT(val_2160,0.001769);
#define CTNODE_cmu_us_rms_dur_NO_3876 3884
DEF_STATIC_CONST_VAL_FLOAT(val_2161,-0.310117);
#define CTNODE_cmu_us_rms_dur_NO_3887 3889
DEF_STATIC_CONST_VAL_FLOAT(val_2162,-0.224577);
#define CTNODE_cmu_us_rms_dur_NO_3889 3891
DEF_STATIC_CONST_VAL_FLOAT(val_2163,0.017824);
#define CTNODE_cmu_us_rms_dur_NO_3886 3892
DEF_STATIC_CONST_VAL_FLOAT(val_2164,0.499050);
#define CTNODE_cmu_us_rms_dur_NO_3892 3894
DEF_STATIC_CONST_VAL_STRING(val_2165,"mid");
DEF_STATIC_CONST_VAL_FLOAT(val_2166,0.435532);
#define CTNODE_cmu_us_rms_dur_NO_3894 3896
DEF_STATIC_CONST_VAL_FLOAT(val_2167,-0.269315);
#define CTNODE_cmu_us_rms_dur_NO_3896 3898
DEF_STATIC_CONST_VAL_FLOAT(val_2168,-0.108750);
#define CTNODE_cmu_us_rms_dur_NO_3898 3900
DEF_STATIC_CONST_VAL_FLOAT(val_2169,0.205650);
#define CTNODE_cmu_us_rms_dur_NO_3885 3901
DEF_STATIC_CONST_VAL_FLOAT(val_2170,-0.359674);
#define CTNODE_cmu_us_rms_dur_NO_3902 3904
DEF_STATIC_CONST_VAL_FLOAT(val_2171,0.584286);
#define CTNODE_cmu_us_rms_dur_NO_3901 3905
DEF_STATIC_CONST_VAL_FLOAT(val_2172,0.037167);
#define CTNODE_cmu_us_rms_dur_NO_3907 3909
DEF_STATIC_CONST_VAL_FLOAT(val_2173,-0.332136);
#define CTNODE_cmu_us_rms_dur_NO_3906 3910
DEF_STATIC_CONST_VAL_FLOAT(val_2174,0.524107);
#define CTNODE_cmu_us_rms_dur_NO_3905 3911
DEF_STATIC_CONST_VAL_STRING(val_2175,"p_136");
DEF_STATIC_CONST_VAL_FLOAT(val_2176,-0.762625);
#define CTNODE_cmu_us_rms_dur_NO_3912 3914
DEF_STATIC_CONST_VAL_FLOAT(val_2177,-0.529374);
#define CTNODE_cmu_us_rms_dur_NO_3911 3915
DEF_STATIC_CONST_VAL_STRING(val_2178,"aw_23");
DEF_STATIC_CONST_VAL_FLOAT(val_2179,0.225763);
#define CTNODE_cmu_us_rms_dur_NO_3915 3917
DEF_STATIC_CONST_VAL_FLOAT(val_2180,-0.284363);
#define CTNODE_cmu_us_rms_dur_NO_3920 3922
DEF_STATIC_CONST_VAL_FLOAT(val_2181,-0.406609);
#define CTNODE_cmu_us_rms_dur_NO_3922 3924
DEF_STATIC_CONST_VAL_FLOAT(val_2182,-0.633354);
#define CTNODE_cmu_us_rms_dur_NO_3925 3927
DEF_STATIC_CONST_VAL_FLOAT(val_2183,-0.685933);
#define CTNODE_cmu_us_rms_dur_NO_3924 3928
DEF_STATIC_CONST_VAL_FLOAT(val_2184,-0.769772);
#define CTNODE_cmu_us_rms_dur_NO_3919 3929
DEF_STATIC_CONST_VAL_FLOAT(val_2185,0.042070);
#define CTNODE_cmu_us_rms_dur_NO_3930 3932
DEF_STATIC_CONST_VAL_FLOAT(val_2186,-0.179616);
#define CTNODE_cmu_us_rms_dur_NO_3929 3933
DEF_STATIC_CONST_VAL_STRING(val_2187,"aw");
DEF_STATIC_CONST_VAL_FLOAT(val_2188,-0.647965);
#define CTNODE_cmu_us_rms_dur_NO_3933 3935
DEF_STATIC_CONST_VAL_FLOAT(val_2189,-0.202946);
#define CTNODE_cmu_us_rms_dur_NO_3936 3938
DEF_STATIC_CONST_VAL_FLOAT(val_2190,-0.573132);
#define CTNODE_cmu_us_rms_dur_NO_3938 3940
DEF_STATIC_CONST_VAL_FLOAT(val_2191,-0.268431);
#define CTNODE_cmu_us_rms_dur_NO_3941 3943
DEF_STATIC_CONST_VAL_FLOAT(val_2192,-0.495817);
#define CTNODE_cmu_us_rms_dur_NO_3944 3946
#define CTNODE_cmu_us_rms_dur_NO_3943 3947
DEF_STATIC_CONST_VAL_FLOAT(val_2193,-0.531497);
#define CTNODE_cmu_us_rms_dur_NO_3947 3949
DEF_STATIC_CONST_VAL_FLOAT(val_2194,-0.367912);
#define CTNODE_cmu_us_rms_dur_NO_3940 3950
DEF_STATIC_CONST_VAL_FLOAT(val_2195,-0.165481);
#define CTNODE_cmu_us_rms_dur_NO_3935 3951
DEF_STATIC_CONST_VAL_FLOAT(val_2196,-0.579477);
#define CTNODE_cmu_us_rms_dur_NO_3951 3953
DEF_STATIC_CONST_VAL_FLOAT(val_2197,0.241238);
#define CTNODE_cmu_us_rms_dur_NO_3954 3956
DEF_STATIC_CONST_VAL_FLOAT(val_2198,-0.327887);
#define CTNODE_cmu_us_rms_dur_NO_3953 3957
DEF_STATIC_CONST_VAL_FLOAT(val_2199,-0.484734);
#define CTNODE_cmu_us_rms_dur_NO_3957 3959
DEF_STATIC_CONST_VAL_FLOAT(val_2200,-0.417340);
#define CTNODE_cmu_us_rms_dur_NO_3959 3961
DEF_STATIC_CONST_VAL_FLOAT(val_2201,-0.132495);
#define CTNODE_cmu_us_rms_dur_NO_3963 3965
DEF_STATIC_CONST_VAL_FLOAT(val_2202,-0.280277);
#define CTNODE_cmu_us_rms_dur_NO_3962 3966
DEF_STATIC_CONST_VAL_FLOAT(val_2203,-0.334043);
#define CTNODE_cmu_us_rms_dur_NO_3966 3968
DEF_STATIC_CONST_VAL_FLOAT(val_2204,-0.327166);
#define CTNODE_cmu_us_rms_dur_NO_3968 3970
DEF_STATIC_CONST_VAL_FLOAT(val_2205,-0.438530);
#define CTNODE_cmu_us_rms_dur_NO_3961 3971
DEF_STATIC_CONST_VAL_FLOAT(val_2206,-0.179700);
#define CTNODE_cmu_us_rms_dur_NO_3974 3976
DEF_STATIC_CONST_VAL_FLOAT(val_2207,-0.056117);
#define CTNODE_cmu_us_rms_dur_NO_3973 3977
DEF_STATIC_CONST_VAL_FLOAT(val_2208,0.048551);
#define CTNODE_cmu_us_rms_dur_NO_3972 3978
DEF_STATIC_CONST_VAL_FLOAT(val_2209,-0.112460);
#define CTNODE_cmu_us_rms_dur_NO_3978 3980
DEF_STATIC_CONST_VAL_FLOAT(val_2210,-0.253286);
#define CTNODE_cmu_us_rms_dur_NO_3971 3981
DEF_STATIC_CONST_VAL_FLOAT(val_2211,-0.427855);
#define CTNODE_cmu_us_rms_dur_NO_3981 3983
DEF_STATIC_CONST_VAL_FLOAT(val_2212,-0.018088);
#define CTNODE_cmu_us_rms_dur_NO_3983 3985
DEF_STATIC_CONST_VAL_FLOAT(val_2213,-0.315661);
#define CTNODE_cmu_us_rms_dur_NO_3918 3986
DEF_STATIC_CONST_VAL_FLOAT(val_2214,-0.591704);
#define CTNODE_cmu_us_rms_dur_NO_3988 3990
DEF_STATIC_CONST_VAL_FLOAT(val_2215,-0.521823);
#define CTNODE_cmu_us_rms_dur_NO_3987 3991
DEF_STATIC_CONST_VAL_FLOAT(val_2216,-0.448139);
#define CTNODE_cmu_us_rms_dur_NO_3991 3993
DEF_STATIC_CONST_VAL_FLOAT(val_2217,-0.078765);
#define CTNODE_cmu_us_rms_dur_NO_3993 3995
DEF_STATIC_CONST_VAL_FLOAT(val_2218,-0.390765);
#define CTNODE_cmu_us_rms_dur_NO_3986 3996
DEF_STATIC_CONST_VAL_FLOAT(val_2219,0.373390);
#define CTNODE_cmu_us_rms_dur_NO_3997 3999
DEF_STATIC_CONST_VAL_FLOAT(val_2220,-0.169151);
#define CTNODE_cmu_us_rms_dur_NO_3996 4000
DEF_STATIC_CONST_VAL_FLOAT(val_2221,0.030591);
#define CTNODE_cmu_us_rms_dur_NO_4001 4003
DEF_STATIC_CONST_VAL_FLOAT(val_2222,-0.624605);
#define CTNODE_cmu_us_rms_dur_NO_4003 4005
DEF_STATIC_CONST_VAL_FLOAT(val_2223,-0.548210);
#define CTNODE_cmu_us_rms_dur_NO_4005 4007
DEF_STATIC_CONST_VAL_FLOAT(val_2224,-0.235637);
#define CTNODE_cmu_us_rms_dur_NO_4007 4009
DEF_STATIC_CONST_VAL_FLOAT(val_2225,-0.419455);
#define CTNODE_cmu_us_rms_dur_NO_4000 4010
DEF_STATIC_CONST_VAL_FLOAT(val_2226,0.376482);
#define CTNODE_cmu_us_rms_dur_NO_4010 4012
DEF_STATIC_CONST_VAL_FLOAT(val_2227,-0.460831);
#define CTNODE_cmu_us_rms_dur_NO_4013 4015
DEF_STATIC_CONST_VAL_FLOAT(val_2228,0.438760);
#define CTNODE_cmu_us_rms_dur_NO_4016 4018
DEF_STATIC_CONST_VAL_FLOAT(val_2229,0.079148);
#define CTNODE_cmu_us_rms_dur_NO_4015 4019
DEF_STATIC_CONST_VAL_FLOAT(val_2230,0.324401);
#define CTNODE_cmu_us_rms_dur_NO_4019 4021
DEF_STATIC_CONST_VAL_FLOAT(val_2231,-0.209974);
#define CTNODE_cmu_us_rms_dur_NO_4022 4024
DEF_STATIC_CONST_VAL_FLOAT(val_2232,-0.589469);
#define CTNODE_cmu_us_rms_dur_NO_4021 4025
DEF_STATIC_CONST_VAL_FLOAT(val_2233,0.101721);
#define CTNODE_cmu_us_rms_dur_NO_4012 4026
DEF_STATIC_CONST_VAL_FLOAT(val_2234,0.179246);
#define CTNODE_cmu_us_rms_dur_NO_4026 4028
DEF_STATIC_CONST_VAL_FLOAT(val_2235,-0.250107);
#define CTNODE_cmu_us_rms_dur_NO_4029 4031
DEF_STATIC_CONST_VAL_FLOAT(val_2236,-0.070298);
#define CTNODE_cmu_us_rms_dur_NO_4028 4032
DEF_STATIC_CONST_VAL_FLOAT(val_2237,-0.439839);
#define CTNODE_cmu_us_rms_dur_NO_4033 4035
DEF_STATIC_CONST_VAL_FLOAT(val_2238,-0.087617);
#define CTNODE_cmu_us_rms_dur_NO_4035 4037
DEF_STATIC_CONST_VAL_FLOAT(val_2239,-0.346342);
#define CTNODE_cmu_us_rms_dur_NO_4032 4038
DEF_STATIC_CONST_VAL_FLOAT(val_2240,-0.341378);
#define CTNODE_cmu_us_rms_dur_NO_4038 4040
DEF_STATIC_CONST_VAL_FLOAT(val_2241,-0.494306);
#define CTNODE_cmu_us_rms_dur_NO_3917 4041
DEF_STATIC_CONST_VAL_STRING(val_2242,"ay_32");
DEF_STATIC_CONST_VAL_FLOAT(val_2243,0.035053);
#define CTNODE_cmu_us_rms_dur_NO_4043 4045
DEF_STATIC_CONST_VAL_FLOAT(val_2244,-0.451472);
#define CTNODE_cmu_us_rms_dur_NO_4042 4046
DEF_STATIC_CONST_VAL_FLOAT(val_2245,13.400000);
DEF_STATIC_CONST_VAL_FLOAT(val_2246,0.571610);
#define CTNODE_cmu_us_rms_dur_NO_4046 4048
DEF_STATIC_CONST_VAL_FLOAT(val_2247,-0.145618);
#define CTNODE_cmu_us_rms_dur_NO_4041 4049
DEF_STATIC_CONST_VAL_FLOAT(val_2248,-0.505619);
#define CTNODE_cmu_us_rms_dur_NO_4049 4051
DEF_STATIC_CONST_VAL_FLOAT(val_2249,-0.011278);
#define CTNODE_cmu_us_rms_dur_NO_4051 4053
DEF_STATIC_CONST_VAL_FLOAT(val_2250,-0.290615);
#define CTNODE_cmu_us_rms_dur_NO_3884 4054
DEF_STATIC_CONST_VAL_FLOAT(val_2251,-0.830224);
#define CTNODE_cmu_us_rms_dur_NO_4055 4057
DEF_STATIC_CONST_VAL_FLOAT(val_2252,-0.571763);
#define CTNODE_cmu_us_rms_dur_NO_4057 4059
DEF_STATIC_CONST_VAL_FLOAT(val_2253,-0.277237);
#define CTNODE_cmu_us_rms_dur_NO_4059 4061
DEF_STATIC_CONST_VAL_FLOAT(val_2254,-0.488635);
#define CTNODE_cmu_us_rms_dur_NO_4054 4062
DEF_STATIC_CONST_VAL_FLOAT(val_2255,-0.064579);
#define CTNODE_cmu_us_rms_dur_NO_4063 4065
DEF_STATIC_CONST_VAL_FLOAT(val_2256,-0.369678);
#define CTNODE_cmu_us_rms_dur_NO_4062 4066
DEF_STATIC_CONST_VAL_FLOAT(val_2257,-0.475721);
#define CTNODE_cmu_us_rms_dur_NO_3853 4067
DEF_STATIC_CONST_VAL_FLOAT(val_2258,0.525399);
#define CTNODE_cmu_us_rms_dur_NO_4068 4070
DEF_STATIC_CONST_VAL_FLOAT(val_2259,0.996876);
#define CTNODE_cmu_us_rms_dur_NO_4067 4071
DEF_STATIC_CONST_VAL_STRING(val_2260,"f_73");
DEF_STATIC_CONST_VAL_FLOAT(val_2261,1.040920);
#define CTNODE_cmu_us_rms_dur_NO_4071 4073
DEF_STATIC_CONST_VAL_FLOAT(val_2262,-0.201608);
#define CTNODE_cmu_us_rms_dur_NO_4075 4077
DEF_STATIC_CONST_VAL_FLOAT(val_2263,0.243646);
#define CTNODE_cmu_us_rms_dur_NO_4074 4078
DEF_STATIC_CONST_VAL_FLOAT(val_2264,8.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_2265,-0.014802);
#define CTNODE_cmu_us_rms_dur_NO_4079 4081
DEF_STATIC_CONST_VAL_FLOAT(val_2266,0.327208);
#define CTNODE_cmu_us_rms_dur_NO_4078 4082
DEF_STATIC_CONST_VAL_FLOAT(val_2267,0.269640);
#define CTNODE_cmu_us_rms_dur_NO_4083 4085
DEF_STATIC_CONST_VAL_FLOAT(val_2268,1.133170);
#define CTNODE_cmu_us_rms_dur_NO_4085 4087
DEF_STATIC_CONST_VAL_FLOAT(val_2269,0.720757);
#define CTNODE_cmu_us_rms_dur_NO_4082 4088
DEF_STATIC_CONST_VAL_FLOAT(val_2270,0.158039);
#define CTNODE_cmu_us_rms_dur_NO_4073 4089
DEF_STATIC_CONST_VAL_STRING(val_2271,"ay_33");
DEF_STATIC_CONST_VAL_FLOAT(val_2272,-0.563214);
#define CTNODE_cmu_us_rms_dur_NO_4089 4091
DEF_STATIC_CONST_VAL_FLOAT(val_2273,-0.161933);
#define CTNODE_cmu_us_rms_dur_NO_4093 4095
DEF_STATIC_CONST_VAL_FLOAT(val_2274,-0.426779);
#define CTNODE_cmu_us_rms_dur_NO_4095 4097
DEF_STATIC_CONST_VAL_FLOAT(val_2275,-0.334366);
#define CTNODE_cmu_us_rms_dur_NO_4092 4098
DEF_STATIC_CONST_VAL_FLOAT(val_2276,-0.149653);
#define CTNODE_cmu_us_rms_dur_NO_4099 4101
DEF_STATIC_CONST_VAL_FLOAT(val_2277,-0.533993);
#define CTNODE_cmu_us_rms_dur_NO_4098 4102
DEF_STATIC_CONST_VAL_FLOAT(val_2278,0.214158);
#define CTNODE_cmu_us_rms_dur_NO_4104 4106
DEF_STATIC_CONST_VAL_FLOAT(val_2279,0.828323);
#define CTNODE_cmu_us_rms_dur_NO_4103 4107
DEF_STATIC_CONST_VAL_FLOAT(val_2280,0.096764);
#define CTNODE_cmu_us_rms_dur_NO_4108 4110
DEF_STATIC_CONST_VAL_FLOAT(val_2281,-0.486150);
#define CTNODE_cmu_us_rms_dur_NO_4107 4111
DEF_STATIC_CONST_VAL_STRING(val_2282,"g_77");
DEF_STATIC_CONST_VAL_FLOAT(val_2283,0.789098);
#define CTNODE_cmu_us_rms_dur_NO_4113 4115
DEF_STATIC_CONST_VAL_FLOAT(val_2284,0.585322);
#define CTNODE_cmu_us_rms_dur_NO_4115 4117
DEF_STATIC_CONST_VAL_FLOAT(val_2285,0.566876);
#define CTNODE_cmu_us_rms_dur_NO_4117 4119
DEF_STATIC_CONST_VAL_FLOAT(val_2286,0.529338);
#define CTNODE_cmu_us_rms_dur_NO_4119 4121
DEF_STATIC_CONST_VAL_FLOAT(val_2287,0.570165);
#define CTNODE_cmu_us_rms_dur_NO_4122 4124
DEF_STATIC_CONST_VAL_FLOAT(val_2288,0.347342);
#define CTNODE_cmu_us_rms_dur_NO_4124 4126
DEF_STATIC_CONST_VAL_FLOAT(val_2289,-0.091866);
#define CTNODE_cmu_us_rms_dur_NO_4121 4127
DEF_STATIC_CONST_VAL_FLOAT(val_2290,0.446803);
#define CTNODE_cmu_us_rms_dur_NO_4128 4130
DEF_STATIC_CONST_VAL_FLOAT(val_2291,7.900000);
DEF_STATIC_CONST_VAL_FLOAT(val_2292,-0.197345);
#define CTNODE_cmu_us_rms_dur_NO_4130 4132
DEF_STATIC_CONST_VAL_FLOAT(val_2293,0.000638);
#define CTNODE_cmu_us_rms_dur_NO_4132 4134
DEF_STATIC_CONST_VAL_FLOAT(val_2294,0.303184);
#define CTNODE_cmu_us_rms_dur_NO_4127 4135
DEF_STATIC_CONST_VAL_FLOAT(val_2295,-0.260755);
#define CTNODE_cmu_us_rms_dur_NO_4112 4136
DEF_STATIC_CONST_VAL_FLOAT(val_2296,-0.100919);
#define CTNODE_cmu_us_rms_dur_NO_4111 4137
DEF_STATIC_CONST_VAL_FLOAT(val_2297,-0.333555);
#define CTNODE_cmu_us_rms_dur_NO_4137 4139
DEF_STATIC_CONST_VAL_FLOAT(val_2298,-0.239646);
#define CTNODE_cmu_us_rms_dur_NO_4139 4141
DEF_STATIC_CONST_VAL_FLOAT(val_2299,0.794172);
#define CTNODE_cmu_us_rms_dur_NO_4142 4144
DEF_STATIC_CONST_VAL_FLOAT(val_2300,0.217313);
#define CTNODE_cmu_us_rms_dur_NO_4141 4145
DEF_STATIC_CONST_VAL_FLOAT(val_2301,-0.359658);
#define CTNODE_cmu_us_rms_dur_NO_4147 4149
DEF_STATIC_CONST_VAL_FLOAT(val_2302,0.018686);
#define CTNODE_cmu_us_rms_dur_NO_4146 4150
DEF_STATIC_CONST_VAL_FLOAT(val_2303,0.368474);
#define CTNODE_cmu_us_rms_dur_NO_4150 4152
DEF_STATIC_CONST_VAL_FLOAT(val_2304,0.332782);
#define CTNODE_cmu_us_rms_dur_NO_4152 4154
DEF_STATIC_CONST_VAL_FLOAT(val_2305,0.205284);
#define CTNODE_cmu_us_rms_dur_NO_4155 4157
DEF_STATIC_CONST_VAL_FLOAT(val_2306,-0.128446);
#define CTNODE_cmu_us_rms_dur_NO_4154 4158
DEF_STATIC_CONST_VAL_FLOAT(val_2307,-0.372061);
#define CTNODE_cmu_us_rms_dur_NO_4158 4160
DEF_STATIC_CONST_VAL_FLOAT(val_2308,-0.107621);
#define CTNODE_cmu_us_rms_dur_NO_4145 4161
DEF_STATIC_CONST_VAL_FLOAT(val_2309,0.208894);
#define CTNODE_cmu_us_rms_dur_NO_4162 4164
DEF_STATIC_CONST_VAL_FLOAT(val_2310,-0.232349);
#define CTNODE_cmu_us_rms_dur_NO_4161 4165
DEF_STATIC_CONST_VAL_FLOAT(val_2311,0.148680);
#define CTNODE_cmu_us_rms_dur_NO_4166 4168
DEF_STATIC_CONST_VAL_FLOAT(val_2312,0.804710);
#define CTNODE_cmu_us_rms_dur_NO_4168 4170
DEF_STATIC_CONST_VAL_FLOAT(val_2313,0.449200);
#define CTNODE_cmu_us_rms_dur_NO_4170 4172
DEF_STATIC_CONST_VAL_FLOAT(val_2314,0.245366);
#define CTNODE_cmu_us_rms_dur_NO_4165 4173
DEF_STATIC_CONST_VAL_FLOAT(val_2315,-0.140499);
#define CTNODE_cmu_us_rms_dur_NO_4173 4175
DEF_STATIC_CONST_VAL_FLOAT(val_2316,0.216488);
#define CTNODE_cmu_us_rms_dur_NO_4102 4176
DEF_STATIC_CONST_VAL_FLOAT(val_2317,-0.404940);
#define CTNODE_cmu_us_rms_dur_NO_4176 4178
DEF_STATIC_CONST_VAL_FLOAT(val_2318,-0.275942);
#define CTNODE_cmu_us_rms_dur_NO_4178 4180
DEF_STATIC_CONST_VAL_FLOAT(val_2319,0.036924);
#define CTNODE_cmu_us_rms_dur_NO_4091 4181
DEF_STATIC_CONST_VAL_FLOAT(val_2320,-0.467593);
#define CTNODE_cmu_us_rms_dur_NO_4182 4184
DEF_STATIC_CONST_VAL_FLOAT(val_2321,-0.715501);
#define CTNODE_cmu_us_rms_dur_NO_4181 4185
DEF_STATIC_CONST_VAL_FLOAT(val_2322,0.684033);
#define CTNODE_cmu_us_rms_dur_NO_4186 4188
DEF_STATIC_CONST_VAL_FLOAT(val_2323,0.241142);
#define CTNODE_cmu_us_rms_dur_NO_4188 4190
DEF_STATIC_CONST_VAL_FLOAT(val_2324,-0.039813);
#define CTNODE_cmu_us_rms_dur_NO_4185 4191
DEF_STATIC_CONST_VAL_FLOAT(val_2325,-0.230203);
#define CTNODE_cmu_us_rms_dur_NO_4192 4194
DEF_STATIC_CONST_VAL_FLOAT(val_2326,-0.578000);
#define CTNODE_cmu_us_rms_dur_NO_4191 4195
DEF_STATIC_CONST_VAL_FLOAT(val_2327,-0.041134);
#define CTNODE_cmu_us_rms_dur_NO_4196 4198
DEF_STATIC_CONST_VAL_FLOAT(val_2328,0.466861);
#define CTNODE_cmu_us_rms_dur_NO_4195 4199
DEF_STATIC_CONST_VAL_STRING(val_2329,"b_36");
DEF_STATIC_CONST_VAL_FLOAT(val_2330,-0.530556);
#define CTNODE_cmu_us_rms_dur_NO_4199 4201
DEF_STATIC_CONST_VAL_FLOAT(val_2331,-0.444004);
#define CTNODE_cmu_us_rms_dur_NO_4203 4205
DEF_STATIC_CONST_VAL_FLOAT(val_2332,-0.303071);
#define CTNODE_cmu_us_rms_dur_NO_4202 4206
DEF_STATIC_CONST_VAL_FLOAT(val_2333,-0.066669);
#define CTNODE_cmu_us_rms_dur_NO_4208 4210
DEF_STATIC_CONST_VAL_FLOAT(val_2334,-0.327181);
#define CTNODE_cmu_us_rms_dur_NO_4207 4211
DEF_STATIC_CONST_VAL_FLOAT(val_2335,-0.043361);
#define CTNODE_cmu_us_rms_dur_NO_4211 4213
DEF_STATIC_CONST_VAL_FLOAT(val_2336,0.317061);
#define CTNODE_cmu_us_rms_dur_NO_4206 4214
DEF_STATIC_CONST_VAL_FLOAT(val_2337,-0.386255);
#define CTNODE_cmu_us_rms_dur_NO_4201 4215
DEF_STATIC_CONST_VAL_FLOAT(val_2338,11.200000);
DEF_STATIC_CONST_VAL_FLOAT(val_2339,0.567851);
#define CTNODE_cmu_us_rms_dur_NO_4219 4221
DEF_STATIC_CONST_VAL_FLOAT(val_2340,0.022509);
#define CTNODE_cmu_us_rms_dur_NO_4218 4222
DEF_STATIC_CONST_VAL_FLOAT(val_2341,-0.114458);
#define CTNODE_cmu_us_rms_dur_NO_4217 4223
DEF_STATIC_CONST_VAL_FLOAT(val_2342,0.054434);
#define CTNODE_cmu_us_rms_dur_NO_4223 4225
DEF_STATIC_CONST_VAL_FLOAT(val_2343,-0.304118);
#define CTNODE_cmu_us_rms_dur_NO_4216 4226
DEF_STATIC_CONST_VAL_FLOAT(val_2344,0.573713);
#define CTNODE_cmu_us_rms_dur_NO_4215 4227
DEF_STATIC_CONST_VAL_FLOAT(val_2345,-0.346774);
#define CTNODE_cmu_us_rms_dur_NO_4227 4229
DEF_STATIC_CONST_VAL_FLOAT(val_2346,0.111503);
#define CTNODE_cmu_us_rms_dur_NO_4229 4231
DEF_STATIC_CONST_VAL_FLOAT(val_2347,0.016096);
#define CTNODE_cmu_us_rms_dur_NO_4231 4233
DEF_STATIC_CONST_VAL_FLOAT(val_2348,-0.346043);
#define CTNODE_cmu_us_rms_dur_NO_3816 4234
DEF_STATIC_CONST_VAL_FLOAT(val_2349,1.174820);
#define CTNODE_cmu_us_rms_dur_NO_4235 4237
DEF_STATIC_CONST_VAL_FLOAT(val_2350,0.176135);
#define CTNODE_cmu_us_rms_dur_NO_4239 4241
DEF_STATIC_CONST_VAL_FLOAT(val_2351,-0.128346);
#define CTNODE_cmu_us_rms_dur_NO_4241 4243
DEF_STATIC_CONST_VAL_FLOAT(val_2352,-0.558916);
#define CTNODE_cmu_us_rms_dur_NO_4244 4246
DEF_STATIC_CONST_VAL_FLOAT(val_2353,-0.598931);
#define CTNODE_cmu_us_rms_dur_NO_4243 4247
DEF_STATIC_CONST_VAL_FLOAT(val_2354,-0.259081);
#define CTNODE_cmu_us_rms_dur_NO_4238 4248
DEF_STATIC_CONST_VAL_FLOAT(val_2355,-0.105772);
#define CTNODE_cmu_us_rms_dur_NO_4248 4250
DEF_STATIC_CONST_VAL_FLOAT(val_2356,0.382545);
#define CTNODE_cmu_us_rms_dur_NO_4237 4251
DEF_STATIC_CONST_VAL_FLOAT(val_2357,1.214320);
#define CTNODE_cmu_us_rms_dur_NO_4253 4255
DEF_STATIC_CONST_VAL_FLOAT(val_2358,0.581939);
#define CTNODE_cmu_us_rms_dur_NO_4252 4256
DEF_STATIC_CONST_VAL_FLOAT(val_2359,0.236021);
#define CTNODE_cmu_us_rms_dur_NO_4251 4257
DEF_STATIC_CONST_VAL_FLOAT(val_2360,0.610534);
#define CTNODE_cmu_us_rms_dur_NO_4258 4260
DEF_STATIC_CONST_VAL_FLOAT(val_2361,-0.109735);
#define CTNODE_cmu_us_rms_dur_NO_4260 4262
DEF_STATIC_CONST_VAL_FLOAT(val_2362,0.354929);
#define CTNODE_cmu_us_rms_dur_NO_4257 4263
DEF_STATIC_CONST_VAL_FLOAT(val_2363,-0.450647);
#define CTNODE_cmu_us_rms_dur_NO_4234 4264
DEF_STATIC_CONST_VAL_FLOAT(val_2364,-0.946351);
#define CTNODE_cmu_us_rms_dur_NO_4266 4268
DEF_STATIC_CONST_VAL_FLOAT(val_2365,-1.306710);
#define CTNODE_cmu_us_rms_dur_NO_4265 4269
DEF_STATIC_CONST_VAL_FLOAT(val_2366,-0.893670);
#define CTNODE_cmu_us_rms_dur_NO_4269 4271
DEF_STATIC_CONST_VAL_FLOAT(val_2367,-0.498517);
#define CTNODE_cmu_us_rms_dur_NO_4264 4272
DEF_STATIC_CONST_VAL_FLOAT(val_2368,0.252979);
#define CTNODE_cmu_us_rms_dur_NO_4274 4276
DEF_STATIC_CONST_VAL_FLOAT(val_2369,-0.418051);
#define CTNODE_cmu_us_rms_dur_NO_4276 4278
DEF_STATIC_CONST_VAL_FLOAT(val_2370,0.033651);
#define CTNODE_cmu_us_rms_dur_NO_4273 4279
DEF_STATIC_CONST_VAL_FLOAT(val_2371,-0.742103);
#define CTNODE_cmu_us_rms_dur_NO_4281 4283
DEF_STATIC_CONST_VAL_FLOAT(val_2372,-0.880665);
#define CTNODE_cmu_us_rms_dur_NO_4280 4284
DEF_STATIC_CONST_VAL_FLOAT(val_2373,0.090725);
#define CTNODE_cmu_us_rms_dur_NO_4285 4287
DEF_STATIC_CONST_VAL_FLOAT(val_2374,-0.329804);
#define CTNODE_cmu_us_rms_dur_NO_4284 4288
DEF_STATIC_CONST_VAL_FLOAT(val_2375,-0.586052);
#define CTNODE_cmu_us_rms_dur_NO_4289 4291
DEF_STATIC_CONST_VAL_FLOAT(val_2376,-0.446498);
#define CTNODE_cmu_us_rms_dur_NO_4291 4293
DEF_STATIC_CONST_VAL_FLOAT(val_2377,-0.207407);
#define CTNODE_cmu_us_rms_dur_NO_4293 4295
DEF_STATIC_CONST_VAL_FLOAT(val_2378,-0.016641);
#define CTNODE_cmu_us_rms_dur_NO_4288 4296
DEF_STATIC_CONST_VAL_FLOAT(val_2379,-0.266318);
#define CTNODE_cmu_us_rms_dur_NO_4296 4298
DEF_STATIC_CONST_VAL_FLOAT(val_2380,-0.315514);
#define CTNODE_cmu_us_rms_dur_NO_4298 4300
DEF_STATIC_CONST_VAL_FLOAT(val_2381,-0.831043);
#define CTNODE_cmu_us_rms_dur_NO_4300 4302
DEF_STATIC_CONST_VAL_FLOAT(val_2382,-0.658652);
#define CTNODE_cmu_us_rms_dur_NO_4304 4306
DEF_STATIC_CONST_VAL_FLOAT(val_2383,-0.623854);
#define CTNODE_cmu_us_rms_dur_NO_4306 4308
DEF_STATIC_CONST_VAL_FLOAT(val_2384,-0.400752);
#define CTNODE_cmu_us_rms_dur_NO_4303 4309
DEF_STATIC_CONST_VAL_FLOAT(val_2385,-0.635699);
#define CTNODE_cmu_us_rms_dur_NO_4309 4311
DEF_STATIC_CONST_VAL_FLOAT(val_2386,-0.721019);
#define CTNODE_cmu_us_rms_dur_NO_4302 4312
DEF_STATIC_CONST_VAL_FLOAT(val_2387,-0.562608);
#define CTNODE_cmu_us_rms_dur_NO_4314 4316
DEF_STATIC_CONST_VAL_FLOAT(val_2388,-0.646231);
#define CTNODE_cmu_us_rms_dur_NO_4313 4317
DEF_STATIC_CONST_VAL_FLOAT(val_2389,-0.319948);
#define CTNODE_cmu_us_rms_dur_NO_4317 4319
DEF_STATIC_CONST_VAL_STRING(val_2390,"uw_181");
DEF_STATIC_CONST_VAL_FLOAT(val_2391,-0.628087);
#define CTNODE_cmu_us_rms_dur_NO_4320 4322
DEF_STATIC_CONST_VAL_STRING(val_2392,"uw_179");
DEF_STATIC_CONST_VAL_FLOAT(val_2393,-0.558284);
#define CTNODE_cmu_us_rms_dur_NO_4322 4324
DEF_STATIC_CONST_VAL_FLOAT(val_2394,-0.182302);
#define CTNODE_cmu_us_rms_dur_NO_4324 4326
DEF_STATIC_CONST_VAL_FLOAT(val_2395,-0.352707);
#define CTNODE_cmu_us_rms_dur_NO_4326 4328
DEF_STATIC_CONST_VAL_FLOAT(val_2396,-0.513463);
#define CTNODE_cmu_us_rms_dur_NO_4319 4329
DEF_STATIC_CONST_VAL_FLOAT(val_2397,-0.700812);
#define CTNODE_cmu_us_rms_dur_NO_4330 4332
DEF_STATIC_CONST_VAL_FLOAT(val_2398,-0.537261);
#define CTNODE_cmu_us_rms_dur_NO_4329 4333
DEF_STATIC_CONST_VAL_FLOAT(val_2399,-0.601600);
#define CTNODE_cmu_us_rms_dur_NO_4335 4337
DEF_STATIC_CONST_VAL_FLOAT(val_2400,-0.410519);
#define CTNODE_cmu_us_rms_dur_NO_4334 4338
DEF_STATIC_CONST_VAL_FLOAT(val_2401,-0.694170);
#define CTNODE_cmu_us_rms_dur_NO_4333 4339
DEF_STATIC_CONST_VAL_FLOAT(val_2402,-0.458675);
#define CTNODE_cmu_us_rms_dur_NO_4340 4342
DEF_STATIC_CONST_VAL_FLOAT(val_2403,-0.580647);
#define CTNODE_cmu_us_rms_dur_NO_4339 4343
DEF_STATIC_CONST_VAL_FLOAT(val_2404,-0.463872);
#define CTNODE_cmu_us_rms_dur_NO_4343 4345
DEF_STATIC_CONST_VAL_FLOAT(val_2405,-0.286863);
#define CTNODE_cmu_us_rms_dur_NO_4312 4346
DEF_STATIC_CONST_VAL_FLOAT(val_2406,-0.679694);
#define CTNODE_cmu_us_rms_dur_NO_4279 4347
DEF_STATIC_CONST_VAL_FLOAT(val_2407,-0.043488);
#define CTNODE_cmu_us_rms_dur_NO_4349 4351
DEF_STATIC_CONST_VAL_FLOAT(val_2408,0.383482);
#define CTNODE_cmu_us_rms_dur_NO_4348 4352
DEF_STATIC_CONST_VAL_FLOAT(val_2409,-0.171843);
#define CTNODE_cmu_us_rms_dur_NO_4347 4353
DEF_STATIC_CONST_VAL_FLOAT(val_2410,-0.287407);
#define CTNODE_cmu_us_rms_dur_NO_4354 4356
DEF_STATIC_CONST_VAL_FLOAT(val_2411,-0.193882);
#define CTNODE_cmu_us_rms_dur_NO_4353 4357
DEF_STATIC_CONST_VAL_FLOAT(val_2412,-0.480503);
#define CTNODE_cmu_us_rms_dur_NO_4272 4358
DEF_STATIC_CONST_VAL_FLOAT(val_2413,1.162500);
#define CTNODE_cmu_us_rms_dur_NO_4359 4361
DEF_STATIC_CONST_VAL_FLOAT(val_2414,-0.926748);
#define CTNODE_cmu_us_rms_dur_NO_4361 4363
DEF_STATIC_CONST_VAL_FLOAT(val_2415,-0.519002);
#define CTNODE_cmu_us_rms_dur_NO_4364 4366
DEF_STATIC_CONST_VAL_FLOAT(val_2416,-0.389675);
#define CTNODE_cmu_us_rms_dur_NO_4368 4370
DEF_STATIC_CONST_VAL_FLOAT(val_2417,-0.322610);
#define CTNODE_cmu_us_rms_dur_NO_4370 4372
DEF_STATIC_CONST_VAL_FLOAT(val_2418,0.189015);
#define CTNODE_cmu_us_rms_dur_NO_4374 4376
DEF_STATIC_CONST_VAL_FLOAT(val_2419,-0.038802);
#define CTNODE_cmu_us_rms_dur_NO_4377 4379
DEF_STATIC_CONST_VAL_FLOAT(val_2420,0.102420);
#define CTNODE_cmu_us_rms_dur_NO_4376 4380
DEF_STATIC_CONST_VAL_FLOAT(val_2421,-0.182586);
#define CTNODE_cmu_us_rms_dur_NO_4373 4381
DEF_STATIC_CONST_VAL_FLOAT(val_2422,-0.385253);
#define CTNODE_cmu_us_rms_dur_NO_4381 4383
DEF_STATIC_CONST_VAL_FLOAT(val_2423,-0.054235);
#define CTNODE_cmu_us_rms_dur_NO_4372 4384
DEF_STATIC_CONST_VAL_FLOAT(val_2424,0.009707);
#define CTNODE_cmu_us_rms_dur_NO_4384 4386
DEF_STATIC_CONST_VAL_FLOAT(val_2425,0.416808);
#define CTNODE_cmu_us_rms_dur_NO_4367 4387
DEF_STATIC_CONST_VAL_FLOAT(val_2426,-0.560528);
#define CTNODE_cmu_us_rms_dur_NO_4387 4389
DEF_STATIC_CONST_VAL_FLOAT(val_2427,-0.169979);
#define CTNODE_cmu_us_rms_dur_NO_4366 4390
DEF_STATIC_CONST_VAL_FLOAT(val_2428,0.330050);
#define CTNODE_cmu_us_rms_dur_NO_4393 4395
DEF_STATIC_CONST_VAL_FLOAT(val_2429,0.222304);
#define CTNODE_cmu_us_rms_dur_NO_4395 4397
DEF_STATIC_CONST_VAL_FLOAT(val_2430,-0.272983);
#define CTNODE_cmu_us_rms_dur_NO_4397 4399
DEF_STATIC_CONST_VAL_FLOAT(val_2431,-0.062375);
#define CTNODE_cmu_us_rms_dur_NO_4392 4400
DEF_STATIC_CONST_VAL_FLOAT(val_2432,0.796736);
#define CTNODE_cmu_us_rms_dur_NO_4391 4401
DEF_STATIC_CONST_VAL_FLOAT(val_2433,0.292702);
#define CTNODE_cmu_us_rms_dur_NO_4403 4405
DEF_STATIC_CONST_VAL_FLOAT(val_2434,-0.289409);
#define CTNODE_cmu_us_rms_dur_NO_4405 4407
DEF_STATIC_CONST_VAL_FLOAT(val_2435,0.004378);
#define CTNODE_cmu_us_rms_dur_NO_4402 4408
DEF_STATIC_CONST_VAL_FLOAT(val_2436,0.290760);
#define CTNODE_cmu_us_rms_dur_NO_4401 4409
DEF_STATIC_CONST_VAL_FLOAT(val_2437,-0.018169);
#define CTNODE_cmu_us_rms_dur_NO_4409 4411
DEF_STATIC_CONST_VAL_FLOAT(val_2438,-0.255704);
#define CTNODE_cmu_us_rms_dur_NO_4390 4412
DEF_STATIC_CONST_VAL_FLOAT(val_2439,0.380019);
#define CTNODE_cmu_us_rms_dur_NO_4412 4414
DEF_STATIC_CONST_VAL_FLOAT(val_2440,-0.144122);
#define CTNODE_cmu_us_rms_dur_NO_4414 4416
DEF_STATIC_CONST_VAL_FLOAT(val_2441,-0.390893);
#define CTNODE_cmu_us_rms_dur_NO_4416 4418
DEF_STATIC_CONST_VAL_FLOAT(val_2442,-0.524968);
#define CTNODE_cmu_us_rms_dur_NO_4363 4419
DEF_STATIC_CONST_VAL_FLOAT(val_2443,0.023197);
#define CTNODE_cmu_us_rms_dur_NO_4419 4421
DEF_STATIC_CONST_VAL_FLOAT(val_2444,0.824246);
#define CTNODE_cmu_us_rms_dur_NO_4358 4422
DEF_STATIC_CONST_VAL_FLOAT(val_2445,0.391320);
#define CTNODE_cmu_us_rms_dur_NO_4424 4426
DEF_STATIC_CONST_VAL_FLOAT(val_2446,0.819166);
#define CTNODE_cmu_us_rms_dur_NO_4423 4427
DEF_STATIC_CONST_VAL_FLOAT(val_2447,0.042884);
#define CTNODE_cmu_us_rms_dur_NO_4422 4428
DEF_STATIC_CONST_VAL_FLOAT(val_2448,0.967680);
#define CTNODE_cmu_us_rms_dur_NO_4429 4431
DEF_STATIC_CONST_VAL_FLOAT(val_2449,0.216793);
#define CTNODE_cmu_us_rms_dur_NO_4431 4433
DEF_STATIC_CONST_VAL_FLOAT(val_2450,0.050075);
#define CTNODE_cmu_us_rms_dur_NO_4428 4434
DEF_STATIC_CONST_VAL_FLOAT(val_2451,-0.045040);
#define CTNODE_cmu_us_rms_dur_NO_4435 4437
DEF_STATIC_CONST_VAL_FLOAT(val_2452,-0.321178);
#define CTNODE_cmu_us_rms_dur_NO_4438 4440
DEF_STATIC_CONST_VAL_FLOAT(val_2453,-0.595040);
#define CTNODE_cmu_us_rms_dur_NO_4437 4441
DEF_STATIC_CONST_VAL_FLOAT(val_2454,-0.599933);
#define CTNODE_cmu_us_rms_dur_NO_4441 4443
DEF_STATIC_CONST_VAL_FLOAT(val_2455,-1.007450);
#define CTNODE_cmu_us_rms_dur_NO_4443 4445
DEF_STATIC_CONST_VAL_FLOAT(val_2456,-0.699911);
#define CTNODE_cmu_us_rms_dur_NO_4434 4446
DEF_STATIC_CONST_VAL_STRING(val_2457,"p_138");
DEF_STATIC_CONST_VAL_FLOAT(val_2458,-0.996800);
#define CTNODE_cmu_us_rms_dur_NO_4446 4448
DEF_STATIC_CONST_VAL_FLOAT(val_2459,-0.044842);
#define CTNODE_cmu_us_rms_dur_NO_4449 4451
DEF_STATIC_CONST_VAL_FLOAT(val_2460,0.672429);
#define CTNODE_cmu_us_rms_dur_NO_4448 4452
DEF_STATIC_CONST_VAL_FLOAT(val_2461,-0.563183);
#define CTNODE_cmu_us_rms_dur_NO_4454 4456
DEF_STATIC_CONST_VAL_FLOAT(val_2462,0.011130);
#define CTNODE_cmu_us_rms_dur_NO_4457 4459
DEF_STATIC_CONST_VAL_FLOAT(val_2463,-0.445713);
#define CTNODE_cmu_us_rms_dur_NO_4456 4460
DEF_STATIC_CONST_VAL_FLOAT(val_2464,-0.218037);
#define CTNODE_cmu_us_rms_dur_NO_4461 4463
DEF_STATIC_CONST_VAL_FLOAT(val_2465,0.114157);
#define CTNODE_cmu_us_rms_dur_NO_4460 4464
DEF_STATIC_CONST_VAL_FLOAT(val_2466,0.389839);
#define CTNODE_cmu_us_rms_dur_NO_4465 4467
DEF_STATIC_CONST_VAL_FLOAT(val_2467,-0.159119);
#define CTNODE_cmu_us_rms_dur_NO_4464 4468
DEF_STATIC_CONST_VAL_FLOAT(val_2468,0.500035);
#define CTNODE_cmu_us_rms_dur_NO_4453 4469
DEF_STATIC_CONST_VAL_FLOAT(val_2469,0.896570);
#define CTNODE_cmu_us_rms_dur_NO_4452 4470
DEF_STATIC_CONST_VAL_FLOAT(val_2470,0.220492);
#define CTNODE_cmu_us_rms_dur_NO_4471 4473
DEF_STATIC_CONST_VAL_FLOAT(val_2471,0.648591);
#define CTNODE_cmu_us_rms_dur_NO_4470 4474
DEF_STATIC_CONST_VAL_FLOAT(val_2472,0.453009);
#define CTNODE_cmu_us_rms_dur_NO_4474 4476
DEF_STATIC_CONST_VAL_FLOAT(val_2473,0.307778);
#define CTNODE_cmu_us_rms_dur_NO_4478 4480
DEF_STATIC_CONST_VAL_FLOAT(val_2474,0.476609);
#define CTNODE_cmu_us_rms_dur_NO_4477 4481
DEF_STATIC_CONST_VAL_FLOAT(val_2475,0.180142);
#define CTNODE_cmu_us_rms_dur_NO_4481 4483
DEF_STATIC_CONST_VAL_FLOAT(val_2476,-0.161779);
#define CTNODE_cmu_us_rms_dur_NO_4476 4484
DEF_STATIC_CONST_VAL_FLOAT(val_2477,0.589006);
#define CTNODE_cmu_us_rms_dur_NO_4486 4488
DEF_STATIC_CONST_VAL_FLOAT(val_2478,0.121549);
#define CTNODE_cmu_us_rms_dur_NO_4485 4489
DEF_STATIC_CONST_VAL_FLOAT(val_2479,5.700000);
DEF_STATIC_CONST_VAL_FLOAT(val_2480,-0.025042);
#define CTNODE_cmu_us_rms_dur_NO_4490 4492
DEF_STATIC_CONST_VAL_FLOAT(val_2481,0.335645);
#define CTNODE_cmu_us_rms_dur_NO_4489 4493
DEF_STATIC_CONST_VAL_FLOAT(val_2482,-0.078405);
#define CTNODE_cmu_us_rms_dur_NO_4493 4495
DEF_STATIC_CONST_VAL_FLOAT(val_2483,-0.490657);
#define CTNODE_cmu_us_rms_dur_NO_4484 4496
DEF_STATIC_CONST_VAL_FLOAT(val_2484,-0.783469);
#define CTNODE_cmu_us_rms_dur_NO_4498 4500
DEF_STATIC_CONST_VAL_FLOAT(val_2485,-0.458736);
#define CTNODE_cmu_us_rms_dur_NO_4497 4501
DEF_STATIC_CONST_VAL_FLOAT(val_2486,-0.623543);
#define CTNODE_cmu_us_rms_dur_NO_4501 4503
DEF_STATIC_CONST_VAL_FLOAT(val_2487,-0.224606);
#define CTNODE_cmu_us_rms_dur_NO_4505 4507
DEF_STATIC_CONST_VAL_FLOAT(val_2488,-0.503689);
#define CTNODE_cmu_us_rms_dur_NO_4504 4508
DEF_STATIC_CONST_VAL_FLOAT(val_2489,-0.259019);
#define CTNODE_cmu_us_rms_dur_NO_4509 4511
DEF_STATIC_CONST_VAL_FLOAT(val_2490,-0.503924);
#define CTNODE_cmu_us_rms_dur_NO_4508 4512
DEF_STATIC_CONST_VAL_FLOAT(val_2491,0.537886);
#define CTNODE_cmu_us_rms_dur_NO_4513 4515
DEF_STATIC_CONST_VAL_FLOAT(val_2492,-0.321744);
#define CTNODE_cmu_us_rms_dur_NO_4515 4517
DEF_STATIC_CONST_VAL_FLOAT(val_2493,5.300000);
DEF_STATIC_CONST_VAL_FLOAT(val_2494,0.083573);
#define CTNODE_cmu_us_rms_dur_NO_4517 4519
DEF_STATIC_CONST_VAL_FLOAT(val_2495,0.661593);
#define CTNODE_cmu_us_rms_dur_NO_4512 4520
DEF_STATIC_CONST_VAL_FLOAT(val_2496,0.048601);
#define CTNODE_cmu_us_rms_dur_NO_4521 4523
DEF_STATIC_CONST_VAL_FLOAT(val_2497,0.512467);
#define CTNODE_cmu_us_rms_dur_NO_4520 4524
DEF_STATIC_CONST_VAL_FLOAT(val_2498,-0.631991);
#define CTNODE_cmu_us_rms_dur_NO_4525 4527
DEF_STATIC_CONST_VAL_FLOAT(val_2499,-0.711995);
#define CTNODE_cmu_us_rms_dur_NO_4528 4530
DEF_STATIC_CONST_VAL_FLOAT(val_2500,-0.327717);
#define CTNODE_cmu_us_rms_dur_NO_4527 4531
DEF_STATIC_CONST_VAL_FLOAT(val_2501,0.025311);
#define CTNODE_cmu_us_rms_dur_NO_4524 4532
DEF_STATIC_CONST_VAL_FLOAT(val_2502,-0.699568);
#define CTNODE_cmu_us_rms_dur_NO_4533 4535
DEF_STATIC_CONST_VAL_FLOAT(val_2503,-0.075335);
#define CTNODE_cmu_us_rms_dur_NO_4532 4536
DEF_STATIC_CONST_VAL_FLOAT(val_2504,-0.557751);
#define CTNODE_cmu_us_rms_dur_NO_4537 4539
DEF_STATIC_CONST_VAL_FLOAT(val_2505,-0.292317);
#define CTNODE_cmu_us_rms_dur_NO_4536 4540
DEF_STATIC_CONST_VAL_FLOAT(val_2506,-0.340919);
#define CTNODE_cmu_us_rms_dur_NO_4540 4542
DEF_STATIC_CONST_VAL_FLOAT(val_2507,-0.103708);
#define CTNODE_cmu_us_rms_dur_NO_4543 4545
DEF_STATIC_CONST_VAL_FLOAT(val_2508,0.522606);
#define CTNODE_cmu_us_rms_dur_NO_4547 4549
DEF_STATIC_CONST_VAL_FLOAT(val_2509,0.064256);
#define CTNODE_cmu_us_rms_dur_NO_4546 4550
DEF_STATIC_CONST_VAL_FLOAT(val_2510,-0.095553);
#define CTNODE_cmu_us_rms_dur_NO_4545 4551
DEF_STATIC_CONST_VAL_FLOAT(val_2511,0.780530);
#define CTNODE_cmu_us_rms_dur_NO_4551 4553
DEF_STATIC_CONST_VAL_FLOAT(val_2512,0.128247);
#define CTNODE_cmu_us_rms_dur_NO_4542 4554
DEF_STATIC_CONST_VAL_FLOAT(val_2513,-0.198776);
#define CTNODE_cmu_us_rms_dur_NO_4557 4559
DEF_STATIC_CONST_VAL_FLOAT(val_2514,0.228946);
#define CTNODE_cmu_us_rms_dur_NO_4556 4560
DEF_STATIC_CONST_VAL_FLOAT(val_2515,-0.395004);
#define CTNODE_cmu_us_rms_dur_NO_4555 4561
DEF_STATIC_CONST_VAL_FLOAT(val_2516,0.751603);
#define CTNODE_cmu_us_rms_dur_NO_4562 4564
DEF_STATIC_CONST_VAL_FLOAT(val_2517,0.430430);
#define CTNODE_cmu_us_rms_dur_NO_4564 4566
DEF_STATIC_CONST_VAL_FLOAT(val_2518,-0.180325);
#define CTNODE_cmu_us_rms_dur_NO_4561 4567
DEF_STATIC_CONST_VAL_FLOAT(val_2519,-0.160767);
#define CTNODE_cmu_us_rms_dur_NO_4554 4568
DEF_STATIC_CONST_VAL_FLOAT(val_2520,0.376565);
#define CTNODE_cmu_us_rms_dur_NO_4568 4570
DEF_STATIC_CONST_VAL_FLOAT(val_2521,-0.223242);
#define CTNODE_cmu_us_rms_dur_NO_4571 4573
DEF_STATIC_CONST_VAL_FLOAT(val_2522,-0.577895);
#define CTNODE_cmu_us_rms_dur_NO_4570 4574
DEF_STATIC_CONST_VAL_FLOAT(val_2523,0.041577);
#define CTNODE_cmu_us_rms_dur_NO_4574 4576
DEF_STATIC_CONST_VAL_FLOAT(val_2524,-0.023457);
#define CTNODE_cmu_us_rms_dur_NO_4576 4578
DEF_STATIC_CONST_VAL_FLOAT(val_2525,-0.402543);
#define CTNODE_cmu_us_rms_dur_NO_4503 4579
DEF_STATIC_CONST_VAL_FLOAT(val_2526,-0.517725);
#define CTNODE_cmu_us_rms_dur_NO_4496 4580
DEF_STATIC_CONST_VAL_FLOAT(val_2527,-0.459977);
#define CTNODE_cmu_us_rms_dur_NO_4582 4584
DEF_STATIC_CONST_VAL_FLOAT(val_2528,0.081384);
#define CTNODE_cmu_us_rms_dur_NO_4585 4587
DEF_STATIC_CONST_VAL_FLOAT(val_2529,-0.527535);
#define CTNODE_cmu_us_rms_dur_NO_4587 4589
DEF_STATIC_CONST_VAL_FLOAT(val_2530,-0.207377);
#define CTNODE_cmu_us_rms_dur_NO_4584 4590
DEF_STATIC_CONST_VAL_FLOAT(val_2531,0.502808);
#define CTNODE_cmu_us_rms_dur_NO_4590 4592
DEF_STATIC_CONST_VAL_FLOAT(val_2532,0.343920);
#define CTNODE_cmu_us_rms_dur_NO_4592 4594
DEF_STATIC_CONST_VAL_FLOAT(val_2533,0.055835);
#define CTNODE_cmu_us_rms_dur_NO_4594 4596
DEF_STATIC_CONST_VAL_FLOAT(val_2534,-0.319276);
#define CTNODE_cmu_us_rms_dur_NO_4581 4597
DEF_STATIC_CONST_VAL_FLOAT(val_2535,0.574297);
#define CTNODE_cmu_us_rms_dur_NO_4580 4598
DEF_STATIC_CONST_VAL_FLOAT(val_2536,0.360232);
#define CTNODE_cmu_us_rms_dur_NO_4598 4600
DEF_STATIC_CONST_VAL_FLOAT(val_2537,-0.906251);
#define CTNODE_cmu_us_rms_dur_NO_4600 4602
DEF_STATIC_CONST_VAL_FLOAT(val_2538,0.817422);
#define CTNODE_cmu_us_rms_dur_NO_4603 4605
DEF_STATIC_CONST_VAL_FLOAT(val_2539,0.600631);
#define CTNODE_cmu_us_rms_dur_NO_4606 4608
DEF_STATIC_CONST_VAL_FLOAT(val_2540,-0.048846);
#define CTNODE_cmu_us_rms_dur_NO_4609 4611
DEF_STATIC_CONST_VAL_FLOAT(val_2541,0.403619);
#define CTNODE_cmu_us_rms_dur_NO_4608 4612
DEF_STATIC_CONST_VAL_FLOAT(val_2542,-0.323784);
#define CTNODE_cmu_us_rms_dur_NO_4612 4614
DEF_STATIC_CONST_VAL_FLOAT(val_2543,0.062940);
#define CTNODE_cmu_us_rms_dur_NO_4614 4616
DEF_STATIC_CONST_VAL_FLOAT(val_2544,-0.151524);
#define CTNODE_cmu_us_rms_dur_NO_4605 4617
DEF_STATIC_CONST_VAL_FLOAT(val_2545,-0.377671);
#define CTNODE_cmu_us_rms_dur_NO_4619 4621
DEF_STATIC_CONST_VAL_FLOAT(val_2546,-0.522329);
#define CTNODE_cmu_us_rms_dur_NO_4618 4622
DEF_STATIC_CONST_VAL_FLOAT(val_2547,0.348052);
#define CTNODE_cmu_us_rms_dur_NO_4625 4627
DEF_STATIC_CONST_VAL_FLOAT(val_2548,-0.017791);
#define CTNODE_cmu_us_rms_dur_NO_4624 4628
DEF_STATIC_CONST_VAL_FLOAT(val_2549,-0.378512);
#define CTNODE_cmu_us_rms_dur_NO_4628 4630
DEF_STATIC_CONST_VAL_FLOAT(val_2550,-0.041871);
#define CTNODE_cmu_us_rms_dur_NO_4623 4631
DEF_STATIC_CONST_VAL_FLOAT(val_2551,-0.294800);
#define CTNODE_cmu_us_rms_dur_NO_4622 4632
DEF_STATIC_CONST_VAL_FLOAT(val_2552,-0.458490);
#define CTNODE_cmu_us_rms_dur_NO_4632 4634
#define CTNODE_cmu_us_rms_dur_NO_4635 4637
DEF_STATIC_CONST_VAL_FLOAT(val_2553,-0.400888);
#define CTNODE_cmu_us_rms_dur_NO_4634 4638
DEF_STATIC_CONST_VAL_FLOAT(val_2554,-0.086786);
#define CTNODE_cmu_us_rms_dur_NO_4617 4639
DEF_STATIC_CONST_VAL_FLOAT(val_2555,-0.627059);
#define CTNODE_cmu_us_rms_dur_NO_4639 4641
DEF_STATIC_CONST_VAL_FLOAT(val_2556,-0.587275);
#define CTNODE_cmu_us_rms_dur_NO_4642 4644
DEF_STATIC_CONST_VAL_FLOAT(val_2557,-0.460245);
#define CTNODE_cmu_us_rms_dur_NO_4641 4645
DEF_STATIC_CONST_VAL_FLOAT(val_2558,-0.285508);
#define CTNODE_cmu_us_rms_dur_NO_4602 4646
DEF_STATIC_CONST_VAL_FLOAT(val_2559,-0.363327);
#define CTNODE_cmu_us_rms_dur_NO_4649 4651
DEF_STATIC_CONST_VAL_FLOAT(val_2560,-0.688828);
#define CTNODE_cmu_us_rms_dur_NO_4648 4652
DEF_STATIC_CONST_VAL_FLOAT(val_2561,-0.559722);
#define CTNODE_cmu_us_rms_dur_NO_4652 4654
DEF_STATIC_CONST_VAL_FLOAT(val_2562,-0.406072);
#define CTNODE_cmu_us_rms_dur_NO_4654 4656
DEF_STATIC_CONST_VAL_FLOAT(val_2563,0.436704);
#define CTNODE_cmu_us_rms_dur_NO_4656 4658
DEF_STATIC_CONST_VAL_FLOAT(val_2564,-0.382626);
#define CTNODE_cmu_us_rms_dur_NO_4658 4660
DEF_STATIC_CONST_VAL_FLOAT(val_2565,0.010744);
#define CTNODE_cmu_us_rms_dur_NO_4660 4662
DEF_STATIC_CONST_VAL_FLOAT(val_2566,-0.254216);
#define CTNODE_cmu_us_rms_dur_NO_4647 4663
DEF_STATIC_CONST_VAL_FLOAT(val_2567,0.947419);
#define CTNODE_cmu_us_rms_dur_NO_4663 4665
DEF_STATIC_CONST_VAL_FLOAT(val_2568,0.499037);
#define CTNODE_cmu_us_rms_dur_NO_4665 4667
DEF_STATIC_CONST_VAL_FLOAT(val_2569,0.055002);
#define CTNODE_cmu_us_rms_dur_NO_4646 4668
DEF_STATIC_CONST_VAL_FLOAT(val_2570,-0.671396);
#define CTNODE_cmu_us_rms_dur_NO_4670 4672
DEF_STATIC_CONST_VAL_FLOAT(val_2571,-0.451274);
#define CTNODE_cmu_us_rms_dur_NO_4672 4674
DEF_STATIC_CONST_VAL_FLOAT(val_2572,-0.194856);
#define CTNODE_cmu_us_rms_dur_NO_4669 4675
DEF_STATIC_CONST_VAL_FLOAT(val_2573,-0.906945);
#define CTNODE_cmu_us_rms_dur_NO_4668 4676
DEF_STATIC_CONST_VAL_FLOAT(val_2574,-0.191778);
#define CTNODE_cmu_us_rms_dur_NO_4678 4680
DEF_STATIC_CONST_VAL_FLOAT(val_2575,0.662288);
#define CTNODE_cmu_us_rms_dur_NO_4680 4682
DEF_STATIC_CONST_VAL_FLOAT(val_2576,0.120393);
#define CTNODE_cmu_us_rms_dur_NO_4677 4683
DEF_STATIC_CONST_VAL_FLOAT(val_2577,0.437562);
#define CTNODE_cmu_us_rms_dur_NO_4684 4686
DEF_STATIC_CONST_VAL_FLOAT(val_2578,-0.482797);
#define CTNODE_cmu_us_rms_dur_NO_4687 4689
DEF_STATIC_CONST_VAL_FLOAT(val_2579,-0.164249);
#define CTNODE_cmu_us_rms_dur_NO_4689 4691
DEF_STATIC_CONST_VAL_FLOAT(val_2580,-0.374720);
#define CTNODE_cmu_us_rms_dur_NO_4686 4692
DEF_STATIC_CONST_VAL_FLOAT(val_2581,-0.061708);
#define CTNODE_cmu_us_rms_dur_NO_4693 4695
DEF_STATIC_CONST_VAL_FLOAT(val_2582,-0.422589);
#define CTNODE_cmu_us_rms_dur_NO_4692 4696
DEF_STATIC_CONST_VAL_FLOAT(val_2583,0.014985);
#define CTNODE_cmu_us_rms_dur_NO_4698 4700
DEF_STATIC_CONST_VAL_FLOAT(val_2584,0.220665);
#define CTNODE_cmu_us_rms_dur_NO_4697 4701
DEF_STATIC_CONST_VAL_FLOAT(val_2585,-0.214518);
#define CTNODE_cmu_us_rms_dur_NO_4696 4702
DEF_STATIC_CONST_VAL_FLOAT(val_2586,0.400302);
#define CTNODE_cmu_us_rms_dur_NO_4683 4703
DEF_STATIC_CONST_VAL_FLOAT(val_2587,-0.470548);
#define CTNODE_cmu_us_rms_dur_NO_4705 4707
DEF_STATIC_CONST_VAL_FLOAT(val_2588,-0.353448);
#define CTNODE_cmu_us_rms_dur_NO_4704 4708
DEF_STATIC_CONST_VAL_FLOAT(val_2589,-0.602039);
#define CTNODE_cmu_us_rms_dur_NO_4709 4711
DEF_STATIC_CONST_VAL_FLOAT(val_2590,-0.567738);
#define CTNODE_cmu_us_rms_dur_NO_4708 4712
DEF_STATIC_CONST_VAL_FLOAT(val_2591,-0.505922);
#define CTNODE_cmu_us_rms_dur_NO_4703 4713
DEF_STATIC_CONST_VAL_FLOAT(val_2592,-0.510719);
#define CTNODE_cmu_us_rms_dur_NO_4714 4716
DEF_STATIC_CONST_VAL_FLOAT(val_2593,-0.676419);
#define CTNODE_cmu_us_rms_dur_NO_4713 4717
DEF_STATIC_CONST_VAL_FLOAT(val_2594,-0.281599);
#define CTNODE_cmu_us_rms_dur_NO_4721 4723
DEF_STATIC_CONST_VAL_FLOAT(val_2595,-0.054400);
#define CTNODE_cmu_us_rms_dur_NO_4720 4724
DEF_STATIC_CONST_VAL_FLOAT(val_2596,-0.455693);
#define CTNODE_cmu_us_rms_dur_NO_4719 4725
DEF_STATIC_CONST_VAL_FLOAT(val_2597,0.095578);
#define CTNODE_cmu_us_rms_dur_NO_4718 4726
DEF_STATIC_CONST_VAL_FLOAT(val_2598,-0.761263);
#define CTNODE_cmu_us_rms_dur_NO_4726 4728
DEF_STATIC_CONST_VAL_FLOAT(val_2599,-0.701715);
#define CTNODE_cmu_us_rms_dur_NO_4728 4730
DEF_STATIC_CONST_VAL_FLOAT(val_2600,-0.238145);
#define CTNODE_cmu_us_rms_dur_NO_4730 4732
DEF_STATIC_CONST_VAL_FLOAT(val_2601,-0.639305);
#define CTNODE_cmu_us_rms_dur_NO_4732 4734
DEF_STATIC_CONST_VAL_FLOAT(val_2602,-0.492891);
#define CTNODE_cmu_us_rms_dur_NO_4717 4735
DEF_STATIC_CONST_VAL_FLOAT(val_2603,-0.411218);
#define CTNODE_cmu_us_rms_dur_NO_4737 4739
DEF_STATIC_CONST_VAL_FLOAT(val_2604,-0.690349);
#define CTNODE_cmu_us_rms_dur_NO_4736 4740
DEF_STATIC_CONST_VAL_FLOAT(val_2605,-0.240241);
#define CTNODE_cmu_us_rms_dur_NO_4740 4742
DEF_STATIC_CONST_VAL_FLOAT(val_2606,-0.493610);
#define CTNODE_cmu_us_rms_dur_NO_4735 4743
DEF_STATIC_CONST_VAL_FLOAT(val_2607,-0.538619);
#define CTNODE_cmu_us_rms_dur_NO_4746 4748
DEF_STATIC_CONST_VAL_FLOAT(val_2608,-0.727544);
#define CTNODE_cmu_us_rms_dur_NO_4745 4749
DEF_STATIC_CONST_VAL_FLOAT(val_2609,-0.496881);
#define CTNODE_cmu_us_rms_dur_NO_4750 4752
DEF_STATIC_CONST_VAL_FLOAT(val_2610,-0.125073);
#define CTNODE_cmu_us_rms_dur_NO_4749 4753
DEF_STATIC_CONST_VAL_FLOAT(val_2611,-0.370127);
#define CTNODE_cmu_us_rms_dur_NO_4753 4755
DEF_STATIC_CONST_VAL_FLOAT(val_2612,-0.602565);
#define CTNODE_cmu_us_rms_dur_NO_4744 4756
DEF_STATIC_CONST_VAL_FLOAT(val_2613,-0.411794);
#define CTNODE_cmu_us_rms_dur_NO_4756 4758
DEF_STATIC_CONST_VAL_FLOAT(val_2614,0.076774);
#define CTNODE_cmu_us_rms_dur_NO_4758 4760
DEF_STATIC_CONST_VAL_FLOAT(val_2615,-0.205987);
#define CTNODE_cmu_us_rms_dur_NO_4743 4761
DEF_STATIC_CONST_VAL_FLOAT(val_2616,-0.022568);
#define CTNODE_cmu_us_rms_dur_NO_4764 4766
DEF_STATIC_CONST_VAL_FLOAT(val_2617,-0.519421);
#define CTNODE_cmu_us_rms_dur_NO_4763 4767
DEF_STATIC_CONST_VAL_FLOAT(val_2618,-0.461740);
#define CTNODE_cmu_us_rms_dur_NO_4767 4769
DEF_STATIC_CONST_VAL_FLOAT(val_2619,-0.862953);
#define CTNODE_cmu_us_rms_dur_NO_4769 4771
DEF_STATIC_CONST_VAL_FLOAT(val_2620,-0.450934);
#define CTNODE_cmu_us_rms_dur_NO_4771 4773
DEF_STATIC_CONST_VAL_FLOAT(val_2621,-0.648247);
#define CTNODE_cmu_us_rms_dur_NO_4762 4774
DEF_STATIC_CONST_VAL_FLOAT(val_2622,-0.657693);
#define CTNODE_cmu_us_rms_dur_NO_4774 4776
DEF_STATIC_CONST_VAL_FLOAT(val_2623,-0.154343);
#define CTNODE_cmu_us_rms_dur_NO_4776 4778
DEF_STATIC_CONST_VAL_FLOAT(val_2624,0.324567);
#define CTNODE_cmu_us_rms_dur_NO_4761 4779
DEF_STATIC_CONST_VAL_FLOAT(val_2625,-0.732426);
#define CTNODE_cmu_us_rms_dur_NO_4781 4783
DEF_STATIC_CONST_VAL_FLOAT(val_2626,-0.714187);
#define CTNODE_cmu_us_rms_dur_NO_4784 4786
DEF_STATIC_CONST_VAL_FLOAT(val_2627,-0.443552);
#define CTNODE_cmu_us_rms_dur_NO_4783 4787
DEF_STATIC_CONST_VAL_FLOAT(val_2628,-0.327044);
#define CTNODE_cmu_us_rms_dur_NO_4780 4788
DEF_STATIC_CONST_VAL_FLOAT(val_2629,-0.208394);
#define CTNODE_cmu_us_rms_dur_NO_4779 4789
DEF_STATIC_CONST_VAL_FLOAT(val_2630,-0.128224);
#define CTNODE_cmu_us_rms_dur_NO_4790 4792
DEF_STATIC_CONST_VAL_FLOAT(val_2631,0.397245);
#define CTNODE_cmu_us_rms_dur_NO_4789 4793
DEF_STATIC_CONST_VAL_FLOAT(val_2632,0.426864);
#define CTNODE_cmu_us_rms_dur_NO_4793 4795
DEF_STATIC_CONST_VAL_FLOAT(val_2633,0.450727);
#define CTNODE_cmu_us_rms_dur_NO_4796 4798
DEF_STATIC_CONST_VAL_FLOAT(val_2634,-0.222764);
#define CTNODE_cmu_us_rms_dur_NO_4795 4799
DEF_STATIC_CONST_VAL_FLOAT(val_2635,0.756237);
#define CTNODE_cmu_us_rms_dur_NO_4800 4802
DEF_STATIC_CONST_VAL_FLOAT(val_2636,-0.772108);
#define CTNODE_cmu_us_rms_dur_NO_4802 4804
DEF_STATIC_CONST_VAL_FLOAT(val_2637,-0.426053);
#define CTNODE_cmu_us_rms_dur_NO_4804 4806
DEF_STATIC_CONST_VAL_FLOAT(val_2638,-0.168882);
#define CTNODE_cmu_us_rms_dur_NO_4806 4808
DEF_STATIC_CONST_VAL_FLOAT(val_2639,0.433135);
#define CTNODE_cmu_us_rms_dur_NO_4808 4810
DEF_STATIC_CONST_VAL_FLOAT(val_2640,0.197475);
#define CTNODE_cmu_us_rms_dur_NO_4799 4811
DEF_STATIC_CONST_VAL_FLOAT(val_2641,-0.193350);
#define CTNODE_cmu_us_rms_dur_NO_4813 4815
DEF_STATIC_CONST_VAL_FLOAT(val_2642,-0.462316);
#define CTNODE_cmu_us_rms_dur_NO_4812 4816
DEF_STATIC_CONST_VAL_FLOAT(val_2643,-0.793844);
#define CTNODE_cmu_us_rms_dur_NO_4817 4819
DEF_STATIC_CONST_VAL_FLOAT(val_2644,-0.451365);
#define CTNODE_cmu_us_rms_dur_NO_4816 4820
DEF_STATIC_CONST_VAL_FLOAT(val_2645,-0.273188);
#define CTNODE_cmu_us_rms_dur_NO_4820 4822
DEF_STATIC_CONST_VAL_FLOAT(val_2646,-0.571280);
#define CTNODE_cmu_us_rms_dur_NO_4811 4823
DEF_STATIC_CONST_VAL_FLOAT(val_2647,0.478651);
#define CTNODE_cmu_us_rms_dur_NO_4824 4826
DEF_STATIC_CONST_VAL_FLOAT(val_2648,-0.204347);
#define CTNODE_cmu_us_rms_dur_NO_4823 4827
DEF_STATIC_CONST_VAL_FLOAT(val_2649,0.368313);
#define CTNODE_cmu_us_rms_dur_NO_4827 4829
DEF_STATIC_CONST_VAL_FLOAT(val_2650,0.425689);
#define CTNODE_cmu_us_rms_dur_NO_4831 4833
DEF_STATIC_CONST_VAL_FLOAT(val_2651,0.013600);
#define CTNODE_cmu_us_rms_dur_NO_4830 4834
DEF_STATIC_CONST_VAL_FLOAT(val_2652,-0.241502);
#define CTNODE_cmu_us_rms_dur_NO_4829 4835
DEF_STATIC_CONST_VAL_STRING(val_2653,"uh_176");
DEF_STATIC_CONST_VAL_FLOAT(val_2654,0.174378);
#define CTNODE_cmu_us_rms_dur_NO_4835 4837
DEF_STATIC_CONST_VAL_FLOAT(val_2655,-0.462124);
#define CTNODE_cmu_us_rms_dur_NO_4839 4841
DEF_STATIC_CONST_VAL_FLOAT(val_2656,-0.000272);
#define CTNODE_cmu_us_rms_dur_NO_4838 4842
DEF_STATIC_CONST_VAL_FLOAT(val_2657,-0.607233);
#define CTNODE_cmu_us_rms_dur_NO_4843 4845
DEF_STATIC_CONST_VAL_FLOAT(val_2658,-0.703579);
#define CTNODE_cmu_us_rms_dur_NO_4842 4846
DEF_STATIC_CONST_VAL_FLOAT(val_2659,-0.390137);
#define CTNODE_cmu_us_rms_dur_NO_4837 4847
DEF_STATIC_CONST_VAL_FLOAT(val_2660,-0.648596);
#define CTNODE_cmu_us_rms_dur_NO_4849 4851
DEF_STATIC_CONST_VAL_FLOAT(val_2661,-0.356082);
#define CTNODE_cmu_us_rms_dur_NO_4848 4852
DEF_STATIC_CONST_VAL_FLOAT(val_2662,-0.305669);
#define CTNODE_cmu_us_rms_dur_NO_4847 4853
DEF_STATIC_CONST_VAL_FLOAT(val_2663,-0.462761);
#define CTNODE_cmu_us_rms_dur_NO_4855 4857
DEF_STATIC_CONST_VAL_FLOAT(val_2664,-0.074145);
#define CTNODE_cmu_us_rms_dur_NO_4854 4858
DEF_STATIC_CONST_VAL_FLOAT(val_2665,-0.393321);
#define CTNODE_cmu_us_rms_dur_NO_4858 4860
DEF_STATIC_CONST_VAL_FLOAT(val_2666,-0.619607);
#define CTNODE_cmu_us_rms_dur_NO_4853 4861
DEF_STATIC_CONST_VAL_FLOAT(val_2667,-0.502053);
#define CTNODE_cmu_us_rms_dur_NO_4862 4864
DEF_STATIC_CONST_VAL_FLOAT(val_2668,-0.269657);
#define CTNODE_cmu_us_rms_dur_NO_4865 4867
DEF_STATIC_CONST_VAL_FLOAT(val_2669,-0.603267);
#define CTNODE_cmu_us_rms_dur_NO_4864 4868
DEF_STATIC_CONST_VAL_FLOAT(val_2670,-0.614352);
#define CTNODE_cmu_us_rms_dur_NO_4871 4873
DEF_STATIC_CONST_VAL_FLOAT(val_2671,-0.458971);
#define CTNODE_cmu_us_rms_dur_NO_4870 4874
DEF_STATIC_CONST_VAL_FLOAT(val_2672,-0.285576);
#define CTNODE_cmu_us_rms_dur_NO_4874 4876
DEF_STATIC_CONST_VAL_FLOAT(val_2673,-0.286553);
#define CTNODE_cmu_us_rms_dur_NO_4869 4877
DEF_STATIC_CONST_VAL_FLOAT(val_2674,-0.362176);
#define CTNODE_cmu_us_rms_dur_NO_4877 4879
DEF_STATIC_CONST_VAL_FLOAT(val_2675,0.178103);
#define CTNODE_cmu_us_rms_dur_NO_4868 4880
DEF_STATIC_CONST_VAL_FLOAT(val_2676,-0.577044);
#define CTNODE_cmu_us_rms_dur_NO_4881 4883
DEF_STATIC_CONST_VAL_FLOAT(val_2677,-0.059614);
#define CTNODE_cmu_us_rms_dur_NO_4883 4885
DEF_STATIC_CONST_VAL_FLOAT(val_2678,-0.414610);
#define CTNODE_cmu_us_rms_dur_NO_4880 4886
DEF_STATIC_CONST_VAL_FLOAT(val_2679,-0.247993);
#define CTNODE_cmu_us_rms_dur_NO_4887 4889
DEF_STATIC_CONST_VAL_FLOAT(val_2680,-0.485966);
#define CTNODE_cmu_us_rms_dur_NO_4886 4890
DEF_STATIC_CONST_VAL_FLOAT(val_2681,-0.290341);
#define CTNODE_cmu_us_rms_dur_NO_4892 4894
DEF_STATIC_CONST_VAL_FLOAT(val_2682,-0.533411);
#define CTNODE_cmu_us_rms_dur_NO_4891 4895
DEF_STATIC_CONST_VAL_FLOAT(val_2683,0.069236);
#define CTNODE_cmu_us_rms_dur_NO_4895 4897
DEF_STATIC_CONST_VAL_FLOAT(val_2684,0.009354);
#define CTNODE_cmu_us_rms_dur_NO_4899 4901
DEF_STATIC_CONST_VAL_FLOAT(val_2685,-0.171234);
#define CTNODE_cmu_us_rms_dur_NO_4898 4902
DEF_STATIC_CONST_VAL_FLOAT(val_2686,-0.432831);
#define CTNODE_cmu_us_rms_dur_NO_4902 4904
DEF_STATIC_CONST_VAL_FLOAT(val_2687,-0.112676);
#define CTNODE_cmu_us_rms_dur_NO_4904 4906
DEF_STATIC_CONST_VAL_FLOAT(val_2688,-0.332646);
#define CTNODE_cmu_us_rms_dur_NO_4897 4907
#define CTNODE_cmu_us_rms_dur_NO_4890 4908
DEF_STATIC_CONST_VAL_FLOAT(val_2689,-0.392587);
#define CTNODE_cmu_us_rms_dur_NO_4908 4910
DEF_STATIC_CONST_VAL_FLOAT(val_2690,0.183623);
#define CTNODE_cmu_us_rms_dur_NO_4911 4913
DEF_STATIC_CONST_VAL_STRING(val_2691,"det");
DEF_STATIC_CONST_VAL_FLOAT(val_2692,-0.550827);
#define CTNODE_cmu_us_rms_dur_NO_4914 4916
DEF_STATIC_CONST_VAL_FLOAT(val_2693,-0.255409);
#define CTNODE_cmu_us_rms_dur_NO_4913 4917
DEF_STATIC_CONST_VAL_FLOAT(val_2694,0.389166);
#define CTNODE_cmu_us_rms_dur_NO_4919 4921
DEF_STATIC_CONST_VAL_FLOAT(val_2695,-0.251358);
#define CTNODE_cmu_us_rms_dur_NO_4921 4923
DEF_STATIC_CONST_VAL_FLOAT(val_2696,-0.146734);
#define CTNODE_cmu_us_rms_dur_NO_4923 4925
DEF_STATIC_CONST_VAL_FLOAT(val_2697,0.350474);
#define CTNODE_cmu_us_rms_dur_NO_4925 4927
DEF_STATIC_CONST_VAL_FLOAT(val_2698,0.177579);
#define CTNODE_cmu_us_rms_dur_NO_4927 4929
DEF_STATIC_CONST_VAL_FLOAT(val_2699,-0.190741);
#define CTNODE_cmu_us_rms_dur_NO_4918 4930
DEF_STATIC_CONST_VAL_FLOAT(val_2700,0.066170);
#define CTNODE_cmu_us_rms_dur_NO_4930 4932
DEF_STATIC_CONST_VAL_FLOAT(val_2701,-0.391547);
#define CTNODE_cmu_us_rms_dur_NO_4932 4934
DEF_STATIC_CONST_VAL_FLOAT(val_2702,-0.095429);
#define CTNODE_cmu_us_rms_dur_NO_4934 4936
DEF_STATIC_CONST_VAL_FLOAT(val_2703,-0.320339);
#define CTNODE_cmu_us_rms_dur_NO_4917 4937
DEF_STATIC_CONST_VAL_FLOAT(val_2704,0.060813);
#define CTNODE_cmu_us_rms_dur_NO_4937 4939
DEF_STATIC_CONST_VAL_FLOAT(val_2705,-0.284797);
#define CTNODE_cmu_us_rms_dur_NO_4940 4942
DEF_STATIC_CONST_VAL_FLOAT(val_2706,-0.523435);
#define CTNODE_cmu_us_rms_dur_NO_4939 4943
DEF_STATIC_CONST_VAL_FLOAT(val_2707,-0.401986);
#define CTNODE_cmu_us_rms_dur_NO_4943 4945
DEF_STATIC_CONST_VAL_FLOAT(val_2708,-0.202195);
#define CTNODE_cmu_us_rms_dur_NO_4946 4948
DEF_STATIC_CONST_VAL_FLOAT(val_2709,-0.312734);
#define CTNODE_cmu_us_rms_dur_NO_4945 4949
DEF_STATIC_CONST_VAL_FLOAT(val_2710,-0.256494);
#define CTNODE_cmu_us_rms_dur_NO_4949 4951
DEF_STATIC_CONST_VAL_FLOAT(val_2711,0.220783);
#define CTNODE_cmu_us_rms_dur_NO_4951 4953
DEF_STATIC_CONST_VAL_FLOAT(val_2712,-0.083745);
#define CTNODE_cmu_us_rms_dur_NO_4910 4954
DEF_STATIC_CONST_VAL_FLOAT(val_2713,-0.015126);
#define CTNODE_cmu_us_rms_dur_NO_4955 4957
DEF_STATIC_CONST_VAL_FLOAT(val_2714,0.419819);
#define CTNODE_cmu_us_rms_dur_NO_4954 4958
DEF_STATIC_CONST_VAL_FLOAT(val_2715,0.001685);
#define CTNODE_cmu_us_rms_dur_NO_4962 4964
DEF_STATIC_CONST_VAL_FLOAT(val_2716,-0.298088);
#define CTNODE_cmu_us_rms_dur_NO_4961 4965
DEF_STATIC_CONST_VAL_FLOAT(val_2717,0.089636);
#define CTNODE_cmu_us_rms_dur_NO_4960 4966
DEF_STATIC_CONST_VAL_FLOAT(val_2718,-0.408020);
#define CTNODE_cmu_us_rms_dur_NO_4959 4967
DEF_STATIC_CONST_VAL_FLOAT(val_2719,-0.258026);
#define CTNODE_cmu_us_rms_dur_NO_4968 4970
DEF_STATIC_CONST_VAL_FLOAT(val_2720,0.081879);
#define CTNODE_cmu_us_rms_dur_NO_4967 4971
DEF_STATIC_CONST_VAL_FLOAT(val_2721,0.192138);
#define CTNODE_cmu_us_rms_dur_NO_4958 4972
DEF_STATIC_CONST_VAL_FLOAT(val_2722,-0.044604);
#define CTNODE_cmu_us_rms_dur_NO_4972 4974
DEF_STATIC_CONST_VAL_FLOAT(val_2723,0.323309);
#define CTNODE_cmu_us_rms_dur_NO_4861 4975
DEF_STATIC_CONST_VAL_FLOAT(val_2724,0.210235);
#define CTNODE_cmu_us_rms_dur_NO_4975 4977
DEF_STATIC_CONST_VAL_FLOAT(val_2725,-0.458614);
#define CTNODE_cmu_us_rms_dur_NO_4978 4980
DEF_STATIC_CONST_VAL_FLOAT(val_2726,-0.600636);
#define CTNODE_cmu_us_rms_dur_NO_4977 4981
DEF_STATIC_CONST_VAL_FLOAT(val_2727,-0.677725);
#define CTNODE_cmu_us_rms_dur_NO_4982 4984
DEF_STATIC_CONST_VAL_FLOAT(val_2728,-0.535590);
#define CTNODE_cmu_us_rms_dur_NO_4984 4986
DEF_STATIC_CONST_VAL_FLOAT(val_2729,-0.569381);
#define CTNODE_cmu_us_rms_dur_NO_4987 4989
DEF_STATIC_CONST_VAL_FLOAT(val_2730,-0.153713);
#define CTNODE_cmu_us_rms_dur_NO_4989 4991
DEF_STATIC_CONST_VAL_FLOAT(val_2731,-0.472337);
#define CTNODE_cmu_us_rms_dur_NO_4991 4993
DEF_STATIC_CONST_VAL_FLOAT(val_2732,-0.247593);
#define CTNODE_cmu_us_rms_dur_NO_4993 4995
DEF_STATIC_CONST_VAL_FLOAT(val_2733,-0.408610);
#define CTNODE_cmu_us_rms_dur_NO_4986 4996
DEF_STATIC_CONST_VAL_FLOAT(val_2734,-0.387613);
#define CTNODE_cmu_us_rms_dur_NO_4998 5000
DEF_STATIC_CONST_VAL_FLOAT(val_2735,-0.490166);
#define CTNODE_cmu_us_rms_dur_NO_4997 5001
DEF_STATIC_CONST_VAL_FLOAT(val_2736,-0.175550);
#define CTNODE_cmu_us_rms_dur_NO_5001 5003
DEF_STATIC_CONST_VAL_FLOAT(val_2737,-0.351709);
#define CTNODE_cmu_us_rms_dur_NO_4996 5004
DEF_STATIC_CONST_VAL_FLOAT(val_2738,-0.097239);
#define CTNODE_cmu_us_rms_dur_NO_5006 5008
DEF_STATIC_CONST_VAL_FLOAT(val_2739,-0.359532);
#define CTNODE_cmu_us_rms_dur_NO_5005 5009
DEF_STATIC_CONST_VAL_FLOAT(val_2740,-0.446829);
#define CTNODE_cmu_us_rms_dur_NO_5004 5010
DEF_STATIC_CONST_VAL_FLOAT(val_2741,0.105322);
#define CTNODE_cmu_us_rms_dur_NO_5011 5013
DEF_STATIC_CONST_VAL_FLOAT(val_2742,-0.184685);
#define CTNODE_cmu_us_rms_dur_NO_5010 5014
DEF_STATIC_CONST_VAL_FLOAT(val_2743,-0.076283);
#define CTNODE_cmu_us_rms_dur_NO_5014 5016
DEF_STATIC_CONST_VAL_FLOAT(val_2744,-0.324475);
#define CTNODE_cmu_us_rms_dur_NO_5016 5018
DEF_STATIC_CONST_VAL_FLOAT(val_2745,-0.360911);
#define CTNODE_cmu_us_rms_dur_NO_4981 5019
DEF_STATIC_CONST_VAL_FLOAT(val_2746,0.219386);
#define CTNODE_cmu_us_rms_dur_NO_5022 5024
DEF_STATIC_CONST_VAL_FLOAT(val_2747,-0.081107);
#define CTNODE_cmu_us_rms_dur_NO_5021 5025
DEF_STATIC_CONST_VAL_FLOAT(val_2748,-0.136491);
#define CTNODE_cmu_us_rms_dur_NO_5026 5028
DEF_STATIC_CONST_VAL_FLOAT(val_2749,0.105355);
#define CTNODE_cmu_us_rms_dur_NO_5025 5029
DEF_STATIC_CONST_VAL_FLOAT(val_2750,-0.249050);
#define CTNODE_cmu_us_rms_dur_NO_5030 5032
DEF_STATIC_CONST_VAL_FLOAT(val_2751,0.183208);
#define CTNODE_cmu_us_rms_dur_NO_5029 5033
DEF_STATIC_CONST_VAL_FLOAT(val_2752,0.011834);
#define CTNODE_cmu_us_rms_dur_NO_5034 5036
DEF_STATIC_CONST_VAL_FLOAT(val_2753,-0.331579);
#define CTNODE_cmu_us_rms_dur_NO_5033 5037
DEF_STATIC_CONST_VAL_FLOAT(val_2754,-0.631557);
#define CTNODE_cmu_us_rms_dur_NO_5037 5039
DEF_STATIC_CONST_VAL_FLOAT(val_2755,-0.313388);
#define CTNODE_cmu_us_rms_dur_NO_5042 5044
DEF_STATIC_CONST_VAL_FLOAT(val_2756,0.007068);
#define CTNODE_cmu_us_rms_dur_NO_5041 5045
DEF_STATIC_CONST_VAL_FLOAT(val_2757,-0.388601);
#define CTNODE_cmu_us_rms_dur_NO_5040 5046
DEF_STATIC_CONST_VAL_FLOAT(val_2758,-0.499622);
#define CTNODE_cmu_us_rms_dur_NO_5046 5048
DEF_STATIC_CONST_VAL_FLOAT(val_2759,-0.311048);
#define CTNODE_cmu_us_rms_dur_NO_5039 5049
DEF_STATIC_CONST_VAL_FLOAT(val_2760,-0.495806);
#define CTNODE_cmu_us_rms_dur_NO_5020 5050
DEF_STATIC_CONST_VAL_FLOAT(val_2761,0.045916);
#define CTNODE_cmu_us_rms_dur_NO_5051 5053
DEF_STATIC_CONST_VAL_FLOAT(val_2762,0.166846);
#define CTNODE_cmu_us_rms_dur_NO_5050 5054
DEF_STATIC_CONST_VAL_FLOAT(val_2763,-0.080301);
#define CTNODE_cmu_us_rms_dur_NO_5019 5055
DEF_STATIC_CONST_VAL_FLOAT(val_2764,0.091744);
#define CTNODE_cmu_us_rms_dur_NO_5055 5057
DEF_STATIC_CONST_VAL_FLOAT(val_2765,-0.266740);
#define CTNODE_cmu_us_rms_dur_NO_5059 5061
DEF_STATIC_CONST_VAL_FLOAT(val_2766,-0.013685);
#define CTNODE_cmu_us_rms_dur_NO_5058 5062
DEF_STATIC_CONST_VAL_FLOAT(val_2767,-0.692495);
#define CTNODE_cmu_us_rms_dur_NO_5063 5065
DEF_STATIC_CONST_VAL_FLOAT(val_2768,-0.419177);
#define CTNODE_cmu_us_rms_dur_NO_5066 5068
DEF_STATIC_CONST_VAL_FLOAT(val_2769,-0.172033);
#define CTNODE_cmu_us_rms_dur_NO_5065 5069
DEF_STATIC_CONST_VAL_FLOAT(val_2770,-0.249632);
#define CTNODE_cmu_us_rms_dur_NO_5069 5071
DEF_STATIC_CONST_VAL_FLOAT(val_2771,-0.297251);
#define CTNODE_cmu_us_rms_dur_NO_5071 5073
DEF_STATIC_CONST_VAL_FLOAT(val_2772,-0.621656);
#define CTNODE_cmu_us_rms_dur_NO_5073 5075
DEF_STATIC_CONST_VAL_FLOAT(val_2773,-0.332638);
#define CTNODE_cmu_us_rms_dur_NO_5076 5078
DEF_STATIC_CONST_VAL_FLOAT(val_2774,-0.371627);
#define CTNODE_cmu_us_rms_dur_NO_5078 5080
DEF_STATIC_CONST_VAL_FLOAT(val_2775,-0.501796);
#define CTNODE_cmu_us_rms_dur_NO_5075 5081
DEF_STATIC_CONST_VAL_FLOAT(val_2776,-0.574133);
#define CTNODE_cmu_us_rms_dur_NO_5062 5082
DEF_STATIC_CONST_VAL_FLOAT(val_2777,0.057834);
#define CTNODE_cmu_us_rms_dur_NO_5082 5084
DEF_STATIC_CONST_VAL_FLOAT(val_2778,-0.103023);
#define CTNODE_cmu_us_rms_dur_NO_5084 5086
DEF_STATIC_CONST_VAL_FLOAT(val_2779,-0.159195);
#define CTNODE_cmu_us_rms_dur_NO_5086 5088
DEF_STATIC_CONST_VAL_FLOAT(val_2780,-0.633414);
#define CTNODE_cmu_us_rms_dur_NO_5089 5091
DEF_STATIC_CONST_VAL_FLOAT(val_2781,-0.420712);
#define CTNODE_cmu_us_rms_dur_NO_5092 5094
DEF_STATIC_CONST_VAL_FLOAT(val_2782,-0.277456);
#define CTNODE_cmu_us_rms_dur_NO_5091 5095
DEF_STATIC_CONST_VAL_FLOAT(val_2783,-0.482441);
#define CTNODE_cmu_us_rms_dur_NO_5095 5097
DEF_STATIC_CONST_VAL_FLOAT(val_2784,-0.574009);
#define CTNODE_cmu_us_rms_dur_NO_5088 5098
DEF_STATIC_CONST_VAL_FLOAT(val_2785,-0.221834);
#define CTNODE_cmu_us_rms_dur_NO_5057 5099
DEF_STATIC_CONST_VAL_FLOAT(val_2786,-0.161621);
#define CTNODE_cmu_us_rms_dur_NO_5100 5102
DEF_STATIC_CONST_VAL_FLOAT(val_2787,-0.225444);
#define CTNODE_cmu_us_rms_dur_NO_5103 5105
DEF_STATIC_CONST_VAL_FLOAT(val_2788,-0.402190);
#define CTNODE_cmu_us_rms_dur_NO_5102 5106
DEF_STATIC_CONST_VAL_FLOAT(val_2789,-0.478368);
#define CTNODE_cmu_us_rms_dur_NO_5099 5107
DEF_STATIC_CONST_VAL_FLOAT(val_2790,0.277128);
#define CTNODE_cmu_us_rms_dur_NO_5107 5109
DEF_STATIC_CONST_VAL_FLOAT(val_2791,0.114460);
#define CTNODE_cmu_us_rms_dur_NO_5110 5112
DEF_STATIC_CONST_VAL_FLOAT(val_2792,-0.522382);
#define CTNODE_cmu_us_rms_dur_NO_5114 5116
DEF_STATIC_CONST_VAL_FLOAT(val_2793,-0.362865);
#define CTNODE_cmu_us_rms_dur_NO_5113 5117
DEF_STATIC_CONST_VAL_FLOAT(val_2794,0.072054);
#define CTNODE_cmu_us_rms_dur_NO_5117 5119
DEF_STATIC_CONST_VAL_FLOAT(val_2795,-0.338369);
#define CTNODE_cmu_us_rms_dur_NO_5112 5120
DEF_STATIC_CONST_VAL_FLOAT(val_2796,0.044371);
#define CTNODE_cmu_us_rms_dur_NO_5109 5121
DEF_STATIC_CONST_VAL_FLOAT(val_2797,-0.474080);
#define CTNODE_cmu_us_rms_dur_NO_4676 5122
DEF_STATIC_CONST_VAL_FLOAT(val_2798,-0.202657);
#define CTNODE_cmu_us_rms_dur_NO_5124 5126
DEF_STATIC_CONST_VAL_FLOAT(val_2799,0.133209);
#define CTNODE_cmu_us_rms_dur_NO_5126 5128
DEF_STATIC_CONST_VAL_FLOAT(val_2800,0.450999);
#define CTNODE_cmu_us_rms_dur_NO_5123 5129
DEF_STATIC_CONST_VAL_FLOAT(val_2801,-0.582515);
#define CTNODE_cmu_us_rms_dur_NO_5129 5131
DEF_STATIC_CONST_VAL_FLOAT(val_2802,-0.139761);
#define CTNODE_cmu_us_rms_dur_NO_5132 5134
DEF_STATIC_CONST_VAL_FLOAT(val_2803,0.082953);
#define CTNODE_cmu_us_rms_dur_NO_5131 5135
DEF_STATIC_CONST_VAL_FLOAT(val_2804,-0.139571);
#define CTNODE_cmu_us_rms_dur_NO_5135 5137
DEF_STATIC_CONST_VAL_FLOAT(val_2805,-0.550376);
#define CTNODE_cmu_us_rms_dur_NO_5122 5138
DEF_STATIC_CONST_VAL_FLOAT(val_2806,-1.167260);
#define CTNODE_cmu_us_rms_dur_NO_5139 5141
DEF_STATIC_CONST_VAL_FLOAT(val_2807,-0.138498);
#define CTNODE_cmu_us_rms_dur_NO_5141 5143
DEF_STATIC_CONST_VAL_FLOAT(val_2808,-0.465980);
#define CTNODE_cmu_us_rms_dur_NO_5144 5146
DEF_STATIC_CONST_VAL_FLOAT(val_2809,-0.196911);
#define CTNODE_cmu_us_rms_dur_NO_5143 5147
DEF_STATIC_CONST_VAL_FLOAT(val_2810,-0.726849);
#define CTNODE_cmu_us_rms_dur_NO_5147 5149
DEF_STATIC_CONST_VAL_FLOAT(val_2811,-0.604095);
#define CTNODE_cmu_us_rms_dur_NO_5150 5152
DEF_STATIC_CONST_VAL_FLOAT(val_2812,-0.454079);
#define CTNODE_cmu_us_rms_dur_NO_5152 5154
DEF_STATIC_CONST_VAL_FLOAT(val_2813,-0.299289);
#define CTNODE_cmu_us_rms_dur_NO_5149 5155
DEF_STATIC_CONST_VAL_FLOAT(val_2814,-0.676481);
#define CTNODE_cmu_us_rms_dur_NO_5155 5157
DEF_STATIC_CONST_VAL_FLOAT(val_2815,-0.520982);
#define CTNODE_cmu_us_rms_dur_NO_5138 5158
DEF_STATIC_CONST_VAL_FLOAT(val_2816,-0.217267);
#define CTNODE_cmu_us_rms_dur_NO_5159 5161
DEF_STATIC_CONST_VAL_FLOAT(val_2817,-0.769527);
#define CTNODE_cmu_us_rms_dur_NO_5161 5163
DEF_STATIC_CONST_VAL_FLOAT(val_2818,-0.677416);
#define CTNODE_cmu_us_rms_dur_NO_5163 5165
DEF_STATIC_CONST_VAL_FLOAT(val_2819,-0.646087);
#define CTNODE_cmu_us_rms_dur_NO_5166 5168
DEF_STATIC_CONST_VAL_FLOAT(val_2820,-0.474610);
#define CTNODE_cmu_us_rms_dur_NO_5165 5169
DEF_STATIC_CONST_VAL_FLOAT(val_2821,-0.242379);
#define CTNODE_cmu_us_rms_dur_NO_5158 5170
DEF_STATIC_CONST_VAL_FLOAT(val_2822,0.308903);
#define CTNODE_cmu_us_rms_dur_NO_5171 5173
DEF_STATIC_CONST_VAL_FLOAT(val_2823,-0.078110);
#define CTNODE_cmu_us_rms_dur_NO_5170 5174
DEF_STATIC_CONST_VAL_FLOAT(val_2824,0.233699);
#define CTNODE_cmu_us_rms_dur_NO_5174 5176
DEF_STATIC_CONST_VAL_FLOAT(val_2825,-0.062076);
#define CTNODE_cmu_us_rms_dur_NO_5176 5178
DEF_STATIC_CONST_VAL_FLOAT(val_2826,-0.704732);
#define CTNODE_cmu_us_rms_dur_NO_5181 5183
DEF_STATIC_CONST_VAL_FLOAT(val_2827,-0.563533);
#define CTNODE_cmu_us_rms_dur_NO_5180 5184
DEF_STATIC_CONST_VAL_FLOAT(val_2828,-0.409423);
#define CTNODE_cmu_us_rms_dur_NO_5179 5185
DEF_STATIC_CONST_VAL_FLOAT(val_2829,-0.337740);
#define CTNODE_cmu_us_rms_dur_NO_5186 5188
DEF_STATIC_CONST_VAL_FLOAT(val_2830,-0.712457);
#define CTNODE_cmu_us_rms_dur_NO_5185 5189
DEF_STATIC_CONST_VAL_FLOAT(val_2831,-0.475795);
#define CTNODE_cmu_us_rms_dur_NO_5191 5193
DEF_STATIC_CONST_VAL_FLOAT(val_2832,-0.592616);
#define CTNODE_cmu_us_rms_dur_NO_5190 5194
DEF_STATIC_CONST_VAL_FLOAT(val_2833,-0.098089);
#define CTNODE_cmu_us_rms_dur_NO_5194 5196
DEF_STATIC_CONST_VAL_FLOAT(val_2834,-0.394676);
#define CTNODE_cmu_us_rms_dur_NO_5189 5197
DEF_STATIC_CONST_VAL_FLOAT(val_2835,-0.069548);
#define CTNODE_cmu_us_rms_dur_NO_5178 5198
DEF_STATIC_CONST_VAL_FLOAT(val_2836,-0.006383);
#define CTNODE_cmu_us_rms_dur_NO_5198 5200
DEF_STATIC_CONST_VAL_FLOAT(val_2837,-0.360594);
