/*****************************************************/
/**  Autogenerated cmu_us_rms f0 carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_rms_cg_f0_trees.h"

static const cst_cart_node cmu_us_rms_f0_zh_204_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_zh_204_NO_0000, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0002 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_zh_204_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_zh_204_cart = {
  cmu_us_rms_f0_zh_204_cart_nodes,
  cmu_us_rms_f0_zh_204_feat_table
};

static const cst_cart_node cmu_us_rms_f0_zh_205_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0003 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_zh_205_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_zh_205_cart = {
  cmu_us_rms_f0_zh_205_cart_nodes,
  cmu_us_rms_f0_zh_205_feat_table
};

static const cst_cart_node cmu_us_rms_f0_zh_206_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0004 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_zh_206_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_zh_206_cart = {
  cmu_us_rms_f0_zh_206_cart_nodes,
  cmu_us_rms_f0_zh_206_feat_table
};

static const cst_cart_node cmu_us_rms_f0_oy_131_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_131_NO_0000, (cst_val *)&val_0005},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_131_NO_0001, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_131_NO_0003, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_131_NO_0006, (cst_val *)&val_0011},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_oy_131_NO_0007, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_oy_131_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_oy_131_cart = {
  cmu_us_rms_f0_oy_131_cart_nodes,
  cmu_us_rms_f0_oy_131_feat_table
};

static const cst_cart_node cmu_us_rms_f0_oy_132_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_132_NO_0000, (cst_val *)&val_0016},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_oy_132_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_oy_132_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_oy_132_cart = {
  cmu_us_rms_f0_oy_132_cart_nodes,
  cmu_us_rms_f0_oy_132_feat_table
};

static const cst_cart_node cmu_us_rms_f0_oy_133_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_oy_133_NO_0000, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_oy_133_NO_0002, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_oy_133_NO_0004, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_oy_133_feat_table[] = {
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_oy_133_cart = {
  cmu_us_rms_f0_oy_133_cart_nodes,
  cmu_us_rms_f0_oy_133_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ch_41_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_41_NO_0000, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0028 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ch_41_NO_0002, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_41_NO_0004, (cst_val *)&val_0030},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_41_NO_0005, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_41_NO_0007, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ch_41_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ch_41_cart = {
  cmu_us_rms_f0_ch_41_cart_nodes,
  cmu_us_rms_f0_ch_41_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ch_42_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_42_NO_0000, (cst_val *)&val_0037},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_42_NO_0001, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0040 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ch_42_NO_0004, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ch_42_NO_0005, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ch_42_NO_0007, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_42_NO_0009, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_42_NO_0010, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ch_42_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_ch_42_cart = {
  cmu_us_rms_f0_ch_42_cart_nodes,
  cmu_us_rms_f0_ch_42_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ch_43_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ch_43_NO_0000, (cst_val *)&val_0051},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ch_43_NO_0001, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ch_43_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_ch_43_cart = {
  cmu_us_rms_f0_ch_43_cart_nodes,
  cmu_us_rms_f0_ch_43_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aw_21_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0000, (cst_val *)&val_0055},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_21_NO_0001, (cst_val *)&val_0056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0004, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_21_NO_0005, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_21_NO_0007, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0010, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_21_NO_0011, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0013, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0068 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0016, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0017, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_21_NO_0020, (cst_val *)&val_0071},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0021, (cst_val *)&val_0012},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_21_NO_0022, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aw_21_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_aw_21_cart = {
  cmu_us_rms_f0_aw_21_cart_nodes,
  cmu_us_rms_f0_aw_21_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aw_22_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0000, (cst_val *)&val_0076},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0001, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_22_NO_0002, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0004, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0007, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_22_NO_0010, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0012, (cst_val *)&val_0087},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0013, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_22_NO_0016, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_22_NO_0017, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0020, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_22_NO_0022, (cst_val *)&val_0095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aw_22_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_aw_22_cart = {
  cmu_us_rms_f0_aw_22_cart_nodes,
  cmu_us_rms_f0_aw_22_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aw_23_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_23_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_23_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_23_NO_0002, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0100 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_23_NO_0005, (cst_val *)&val_0101},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_23_NO_0006, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_23_NO_0008, (cst_val *)&val_0104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_23_NO_0011, (cst_val *)&val_0107},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_23_NO_0012, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aw_23_NO_0015, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aw_23_NO_0018, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aw_23_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_rms_f0_aw_23_cart = {
  cmu_us_rms_f0_aw_23_cart_nodes,
  cmu_us_rms_f0_aw_23_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ow_126_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0001, (cst_val *)&val_0117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0004, (cst_val *)&val_0055},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0005, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0007, (cst_val *)&val_0122},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0012, (cst_val *)&val_0126},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0013, (cst_val *)&val_0127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0016, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0018, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0020, (cst_val *)&val_0134},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0021, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0024, (cst_val *)&val_0138},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0025, (cst_val *)&val_0042},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_126_NO_0026, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0027, (cst_val *)&val_0139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0032, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0145 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_126_NO_0034, (cst_val *)&val_0146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ow_126_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ow_126_cart = {
  cmu_us_rms_f0_ow_126_cart_nodes,
  cmu_us_rms_f0_ow_126_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ow_127_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0000, (cst_val *)&val_0149},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0002, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0004, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0007, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0008, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0011, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0013, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0159 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0016, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0017, (cst_val *)&val_0160},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0018, (cst_val *)&val_0161},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0019, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0022, (cst_val *)&val_0041},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0023, (cst_val *)&val_0164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0026, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0029, (cst_val *)&val_0169},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0030, (cst_val *)&val_0170},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0172 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_127_NO_0033, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_127_NO_0036, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ow_127_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_f0_ow_127_cart = {
  cmu_us_rms_f0_ow_127_cart_nodes,
  cmu_us_rms_f0_ow_127_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ow_128_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0001, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0179 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0004, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_128_NO_0006, (cst_val *)&val_0181},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0007, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0182 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0009, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0011, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ow_128_NO_0013, (cst_val *)&val_0041},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_128_NO_0014, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0188 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ow_128_NO_0017, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0192 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ow_128_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ow_128_cart = {
  cmu_us_rms_f0_ow_128_cart_nodes,
  cmu_us_rms_f0_ow_128_feat_table
};

static const cst_cart_node cmu_us_rms_f0_b_36_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0001, (cst_val *)&val_0193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0194 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0003, (cst_val *)&val_0195},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0004, (cst_val *)&val_0196},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0005, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0199 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0201 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0012, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0013, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0016, (cst_val *)&val_0204},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0017, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0019, (cst_val *)&val_0206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0022, (cst_val *)&val_0209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0024, (cst_val *)&val_0211},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0025, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0026, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0215 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_36_NO_0030, (cst_val *)&val_0138},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_36_NO_0031, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_b_36_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_f0_b_36_cart = {
  cmu_us_rms_f0_b_36_cart_nodes,
  cmu_us_rms_f0_b_36_feat_table
};

static const cst_cart_node cmu_us_rms_f0_b_37_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_37_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_37_NO_0001, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_37_NO_0003, (cst_val *)&val_0111},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_37_NO_0004, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_37_NO_0007, (cst_val *)&val_0012},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_37_NO_0008, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_37_NO_0012, (cst_val *)&val_0227},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_37_NO_0013, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_37_NO_0016, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_b_37_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_b_37_cart = {
  cmu_us_rms_f0_b_37_cart_nodes,
  cmu_us_rms_f0_b_37_feat_table
};

static const cst_cart_node cmu_us_rms_f0_b_38_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_38_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_38_NO_0001, (cst_val *)&val_0234},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_38_NO_0002, (cst_val *)&val_0235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_b_38_NO_0006, (cst_val *)&val_0239},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_38_NO_0007, (cst_val *)&val_0041},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_b_38_NO_0008, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_b_38_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_f0_b_38_cart = {
  cmu_us_rms_f0_b_38_cart_nodes,
  cmu_us_rms_f0_b_38_feat_table
};

static const cst_cart_node cmu_us_rms_f0_g_76_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_76_NO_0000, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_76_NO_0002, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0245 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_76_NO_0004, (cst_val *)&val_0012},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_76_NO_0005, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0248 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_76_NO_0008, (cst_val *)&val_0249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0251 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_g_76_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_g_76_cart = {
  cmu_us_rms_f0_g_76_cart_nodes,
  cmu_us_rms_f0_g_76_feat_table
};

static const cst_cart_node cmu_us_rms_f0_g_77_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_77_NO_0000, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0253 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_77_NO_0002, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0254 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_77_NO_0004, (cst_val *)&val_0255},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_77_NO_0005, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_g_77_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_rms_f0_g_77_cart = {
  cmu_us_rms_f0_g_77_cart_nodes,
  cmu_us_rms_f0_g_77_feat_table
};

static const cst_cart_node cmu_us_rms_f0_g_78_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_78_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_78_NO_0001, (cst_val *)&val_0259},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_78_NO_0004, (cst_val *)&val_0262},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_78_NO_0005, (cst_val *)&val_0246},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_78_NO_0006, (cst_val *)&val_0263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0264 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_g_78_NO_0008, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_g_78_NO_0012, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0270 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_g_78_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_g_78_cart = {
  cmu_us_rms_f0_g_78_cart_nodes,
  cmu_us_rms_f0_g_78_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ng_121_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_121_NO_0000, (cst_val *)&val_0271},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_121_NO_0001, (cst_val *)&val_0272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0273 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_121_NO_0003, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_121_NO_0006, (cst_val *)&val_0212},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_121_NO_0007, (cst_val *)&val_0276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_121_NO_0009, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ng_121_feat_table[] = {
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_rms_f0_ng_121_cart = {
  cmu_us_rms_f0_ng_121_cart_nodes,
  cmu_us_rms_f0_ng_121_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ng_122_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0000, (cst_val *)&val_0282},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0001, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_122_NO_0004, (cst_val *)&val_0085},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0005, (cst_val *)&val_0286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0288 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0008, (cst_val *)&val_0289},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_122_NO_0009, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0010, (cst_val *)&val_0290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0291 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0012, (cst_val *)&val_0292},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0013, (cst_val *)&val_0293},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0296 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0017, (cst_val *)&val_0297},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0018, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0300 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_122_NO_0022, (cst_val *)&val_0153},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0023, (cst_val *)&val_0301},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_122_NO_0024, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_122_NO_0028, (cst_val *)&val_0305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ng_122_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_rms_f0_ng_122_cart = {
  cmu_us_rms_f0_ng_122_cart_nodes,
  cmu_us_rms_f0_ng_122_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ng_123_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_123_NO_0000, (cst_val *)&val_0308},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_123_NO_0001, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_123_NO_0003, (cst_val *)&val_0310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0311 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ng_123_NO_0005, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_123_NO_0008, (cst_val *)&val_0314},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ng_123_NO_0009, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ng_123_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_f0_ng_123_cart = {
  cmu_us_rms_f0_ng_123_cart_nodes,
  cmu_us_rms_f0_ng_123_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uw_179_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_179_NO_0000, (cst_val *)&val_0318},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0003, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0006, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0323 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0008, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0324 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0010, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_179_NO_0012, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0327 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uw_179_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_uw_179_cart = {
  cmu_us_rms_f0_uw_179_cart_nodes,
  cmu_us_rms_f0_uw_179_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uw_180_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_180_NO_0000, (cst_val *)&val_0328},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0001, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0330 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_180_NO_0003, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0006, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_180_NO_0007, (cst_val *)&val_0333},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0008, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0010, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0013, (cst_val *)&val_0134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0337 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0015, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0017, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0340 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_180_NO_0020, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uw_180_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_f0_uw_180_cart = {
  cmu_us_rms_f0_uw_180_cart_nodes,
  cmu_us_rms_f0_uw_180_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uw_181_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_181_NO_0000, (cst_val *)&val_0343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0344 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0002, (cst_val *)&val_0345},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0003, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uw_181_NO_0006, (cst_val *)&val_0349},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0007, (cst_val *)&val_0329},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0008, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0011, (cst_val *)&val_0012},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0012, (cst_val *)&val_0042},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uw_181_NO_0013, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uw_181_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_uw_181_cart = {
  cmu_us_rms_f0_uw_181_cart_nodes,
  cmu_us_rms_f0_uw_181_feat_table
};

static const cst_cart_node cmu_us_rms_f0_sh_156_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_156_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_156_NO_0001, (cst_val *)&val_0357},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0359 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_156_NO_0004, (cst_val *)&val_0360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0362 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_sh_156_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_sh_156_cart = {
  cmu_us_rms_f0_sh_156_cart_nodes,
  cmu_us_rms_f0_sh_156_feat_table
};

static const cst_cart_node cmu_us_rms_f0_sh_157_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0000, (cst_val *)&val_0252},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0002, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0365 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0005, (cst_val *)&val_0212},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0006, (cst_val *)&val_0366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0369 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0010, (cst_val *)&val_0370},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0011, (cst_val *)&val_0371},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0012, (cst_val *)&val_0372},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0373 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0014, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0375 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0017, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0018, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0378 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0021, (cst_val *)&val_0379},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0022, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0382 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0026, (cst_val *)&val_0383},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0027, (cst_val *)&val_0102},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0028, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0385 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0031, (cst_val *)&val_0386},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_157_NO_0032, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0390 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0036, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0391 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0038, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_157_NO_0039, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0394 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_sh_157_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_rms_f0_sh_157_cart = {
  cmu_us_rms_f0_sh_157_cart_nodes,
  cmu_us_rms_f0_sh_157_feat_table
};

static const cst_cart_node cmu_us_rms_f0_sh_158_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_158_NO_0000, (cst_val *)&val_0395},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_158_NO_0001, (cst_val *)&val_0396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0397 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_158_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0399 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_sh_158_NO_0006, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0400 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_sh_158_NO_0008, (cst_val *)&val_0401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0403 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_sh_158_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_rms_f0_sh_158_cart = {
  cmu_us_rms_f0_sh_158_cart_nodes,
  cmu_us_rms_f0_sh_158_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uh_174_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uh_174_NO_0000, (cst_val *)&val_0404},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uh_174_NO_0001, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0407 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uh_174_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_uh_174_cart = {
  cmu_us_rms_f0_uh_174_cart_nodes,
  cmu_us_rms_f0_uh_174_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uh_175_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uh_175_NO_0000, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0409 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uh_175_NO_0002, (cst_val *)&val_0410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0412 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uh_175_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_rms_f0_uh_175_cart = {
  cmu_us_rms_f0_uh_175_cart_nodes,
  cmu_us_rms_f0_uh_175_feat_table
};

static const cst_cart_node cmu_us_rms_f0_uh_176_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_uh_176_NO_0000, (cst_val *)&val_0413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0414 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_uh_176_NO_0002, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0416 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_uh_176_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_uh_176_cart = {
  cmu_us_rms_f0_uh_176_cart_nodes,
  cmu_us_rms_f0_uh_176_feat_table
};

static const cst_cart_node cmu_us_rms_f0_hh_81_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0001, (cst_val *)&val_0417},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0002, (cst_val *)&val_0183},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0003, (cst_val *)&val_0418},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0422 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0008, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0424 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0010, (cst_val *)&val_0425},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0011, (cst_val *)&val_0426},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0012, (cst_val *)&val_0427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0429 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0015, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0431 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0018, (cst_val *)&val_0432},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0019, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0434 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_81_NO_0022, (cst_val *)&val_0435},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_81_NO_0023, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0438 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_hh_81_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_hh_81_cart = {
  cmu_us_rms_f0_hh_81_cart_nodes,
  cmu_us_rms_f0_hh_81_feat_table
};

static const cst_cart_node cmu_us_rms_f0_hh_82_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0001, (cst_val *)&val_0183},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0002, (cst_val *)&val_0012},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0003, (cst_val *)&val_0439},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0443 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0008, (cst_val *)&val_0183},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0009, (cst_val *)&val_0444},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0010, (cst_val *)&val_0445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0448 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0014, (cst_val *)&val_0449},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0015, (cst_val *)&val_0450},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0016, (cst_val *)&val_0451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0453 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0019, (cst_val *)&val_0012},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0020, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0454 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0022, (cst_val *)&val_0455},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_82_NO_0025, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0458 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_82_NO_0027, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0462 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_hh_82_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_hh_82_cart = {
  cmu_us_rms_f0_hh_82_cart_nodes,
  cmu_us_rms_f0_hh_82_feat_table
};

static const cst_cart_node cmu_us_rms_f0_hh_83_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_83_NO_0000, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0463 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_83_NO_0002, (cst_val *)&val_0464},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_83_NO_0003, (cst_val *)&val_0465},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_83_NO_0004, (cst_val *)&val_0466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0467 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_83_NO_0006, (cst_val *)&val_0468},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_hh_83_NO_0007, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0471 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_hh_83_NO_0011, (cst_val *)&val_0472},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0475 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_hh_83_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_rms_f0_hh_83_cart = {
  cmu_us_rms_f0_hh_83_cart_nodes,
  cmu_us_rms_f0_hh_83_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ae_6_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0000, (cst_val *)&val_0476},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0001, (cst_val *)&val_0153},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0002, (cst_val *)&val_0477},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0003, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0481 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0007, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0482 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0484 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0012, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0486 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0014, (cst_val *)&val_0487},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0015, (cst_val *)&val_0153},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0016, (cst_val *)&val_0488},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0017, (cst_val *)&val_0489},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0018, (cst_val *)&val_0490},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0019, (cst_val *)&val_0491},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0020, (cst_val *)&val_0492},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0021, (cst_val *)&val_0450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0497 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0027, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0028, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0500 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0032, (cst_val *)&val_0501},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0033, (cst_val *)&val_0502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0505 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0037, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0038, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_6_NO_0041, (cst_val *)&val_0509},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0042, (cst_val *)&val_0510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0513 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_6_NO_0046, (cst_val *)&val_0514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0516 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ae_6_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_ae_6_cart = {
  cmu_us_rms_f0_ae_6_cart_nodes,
  cmu_us_rms_f0_ae_6_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ae_7_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0000, (cst_val *)&val_0517},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0002, (cst_val *)&val_0518},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0003, (cst_val *)&val_0519},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0004, (cst_val *)&val_0520},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0005, (cst_val *)&val_0521},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0006, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0523 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0008, (cst_val *)&val_0524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0528 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0013, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0531 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0016, (cst_val *)&val_0532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0534 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0019, (cst_val *)&val_0246},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0020, (cst_val *)&val_0535},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0021, (cst_val *)&val_0536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0538 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0024, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0540 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0027, (cst_val *)&val_0012},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0028, (cst_val *)&val_0541},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0029, (cst_val *)&val_0542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0544 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0032, (cst_val *)&val_0545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0547 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0035, (cst_val *)&val_0548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0550 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0038, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0039, (cst_val *)&val_0551},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0040, (cst_val *)&val_0017},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0041, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0554 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0045, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0556 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0048, (cst_val *)&val_0557},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0049, (cst_val *)&val_0558},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0050, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0559 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0052, (cst_val *)&val_0227},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0053, (cst_val *)&val_0560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0562 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0056, (cst_val *)&val_0563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0565 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0059, (cst_val *)&val_0017},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0060, (cst_val *)&val_0566},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0567 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0062, (cst_val *)&val_0568},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0570 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0065, (cst_val *)&val_0571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0573 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0068, (cst_val *)&val_0574},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_7_NO_0069, (cst_val *)&val_0575},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_7_NO_0070, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0579 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ae_7_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_rms_f0_ae_7_cart = {
  cmu_us_rms_f0_ae_7_cart_nodes,
  cmu_us_rms_f0_ae_7_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ae_8_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0000, (cst_val *)&val_0580},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0001, (cst_val *)&val_0581},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0002, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0003, (cst_val *)&val_0246},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0004, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0583 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0007, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0585 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0010, (cst_val *)&val_0586},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0011, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0588 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0014, (cst_val *)&val_0519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0589 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0016, (cst_val *)&val_0590},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0017, (cst_val *)&val_0591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0592 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0019, (cst_val *)&val_0593},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0020, (cst_val *)&val_0594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0599 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0026, (cst_val *)&val_0085},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0027, (cst_val *)&val_0012},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0028, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0601 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0031, (cst_val *)&val_0602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0604 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0034, (cst_val *)&val_0605},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0035, (cst_val *)&val_0102},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0036, (cst_val *)&val_0606},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0037, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0609 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0041, (cst_val *)&val_0041},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0042, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0610 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0045, (cst_val *)&val_0055},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0046, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0612 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0049, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0613 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0051, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0615 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0054, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0055, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0056, (cst_val *)&val_0616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0617 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0058, (cst_val *)&val_0618},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0059, (cst_val *)&val_0619},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0622 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0063, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0623 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0065, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0624 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0067, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0627 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0070, (cst_val *)&val_0628},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0071, (cst_val *)&val_0012},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0072, (cst_val *)&val_0629},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0073, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0630 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0075, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0633 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0078, (cst_val *)&val_0634},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0079, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0636 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0082, (cst_val *)&val_0637},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0083, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0638 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0085, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0641 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0089, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0642 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ae_8_NO_0091, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0644 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ae_8_NO_0094, (cst_val *)&val_0645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0647 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ae_8_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ae_8_cart = {
  cmu_us_rms_f0_ae_8_cart_nodes,
  cmu_us_rms_f0_ae_8_feat_table
};

static const cst_cart_node cmu_us_rms_f0_y_194_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_194_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_194_NO_0001, (cst_val *)&val_0648},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_194_NO_0002, (cst_val *)&val_0649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0651 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_194_NO_0005, (cst_val *)&val_0652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_194_NO_0008, (cst_val *)&val_0655},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_194_NO_0009, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0658 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_y_194_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_y_194_cart = {
  cmu_us_rms_f0_y_194_cart_nodes,
  cmu_us_rms_f0_y_194_feat_table
};

static const cst_cart_node cmu_us_rms_f0_y_195_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_195_NO_0000, (cst_val *)&val_0659},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_195_NO_0001, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0661 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_195_NO_0003, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0662 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_195_NO_0005, (cst_val *)&val_0663},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0665 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_195_NO_0008, (cst_val *)&val_0666},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_195_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0667 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_195_NO_0011, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0671 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_y_195_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_y_195_cart = {
  cmu_us_rms_f0_y_195_cart_nodes,
  cmu_us_rms_f0_y_195_feat_table
};

static const cst_cart_node cmu_us_rms_f0_y_196_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_196_NO_0000, (cst_val *)&val_0672},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_196_NO_0001, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0673 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_196_NO_0003, (cst_val *)&val_0631},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_196_NO_0004, (cst_val *)&val_0146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0675 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_196_NO_0007, (cst_val *)&val_0676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0678 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_196_NO_0010, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0679 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_196_NO_0012, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0680 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_y_196_NO_0014, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0681 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_y_196_NO_0016, (cst_val *)&val_0682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0684 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_y_196_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_f0_y_196_cart = {
  cmu_us_rms_f0_y_196_cart_nodes,
  cmu_us_rms_f0_y_196_feat_table
};

static const cst_cart_node cmu_us_rms_f0_k_101_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_101_NO_0001, (cst_val *)&val_0160},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0002, (cst_val *)&val_0111},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_101_NO_0003, (cst_val *)&val_0685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0687 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_101_NO_0006, (cst_val *)&val_0688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0689 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0691 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0011, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0692 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0013, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0694 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0016, (cst_val *)&val_0246},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_101_NO_0017, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0696 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_101_NO_0020, (cst_val *)&val_0697},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_101_NO_0021, (cst_val *)&val_0698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0701 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_k_101_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_k_101_cart = {
  cmu_us_rms_f0_k_101_cart_nodes,
  cmu_us_rms_f0_k_101_feat_table
};

static const cst_cart_node cmu_us_rms_f0_k_102_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0001, (cst_val *)&val_0702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0703 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0003, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0704 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0005, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0707 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0008, (cst_val *)&val_0085},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0009, (cst_val *)&val_0708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0710 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0012, (cst_val *)&val_0042},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0013, (cst_val *)&val_0711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0713 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0016, (cst_val *)&val_0714},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0017, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0717 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0020, (cst_val *)&val_0718},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0021, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0022, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0719 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_102_NO_0024, (cst_val *)&val_0720},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0027, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0723 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_102_NO_0030, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0725 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_k_102_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_rms_f0_k_102_cart = {
  cmu_us_rms_f0_k_102_cart_nodes,
  cmu_us_rms_f0_k_102_feat_table
};

static const cst_cart_node cmu_us_rms_f0_k_103_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0000, (cst_val *)&val_0345},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0001, (cst_val *)&val_0726},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0002, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0730 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0006, (cst_val *)&val_0017},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0007, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0732 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0009, (cst_val *)&val_0153},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0010, (cst_val *)&val_0733},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0011, (cst_val *)&val_0212},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0012, (cst_val *)&val_0235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0735 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0015, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0739 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0020, (cst_val *)&val_0160},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0021, (cst_val *)&val_0212},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0022, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0742 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0025, (cst_val *)&val_0743},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0026, (cst_val *)&val_0041},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0027, (cst_val *)&val_0744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0746 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0030, (cst_val *)&val_0747},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0031, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0032, (cst_val *)&val_0748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0752 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0037, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0038, (cst_val *)&val_0753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0755 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0041, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0756 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0043, (cst_val *)&val_0212},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0044, (cst_val *)&val_0757},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0045, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0760 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0049, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0761 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0051, (cst_val *)&val_0012},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0052, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0001 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0056, (cst_val *)&val_0764},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0057, (cst_val *)&val_0246},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0058, (cst_val *)&val_0765},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_k_103_NO_0059, (cst_val *)&val_0766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0768 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_k_103_NO_0062, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0772 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_k_103_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_rms_f0_k_103_cart = {
  cmu_us_rms_f0_k_103_cart_nodes,
  cmu_us_rms_f0_k_103_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aa_1_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0000, (cst_val *)&val_0773},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0001, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0774 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0003, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0775 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0005, (cst_val *)&val_0776},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0006, (cst_val *)&val_0777},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0007, (cst_val *)&val_0778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0779 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0009, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0781 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0012, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0783 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0015, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0784 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0017, (cst_val *)&val_0012},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0018, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0785 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0020, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0788 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0024, (cst_val *)&val_0789},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_1_NO_0025, (cst_val *)&val_0790},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_1_NO_0026, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0794 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aa_1_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_f0_aa_1_cart = {
  cmu_us_rms_f0_aa_1_cart_nodes,
  cmu_us_rms_f0_aa_1_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aa_2_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0000, (cst_val *)&val_0795},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0001, (cst_val *)&val_0796},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0002, (cst_val *)&val_0797},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0003, (cst_val *)&val_0012},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0004, (cst_val *)&val_0798},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0005, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0799 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0007, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0008, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0801 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0011, (cst_val *)&val_0802},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0804 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0014, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0805 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0016, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0141 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0019, (cst_val *)&val_0807},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0810 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0023, (cst_val *)&val_0012},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0024, (cst_val *)&val_0811},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0025, (cst_val *)&val_0812},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0026, (cst_val *)&val_0813},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0027, (cst_val *)&val_0814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0817 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0031, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0821 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0036, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0822 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0038, (cst_val *)&val_0012},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0039, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0040, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0823 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0042, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0826 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0045, (cst_val *)&val_0827},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0046, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0828 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0048, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0829 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_2_NO_0050, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0832 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0053, (cst_val *)&val_0833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0835 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_2_NO_0056, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0838 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aa_2_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_f0_aa_2_cart = {
  cmu_us_rms_f0_aa_2_cart_nodes,
  cmu_us_rms_f0_aa_2_feat_table
};

static const cst_cart_node cmu_us_rms_f0_aa_3_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0000, (cst_val *)&val_0839},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_3_NO_0001, (cst_val *)&val_0012},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_3_NO_0002, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0840 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0004, (cst_val *)&val_0841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0843 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0007, (cst_val *)&val_0844},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0008, (cst_val *)&val_0845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0847 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0011, (cst_val *)&val_0848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0850 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_3_NO_0014, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0851 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_3_NO_0016, (cst_val *)&val_0012},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0017, (cst_val *)&val_0271},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_aa_3_NO_0018, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0854 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_aa_3_NO_0022, (cst_val *)&val_0855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0857 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_aa_3_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_f0_aa_3_cart = {
  cmu_us_rms_f0_aa_3_cart_nodes,
  cmu_us_rms_f0_aa_3_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ay_31_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0001, (cst_val *)&val_0858},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0002, (cst_val *)&val_0246},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0003, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0860 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0006, (cst_val *)&val_0861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0864 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0010, (cst_val *)&val_0246},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0011, (cst_val *)&val_0865},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0012, (cst_val *)&val_0866},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0868 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0015, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0869 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0017, (cst_val *)&val_0051},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0018, (cst_val *)&val_0041},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0019, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0020, (cst_val *)&val_0227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0870 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0022, (cst_val *)&val_0871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0873 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0025, (cst_val *)&val_0874},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0875 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0027, (cst_val *)&val_0876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0880 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0032, (cst_val *)&val_0041},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0033, (cst_val *)&val_0881},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0034, (cst_val *)&val_0882},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0035, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0885 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_31_NO_0039, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0887 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0042, (cst_val *)&val_0888},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_31_NO_0043, (cst_val *)&val_0889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0892 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ay_31_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_ay_31_cart = {
  cmu_us_rms_f0_ay_31_cart_nodes,
  cmu_us_rms_f0_ay_31_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ay_32_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0000, (cst_val *)&val_0893},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0001, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0894 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0003, (cst_val *)&val_0895},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0004, (cst_val *)&val_0896},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0005, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0897 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0007, (cst_val *)&val_0898},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0899 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0010, (cst_val *)&val_0900},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0011, (cst_val *)&val_0410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0901 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0013, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0903 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0015, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0906 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0019, (cst_val *)&val_0907},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0020, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0912 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0026, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0027, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0028, (cst_val *)&val_0913},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0029, (cst_val *)&val_0747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0916 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0033, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0918 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0036, (cst_val *)&val_0041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0037, (cst_val *)&val_0017},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0038, (cst_val *)&val_0748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0920 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0041, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0922 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0044, (cst_val *)&val_0923},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0045, (cst_val *)&val_0924},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0046, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0925 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0048, (cst_val *)&val_0926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0927 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0050, (cst_val *)&val_0012},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_32_NO_0051, (cst_val *)&val_0928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0931 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0055, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0932 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0057, (cst_val *)&val_0246},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_32_NO_0058, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0936 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ay_32_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_ay_32_cart = {
  cmu_us_rms_f0_ay_32_cart_nodes,
  cmu_us_rms_f0_ay_32_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ay_33_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0001, (cst_val *)&val_0937},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0938 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0003, (cst_val *)&val_0939},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0004, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0942 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0008, (cst_val *)&val_0181},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0009, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0010, (cst_val *)&val_0586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0943 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0012, (cst_val *)&val_0944},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0013, (cst_val *)&val_0945},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0946 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0015, (cst_val *)&val_0947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0949 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0018, (cst_val *)&val_0950},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0019, (cst_val *)&val_0951},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0020, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0954 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0023, (cst_val *)&val_0955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0958 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0027, (cst_val *)&val_0959},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0028, (cst_val *)&val_0153},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0029, (cst_val *)&val_0012},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0030, (cst_val *)&val_0960},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0031, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0964 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0036, (cst_val *)&val_0965},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0037, (cst_val *)&val_0966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0967 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0039, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0968 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0041, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0971 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0045, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0972 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0047, (cst_val *)&val_0134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0973 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0049, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0974 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0051, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0976 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ay_33_NO_0054, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0055, (cst_val *)&val_0977},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0978 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0057, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0980 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0060, (cst_val *)&val_0981},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0061, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0984 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ay_33_NO_0064, (cst_val *)&val_0985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0987 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ay_33_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_ay_33_cart = {
  cmu_us_rms_f0_ay_33_cart_nodes,
  cmu_us_rms_f0_ay_33_feat_table
};

static const cst_cart_node cmu_us_rms_f0_w_189_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0001, (cst_val *)&val_0160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0989 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0004, (cst_val *)&val_0153},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0005, (cst_val *)&val_0055},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0006, (cst_val *)&val_0990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0992 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0009, (cst_val *)&val_0993},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0010, (cst_val *)&val_0994},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0011, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0996 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0014, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0997 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0016, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0998 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0018, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0019, (cst_val *)&val_0999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1001 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0022, (cst_val *)&val_1002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1004 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_189_NO_0025, (cst_val *)&val_0252},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0026, (cst_val *)&val_1005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1007 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_189_NO_0029, (cst_val *)&val_1008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1011 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_w_189_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_w_189_cart = {
  cmu_us_rms_f0_w_189_cart_nodes,
  cmu_us_rms_f0_w_189_feat_table
};

static const cst_cart_node cmu_us_rms_f0_w_190_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0000, (cst_val *)&val_1012},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0002, (cst_val *)&val_0212},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0003, (cst_val *)&val_1013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1015 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0006, (cst_val *)&val_0926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1017 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1019 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0012, (cst_val *)&val_0153},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0013, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1020 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0015, (cst_val *)&val_1021},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0016, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0017, (cst_val *)&val_1022},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0018, (cst_val *)&val_1023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1024 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0020, (cst_val *)&val_1025},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0021, (cst_val *)&val_1026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1027 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0023, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1029 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0025, (cst_val *)&val_1030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1032 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0028, (cst_val *)&val_1033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1034 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0030, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1037 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0034, (cst_val *)&val_0012},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0035, (cst_val *)&val_1038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1039 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0037, (cst_val *)&val_1040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0038, (cst_val *)&val_1041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1042 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0040, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1045 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0044, (cst_val *)&val_0830},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_190_NO_0045, (cst_val *)&val_1046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1049 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0049, (cst_val *)&val_0085},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0050, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1051 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0053, (cst_val *)&val_0017},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0054, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1053 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_190_NO_0057, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1056 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_w_190_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_rms_f0_w_190_cart = {
  cmu_us_rms_f0_w_190_cart_nodes,
  cmu_us_rms_f0_w_190_feat_table
};

static const cst_cart_node cmu_us_rms_f0_w_191_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_191_NO_0000, (cst_val *)&val_1057},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0001, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1058 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0003, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1059 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0005, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_191_NO_0006, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1062 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0009, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1064 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0012, (cst_val *)&val_0153},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_191_NO_0013, (cst_val *)&val_1065},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0014, (cst_val *)&val_0085},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_191_NO_0015, (cst_val *)&val_1066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1068 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0018, (cst_val *)&val_0012},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0019, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1070 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_w_191_NO_0022, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1073 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_w_191_NO_0025, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1076 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_w_191_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_w_191_cart = {
  cmu_us_rms_f0_w_191_cart_nodes,
  cmu_us_rms_f0_w_191_feat_table
};

static const cst_cart_node cmu_us_rms_f0_m_111_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0002, (cst_val *)&val_1077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0003, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1081 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0007, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1082 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0009, (cst_val *)&val_1083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1084 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0011, (cst_val *)&val_0183},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0012, (cst_val *)&val_1085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1087 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0015, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1088 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0017, (cst_val *)&val_1089},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0018, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0019, (cst_val *)&val_1090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1093 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0023, (cst_val *)&val_1094},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0024, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1096 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0027, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1097 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0029, (cst_val *)&val_1098},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0030, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1100 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0033, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1101 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0035, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1102 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0037, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0038, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1105 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0042, (cst_val *)&val_1106},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0043, (cst_val *)&val_0160},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0044, (cst_val *)&val_1107},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0045, (cst_val *)&val_1108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1112 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_111_NO_0050, (cst_val *)&val_1113},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0051, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1115 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0054, (cst_val *)&val_1116},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_111_NO_0055, (cst_val *)&val_0305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1119 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_m_111_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_f0_m_111_cart = {
  cmu_us_rms_f0_m_111_cart_nodes,
  cmu_us_rms_f0_m_111_feat_table
};

static const cst_cart_node cmu_us_rms_f0_m_112_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0000, (cst_val *)&val_1120},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1121 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0003, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1122 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0005, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1123 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0007, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1124 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0009, (cst_val *)&val_1125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1126 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0011, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1128 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0014, (cst_val *)&val_0041},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0015, (cst_val *)&val_0041},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0016, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1129 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0018, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1130 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0020, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1132 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0023, (cst_val *)&val_0042},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0024, (cst_val *)&val_1133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1135 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0027, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1136 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0029, (cst_val *)&val_0012},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0030, (cst_val *)&val_1137},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0031, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1138 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0033, (cst_val *)&val_1139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1142 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_112_NO_0037, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1144 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_112_NO_0040, (cst_val *)&val_1145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1147 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_m_112_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_m_112_cart = {
  cmu_us_rms_f0_m_112_cart_nodes,
  cmu_us_rms_f0_m_112_feat_table
};

static const cst_cart_node cmu_us_rms_f0_m_113_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_113_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_113_NO_0001, (cst_val *)&val_1148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1150 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_113_NO_0004, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_113_NO_0005, (cst_val *)&val_0425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1151 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_113_NO_0007, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1152 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_m_113_NO_0009, (cst_val *)&val_0012},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_113_NO_0010, (cst_val *)&val_1153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1155 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_m_113_NO_0013, (cst_val *)&val_1156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1159 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_m_113_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_m_113_cart = {
  cmu_us_rms_f0_m_113_cart_nodes,
  cmu_us_rms_f0_m_113_feat_table
};

static const cst_cart_node cmu_us_rms_f0_pau_143_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_pau_143_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_pau_143_cart = {
  cmu_us_rms_f0_pau_143_cart_nodes,
  cmu_us_rms_f0_pau_143_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ao_16_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_16_NO_0000, (cst_val *)&val_0055},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0001, (cst_val *)&val_1161},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_16_NO_0002, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1163 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0005, (cst_val *)&val_0259},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1165 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_16_NO_0008, (cst_val *)&val_0102},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0009, (cst_val *)&val_1166},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1168 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0012, (cst_val *)&val_1169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_16_NO_0014, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1171 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0016, (cst_val *)&val_1172},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_16_NO_0017, (cst_val *)&val_0212},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_16_NO_0018, (cst_val *)&val_1173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1177 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ao_16_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_f0_ao_16_cart = {
  cmu_us_rms_f0_ao_16_cart_nodes,
  cmu_us_rms_f0_ao_16_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ao_17_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0000, (cst_val *)&val_1178},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0001, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1179 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0003, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1180 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0005, (cst_val *)&val_1181},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0006, (cst_val *)&val_1182},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1183 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0008, (cst_val *)&val_1184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1186 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0011, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1188 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0014, (cst_val *)&val_0085},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0015, (cst_val *)&val_1189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1190 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0017, (cst_val *)&val_1191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1193 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0020, (cst_val *)&val_0055},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0021, (cst_val *)&val_1005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1195 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0024, (cst_val *)&val_1196},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0025, (cst_val *)&val_1197},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0026, (cst_val *)&val_0246},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0027, (cst_val *)&val_0830},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0028, (cst_val *)&val_1198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1202 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0033, (cst_val *)&val_1203},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_17_NO_0034, (cst_val *)&val_0041},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0035, (cst_val *)&val_1204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1207 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_17_NO_0039, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1211 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ao_17_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ao_17_cart = {
  cmu_us_rms_f0_ao_17_cart_nodes,
  cmu_us_rms_f0_ao_17_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ao_18_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0001, (cst_val *)&val_0042},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0002, (cst_val *)&val_1212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1215 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0006, (cst_val *)&val_1216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1217 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0008, (cst_val *)&val_0055},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0009, (cst_val *)&val_1218},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0010, (cst_val *)&val_1219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1221 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0013, (cst_val *)&val_1222},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0014, (cst_val *)&val_0023},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0015, (cst_val *)&val_1223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1225 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0018, (cst_val *)&val_1226},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1229 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0022, (cst_val *)&val_1230},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0023, (cst_val *)&val_1231},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0024, (cst_val *)&val_0427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1234 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0028, (cst_val *)&val_1235},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0029, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1237 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ao_18_NO_0032, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0033, (cst_val *)&val_1026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1239 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0036, (cst_val *)&val_1240},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ao_18_NO_0037, (cst_val *)&val_1241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1244 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ao_18_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_ao_18_cart = {
  cmu_us_rms_f0_ao_18_cart_nodes,
  cmu_us_rms_f0_ao_18_feat_table
};

static const cst_cart_node cmu_us_rms_f0_th_169_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_169_NO_0000, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1245 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_169_NO_0002, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1246 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_169_NO_0004, (cst_val *)&val_1247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1248 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_169_NO_0006, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1250 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_th_169_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
NULL };

const cst_cart cmu_us_rms_f0_th_169_cart = {
  cmu_us_rms_f0_th_169_cart_nodes,
  cmu_us_rms_f0_th_169_feat_table
};

static const cst_cart_node cmu_us_rms_f0_th_170_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_170_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0001, (cst_val *)&val_1251},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_170_NO_0002, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0003, (cst_val *)&val_1252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1254 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0006, (cst_val *)&val_1255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1256 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0008, (cst_val *)&val_1257},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1259 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0011, (cst_val *)&val_1260},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_170_NO_0012, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1262 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_170_NO_0015, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1263 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0017, (cst_val *)&val_1264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1266 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0020, (cst_val *)&val_1267},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_th_170_NO_0021, (cst_val *)&val_1268},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1271 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_th_170_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_th_170_cart = {
  cmu_us_rms_f0_th_170_cart_nodes,
  cmu_us_rms_f0_th_170_feat_table
};

static const cst_cart_node cmu_us_rms_f0_th_171_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_171_NO_0000, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1272 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_th_171_NO_0002, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1274 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_th_171_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_th_171_cart = {
  cmu_us_rms_f0_th_171_cart_nodes,
  cmu_us_rms_f0_th_171_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ah_11_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0000, (cst_val *)&val_1275},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0001, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0003, (cst_val *)&val_0183},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0004, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0008, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1279 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0010, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1280 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0012, (cst_val *)&val_1281},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0013, (cst_val *)&val_1282},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0014, (cst_val *)&val_0104},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0015, (cst_val *)&val_0464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1285 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_11_NO_0019, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1286 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0021, (cst_val *)&val_1287},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_11_NO_0022, (cst_val *)&val_1288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1292 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ah_11_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ah_11_cart = {
  cmu_us_rms_f0_ah_11_cart_nodes,
  cmu_us_rms_f0_ah_11_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ah_12_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0000, (cst_val *)&val_1293},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0001, (cst_val *)&val_0055},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0002, (cst_val *)&val_1294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1296 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0005, (cst_val *)&val_0153},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0006, (cst_val *)&val_1297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1299 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0009, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1300 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0011, (cst_val *)&val_1301},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0012, (cst_val *)&val_1302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1304 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0015, (cst_val *)&val_0246},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0016, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1307 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0020, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1308 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0022, (cst_val *)&val_0055},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0023, (cst_val *)&val_1309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1311 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0026, (cst_val *)&val_1312},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0027, (cst_val *)&val_1313},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0028, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1316 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0032, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1317 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0034, (cst_val *)&val_1318},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0035, (cst_val *)&val_1319},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0036, (cst_val *)&val_0012},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_12_NO_0037, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1321 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_12_NO_0040, (cst_val *)&val_1322},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1326 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ah_12_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ah_12_cart = {
  cmu_us_rms_f0_ah_12_cart_nodes,
  cmu_us_rms_f0_ah_12_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ah_13_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0000, (cst_val *)&val_1327},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_13_NO_0001, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1329 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0004, (cst_val *)&val_1330},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0005, (cst_val *)&val_1331},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0006, (cst_val *)&val_1332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1334 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_13_NO_0009, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0010, (cst_val *)&val_1335},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ah_13_NO_0011, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1339 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ah_13_NO_0016, (cst_val *)&val_1340},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1342 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ah_13_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_f0_ah_13_cart = {
  cmu_us_rms_f0_ah_13_cart_nodes,
  cmu_us_rms_f0_ah_13_feat_table
};

static const cst_cart_node cmu_us_rms_f0_v_184_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_184_NO_0000, (cst_val *)&val_1343},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_184_NO_0001, (cst_val *)&val_1344},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1346 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_184_NO_0004, (cst_val *)&val_1347},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_184_NO_0005, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_184_NO_0006, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1349 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_184_NO_0009, (cst_val *)&val_1350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1351 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_184_NO_0011, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1354 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_v_184_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_v_184_cart = {
  cmu_us_rms_f0_v_184_cart_nodes,
  cmu_us_rms_f0_v_184_feat_table
};

static const cst_cart_node cmu_us_rms_f0_v_185_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_185_NO_0000, (cst_val *)&val_1355},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_185_NO_0001, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1357 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_185_NO_0004, (cst_val *)&val_1358},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_185_NO_0005, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1360 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_185_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1361 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_185_NO_0010, (cst_val *)&val_1362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1364 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_v_185_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_v_185_cart = {
  cmu_us_rms_f0_v_185_cart_nodes,
  cmu_us_rms_f0_v_185_feat_table
};

static const cst_cart_node cmu_us_rms_f0_v_186_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0000, (cst_val *)&val_1365},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0001, (cst_val *)&val_1366},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_186_NO_0002, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1367 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0004, (cst_val *)&val_1368},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1370 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0007, (cst_val *)&val_1371},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_186_NO_0008, (cst_val *)&val_0017},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_186_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1372 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0011, (cst_val *)&val_1373},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0012, (cst_val *)&val_1374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1378 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0017, (cst_val *)&val_0944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1380 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_186_NO_0020, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0021, (cst_val *)&val_1381},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_v_186_NO_0022, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1384 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0026, (cst_val *)&val_1385},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_v_186_NO_0027, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1389 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_v_186_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_v_186_cart = {
  cmu_us_rms_f0_v_186_cart_nodes,
  cmu_us_rms_f0_v_186_feat_table
};

static const cst_cart_node cmu_us_rms_f0_dh_51_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0000, (cst_val *)&val_1390},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0001, (cst_val *)&val_0012},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0002, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1391 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0004, (cst_val *)&val_1392},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0005, (cst_val *)&val_1393},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0006, (cst_val *)&val_1394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1398 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0011, (cst_val *)&val_1399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1401 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0014, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0015, (cst_val *)&val_1402},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0016, (cst_val *)&val_1403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1406 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0020, (cst_val *)&val_1407},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0021, (cst_val *)&val_0252},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0022, (cst_val *)&val_1408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1410 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0025, (cst_val *)&val_0246},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0026, (cst_val *)&val_0951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1413 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0030, (cst_val *)&val_0066},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0031, (cst_val *)&val_1414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1416 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_51_NO_0034, (cst_val *)&val_1417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1418 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0036, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1419 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_51_NO_0038, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1421 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_dh_51_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.p.name",
NULL };

const cst_cart cmu_us_rms_f0_dh_51_cart = {
  cmu_us_rms_f0_dh_51_cart_nodes,
  cmu_us_rms_f0_dh_51_feat_table
};

static const cst_cart_node cmu_us_rms_f0_dh_52_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0000, (cst_val *)&val_1422},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0001, (cst_val *)&val_1423},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0002, (cst_val *)&val_1424},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0003, (cst_val *)&val_1425},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_52_NO_0004, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0005, (cst_val *)&val_1426},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0006, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1430 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0011, (cst_val *)&val_1431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1433 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0014, (cst_val *)&val_1434},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0015, (cst_val *)&val_1435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1437 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0018, (cst_val *)&val_1026},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_52_NO_0019, (cst_val *)&val_0625},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0020, (cst_val *)&val_1438},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1440 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0023, (cst_val *)&val_1441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1444 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0027, (cst_val *)&val_1445},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0028, (cst_val *)&val_1446},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_52_NO_0029, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1448 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_52_NO_0032, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1449 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0034, (cst_val *)&val_1450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1452 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0037, (cst_val *)&val_1453},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1455 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0040, (cst_val *)&val_1330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1456 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_52_NO_0042, (cst_val *)&val_1457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1459 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_dh_52_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_dh_52_cart = {
  cmu_us_rms_f0_dh_52_cart_nodes,
  cmu_us_rms_f0_dh_52_feat_table
};

static const cst_cart_node cmu_us_rms_f0_dh_53_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0000, (cst_val *)&val_1460},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_53_NO_0001, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0002, (cst_val *)&val_1461},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0003, (cst_val *)&val_0951},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0004, (cst_val *)&val_1462},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0005, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1465 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0009, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1466 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0011, (cst_val *)&val_1467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1470 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0015, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1472 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_53_NO_0018, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0019, (cst_val *)&val_1473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1475 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0022, (cst_val *)&val_1476},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0023, (cst_val *)&val_1477},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_dh_53_NO_0024, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1479 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_dh_53_NO_0027, (cst_val *)&val_1480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1483 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_dh_53_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_dh_53_cart = {
  cmu_us_rms_f0_dh_53_cart_nodes,
  cmu_us_rms_f0_dh_53_feat_table
};

static const cst_cart_node cmu_us_rms_f0_d_46_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0001, (cst_val *)&val_1484},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1486 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0004, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0005, (cst_val *)&val_1487},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0006, (cst_val *)&val_1488},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1489 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0008, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1492 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0012, (cst_val *)&val_0519},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0013, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1495 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0016, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0017, (cst_val *)&val_1496},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0018, (cst_val *)&val_1497},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1499 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0021, (cst_val *)&val_1500},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0022, (cst_val *)&val_1501},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0023, (cst_val *)&val_1502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1503 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0025, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1506 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0029, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1508 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0032, (cst_val *)&val_1509},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_46_NO_0033, (cst_val *)&val_1510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1512 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0036, (cst_val *)&val_1513},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1514 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0038, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1515 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_46_NO_0040, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1517 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_d_46_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_rms_f0_d_46_cart = {
  cmu_us_rms_f0_d_46_cart_nodes,
  cmu_us_rms_f0_d_46_feat_table
};

static const cst_cart_node cmu_us_rms_f0_d_47_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0000, (cst_val *)&val_1518},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_47_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1519 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0003, (cst_val *)&val_1212},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0004, (cst_val *)&val_1520},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0005, (cst_val *)&val_1521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1525 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_47_NO_0010, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1526 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0012, (cst_val *)&val_1527},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0013, (cst_val *)&val_1528},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_47_NO_0014, (cst_val *)&val_0012},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0015, (cst_val *)&val_1529},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_47_NO_0016, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0017, (cst_val *)&val_1530},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_47_NO_0018, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1533 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0022, (cst_val *)&val_1534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1536 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0025, (cst_val *)&val_1537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1541 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0030, (cst_val *)&val_1542},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_47_NO_0031, (cst_val *)&val_1477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1545 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_d_47_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_d_47_cart = {
  cmu_us_rms_f0_d_47_cart_nodes,
  cmu_us_rms_f0_d_47_feat_table
};

static const cst_cart_node cmu_us_rms_f0_d_48_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0001, (cst_val *)&val_0519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1546 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0003, (cst_val *)&val_1547},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0004, (cst_val *)&val_0519},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0005, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1550 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0008, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1551 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0010, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1552 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0012, (cst_val *)&val_1553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1554 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0014, (cst_val *)&val_0012},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0015, (cst_val *)&val_1473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1556 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0018, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1558 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0021, (cst_val *)&val_0012},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0022, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1561 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0026, (cst_val *)&val_0519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1562 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0028, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1563 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0030, (cst_val *)&val_1564},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0031, (cst_val *)&val_1565},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0032, (cst_val *)&val_0041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0033, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1568 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0037, (cst_val *)&val_0465},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0038, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1570 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0041, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1572 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0044, (cst_val *)&val_1573},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0045, (cst_val *)&val_1574},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_d_48_NO_0046, (cst_val *)&val_1575},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0047, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1579 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_d_48_NO_0052, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1581 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_d_48_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_d_48_cart = {
  cmu_us_rms_f0_d_48_cart_nodes,
  cmu_us_rms_f0_d_48_feat_table
};

static const cst_cart_node cmu_us_rms_f0_n_116_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0000, (cst_val *)&val_1582},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0001, (cst_val *)&val_1583},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0002, (cst_val *)&val_0051},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0003, (cst_val *)&val_1113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1584 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0005, (cst_val *)&val_0012},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0006, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1587 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0010, (cst_val *)&val_1588},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0011, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1591 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0015, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0016, (cst_val *)&val_0012},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0017, (cst_val *)&val_0204},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0018, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1593 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0021, (cst_val *)&val_1594},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0022, (cst_val *)&val_1595},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0023, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1597 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0026, (cst_val *)&val_1598},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0027, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1602 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0032, (cst_val *)&val_1603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1606 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0036, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0037, (cst_val *)&val_0012},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0038, (cst_val *)&val_1607},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0039, (cst_val *)&val_0204},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0040, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1608 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0042, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1610 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0045, (cst_val *)&val_1611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1612 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0047, (cst_val *)&val_0212},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0048, (cst_val *)&val_1613},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0049, (cst_val *)&val_0012},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0050, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1616 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0054, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1618 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0057, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1619 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0059, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1622 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_116_NO_0063, (cst_val *)&val_0085},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0064, (cst_val *)&val_1623},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0065, (cst_val *)&val_1624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1627 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0069, (cst_val *)&val_1628},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1630 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0072, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1631 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0074, (cst_val *)&val_1632},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_116_NO_0075, (cst_val *)&val_1633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1636 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_n_116_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_f0_n_116_cart = {
  cmu_us_rms_f0_n_116_cart_nodes,
  cmu_us_rms_f0_n_116_feat_table
};

static const cst_cart_node cmu_us_rms_f0_n_117_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0001, (cst_val *)&val_1637},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0002, (cst_val *)&val_1638},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0003, (cst_val *)&val_1639},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0004, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1641 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0007, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0008, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1643 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0011, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1644 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0013, (cst_val *)&val_1645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1647 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0016, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1648 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0018, (cst_val *)&val_1649},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0019, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1651 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0022, (cst_val *)&val_1652},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0023, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1655 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0027, (cst_val *)&val_0134},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0028, (cst_val *)&val_1656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1657 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0030, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1659 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0033, (cst_val *)&val_1660},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0034, (cst_val *)&val_0519},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0035, (cst_val *)&val_1661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1663 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0038, (cst_val *)&val_0017},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0039, (cst_val *)&val_0041},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0040, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1666 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0044, (cst_val *)&val_0012},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0045, (cst_val *)&val_1667},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0046, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1669 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0049, (cst_val *)&val_0212},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0050, (cst_val *)&val_1670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1672 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0053, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1673 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0055, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1675 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0058, (cst_val *)&val_0111},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0059, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1677 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0062, (cst_val *)&val_0041},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0063, (cst_val *)&val_0450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1680 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0067, (cst_val *)&val_1681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1683 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0070, (cst_val *)&val_1684},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0071, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1686 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0073, (cst_val *)&val_1687},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1688 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0075, (cst_val *)&val_1040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1690 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0078, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1691 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0080, (cst_val *)&val_1692},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0081, (cst_val *)&val_1693},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0082, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1695 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0085, (cst_val *)&val_1696},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0086, (cst_val *)&val_1426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1699 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0090, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1700 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0092, (cst_val *)&val_0271},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_117_NO_0093, (cst_val *)&val_0111},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_117_NO_0094, (cst_val *)&val_1701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1705 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_n_117_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_f0_n_117_cart = {
  cmu_us_rms_f0_n_117_cart_nodes,
  cmu_us_rms_f0_n_117_feat_table
};

static const cst_cart_node cmu_us_rms_f0_n_118_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0000, (cst_val *)&val_1706},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0001, (cst_val *)&val_1707},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0002, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0003, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1708 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0005, (cst_val *)&val_0631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1710 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0008, (cst_val *)&val_1711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1713 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0011, (cst_val *)&val_0153},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0012, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1714 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0014, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1717 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0018, (cst_val *)&val_1718},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0019, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0020, (cst_val *)&val_1719},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0021, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1722 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0025, (cst_val *)&val_1723},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0026, (cst_val *)&val_0345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1724 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0028, (cst_val *)&val_0246},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0029, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1726 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0032, (cst_val *)&val_1727},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0033, (cst_val *)&val_1728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1730 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0036, (cst_val *)&val_0012},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0037, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1732 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_n_118_NO_0040, (cst_val *)&val_0085},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0041, (cst_val *)&val_1733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1737 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0046, (cst_val *)&val_1738},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0047, (cst_val *)&val_1739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1741 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_n_118_NO_0050, (cst_val *)&val_0563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1743 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_n_118_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_rms_f0_n_118_cart = {
  cmu_us_rms_f0_n_118_cart_nodes,
  cmu_us_rms_f0_n_118_feat_table
};

static const cst_cart_node cmu_us_rms_f0_jh_96_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_96_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_96_NO_0001, (cst_val *)&val_1744},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_96_NO_0002, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1746 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_96_NO_0005, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1747 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_96_NO_0007, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1750 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_jh_96_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_jh_96_cart = {
  cmu_us_rms_f0_jh_96_cart_nodes,
  cmu_us_rms_f0_jh_96_feat_table
};

static const cst_cart_node cmu_us_rms_f0_jh_97_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_97_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_97_NO_0001, (cst_val *)&val_1365},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_97_NO_0002, (cst_val *)&val_1751},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_97_NO_0003, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1753 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_97_NO_0006, (cst_val *)&val_1754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1756 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_97_NO_0009, (cst_val *)&val_1757},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_97_NO_0010, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1761 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_jh_97_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_f0_jh_97_cart = {
  cmu_us_rms_f0_jh_97_cart_nodes,
  cmu_us_rms_f0_jh_97_feat_table
};

static const cst_cart_node cmu_us_rms_f0_jh_98_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_98_NO_0000, (cst_val *)&val_1762},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_98_NO_0001, (cst_val *)&val_1763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1764 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_98_NO_0003, (cst_val *)&val_1765},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_jh_98_NO_0004, (cst_val *)&val_1766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1768 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_jh_98_NO_0007, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1771 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_jh_98_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_jh_98_cart = {
  cmu_us_rms_f0_jh_98_cart_nodes,
  cmu_us_rms_f0_jh_98_feat_table
};

static const cst_cart_node cmu_us_rms_f0_r_146_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0000, (cst_val *)&val_0153},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0002, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1773 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0005, (cst_val *)&val_1774},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0006, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1775 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0008, (cst_val *)&val_0012},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0009, (cst_val *)&val_1776},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0010, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0013, (cst_val *)&val_1778},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0014, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1780 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0017, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1781 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0019, (cst_val *)&val_1782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1784 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0022, (cst_val *)&val_1785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1787 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0025, (cst_val *)&val_1788},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0026, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0027, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1791 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0031, (cst_val *)&val_0252},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0032, (cst_val *)&val_1792},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0033, (cst_val *)&val_1793},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1796 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0037, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1797 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0039, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1798 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0041, (cst_val *)&val_1799},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0042, (cst_val *)&val_0041},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0043, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1800 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0045, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1803 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0049, (cst_val *)&val_1025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0050, (cst_val *)&val_1804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1806 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0053, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1808 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0056, (cst_val *)&val_0246},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0057, (cst_val *)&val_1809},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0058, (cst_val *)&val_1810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1812 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0061, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1815 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0064, (cst_val *)&val_1816},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0065, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1817 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0067, (cst_val *)&val_1818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1819 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_146_NO_0069, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1821 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_146_NO_0072, (cst_val *)&val_1822},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1824 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_r_146_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_rms_f0_r_146_cart = {
  cmu_us_rms_f0_r_146_cart_nodes,
  cmu_us_rms_f0_r_146_feat_table
};

static const cst_cart_node cmu_us_rms_f0_r_147_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0000, (cst_val *)&val_1825},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1826 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1827 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0005, (cst_val *)&val_1313},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0006, (cst_val *)&val_1828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1831 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0010, (cst_val *)&val_0153},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0011, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0012, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1832 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0014, (cst_val *)&val_1833},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0015, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1835 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0018, (cst_val *)&val_1836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1838 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0021, (cst_val *)&val_0830},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0022, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0023, (cst_val *)&val_0907},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0024, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1841 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0028, (cst_val *)&val_1842},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0029, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0030, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1846 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0035, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1298 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0037, (cst_val *)&val_1847},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0038, (cst_val *)&val_1426},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0039, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1850 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0043, (cst_val *)&val_0153},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0044, (cst_val *)&val_0051},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0045, (cst_val *)&val_1426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1854 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0050, (cst_val *)&val_0246},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0051, (cst_val *)&val_1855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1856 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0053, (cst_val *)&val_1857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1859 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0056, (cst_val *)&val_1860},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0057, (cst_val *)&val_1861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1863 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_147_NO_0060, (cst_val *)&val_1864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1865 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_147_NO_0062, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1867 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_r_147_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_rms_f0_r_147_cart = {
  cmu_us_rms_f0_r_147_cart_nodes,
  cmu_us_rms_f0_r_147_feat_table
};

static const cst_cart_node cmu_us_rms_f0_r_148_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0000, (cst_val *)&val_0153},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0001, (cst_val *)&val_0345},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0002, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1868 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0004, (cst_val *)&val_1869},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1871 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0007, (cst_val *)&val_1872},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0008, (cst_val *)&val_0012},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0009, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0010, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1875 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0014, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1876 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0016, (cst_val *)&val_1877},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1879 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0019, (cst_val *)&val_1880},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0020, (cst_val *)&val_1881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1883 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0023, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1885 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0026, (cst_val *)&val_1886},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0027, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0028, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1889 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0031, (cst_val *)&val_1890},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1892 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0034, (cst_val *)&val_0041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0035, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1894 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0038, (cst_val *)&val_0126},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_r_148_NO_0039, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1896 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0042, (cst_val *)&val_1309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1897 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0044, (cst_val *)&val_0160},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_r_148_NO_0045, (cst_val *)&val_1898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1901 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_r_148_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_f0_r_148_cart = {
  cmu_us_rms_f0_r_148_cart_nodes,
  cmu_us_rms_f0_r_148_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ey_66_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0002, (cst_val *)&val_1302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1903 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0005, (cst_val *)&val_1904},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0006, (cst_val *)&val_1905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1907 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0009, (cst_val *)&val_1908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1910 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0012, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0013, (cst_val *)&val_1911},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0014, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0017, (cst_val *)&val_1913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0552 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0020, (cst_val *)&val_1915},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0021, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1167 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0024, (cst_val *)&val_1917},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0025, (cst_val *)&val_1918},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0026, (cst_val *)&val_0051},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0027, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1919 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0029, (cst_val *)&val_1920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1921 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_66_NO_0031, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1924 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_66_NO_0035, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1927 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ey_66_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_ey_66_cart = {
  cmu_us_rms_f0_ey_66_cart_nodes,
  cmu_us_rms_f0_ey_66_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ey_67_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0000, (cst_val *)&val_0714},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0001, (cst_val *)&val_0637},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0002, (cst_val *)&val_1928},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0003, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1930 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0006, (cst_val *)&val_1931},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0007, (cst_val *)&val_0246},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0008, (cst_val *)&val_0410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1934 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0012, (cst_val *)&val_0246},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0013, (cst_val *)&val_1935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1937 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0016, (cst_val *)&val_1938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1941 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0020, (cst_val *)&val_0041},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0021, (cst_val *)&val_0055},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0022, (cst_val *)&val_1942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1944 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0025, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1946 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0028, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0029, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1947 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0031, (cst_val *)&val_1948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1950 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0034, (cst_val *)&val_0012},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_67_NO_0035, (cst_val *)&val_0102},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0036, (cst_val *)&val_1951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1953 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0039, (cst_val *)&val_0278},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0040, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1956 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0044, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1957 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_67_NO_0046, (cst_val *)&val_1958},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1960 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ey_67_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_ey_67_cart = {
  cmu_us_rms_f0_ey_67_cart_nodes,
  cmu_us_rms_f0_ey_67_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ey_68_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0001, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1961 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0003, (cst_val *)&val_1962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1964 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0006, (cst_val *)&val_1965},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0007, (cst_val *)&val_1966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1967 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1968 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0011, (cst_val *)&val_1969},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0012, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1972 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0015, (cst_val *)&val_0246},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0016, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1973 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0018, (cst_val *)&val_1974},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1976 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0021, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1977 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0023, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1979 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0026, (cst_val *)&val_1980},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0027, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1981 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0029, (cst_val *)&val_0618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1983 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ey_68_NO_0032, (cst_val *)&val_1984},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ey_68_NO_0033, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1987 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ey_68_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_f0_ey_68_cart = {
  cmu_us_rms_f0_ey_68_cart_nodes,
  cmu_us_rms_f0_ey_68_feat_table
};

static const cst_cart_node cmu_us_rms_f0_f_71_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0001, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1988 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0003, (cst_val *)&val_1989},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0004, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1990 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0006, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1993 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0010, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0011, (cst_val *)&val_0156},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0012, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1994 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0014, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1997 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0018, (cst_val *)&val_1872},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0019, (cst_val *)&val_0305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1998 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0021, (cst_val *)&val_1999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2001 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_71_NO_0024, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2002 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_71_NO_0026, (cst_val *)&val_2003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2005 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_f_71_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_rms_f0_f_71_cart = {
  cmu_us_rms_f0_f_71_cart_nodes,
  cmu_us_rms_f0_f_71_feat_table
};

static const cst_cart_node cmu_us_rms_f0_f_72_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0000, (cst_val *)&val_2006},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0002, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0003, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2008 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0006, (cst_val *)&val_2009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2011 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0009, (cst_val *)&val_1116},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0010, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2012 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0012, (cst_val *)&val_2013},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0013, (cst_val *)&val_0111},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0014, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2015 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0017, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0018, (cst_val *)&val_2016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2019 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0022, (cst_val *)&val_2020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2022 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0025, (cst_val *)&val_0923},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0026, (cst_val *)&val_2023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2025 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0029, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2027 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0032, (cst_val *)&val_0017},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0033, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2028 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0035, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2030 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0038, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0039, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2032 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0042, (cst_val *)&val_2033},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0043, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0044, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2035 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0047, (cst_val *)&val_2036},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0048, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0049, (cst_val *)&val_1025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0052, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2041 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0056, (cst_val *)&val_0212},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0057, (cst_val *)&val_2042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2044 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0060, (cst_val *)&val_2045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0061, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2046 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0063, (cst_val *)&val_2047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2049 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_72_NO_0066, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2050 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0068, (cst_val *)&val_2051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2052 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_72_NO_0070, (cst_val *)&val_2053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2055 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_f_72_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_rms_f0_f_72_cart = {
  cmu_us_rms_f0_f_72_cart_nodes,
  cmu_us_rms_f0_f_72_feat_table
};

static const cst_cart_node cmu_us_rms_f0_f_73_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_73_NO_0000, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2056 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_f_73_NO_0002, (cst_val *)&val_2057},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_73_NO_0003, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2059 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_f_73_NO_0006, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2061 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_f_73_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_f_73_cart = {
  cmu_us_rms_f0_f_73_cart_nodes,
  cmu_us_rms_f0_f_73_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ih_86_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0001, (cst_val *)&val_2062},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0002, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2064 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0005, (cst_val *)&val_0625},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0006, (cst_val *)&val_2065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2067 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0009, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2068 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0011, (cst_val *)&val_0814},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0012, (cst_val *)&val_2069},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0013, (cst_val *)&val_2070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2071 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0015, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2073 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0018, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2076 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0022, (cst_val *)&val_0830},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0023, (cst_val *)&val_2077},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0024, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2078 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0026, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0027, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2080 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0030, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2082 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0033, (cst_val *)&val_2083},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0034, (cst_val *)&val_0012},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0035, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2085 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0038, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2086 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0040, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2087 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_86_NO_0042, (cst_val *)&val_2088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2091 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0046, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0048, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2092 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_86_NO_0050, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2094 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ih_86_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_ih_86_cart = {
  cmu_us_rms_f0_ih_86_cart_nodes,
  cmu_us_rms_f0_ih_86_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ih_87_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0000, (cst_val *)&val_2095},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0002, (cst_val *)&val_1089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2096 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0004, (cst_val *)&val_0017},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0005, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2097 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0007, (cst_val *)&val_2098},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0008, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2101 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0012, (cst_val *)&val_2102},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0013, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2103 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0015, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2105 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0018, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2107 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0021, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0022, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2109 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0025, (cst_val *)&val_0055},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0026, (cst_val *)&val_1477},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0027, (cst_val *)&val_2110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2113 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0031, (cst_val *)&val_1107},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0032, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2115 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0035, (cst_val *)&val_0902},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0036, (cst_val *)&val_2116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2118 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0039, (cst_val *)&val_1392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2120 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0042, (cst_val *)&val_0085},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0043, (cst_val *)&val_1872},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0044, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2123 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0048, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2124 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0050, (cst_val *)&val_0051},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0051, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0052, (cst_val *)&val_0017},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0053, (cst_val *)&val_2125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2126 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0055, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2128 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0058, (cst_val *)&val_2129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2130 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0060, (cst_val *)&val_0427},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0061, (cst_val *)&val_2131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2134 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0065, (cst_val *)&val_0041},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0066, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2135 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0068, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2137 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0071, (cst_val *)&val_1089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2138 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0073, (cst_val *)&val_0042},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0074, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2139 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_87_NO_0076, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2140 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0078, (cst_val *)&val_2141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2142 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_87_NO_0080, (cst_val *)&val_2143},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2147 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ih_87_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_ih_87_cart = {
  cmu_us_rms_f0_ih_87_cart_nodes,
  cmu_us_rms_f0_ih_87_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ih_88_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0001, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0004, (cst_val *)&val_0085},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0005, (cst_val *)&val_0042},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0006, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2150 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0009, (cst_val *)&val_2151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2152 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0011, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2153 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0013, (cst_val *)&val_1966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2155 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0016, (cst_val *)&val_0041},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0017, (cst_val *)&val_0041},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0018, (cst_val *)&val_0246},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0019, (cst_val *)&val_2156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2158 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0022, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2160 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0025, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2161 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0027, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2162 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0029, (cst_val *)&val_2163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2165 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0032, (cst_val *)&val_2166},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0033, (cst_val *)&val_2167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2168 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0035, (cst_val *)&val_0098},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0036, (cst_val *)&val_0814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2170 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0039, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2172 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0042, (cst_val *)&val_1477},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0043, (cst_val *)&val_1089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2173 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0045, (cst_val *)&val_0586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2174 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0047, (cst_val *)&val_2175},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0048, (cst_val *)&val_2176},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0049, (cst_val *)&val_2177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2179 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0052, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2181 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0055, (cst_val *)&val_1365},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0056, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2183 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0059, (cst_val *)&val_0041},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0060, (cst_val *)&val_0571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2185 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0063, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2186 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ih_88_NO_0065, (cst_val *)&val_0120},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0066, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2189 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ih_88_NO_0070, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2191 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ih_88_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_f0_ih_88_cart = {
  cmu_us_rms_f0_ih_88_cart_nodes,
  cmu_us_rms_f0_ih_88_feat_table
};

static const cst_cart_node cmu_us_rms_f0_p_136_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_136_NO_0000, (cst_val *)&val_0111},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_136_NO_0001, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2193 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_136_NO_0004, (cst_val *)&val_2194},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_136_NO_0005, (cst_val *)&val_0265},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_136_NO_0006, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2197 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_136_NO_0010, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2200 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_p_136_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_p_136_cart = {
  cmu_us_rms_f0_p_136_cart_nodes,
  cmu_us_rms_f0_p_136_feat_table
};

static const cst_cart_node cmu_us_rms_f0_p_137_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0000, (cst_val *)&val_0153},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0001, (cst_val *)&val_2201},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0002, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2202 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0004, (cst_val *)&val_2203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2205 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0007, (cst_val *)&val_0111},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0008, (cst_val *)&val_0698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2206 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0010, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2208 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0013, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0014, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2209 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0016, (cst_val *)&val_1711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2210 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0018, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2211 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0020, (cst_val *)&val_1881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2212 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0022, (cst_val *)&val_2213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2215 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0025, (cst_val *)&val_2216},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0026, (cst_val *)&val_0748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2218 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_137_NO_0029, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2220 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_137_NO_0032, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2223 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_p_137_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_p_137_cart = {
  cmu_us_rms_f0_p_137_cart_nodes,
  cmu_us_rms_f0_p_137_feat_table
};

static const cst_cart_node cmu_us_rms_f0_p_138_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0001, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2224 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0003, (cst_val *)&val_2225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2226 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0005, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2227 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0007, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2229 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0010, (cst_val *)&val_0246},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0011, (cst_val *)&val_2230},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2231 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0013, (cst_val *)&val_2232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2233 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0015, (cst_val *)&val_0212},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0016, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2235 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0019, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2236 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0021, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2239 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0024, (cst_val *)&val_0698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2240 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0026, (cst_val *)&val_2241},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0027, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2242 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_p_138_NO_0029, (cst_val *)&val_1125},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0030, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2245 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_p_138_NO_0034, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2247 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_p_138_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_rms_f0_p_138_cart = {
  cmu_us_rms_f0_p_138_cart_nodes,
  cmu_us_rms_f0_p_138_feat_table
};

static const cst_cart_node cmu_us_rms_f0_iy_91_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0000, (cst_val *)&val_0055},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0002, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2249 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0005, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2250 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0007, (cst_val *)&val_2251},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0008, (cst_val *)&val_0509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2252 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0010, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2254 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0013, (cst_val *)&val_0012},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0014, (cst_val *)&val_2255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2257 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0017, (cst_val *)&val_2258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2260 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0020, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0021, (cst_val *)&val_0041},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0022, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2261 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0024, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2263 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0027, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0028, (cst_val *)&val_2264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2266 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0031, (cst_val *)&val_0051},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0032, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0033, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2268 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0036, (cst_val *)&val_0625},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0037, (cst_val *)&val_1026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2270 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0040, (cst_val *)&val_0246},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0041, (cst_val *)&val_0757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2271 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0043, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2273 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0046, (cst_val *)&val_0127},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0047, (cst_val *)&val_2274},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0048, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2276 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0051, (cst_val *)&val_0126},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0052, (cst_val *)&val_2277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2281 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0057, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2282 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0059, (cst_val *)&val_2283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2285 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0062, (cst_val *)&val_2286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2287 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0064, (cst_val *)&val_1426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2288 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0066, (cst_val *)&val_0042},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0067, (cst_val *)&val_2289},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0068, (cst_val *)&val_2290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2291 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_91_NO_0070, (cst_val *)&val_2292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2295 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_91_NO_0074, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2297 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_iy_91_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_rms_f0_iy_91_cart = {
  cmu_us_rms_f0_iy_91_cart_nodes,
  cmu_us_rms_f0_iy_91_feat_table
};

static const cst_cart_node cmu_us_rms_f0_iy_92_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0000, (cst_val *)&val_2298},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0001, (cst_val *)&val_0012},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0002, (cst_val *)&val_2299},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0003, (cst_val *)&val_0041},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0004, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2301 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0007, (cst_val *)&val_2302},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0008, (cst_val *)&val_2303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2304 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0011, (cst_val *)&val_0265},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0012, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0017, (cst_val *)&val_2308},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0018, (cst_val *)&val_2309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2310 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0020, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2313 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0024, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0025, (cst_val *)&val_0017},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0026, (cst_val *)&val_2314},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0027, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0028, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2316 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0031, (cst_val *)&val_2317},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0034, (cst_val *)&val_2320},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0035, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2321 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0037, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0038, (cst_val *)&val_2322},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2324 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0041, (cst_val *)&val_0012},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0042, (cst_val *)&val_2325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2328 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0046, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2330 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0049, (cst_val *)&val_2331},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0050, (cst_val *)&val_2332},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0051, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2333 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0053, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2334 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0055, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2335 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0057, (cst_val *)&val_0120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2337 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0060, (cst_val *)&val_2338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2340 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0063, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0064, (cst_val *)&val_2341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0067, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2344 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0069, (cst_val *)&val_0487},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0070, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2346 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0073, (cst_val *)&val_2347},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0074, (cst_val *)&val_2348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2351 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0078, (cst_val *)&val_2352},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0079, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0080, (cst_val *)&val_2353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2356 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0084, (cst_val *)&val_2357},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0085, (cst_val *)&val_2358},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0086, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2361 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_92_NO_0090, (cst_val *)&val_0246},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_92_NO_0091, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2364 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_iy_92_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_f0_iy_92_cart = {
  cmu_us_rms_f0_iy_92_cart_nodes,
  cmu_us_rms_f0_iy_92_feat_table
};

static const cst_cart_node cmu_us_rms_f0_iy_93_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0001, (cst_val *)&val_1257},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0002, (cst_val *)&val_2365},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0003, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2369 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0007, (cst_val *)&val_2370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2372 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0010, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0011, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2374 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0014, (cst_val *)&val_1116},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0015, (cst_val *)&val_0012},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0016, (cst_val *)&val_0102},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0017, (cst_val *)&val_2375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2377 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0020, (cst_val *)&val_1477},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0021, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0022, (cst_val *)&val_2069},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0023, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2382 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0029, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0030, (cst_val *)&val_2383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2385 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_iy_93_NO_0033, (cst_val *)&val_0126},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0034, (cst_val *)&val_0563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2387 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_iy_93_NO_0037, (cst_val *)&val_2388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2391 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_iy_93_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_f0_iy_93_cart = {
  cmu_us_rms_f0_iy_93_cart_nodes,
  cmu_us_rms_f0_iy_93_feat_table
};

static const cst_cart_node cmu_us_rms_f0_l_106_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0000, (cst_val *)&val_2392},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0002, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2393 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0005, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2395 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2396 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0010, (cst_val *)&val_2397},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0011, (cst_val *)&val_0085},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0012, (cst_val *)&val_2398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2400 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0015, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2401 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0017, (cst_val *)&val_0126},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0018, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1099 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0021, (cst_val *)&val_2403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2404 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0023, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2406 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0026, (cst_val *)&val_2407},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0027, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2410 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0031, (cst_val *)&val_0246},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0032, (cst_val *)&val_2411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2413 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0035, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2415 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0038, (cst_val *)&val_0085},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0039, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2416 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0041, (cst_val *)&val_2417},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0042, (cst_val *)&val_2418},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0043, (cst_val *)&val_1403},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0044, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2423 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0050, (cst_val *)&val_0153},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0051, (cst_val *)&val_0246},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0052, (cst_val *)&val_0111},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0053, (cst_val *)&val_0012},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0054, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2427 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0059, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2428 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0061, (cst_val *)&val_0012},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0062, (cst_val *)&val_2429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2431 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0065, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2432 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_106_NO_0067, (cst_val *)&val_2433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2434 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0069, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2436 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0072, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2437 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0074, (cst_val *)&val_0134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2438 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_106_NO_0076, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2440 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_l_106_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_rms_f0_l_106_cart = {
  cmu_us_rms_f0_l_106_cart_nodes,
  cmu_us_rms_f0_l_106_feat_table
};

static const cst_cart_node cmu_us_rms_f0_l_107_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0000, (cst_val *)&val_2441},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0001, (cst_val *)&val_0212},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0002, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2443 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0004, (cst_val *)&val_2444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2446 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0007, (cst_val *)&val_0153},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0008, (cst_val *)&val_2447},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0009, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2448 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0011, (cst_val *)&val_1727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2449 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0013, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2450 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0015, (cst_val *)&val_0410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2452 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0018, (cst_val *)&val_0926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2455 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0022, (cst_val *)&val_0017},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0023, (cst_val *)&val_0085},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0024, (cst_val *)&val_1881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2456 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0026, (cst_val *)&val_2457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2459 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0029, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0030, (cst_val *)&val_2460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2461 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0032, (cst_val *)&val_2462},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0033, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0034, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2465 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0038, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0039, (cst_val *)&val_2466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2468 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0042, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2469 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0044, (cst_val *)&val_2470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2473 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0048, (cst_val *)&val_0246},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0049, (cst_val *)&val_2474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2475 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0051, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2476 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0053, (cst_val *)&val_0435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2478 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0056, (cst_val *)&val_0153},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0057, (cst_val *)&val_2479},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0058, (cst_val *)&val_2480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2481 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_107_NO_0060, (cst_val *)&val_2482},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2483 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0062, (cst_val *)&val_2484},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0063, (cst_val *)&val_2485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2486 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0065, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2488 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0068, (cst_val *)&val_2489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2492 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_107_NO_0072, (cst_val *)&val_2493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2495 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_l_107_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_f0_l_107_cart = {
  cmu_us_rms_f0_l_107_cart_nodes,
  cmu_us_rms_f0_l_107_feat_table
};

static const cst_cart_node cmu_us_rms_f0_l_108_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0001, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2496 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0003, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0004, (cst_val *)&val_0682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2498 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0007, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2500 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0010, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0011, (cst_val *)&val_2460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2501 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0013, (cst_val *)&val_2502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2504 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0016, (cst_val *)&val_0041},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0017, (cst_val *)&val_2505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2506 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0019, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2507 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0021, (cst_val *)&val_2508},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2510 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0024, (cst_val *)&val_0051},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0025, (cst_val *)&val_2511},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0026, (cst_val *)&val_0041},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0027, (cst_val *)&val_2512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2513 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0029, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2515 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0032, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2517 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0035, (cst_val *)&val_0041},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0036, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2519 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0039, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2520 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0041, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2522 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_l_108_NO_0044, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2523 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0046, (cst_val *)&val_2524},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_l_108_NO_0047, (cst_val *)&val_2525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2528 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_l_108_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_rms_f0_l_108_cart = {
  cmu_us_rms_f0_l_108_cart_nodes,
  cmu_us_rms_f0_l_108_feat_table
};

static const cst_cart_node cmu_us_rms_f0_z_199_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0000, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2529 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0002, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2530 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0004, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2531 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0006, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0007, (cst_val *)&val_0212},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_199_NO_0008, (cst_val *)&val_2532},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_199_NO_0009, (cst_val *)&val_2533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2535 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0012, (cst_val *)&val_2536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2538 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0015, (cst_val *)&val_0012},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0016, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_199_NO_0017, (cst_val *)&val_2289},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2542 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_199_NO_0022, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2544 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_z_199_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_rms_f0_z_199_cart = {
  cmu_us_rms_f0_z_199_cart_nodes,
  cmu_us_rms_f0_z_199_feat_table
};

static const cst_cart_node cmu_us_rms_f0_z_200_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0001, (cst_val *)&val_2545},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0002, (cst_val *)&val_2546},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0003, (cst_val *)&val_0773},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2549 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0007, (cst_val *)&val_2550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2551 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0009, (cst_val *)&val_2552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2553 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0011, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2555 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0014, (cst_val *)&val_0557},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0015, (cst_val *)&val_2556},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0016, (cst_val *)&val_0012},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0017, (cst_val *)&val_0017},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0018, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2559 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0022, (cst_val *)&val_0682},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0023, (cst_val *)&val_1833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2561 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0026, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0027, (cst_val *)&val_1833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2564 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0031, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2565 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0033, (cst_val *)&val_0682},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0034, (cst_val *)&val_0085},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0035, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2567 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0038, (cst_val *)&val_2460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2568 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0040, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2570 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0043, (cst_val *)&val_2571},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0044, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2572 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0046, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2574 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0049, (cst_val *)&val_0017},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0050, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2577 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0054, (cst_val *)&val_0017},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0055, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2578 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0057, (cst_val *)&val_2556},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0058, (cst_val *)&val_1040},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0059, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2579 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0061, (cst_val *)&val_2580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2583 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0065, (cst_val *)&val_2584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2585 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0067, (cst_val *)&val_0041},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0068, (cst_val *)&val_2586},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0069, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2589 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_200_NO_0073, (cst_val *)&val_0012},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0074, (cst_val *)&val_1723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2592 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0078, (cst_val *)&val_0259},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0079, (cst_val *)&val_2593},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0080, (cst_val *)&val_2177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2595 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_200_NO_0083, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2598 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_z_200_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_rms_f0_z_200_cart = {
  cmu_us_rms_f0_z_200_cart_nodes,
  cmu_us_rms_f0_z_200_feat_table
};

static const cst_cart_node cmu_us_rms_f0_z_201_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_201_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_201_NO_0001, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2600 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0004, (cst_val *)&val_2571},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0005, (cst_val *)&val_1189},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0006, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2602 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_201_NO_0009, (cst_val *)&val_0153},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0010, (cst_val *)&val_2603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2605 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0013, (cst_val *)&val_2606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2608 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_201_NO_0016, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_z_201_NO_0017, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_z_201_NO_0018, (cst_val *)&val_2609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2613 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_z_201_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_f0_z_201_cart = {
  cmu_us_rms_f0_z_201_cart_nodes,
  cmu_us_rms_f0_z_201_feat_table
};

static const cst_cart_node cmu_us_rms_f0_pau_161_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_pau_161_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_pau_161_cart = {
  cmu_us_rms_f0_pau_161_cart_nodes,
  cmu_us_rms_f0_pau_161_feat_table
};

static const cst_cart_node cmu_us_rms_f0_s_151_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0001, (cst_val *)&val_0153},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0002, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2614 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0004, (cst_val *)&val_2546},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0005, (cst_val *)&val_2484},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0006, (cst_val *)&val_2615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2618 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0010, (cst_val *)&val_1083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2620 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0013, (cst_val *)&val_0733},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0014, (cst_val *)&val_2621},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0015, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2624 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0019, (cst_val *)&val_1426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2625 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0022, (cst_val *)&val_0423},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0023, (cst_val *)&val_2626},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0024, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2629 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0028, (cst_val *)&val_2630},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0029, (cst_val *)&val_0017},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0030, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0031, (cst_val *)&val_0042},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0032, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2632 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0035, (cst_val *)&val_2633},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0036, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2637 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0041, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0042, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2639 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0045, (cst_val *)&val_2640},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0046, (cst_val *)&val_0204},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0047, (cst_val *)&val_2641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2642 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0049, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2644 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0052, (cst_val *)&val_2645},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0053, (cst_val *)&val_2646},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0054, (cst_val *)&val_0051},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0055, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2648 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0059, (cst_val *)&val_2649},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0060, (cst_val *)&val_1313},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0061, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2651 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0064, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2654 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0068, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2655 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0070, (cst_val *)&val_2656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2658 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0073, (cst_val *)&val_0017},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0074, (cst_val *)&val_0102},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0075, (cst_val *)&val_2659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2661 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0078, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2663 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0081, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2664 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0083, (cst_val *)&val_2665},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0084, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2668 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0088, (cst_val *)&val_0246},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0089, (cst_val *)&val_2669},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0090, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2670 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0092, (cst_val *)&val_2671},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0093, (cst_val *)&val_0017},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0094, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2674 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0098, (cst_val *)&val_0802},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2676 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0101, (cst_val *)&val_2677},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0102, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2678 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0104, (cst_val *)&val_2679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2681 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0107, (cst_val *)&val_2682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2684 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0110, (cst_val *)&val_2685},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0111, (cst_val *)&val_0111},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0112, (cst_val *)&val_2686},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2688 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_151_NO_0115, (cst_val *)&val_0866},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0116, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2689 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0118, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2692 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0122, (cst_val *)&val_0153},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0123, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2694 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0126, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2695 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_151_NO_0128, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2697 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_s_151_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_s_151_cart = {
  cmu_us_rms_f0_s_151_cart_nodes,
  cmu_us_rms_f0_s_151_feat_table
};

static const cst_cart_node cmu_us_rms_f0_s_152_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0001, (cst_val *)&val_2698},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0002, (cst_val *)&val_2699},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2700 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0005, (cst_val *)&val_2701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2703 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0008, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0009, (cst_val *)&val_2177},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0010, (cst_val *)&val_0012},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0011, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2705 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0015, (cst_val *)&val_0012},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0016, (cst_val *)&val_1078},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0017, (cst_val *)&val_2706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2710 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0022, (cst_val *)&val_2711},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0023, (cst_val *)&val_1727},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0024, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2713 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0027, (cst_val *)&val_0041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0028, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2715 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0031, (cst_val *)&val_2716},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0032, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2717 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0035, (cst_val *)&val_2718},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0036, (cst_val *)&val_2719},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2722 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0040, (cst_val *)&val_0017},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0041, (cst_val *)&val_2723},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0042, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2724 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0044, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2725 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0046, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2727 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0050, (cst_val *)&val_2728},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0051, (cst_val *)&val_0259},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2730 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0055, (cst_val *)&val_0102},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0056, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2731 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0058, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2732 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0060, (cst_val *)&val_2733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2734 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0062, (cst_val *)&val_1501},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2736 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0065, (cst_val *)&val_2737},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0066, (cst_val *)&val_2003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0067, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2740 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0071, (cst_val *)&val_2320},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0072, (cst_val *)&val_2741},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0073, (cst_val *)&val_0017},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0074, (cst_val *)&val_2742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2744 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0077, (cst_val *)&val_1872},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0078, (cst_val *)&val_1166},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2746 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0081, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2749 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0085, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2750 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0087, (cst_val *)&val_2751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2753 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0090, (cst_val *)&val_0212},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0091, (cst_val *)&val_2754},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0092, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2755 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_152_NO_0095, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2756 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0097, (cst_val *)&val_2757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2759 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0100, (cst_val *)&val_0606},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0101, (cst_val *)&val_2760},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0102, (cst_val *)&val_2761},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0103, (cst_val *)&val_2762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2765 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_152_NO_0107, (cst_val *)&val_2766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2769 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_s_152_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_rms_f0_s_152_cart = {
  cmu_us_rms_f0_s_152_cart_nodes,
  cmu_us_rms_f0_s_152_feat_table
};

static const cst_cart_node cmu_us_rms_f0_s_153_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0000, (cst_val *)&val_0345},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0001, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2770 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0003, (cst_val *)&val_2771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2773 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0006, (cst_val *)&val_0153},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0007, (cst_val *)&val_2774},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0008, (cst_val *)&val_0830},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0009, (cst_val *)&val_2775},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0010, (cst_val *)&val_2776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2779 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0014, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2782 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0018, (cst_val *)&val_0278},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0019, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2783 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0021, (cst_val *)&val_0246},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0022, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2785 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0025, (cst_val *)&val_2786},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0026, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2789 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0030, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2790 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_s_153_NO_0032, (cst_val *)&val_2791},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_s_153_NO_0033, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2794 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_s_153_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_s_153_cart = {
  cmu_us_rms_f0_s_153_cart_nodes,
  cmu_us_rms_f0_s_153_feat_table
};

static const cst_cart_node cmu_us_rms_f0_eh_56_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0000, (cst_val *)&val_2795},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0002, (cst_val *)&val_0153},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0003, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2797 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0006, (cst_val *)&val_2798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2799 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0008, (cst_val *)&val_2800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2802 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0011, (cst_val *)&val_2803},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0012, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2804 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0014, (cst_val *)&val_0731},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0015, (cst_val *)&val_2621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2806 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0018, (cst_val *)&val_2807},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0019, (cst_val *)&val_0563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2810 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0023, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0024, (cst_val *)&val_2811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2813 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0027, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2815 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0030, (cst_val *)&val_2816},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0031, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0032, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2818 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0035, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2820 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_56_NO_0038, (cst_val *)&val_2821},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_56_NO_0039, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2824 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_eh_56_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_rms_f0_eh_56_cart = {
  cmu_us_rms_f0_eh_56_cart_nodes,
  cmu_us_rms_f0_eh_56_feat_table
};

static const cst_cart_node cmu_us_rms_f0_eh_57_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0000, (cst_val *)&val_2825},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0001, (cst_val *)&val_0718},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0002, (cst_val *)&val_0017},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0003, (cst_val *)&val_2826},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0004, (cst_val *)&val_2827},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2829 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0007, (cst_val *)&val_2830},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0008, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2831 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0010, (cst_val *)&val_0711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2001 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0014, (cst_val *)&val_2834},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0015, (cst_val *)&val_0370},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0016, (cst_val *)&val_2116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1756 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0020, (cst_val *)&val_1928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2837 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0022, (cst_val *)&val_2838},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0023, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2839 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0025, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2840 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0028, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2842 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0031, (cst_val *)&val_0427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2843 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0033, (cst_val *)&val_2844},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2846 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0036, (cst_val *)&val_0085},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0037, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2847 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0039, (cst_val *)&val_2848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2850 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0042, (cst_val *)&val_0017},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0043, (cst_val *)&val_2851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2853 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_57_NO_0046, (cst_val *)&val_2854},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_57_NO_0047, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2857 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_eh_57_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_rms_f0_eh_57_cart = {
  cmu_us_rms_f0_eh_57_cart_nodes,
  cmu_us_rms_f0_eh_57_feat_table
};

static const cst_cart_node cmu_us_rms_f0_eh_58_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0000, (cst_val *)&val_0085},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0001, (cst_val *)&val_0616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2859 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_58_NO_0004, (cst_val *)&val_2860},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0005, (cst_val *)&val_0830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2862 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_58_NO_0008, (cst_val *)&val_2863},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_58_NO_0009, (cst_val *)&val_2864},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0010, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0011, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2866 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0014, (cst_val *)&val_0246},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_eh_58_NO_0015, (cst_val *)&val_2867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2870 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_eh_58_NO_0019, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2872 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_eh_58_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_rms_f0_eh_58_cart = {
  cmu_us_rms_f0_eh_58_cart_nodes,
  cmu_us_rms_f0_eh_58_feat_table
};

static const cst_cart_node cmu_us_rms_f0_t_164_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0001, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2873 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0003, (cst_val *)&val_0153},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0004, (cst_val *)&val_2874},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0005, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0006, (cst_val *)&val_2875},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2877 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0009, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2878 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0011, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2880 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0014, (cst_val *)&val_2881},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0015, (cst_val *)&val_0522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2169 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0017, (cst_val *)&val_2882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2885 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0021, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2887 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0024, (cst_val *)&val_0085},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0025, (cst_val *)&val_1754},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0026, (cst_val *)&val_2888},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2889 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0028, (cst_val *)&val_0127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2892 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0032, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0033, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2894 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0036, (cst_val *)&val_2895},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0037, (cst_val *)&val_0041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0038, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2896 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0040, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2897 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0042, (cst_val *)&val_2898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2899 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0044, (cst_val *)&val_2900},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0045, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2902 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0048, (cst_val *)&val_2903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2904 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0050, (cst_val *)&val_0212},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0051, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2906 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0054, (cst_val *)&val_0830},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0055, (cst_val *)&val_2907},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2909 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0058, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2911 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0061, (cst_val *)&val_2912},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0062, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2914 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0065, (cst_val *)&val_0265},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0066, (cst_val *)&val_2915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2917 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_164_NO_0069, (cst_val *)&val_2918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2920 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_164_NO_0072, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2922 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_t_164_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_rms_f0_t_164_cart = {
  cmu_us_rms_f0_t_164_cart_nodes,
  cmu_us_rms_f0_t_164_feat_table
};

static const cst_cart_node cmu_us_rms_f0_t_165_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0001, (cst_val *)&val_0153},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0002, (cst_val *)&val_1125},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0003, (cst_val *)&val_2923},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0004, (cst_val *)&val_2924},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0005, (cst_val *)&val_0012},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0006, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2927 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0010, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0011, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2930 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0015, (cst_val *)&val_0111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2932 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0018, (cst_val *)&val_2933},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0019, (cst_val *)&val_2754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2935 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0022, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0023, (cst_val *)&val_2936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2937 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0025, (cst_val *)&val_2938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2941 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0029, (cst_val *)&val_2942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2944 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0032, (cst_val *)&val_1518},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0033, (cst_val *)&val_0042},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0034, (cst_val *)&val_2945},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0035, (cst_val *)&val_2946},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2949 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0039, (cst_val *)&val_0012},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0040, (cst_val *)&val_2950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2952 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0043, (cst_val *)&val_0449},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0044, (cst_val *)&val_2953},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0045, (cst_val *)&val_0666},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2955 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0048, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2958 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0052, (cst_val *)&val_2959},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0053, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2960 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0055, (cst_val *)&val_0731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2961 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0057, (cst_val *)&val_2962},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0058, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2964 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0061, (cst_val *)&val_0682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2966 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0064, (cst_val *)&val_1477},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0065, (cst_val *)&val_0111},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0066, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2967 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0068, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2969 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0071, (cst_val *)&val_2970},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0072, (cst_val *)&val_2584},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0073, (cst_val *)&val_0041},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0074, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2972 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0077, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2974 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_165_NO_0080, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2976 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_165_NO_0084, (cst_val *)&val_2977},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2979 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_t_165_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_rms_f0_t_165_cart = {
  cmu_us_rms_f0_t_165_cart_nodes,
  cmu_us_rms_f0_t_165_feat_table
};

static const cst_cart_node cmu_us_rms_f0_t_166_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0002, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2980 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0004, (cst_val *)&val_2981},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2982 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0006, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2984 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0009, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2985 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0011, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0013, (cst_val *)&val_2786},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0014, (cst_val *)&val_0153},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0015, (cst_val *)&val_0012},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0016, (cst_val *)&val_0283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2990 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0022, (cst_val *)&val_0017},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0023, (cst_val *)&val_2991},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0024, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2993 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0027, (cst_val *)&val_2994},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0028, (cst_val *)&val_0041},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0029, (cst_val *)&val_2995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2997 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0032, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3000 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0036, (cst_val *)&val_0061},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0037, (cst_val *)&val_3001},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0038, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3003 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0041, (cst_val *)&val_3004},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0042, (cst_val *)&val_3005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3008 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0046, (cst_val *)&val_3009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0047, (cst_val *)&val_0127},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0048, (cst_val *)&val_0727},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_t_166_NO_0049, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3012 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0053, (cst_val *)&val_3013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3015 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_t_166_NO_0056, (cst_val *)&val_3013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3017 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_t_166_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_t_166_cart = {
  cmu_us_rms_f0_t_166_cart_nodes,
  cmu_us_rms_f0_t_166_feat_table
};

static const cst_cart_node cmu_us_rms_f0_er_61_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0001, (cst_val *)&val_0427},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0002, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0003, (cst_val *)&val_3018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3019 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0005, (cst_val *)&val_0715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3021 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0008, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0009, (cst_val *)&val_0055},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0010, (cst_val *)&val_3022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3024 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0013, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3025 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0015, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3026 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0017, (cst_val *)&val_3027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3030 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0021, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0022, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0023, (cst_val *)&val_3031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3033 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0026, (cst_val *)&val_0012},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0027, (cst_val *)&val_3034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3035 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0029, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3036 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0031, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3038 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0034, (cst_val *)&val_3039},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0035, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3040 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0038, (cst_val *)&val_0126},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0039, (cst_val *)&val_3041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3043 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0042, (cst_val *)&val_3044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3046 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0045, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3048 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0048, (cst_val *)&val_3049},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0049, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0050, (cst_val *)&val_3050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3051 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0052, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3053 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0055, (cst_val *)&val_3054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3055 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0057, (cst_val *)&val_3056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3058 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0060, (cst_val *)&val_0085},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0061, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3060 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_61_NO_0064, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3061 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_61_NO_0066, (cst_val *)&val_3062},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3064 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_er_61_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_rms_f0_er_61_cart = {
  cmu_us_rms_f0_er_61_cart_nodes,
  cmu_us_rms_f0_er_61_feat_table
};

static const cst_cart_node cmu_us_rms_f0_er_62_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0001, (cst_val *)&val_3065},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0002, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0003, (cst_val *)&val_2051},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0004, (cst_val *)&val_1318},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0005, (cst_val *)&val_3066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3069 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0009, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3070 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0011, (cst_val *)&val_1477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3072 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0014, (cst_val *)&val_0017},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0015, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3074 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0018, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3076 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0021, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0022, (cst_val *)&val_3077},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0023, (cst_val *)&val_3078},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0024, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3079 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0026, (cst_val *)&val_3080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3082 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0029, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3084 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0032, (cst_val *)&val_3085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3086 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0034, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3087 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0036, (cst_val *)&val_0246},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0037, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3089 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0040, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3091 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0043, (cst_val *)&val_3092},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0044, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0045, (cst_val *)&val_1652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3093 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0047, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3096 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0051, (cst_val *)&val_3097},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0052, (cst_val *)&val_3098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3101 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0056, (cst_val *)&val_2532},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0057, (cst_val *)&val_3102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3103 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0059, (cst_val *)&val_0718},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0060, (cst_val *)&val_1935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3104 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0062, (cst_val *)&val_1477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3106 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0065, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3108 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_62_NO_0068, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3109 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_62_NO_0070, (cst_val *)&val_3110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3112 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_er_62_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_er_62_cart = {
  cmu_us_rms_f0_er_62_cart_nodes,
  cmu_us_rms_f0_er_62_feat_table
};

static const cst_cart_node cmu_us_rms_f0_er_63_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_63_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_63_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_63_NO_0002, (cst_val *)&val_0246},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0003, (cst_val *)&val_3113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3115 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0006, (cst_val *)&val_3116},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0007, (cst_val *)&val_3117},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_er_63_NO_0008, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3120 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0012, (cst_val *)&val_3121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3123 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0015, (cst_val *)&val_3124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3125 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0017, (cst_val *)&val_3126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3128 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0020, (cst_val *)&val_3129},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0021, (cst_val *)&val_1025},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_er_63_NO_0022, (cst_val *)&val_3130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3134 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_er_63_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_rms_f0_er_63_cart = {
  cmu_us_rms_f0_er_63_cart_nodes,
  cmu_us_rms_f0_er_63_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ax_26_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0002, (cst_val *)&val_0130},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0003, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3136 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0006, (cst_val *)&val_2493},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0007, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3137 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0009, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3139 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0011, (cst_val *)&val_1723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3140 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0013, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3142 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0016, (cst_val *)&val_3143},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0017, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3145 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0020, (cst_val *)&val_3146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3148 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0023, (cst_val *)&val_3149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3150 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0025, (cst_val *)&val_0041},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0026, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3152 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0029, (cst_val *)&val_0265},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0030, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3153 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0032, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3154 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0034, (cst_val *)&val_3155},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0035, (cst_val *)&val_3156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3158 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0039, (cst_val *)&val_3159},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0040, (cst_val *)&val_3160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3162 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0043, (cst_val *)&val_3163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3165 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0046, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0047, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3166 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_26_NO_0049, (cst_val *)&val_0098},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3168 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0052, (cst_val *)&val_3169},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_26_NO_0053, (cst_val *)&val_0757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3172 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ax_26_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_rms_f0_ax_26_cart = {
  cmu_us_rms_f0_ax_26_cart_nodes,
  cmu_us_rms_f0_ax_26_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ax_27_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0000, (cst_val *)&val_3173},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0001, (cst_val *)&val_3174},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0002, (cst_val *)&val_3175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3177 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0005, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3178 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0007, (cst_val *)&val_0259},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0008, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3181 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0012, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0013, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0014, (cst_val *)&val_2621},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0015, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3182 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0017, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3183 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0019, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3185 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0022, (cst_val *)&val_3186},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0023, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3188 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0026, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3189 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0028, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3191 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0031, (cst_val *)&val_0017},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0032, (cst_val *)&val_0012},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0033, (cst_val *)&val_0830},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0034, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3192 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0036, (cst_val *)&val_3193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3197 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0041, (cst_val *)&val_3198},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0042, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3199 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0044, (cst_val *)&val_3200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3202 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0047, (cst_val *)&val_3203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3204 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0049, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3206 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0052, (cst_val *)&val_3207},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0053, (cst_val *)&val_1548},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0054, (cst_val *)&val_0246},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3209 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0057, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3211 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_27_NO_0060, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3212 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_27_NO_0062, (cst_val *)&val_0425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3214 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ax_27_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_rms_f0_ax_27_cart = {
  cmu_us_rms_f0_ax_27_cart_nodes,
  cmu_us_rms_f0_ax_27_feat_table
};

static const cst_cart_node cmu_us_rms_f0_ax_28_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0001, (cst_val *)&val_3215},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3216 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0003, (cst_val *)&val_0212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3218 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0006, (cst_val *)&val_0041},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0007, (cst_val *)&val_3219},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0008, (cst_val *)&val_3220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3221 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0010, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0011, (cst_val *)&val_3222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3224 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0014, (cst_val *)&val_3225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3226 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0016, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3228 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0019, (cst_val *)&val_0246},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0020, (cst_val *)&val_0676},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0021, (cst_val *)&val_3229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3231 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0024, (cst_val *)&val_0017},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0025, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3232 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0027, (cst_val *)&val_3233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3235 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0030, (cst_val *)&val_3236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3238 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0033, (cst_val *)&val_0066},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0034, (cst_val *)&val_3239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3241 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0037, (cst_val *)&val_3242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3243 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0039, (cst_val *)&val_2289},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0040, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0041, (cst_val *)&val_3244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3246 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_rms_f0_ax_28_NO_0044, (cst_val *)&val_3247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3250 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0048, (cst_val *)&val_0246},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0049, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3251 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_rms_f0_ax_28_NO_0051, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3254 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_ax_28_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_rms_f0_ax_28_cart = {
  cmu_us_rms_f0_ax_28_cart_nodes,
  cmu_us_rms_f0_ax_28_feat_table
};

static const cst_cart_node cmu_us_rms_f0_pau_141_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_pau_141_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_pau_141_cart = {
  cmu_us_rms_f0_pau_141_cart_nodes,
  cmu_us_rms_f0_pau_141_feat_table
};

static const cst_cart_node cmu_us_rms_f0_pau_142_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_rms_f0_pau_142_feat_table[] = {
NULL };

const cst_cart cmu_us_rms_f0_pau_142_cart = {
  cmu_us_rms_f0_pau_142_cart_nodes,
  cmu_us_rms_f0_pau_142_feat_table
};


const cst_cart * const cmu_us_rms_f0_carts[] = {
 &cmu_us_rms_f0_zh_204_cart,
 &cmu_us_rms_f0_zh_205_cart,
 &cmu_us_rms_f0_zh_206_cart,
 &cmu_us_rms_f0_oy_131_cart,
 &cmu_us_rms_f0_oy_132_cart,
 &cmu_us_rms_f0_oy_133_cart,
 &cmu_us_rms_f0_ch_41_cart,
 &cmu_us_rms_f0_ch_42_cart,
 &cmu_us_rms_f0_ch_43_cart,
 &cmu_us_rms_f0_aw_21_cart,
 &cmu_us_rms_f0_aw_22_cart,
 &cmu_us_rms_f0_aw_23_cart,
 &cmu_us_rms_f0_ow_126_cart,
 &cmu_us_rms_f0_ow_127_cart,
 &cmu_us_rms_f0_ow_128_cart,
 &cmu_us_rms_f0_b_36_cart,
 &cmu_us_rms_f0_b_37_cart,
 &cmu_us_rms_f0_b_38_cart,
 &cmu_us_rms_f0_g_76_cart,
 &cmu_us_rms_f0_g_77_cart,
 &cmu_us_rms_f0_g_78_cart,
 &cmu_us_rms_f0_ng_121_cart,
 &cmu_us_rms_f0_ng_122_cart,
 &cmu_us_rms_f0_ng_123_cart,
 &cmu_us_rms_f0_uw_179_cart,
 &cmu_us_rms_f0_uw_180_cart,
 &cmu_us_rms_f0_uw_181_cart,
 &cmu_us_rms_f0_sh_156_cart,
 &cmu_us_rms_f0_sh_157_cart,
 &cmu_us_rms_f0_sh_158_cart,
 &cmu_us_rms_f0_uh_174_cart,
 &cmu_us_rms_f0_uh_175_cart,
 &cmu_us_rms_f0_uh_176_cart,
 &cmu_us_rms_f0_hh_81_cart,
 &cmu_us_rms_f0_hh_82_cart,
 &cmu_us_rms_f0_hh_83_cart,
 &cmu_us_rms_f0_ae_6_cart,
 &cmu_us_rms_f0_ae_7_cart,
 &cmu_us_rms_f0_ae_8_cart,
 &cmu_us_rms_f0_y_194_cart,
 &cmu_us_rms_f0_y_195_cart,
 &cmu_us_rms_f0_y_196_cart,
 &cmu_us_rms_f0_k_101_cart,
 &cmu_us_rms_f0_k_102_cart,
 &cmu_us_rms_f0_k_103_cart,
 &cmu_us_rms_f0_aa_1_cart,
 &cmu_us_rms_f0_aa_2_cart,
 &cmu_us_rms_f0_aa_3_cart,
 &cmu_us_rms_f0_ay_31_cart,
 &cmu_us_rms_f0_ay_32_cart,
 &cmu_us_rms_f0_ay_33_cart,
 &cmu_us_rms_f0_w_189_cart,
 &cmu_us_rms_f0_w_190_cart,
 &cmu_us_rms_f0_w_191_cart,
 &cmu_us_rms_f0_m_111_cart,
 &cmu_us_rms_f0_m_112_cart,
 &cmu_us_rms_f0_m_113_cart,
 &cmu_us_rms_f0_pau_143_cart,
 &cmu_us_rms_f0_ao_16_cart,
 &cmu_us_rms_f0_ao_17_cart,
 &cmu_us_rms_f0_ao_18_cart,
 &cmu_us_rms_f0_th_169_cart,
 &cmu_us_rms_f0_th_170_cart,
 &cmu_us_rms_f0_th_171_cart,
 &cmu_us_rms_f0_ah_11_cart,
 &cmu_us_rms_f0_ah_12_cart,
 &cmu_us_rms_f0_ah_13_cart,
 &cmu_us_rms_f0_v_184_cart,
 &cmu_us_rms_f0_v_185_cart,
 &cmu_us_rms_f0_v_186_cart,
 &cmu_us_rms_f0_dh_51_cart,
 &cmu_us_rms_f0_dh_52_cart,
 &cmu_us_rms_f0_dh_53_cart,
 &cmu_us_rms_f0_d_46_cart,
 &cmu_us_rms_f0_d_47_cart,
 &cmu_us_rms_f0_d_48_cart,
 &cmu_us_rms_f0_n_116_cart,
 &cmu_us_rms_f0_n_117_cart,
 &cmu_us_rms_f0_n_118_cart,
 &cmu_us_rms_f0_jh_96_cart,
 &cmu_us_rms_f0_jh_97_cart,
 &cmu_us_rms_f0_jh_98_cart,
 &cmu_us_rms_f0_r_146_cart,
 &cmu_us_rms_f0_r_147_cart,
 &cmu_us_rms_f0_r_148_cart,
 &cmu_us_rms_f0_ey_66_cart,
 &cmu_us_rms_f0_ey_67_cart,
 &cmu_us_rms_f0_ey_68_cart,
 &cmu_us_rms_f0_f_71_cart,
 &cmu_us_rms_f0_f_72_cart,
 &cmu_us_rms_f0_f_73_cart,
 &cmu_us_rms_f0_ih_86_cart,
 &cmu_us_rms_f0_ih_87_cart,
 &cmu_us_rms_f0_ih_88_cart,
 &cmu_us_rms_f0_p_136_cart,
 &cmu_us_rms_f0_p_137_cart,
 &cmu_us_rms_f0_p_138_cart,
 &cmu_us_rms_f0_iy_91_cart,
 &cmu_us_rms_f0_iy_92_cart,
 &cmu_us_rms_f0_iy_93_cart,
 &cmu_us_rms_f0_l_106_cart,
 &cmu_us_rms_f0_l_107_cart,
 &cmu_us_rms_f0_l_108_cart,
 &cmu_us_rms_f0_z_199_cart,
 &cmu_us_rms_f0_z_200_cart,
 &cmu_us_rms_f0_z_201_cart,
 &cmu_us_rms_f0_pau_161_cart,
 &cmu_us_rms_f0_s_151_cart,
 &cmu_us_rms_f0_s_152_cart,
 &cmu_us_rms_f0_s_153_cart,
 &cmu_us_rms_f0_eh_56_cart,
 &cmu_us_rms_f0_eh_57_cart,
 &cmu_us_rms_f0_eh_58_cart,
 &cmu_us_rms_f0_t_164_cart,
 &cmu_us_rms_f0_t_165_cart,
 &cmu_us_rms_f0_t_166_cart,
 &cmu_us_rms_f0_er_61_cart,
 &cmu_us_rms_f0_er_62_cart,
 &cmu_us_rms_f0_er_63_cart,
 &cmu_us_rms_f0_ax_26_cart,
 &cmu_us_rms_f0_ax_27_cart,
 &cmu_us_rms_f0_ax_28_cart,
 &cmu_us_rms_f0_pau_141_cart,
 &cmu_us_rms_f0_pau_142_cart,
 0 };
