/*****************************************************/
/**  Autogenerated cmu_us_awb f0 carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_awb_cg_f0_trees.h"

static const cst_cart_node cmu_us_awb_f0_zh_204_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0000 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_zh_204_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_zh_204_cart = {
  cmu_us_awb_f0_zh_204_cart_nodes,
  cmu_us_awb_f0_zh_204_feat_table
};

static const cst_cart_node cmu_us_awb_f0_zh_205_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0001 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_zh_205_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_zh_205_cart = {
  cmu_us_awb_f0_zh_205_cart_nodes,
  cmu_us_awb_f0_zh_205_feat_table
};

static const cst_cart_node cmu_us_awb_f0_zh_206_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_zh_206_NO_0000, (cst_val *)&val_0002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0004 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_zh_206_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_zh_206_cart = {
  cmu_us_awb_f0_zh_206_cart_nodes,
  cmu_us_awb_f0_zh_206_feat_table
};

static const cst_cart_node cmu_us_awb_f0_oy_131_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_131_NO_0000, (cst_val *)&val_0005},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_131_NO_0001, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_131_NO_0003, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_oy_131_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_oy_131_cart = {
  cmu_us_awb_f0_oy_131_cart_nodes,
  cmu_us_awb_f0_oy_131_feat_table
};

static const cst_cart_node cmu_us_awb_f0_oy_132_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_132_NO_0000, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_132_NO_0002, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_oy_132_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_oy_132_cart = {
  cmu_us_awb_f0_oy_132_cart_nodes,
  cmu_us_awb_f0_oy_132_feat_table
};

static const cst_cart_node cmu_us_awb_f0_oy_133_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_133_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_133_NO_0001, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_oy_133_NO_0004, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0023 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_oy_133_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_oy_133_cart = {
  cmu_us_awb_f0_oy_133_cart_nodes,
  cmu_us_awb_f0_oy_133_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ch_41_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_41_NO_0000, (cst_val *)&val_0024},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_41_NO_0001, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_41_NO_0004, (cst_val *)&val_0028},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_41_NO_0005, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_41_NO_0006, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_41_NO_0010, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ch_41_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_f0_ch_41_cart = {
  cmu_us_awb_f0_ch_41_cart_nodes,
  cmu_us_awb_f0_ch_41_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ch_42_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_42_NO_0000, (cst_val *)&val_0024},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_42_NO_0001, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_42_NO_0004, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_42_NO_0006, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0041 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ch_42_NO_0008, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_42_NO_0010, (cst_val *)&val_0044},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_42_NO_0011, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ch_42_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ch_42_cart = {
  cmu_us_awb_f0_ch_42_cart_nodes,
  cmu_us_awb_f0_ch_42_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ch_43_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_43_NO_0000, (cst_val *)&val_0049},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ch_43_NO_0001, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ch_43_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ch_43_cart = {
  cmu_us_awb_f0_ch_43_cart_nodes,
  cmu_us_awb_f0_ch_43_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aw_21_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_21_NO_0000, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_21_NO_0002, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_21_NO_0003, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_21_NO_0006, (cst_val *)&val_0058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aw_21_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_aw_21_cart = {
  cmu_us_awb_f0_aw_21_cart_nodes,
  cmu_us_awb_f0_aw_21_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aw_22_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_22_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0061 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0002, (cst_val *)&val_0062},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0003, (cst_val *)&val_0063},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0004, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0008, (cst_val *)&val_0068},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0009, (cst_val *)&val_0069},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_22_NO_0010, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_22_NO_0013, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0074 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_22_NO_0016, (cst_val *)&val_0075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aw_22_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_aw_22_cart = {
  cmu_us_awb_f0_aw_22_cart_nodes,
  cmu_us_awb_f0_aw_22_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aw_23_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_23_NO_0000, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_23_NO_0002, (cst_val *)&val_0079},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_23_NO_0003, (cst_val *)&val_0080},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aw_23_NO_0004, (cst_val *)&val_0081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aw_23_NO_0008, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aw_23_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_aw_23_cart = {
  cmu_us_awb_f0_aw_23_cart_nodes,
  cmu_us_awb_f0_aw_23_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ow_126_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_126_NO_0000, (cst_val *)&val_0088},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_126_NO_0001, (cst_val *)&val_0089},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_126_NO_0002, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_126_NO_0003, (cst_val *)&val_0090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_126_NO_0008, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_126_NO_0010, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_126_NO_0012, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ow_126_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_f0_ow_126_cart = {
  cmu_us_awb_f0_ow_126_cart_nodes,
  cmu_us_awb_f0_ow_126_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ow_127_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0000, (cst_val *)&val_0100},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0001, (cst_val *)&val_0101},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0002, (cst_val *)&val_0102},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0003, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0005, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0007, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0107 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0010, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0012, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0015, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0018, (cst_val *)&val_0115},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0019, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0021, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_127_NO_0023, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0121 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0026, (cst_val *)&val_0122},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_127_NO_0027, (cst_val *)&val_0123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ow_127_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ow_127_cart = {
  cmu_us_awb_f0_ow_127_cart_nodes,
  cmu_us_awb_f0_ow_127_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ow_128_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0000, (cst_val *)&val_0127},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0001, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0003, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0005, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0008, (cst_val *)&val_0042},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0009, (cst_val *)&val_0133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0012, (cst_val *)&val_0032},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0013, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0014, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0017, (cst_val *)&val_0139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0019, (cst_val *)&val_0141},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0020, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0022, (cst_val *)&val_0058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ow_128_NO_0024, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0146 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ow_128_NO_0027, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ow_128_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_f0_ow_128_cart = {
  cmu_us_awb_f0_ow_128_cart_nodes,
  cmu_us_awb_f0_ow_128_feat_table
};

static const cst_cart_node cmu_us_awb_f0_b_36_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0001, (cst_val *)&val_0151},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0002, (cst_val *)&val_0152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0006, (cst_val *)&val_0156},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0007, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0009, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0011, (cst_val *)&val_0159},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0012, (cst_val *)&val_0160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0015, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0016, (cst_val *)&val_0163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0166 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0020, (cst_val *)&val_0167},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0021, (cst_val *)&val_0032},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0022, (cst_val *)&val_0168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0171 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_36_NO_0026, (cst_val *)&val_0172},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_36_NO_0027, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_b_36_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_f0_b_36_cart = {
  cmu_us_awb_f0_b_36_cart_nodes,
  cmu_us_awb_f0_b_36_feat_table
};

static const cst_cart_node cmu_us_awb_f0_b_37_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_37_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_37_NO_0001, (cst_val *)&val_0176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0178 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_37_NO_0004, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_37_NO_0006, (cst_val *)&val_0181},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_37_NO_0007, (cst_val *)&val_0182},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_37_NO_0010, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_37_NO_0012, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0188 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_b_37_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_b_37_cart = {
  cmu_us_awb_f0_b_37_cart_nodes,
  cmu_us_awb_f0_b_37_feat_table
};

static const cst_cart_node cmu_us_awb_f0_b_38_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_38_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_38_NO_0001, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_b_38_NO_0004, (cst_val *)&val_0192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0193 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_b_38_NO_0006, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0195 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_b_38_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_b_38_cart = {
  cmu_us_awb_f0_b_38_cart_nodes,
  cmu_us_awb_f0_b_38_feat_table
};

static const cst_cart_node cmu_us_awb_f0_g_76_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_g_76_NO_0000, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0196 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_76_NO_0002, (cst_val *)&val_0156},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_76_NO_0003, (cst_val *)&val_0197},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_g_76_NO_0004, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_76_NO_0006, (cst_val *)&val_0199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_76_NO_0010, (cst_val *)&val_0203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0204 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_76_NO_0012, (cst_val *)&val_0205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_g_76_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_g_76_cart = {
  cmu_us_awb_f0_g_76_cart_nodes,
  cmu_us_awb_f0_g_76_feat_table
};

static const cst_cart_node cmu_us_awb_f0_g_77_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_77_NO_0000, (cst_val *)&val_0208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0209 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_77_NO_0002, (cst_val *)&val_0210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0212 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_g_77_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_g_77_cart = {
  cmu_us_awb_f0_g_77_cart_nodes,
  cmu_us_awb_f0_g_77_feat_table
};

static const cst_cart_node cmu_us_awb_f0_g_78_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_78_NO_0000, (cst_val *)&val_0213},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_g_78_NO_0001, (cst_val *)&val_0032},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_78_NO_0002, (cst_val *)&val_0214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_78_NO_0005, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_g_78_NO_0008, (cst_val *)&val_0220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_g_78_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_g_78_cart = {
  cmu_us_awb_f0_g_78_cart_nodes,
  cmu_us_awb_f0_g_78_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ng_121_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_121_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0223 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_121_NO_0002, (cst_val *)&val_0224},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_121_NO_0003, (cst_val *)&val_0225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_121_NO_0005, (cst_val *)&val_0227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_121_NO_0008, (cst_val *)&val_0230},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_121_NO_0009, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_121_NO_0010, (cst_val *)&val_0231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ng_121_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_ng_121_cart = {
  cmu_us_awb_f0_ng_121_cart_nodes,
  cmu_us_awb_f0_ng_121_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ng_122_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_122_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_122_NO_0001, (cst_val *)&val_0236},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_122_NO_0002, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_122_NO_0003, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_122_NO_0007, (cst_val *)&val_0241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0244 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ng_122_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ng_122_cart = {
  cmu_us_awb_f0_ng_122_cart_nodes,
  cmu_us_awb_f0_ng_122_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ng_123_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_123_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0245 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_123_NO_0002, (cst_val *)&val_0246},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_123_NO_0003, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0248 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_123_NO_0006, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0249 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_123_NO_0008, (cst_val *)&val_0250},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_123_NO_0009, (cst_val *)&val_0251},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ng_123_NO_0010, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0253 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ng_123_NO_0012, (cst_val *)&val_0254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ng_123_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
NULL };

const cst_cart cmu_us_awb_f0_ng_123_cart = {
  cmu_us_awb_f0_ng_123_cart_nodes,
  cmu_us_awb_f0_ng_123_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uw_179_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_179_NO_0000, (cst_val *)&val_0259},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_179_NO_0001, (cst_val *)&val_0260},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_179_NO_0002, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0261 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_179_NO_0004, (cst_val *)&val_0262},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0264 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_179_NO_0007, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_179_NO_0010, (cst_val *)&val_0268},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0270 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uw_179_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_uw_179_cart = {
  cmu_us_awb_f0_uw_179_cart_nodes,
  cmu_us_awb_f0_uw_179_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uw_180_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_180_NO_0000, (cst_val *)&val_0271},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_180_NO_0001, (cst_val *)&val_0272},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_180_NO_0002, (cst_val *)&val_0089},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_180_NO_0003, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_180_NO_0006, (cst_val *)&val_0276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0278 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_180_NO_0009, (cst_val *)&val_0112},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_180_NO_0010, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_180_NO_0014, (cst_val *)&val_0282},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_180_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uw_180_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_f0_uw_180_cart = {
  cmu_us_awb_f0_uw_180_cart_nodes,
  cmu_us_awb_f0_uw_180_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uw_181_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_181_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_181_NO_0001, (cst_val *)&val_0286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_181_NO_0003, (cst_val *)&val_0288},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_181_NO_0004, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0289 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_181_NO_0006, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0291 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_181_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uw_181_NO_0011, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_181_NO_0012, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0295 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uw_181_NO_0016, (cst_val *)&val_0296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uw_181_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_uw_181_cart = {
  cmu_us_awb_f0_uw_181_cart_nodes,
  cmu_us_awb_f0_uw_181_feat_table
};

static const cst_cart_node cmu_us_awb_f0_sh_156_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_156_NO_0000, (cst_val *)&val_0299},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_156_NO_0001, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_156_NO_0004, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_sh_156_feat_table[] = {
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_sh_156_cart = {
  cmu_us_awb_f0_sh_156_cart_nodes,
  cmu_us_awb_f0_sh_156_feat_table
};

static const cst_cart_node cmu_us_awb_f0_sh_157_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0001, (cst_val *)&val_0136},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0002, (cst_val *)&val_0305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0005, (cst_val *)&val_0308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0008, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0010, (cst_val *)&val_0079},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0011, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0012, (cst_val *)&val_0032},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0314 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0016, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0318 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_157_NO_0020, (cst_val *)&val_0128},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0021, (cst_val *)&val_0319},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0022, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0323 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_157_NO_0026, (cst_val *)&val_0324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_sh_157_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_awb_f0_sh_157_cart = {
  cmu_us_awb_f0_sh_157_cart_nodes,
  cmu_us_awb_f0_sh_157_feat_table
};

static const cst_cart_node cmu_us_awb_f0_sh_158_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_158_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_158_NO_0001, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0328 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_158_NO_0004, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0330 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_158_NO_0006, (cst_val *)&val_0331},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_sh_158_NO_0007, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_sh_158_NO_0009, (cst_val *)&val_0333},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_sh_158_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_f0_sh_158_cart = {
  cmu_us_awb_f0_sh_158_cart_nodes,
  cmu_us_awb_f0_sh_158_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uh_174_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uh_174_NO_0000, (cst_val *)&val_0337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0339 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uh_174_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_uh_174_cart = {
  cmu_us_awb_f0_uh_174_cart_nodes,
  cmu_us_awb_f0_uh_174_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uh_175_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uh_175_NO_0000, (cst_val *)&val_0340},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uh_175_NO_0001, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_uh_175_NO_0004, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0345 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uh_175_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_uh_175_cart = {
  cmu_us_awb_f0_uh_175_cart_nodes,
  cmu_us_awb_f0_uh_175_feat_table
};

static const cst_cart_node cmu_us_awb_f0_uh_176_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_uh_176_NO_0000, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_uh_176_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_uh_176_cart = {
  cmu_us_awb_f0_uh_176_cart_nodes,
  cmu_us_awb_f0_uh_176_feat_table
};

static const cst_cart_node cmu_us_awb_f0_hh_81_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0000, (cst_val *)&val_0349},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0001, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0004, (cst_val *)&val_0353},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0005, (cst_val *)&val_0354},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0006, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0357 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_81_NO_0009, (cst_val *)&val_0089},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_81_NO_0010, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0359 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0013, (cst_val *)&val_0360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0362 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0016, (cst_val *)&val_0363},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_81_NO_0017, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0366 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_hh_81_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_hh_81_cart = {
  cmu_us_awb_f0_hh_81_cart_nodes,
  cmu_us_awb_f0_hh_81_feat_table
};

static const cst_cart_node cmu_us_awb_f0_hh_82_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0000, (cst_val *)&val_0367},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0001, (cst_val *)&val_0368},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0002, (cst_val *)&val_0369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0371 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0005, (cst_val *)&val_0372},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0374 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0008, (cst_val *)&val_0375},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_82_NO_0009, (cst_val *)&val_0079},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0010, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0379 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_82_NO_0014, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0380 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_82_NO_0016, (cst_val *)&val_0024},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_82_NO_0017, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0383 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_hh_82_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_f0_hh_82_cart = {
  cmu_us_awb_f0_hh_82_cart_nodes,
  cmu_us_awb_f0_hh_82_feat_table
};

static const cst_cart_node cmu_us_awb_f0_hh_83_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0000, (cst_val *)&val_0384},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0001, (cst_val *)&val_0385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0386 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0003, (cst_val *)&val_0387},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_83_NO_0004, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0390 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0008, (cst_val *)&val_0391},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0009, (cst_val *)&val_0392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0393 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_hh_83_NO_0011, (cst_val *)&val_0394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0396 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_83_NO_0014, (cst_val *)&val_0397},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_83_NO_0015, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0399 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_hh_83_NO_0018, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0401 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_hh_83_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_hh_83_cart = {
  cmu_us_awb_f0_hh_83_cart_nodes,
  cmu_us_awb_f0_hh_83_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ae_6_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0000, (cst_val *)&val_0402},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0001, (cst_val *)&val_0403},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0002, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0406 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0006, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0407 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0008, (cst_val *)&val_0408},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0409 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0011, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0411 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0014, (cst_val *)&val_0089},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0015, (cst_val *)&val_0412},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0016, (cst_val *)&val_0413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0415 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0019, (cst_val *)&val_0416},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_6_NO_0020, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0419 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_6_NO_0024, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0422 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ae_6_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_ae_6_cart = {
  cmu_us_awb_f0_ae_6_cart_nodes,
  cmu_us_awb_f0_ae_6_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ae_7_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0000, (cst_val *)&val_0423},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0001, (cst_val *)&val_0032},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0002, (cst_val *)&val_0424},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0003, (cst_val *)&val_0425},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0004, (cst_val *)&val_0426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0427 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0006, (cst_val *)&val_0428},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0430 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0009, (cst_val *)&val_0431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0433 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0012, (cst_val *)&val_0434},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0013, (cst_val *)&val_0435},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0014, (cst_val *)&val_0436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0440 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0019, (cst_val *)&val_0441},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0020, (cst_val *)&val_0442},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0021, (cst_val *)&val_0443},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0022, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0445 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0025, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0448 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0029, (cst_val *)&val_0449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0450 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0031, (cst_val *)&val_0451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0453 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0034, (cst_val *)&val_0416},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0035, (cst_val *)&val_0454},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0036, (cst_val *)&val_0079},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0037, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0455 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0039, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0042, (cst_val *)&val_0040},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0043, (cst_val *)&val_0224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0459 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0046, (cst_val *)&val_0460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0463 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0050, (cst_val *)&val_0464},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0051, (cst_val *)&val_0108},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0052, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0466 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0054, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0467 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0056, (cst_val *)&val_0468},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0057, (cst_val *)&val_0032},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0058, (cst_val *)&val_0112},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0059, (cst_val *)&val_0469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0471 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0062, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0473 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0065, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0477 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0069, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0479 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0071, (cst_val *)&val_0141},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0072, (cst_val *)&val_0480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0483 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0076, (cst_val *)&val_0072},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0077, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0485 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0080, (cst_val *)&val_0486},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_7_NO_0081, (cst_val *)&val_0487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0489 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_7_NO_0084, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0491 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ae_7_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_ae_7_cart = {
  cmu_us_awb_f0_ae_7_cart_nodes,
  cmu_us_awb_f0_ae_7_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ae_8_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0001, (cst_val *)&val_0355},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0002, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0494 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0005, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0496 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0008, (cst_val *)&val_0497},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0009, (cst_val *)&val_0118},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0010, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0011, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0500 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0015, (cst_val *)&val_0501},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0016, (cst_val *)&val_0502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0505 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0020, (cst_val *)&val_0506},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0021, (cst_val *)&val_0507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0509 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ae_8_NO_0024, (cst_val *)&val_0492},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0025, (cst_val *)&val_0510},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0026, (cst_val *)&val_0511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0513 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0029, (cst_val *)&val_0514},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0030, (cst_val *)&val_0515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0517 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0033, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0519 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0036, (cst_val *)&val_0520},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0037, (cst_val *)&val_0521},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0038, (cst_val *)&val_0522},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0039, (cst_val *)&val_0523},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0525 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0042, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0527 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ae_8_NO_0044, (cst_val *)&val_0528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0532 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ae_8_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_ae_8_cart = {
  cmu_us_awb_f0_ae_8_cart_nodes,
  cmu_us_awb_f0_ae_8_feat_table
};

static const cst_cart_node cmu_us_awb_f0_y_194_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_y_194_NO_0000, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0533 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_194_NO_0002, (cst_val *)&val_0534},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_194_NO_0003, (cst_val *)&val_0535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0536 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_y_194_NO_0005, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0538 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_194_NO_0008, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0540 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_y_194_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_f0_y_194_cart = {
  cmu_us_awb_f0_y_194_cart_nodes,
  cmu_us_awb_f0_y_194_feat_table
};

static const cst_cart_node cmu_us_awb_f0_y_195_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_195_NO_0000, (cst_val *)&val_0541},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_195_NO_0001, (cst_val *)&val_0542},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_195_NO_0002, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0546 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_y_195_NO_0006, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0547 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_195_NO_0008, (cst_val *)&val_0548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0550 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_y_195_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_y_195_cart = {
  cmu_us_awb_f0_y_195_cart_nodes,
  cmu_us_awb_f0_y_195_feat_table
};

static const cst_cart_node cmu_us_awb_f0_y_196_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_196_NO_0000, (cst_val *)&val_0551},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_196_NO_0001, (cst_val *)&val_0552},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_196_NO_0002, (cst_val *)&val_0553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0555 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_y_196_NO_0005, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0557 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_y_196_NO_0008, (cst_val *)&val_0558},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_y_196_NO_0009, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0561 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_y_196_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_f0_y_196_cart = {
  cmu_us_awb_f0_y_196_cart_nodes,
  cmu_us_awb_f0_y_196_feat_table
};

static const cst_cart_node cmu_us_awb_f0_k_101_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0001, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0563 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0004, (cst_val *)&val_0025},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0005, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0565 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_101_NO_0008, (cst_val *)&val_0566},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_101_NO_0009, (cst_val *)&val_0213},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_101_NO_0010, (cst_val *)&val_0567},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_101_NO_0011, (cst_val *)&val_0413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0570 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0015, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0572 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_101_NO_0018, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0574 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_k_101_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_k_101_cart = {
  cmu_us_awb_f0_k_101_cart_nodes,
  cmu_us_awb_f0_k_101_feat_table
};

static const cst_cart_node cmu_us_awb_f0_k_102_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0001, (cst_val *)&val_0575},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0002, (cst_val *)&val_0576},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0003, (cst_val *)&val_0577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0578 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0005, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0580 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0008, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0584 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0012, (cst_val *)&val_0576},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0013, (cst_val *)&val_0032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0014, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0586 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0017, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0587 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0019, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0588 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0021, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0589 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0023, (cst_val *)&val_0590},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0024, (cst_val *)&val_0591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0592 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0026, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0594 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0029, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0596 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0032, (cst_val *)&val_0210},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0033, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0598 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_102_NO_0035, (cst_val *)&val_0599},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0600 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_102_NO_0038, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0602 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_k_102_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_awb_f0_k_102_cart = {
  cmu_us_awb_f0_k_102_cart_nodes,
  cmu_us_awb_f0_k_102_feat_table
};

static const cst_cart_node cmu_us_awb_f0_k_103_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_103_NO_0000, (cst_val *)&val_0603},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0001, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0002, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0604 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0004, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0005, (cst_val *)&val_0397},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0006, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0606 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_103_NO_0009, (cst_val *)&val_0607},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0610 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0013, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_103_NO_0014, (cst_val *)&val_0611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0613 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0017, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0614 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0019, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0615 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0021, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0616 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0023, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0619 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0026, (cst_val *)&val_0042},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0027, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0621 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_103_NO_0030, (cst_val *)&val_0622},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0031, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0624 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_k_103_NO_0034, (cst_val *)&val_0625},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0035, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0627 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_k_103_NO_0038, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0629 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_k_103_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_f0_k_103_cart = {
  cmu_us_awb_f0_k_103_cart_nodes,
  cmu_us_awb_f0_k_103_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aa_1_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_1_NO_0000, (cst_val *)&val_0630},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_1_NO_0001, (cst_val *)&val_0631},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_1_NO_0002, (cst_val *)&val_0632},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0634 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_1_NO_0005, (cst_val *)&val_0635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0637 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_1_NO_0008, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0638 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_1_NO_0010, (cst_val *)&val_0639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0640 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_1_NO_0012, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0642 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aa_1_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_aa_1_cart = {
  cmu_us_awb_f0_aa_1_cart_nodes,
  cmu_us_awb_f0_aa_1_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aa_2_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0000, (cst_val *)&val_0643},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0001, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0002, (cst_val *)&val_0644},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0003, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0004, (cst_val *)&val_0645},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0649 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0009, (cst_val *)&val_0650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0651 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0011, (cst_val *)&val_0652},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0012, (cst_val *)&val_0079},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0013, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0016, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0657 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0020, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0658 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0022, (cst_val *)&val_0311},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0023, (cst_val *)&val_0659},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0024, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0661 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0027, (cst_val *)&val_0662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0664 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0030, (cst_val *)&val_0089},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0031, (cst_val *)&val_0665},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0032, (cst_val *)&val_0112},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0033, (cst_val *)&val_0112},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0034, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0669 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_2_NO_0039, (cst_val *)&val_0670},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0040, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0671 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0042, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0674 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_2_NO_0046, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0676 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aa_2_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_aa_2_cart = {
  cmu_us_awb_f0_aa_2_cart_nodes,
  cmu_us_awb_f0_aa_2_feat_table
};

static const cst_cart_node cmu_us_awb_f0_aa_3_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0001, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0677 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0003, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0679 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0006, (cst_val *)&val_0680},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0007, (cst_val *)&val_0681},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0008, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0684 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0012, (cst_val *)&val_0685},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0013, (cst_val *)&val_0686},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0014, (cst_val *)&val_0025},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0688 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0018, (cst_val *)&val_0689},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0019, (cst_val *)&val_0690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0691 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0021, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0693 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_aa_3_NO_0025, (cst_val *)&val_0694},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0026, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0697 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0030, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0698 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_aa_3_NO_0032, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0700 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_aa_3_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_aa_3_cart = {
  cmu_us_awb_f0_aa_3_cart_nodes,
  cmu_us_awb_f0_aa_3_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ay_31_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0001, (cst_val *)&val_0701},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0002, (cst_val *)&val_0702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0703 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0004, (cst_val *)&val_0704},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0005, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0707 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0008, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0709 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0011, (cst_val *)&val_0710},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0712 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0014, (cst_val *)&val_0713},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0015, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0016, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0715 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0018, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0718 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0021, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0719 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0023, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0720 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0025, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0722 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0028, (cst_val *)&val_0723},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0029, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0724 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0031, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0725 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0033, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0034, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0728 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0037, (cst_val *)&val_0729},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_31_NO_0038, (cst_val *)&val_0730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0733 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0042, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0734 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0044, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0735 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0046, (cst_val *)&val_0079},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_31_NO_0047, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0738 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ay_31_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_ay_31_cart = {
  cmu_us_awb_f0_ay_31_cart_nodes,
  cmu_us_awb_f0_ay_31_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ay_32_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0000, (cst_val *)&val_0739},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0001, (cst_val *)&val_0740},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0002, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0003, (cst_val *)&val_0690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0741 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0005, (cst_val *)&val_0742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0744 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0008, (cst_val *)&val_0108},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0009, (cst_val *)&val_0745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0748 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0013, (cst_val *)&val_0749},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0014, (cst_val *)&val_0750},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0751 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0016, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0753 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0019, (cst_val *)&val_0754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0756 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0022, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0023, (cst_val *)&val_0757},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0024, (cst_val *)&val_0758},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0761 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0028, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0029, (cst_val *)&val_0762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0763 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0031, (cst_val *)&val_0764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0766 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0034, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0767 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_32_NO_0036, (cst_val *)&val_0112},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0037, (cst_val *)&val_0768},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0770 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_32_NO_0040, (cst_val *)&val_0771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0773 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ay_32_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_ay_32_cart = {
  cmu_us_awb_f0_ay_32_cart_nodes,
  cmu_us_awb_f0_ay_32_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ay_33_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0001, (cst_val *)&val_0774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0775 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0003, (cst_val *)&val_0776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0778 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0006, (cst_val *)&val_0779},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0007, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0008, (cst_val *)&val_0780},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0009, (cst_val *)&val_0750},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0781 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0011, (cst_val *)&val_0782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0784 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0785 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0017, (cst_val *)&val_0786},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0018, (cst_val *)&val_0787},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0019, (cst_val *)&val_0788},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0792 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0024, (cst_val *)&val_0793},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0025, (cst_val *)&val_0794},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0026, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0027, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0795 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0029, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0797 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0032, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0798 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0034, (cst_val *)&val_0799},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0035, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0036, (cst_val *)&val_0800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0803 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0040, (cst_val *)&val_0804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0806 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ay_33_NO_0043, (cst_val *)&val_0807},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0809 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ay_33_NO_0046, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0811 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ay_33_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_f0_ay_33_cart = {
  cmu_us_awb_f0_ay_33_cart_nodes,
  cmu_us_awb_f0_ay_33_feat_table
};

static const cst_cart_node cmu_us_awb_f0_w_189_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0000, (cst_val *)&val_0331},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0001, (cst_val *)&val_0812},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_189_NO_0002, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0814 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_189_NO_0005, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0815 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0007, (cst_val *)&val_0816},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_189_NO_0008, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0818 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_189_NO_0011, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0819 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0013, (cst_val *)&val_0820},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0822 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0016, (cst_val *)&val_0115},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_189_NO_0017, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0824 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0020, (cst_val *)&val_0825},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0021, (cst_val *)&val_0826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0828 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_189_NO_0024, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0830 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_w_189_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_f0_w_189_cart = {
  cmu_us_awb_f0_w_189_cart_nodes,
  cmu_us_awb_f0_w_189_feat_table
};

static const cst_cart_node cmu_us_awb_f0_w_190_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0000, (cst_val *)&val_0831},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0001, (cst_val *)&val_0832},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0002, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0834 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0005, (cst_val *)&val_0835},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0006, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0836 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0008, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0009, (cst_val *)&val_0837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0841 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0014, (cst_val *)&val_0842},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0015, (cst_val *)&val_0843},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0016, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0844 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0018, (cst_val *)&val_0079},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0019, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0847 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0023, (cst_val *)&val_0434},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0024, (cst_val *)&val_0024},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0025, (cst_val *)&val_0848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0850 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0028, (cst_val *)&val_0851},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0029, (cst_val *)&val_0754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0852 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0031, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0856 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_190_NO_0035, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0858 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0038, (cst_val *)&val_0859},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_190_NO_0039, (cst_val *)&val_0860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0863 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_w_190_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_w_190_cart = {
  cmu_us_awb_f0_w_190_cart_nodes,
  cmu_us_awb_f0_w_190_feat_table
};

static const cst_cart_node cmu_us_awb_f0_w_191_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0000, (cst_val *)&val_0864},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0001, (cst_val *)&val_0865},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0002, (cst_val *)&val_0754},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_191_NO_0003, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0866 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0005, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0870 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_191_NO_0009, (cst_val *)&val_0079},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0010, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0872 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0013, (cst_val *)&val_0873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0875 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0016, (cst_val *)&val_0876},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_191_NO_0017, (cst_val *)&val_0434},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_w_191_NO_0018, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0877 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_w_191_NO_0020, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0882 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_w_191_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_f0_w_191_cart = {
  cmu_us_awb_f0_w_191_cart_nodes,
  cmu_us_awb_f0_w_191_feat_table
};

static const cst_cart_node cmu_us_awb_f0_m_111_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_111_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_111_NO_0001, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0883 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0003, (cst_val *)&val_0884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0886 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0006, (cst_val *)&val_0887},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0007, (cst_val *)&val_0888},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_111_NO_0008, (cst_val *)&val_0112},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0009, (cst_val *)&val_0889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_111_NO_0012, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_111_NO_0015, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0892 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0017, (cst_val *)&val_0893},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0018, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0897 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_111_NO_0022, (cst_val *)&val_0898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0899 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_m_111_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_m_111_cart = {
  cmu_us_awb_f0_m_111_cart_nodes,
  cmu_us_awb_f0_m_111_feat_table
};

static const cst_cart_node cmu_us_awb_f0_m_112_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0000, (cst_val *)&val_0900},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0001, (cst_val *)&val_0901},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0002, (cst_val *)&val_0376},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0003, (cst_val *)&val_0902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0903 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0005, (cst_val *)&val_0904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0907 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0009, (cst_val *)&val_0908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0910 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0012, (cst_val *)&val_0911},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_112_NO_0013, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0014, (cst_val *)&val_0912},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_112_NO_0015, (cst_val *)&val_0108},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_112_NO_0016, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0913 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0018, (cst_val *)&val_0192},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_112_NO_0019, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0914 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0021, (cst_val *)&val_0915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0918 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_112_NO_0025, (cst_val *)&val_0919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0921 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_112_NO_0028, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0925 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_m_112_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_f0_m_112_cart = {
  cmu_us_awb_f0_m_112_cart_nodes,
  cmu_us_awb_f0_m_112_feat_table
};

static const cst_cart_node cmu_us_awb_f0_m_113_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_113_NO_0001, (cst_val *)&val_0926},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_113_NO_0002, (cst_val *)&val_0265},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0003, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0927 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0005, (cst_val *)&val_0112},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_113_NO_0006, (cst_val *)&val_0928},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0007, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0932 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0012, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0934 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0015, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0935 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_113_NO_0017, (cst_val *)&val_0936},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0018, (cst_val *)&val_0108},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0019, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0939 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_m_113_NO_0023, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0941 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_m_113_NO_0026, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0943 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_m_113_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_awb_f0_m_113_cart = {
  cmu_us_awb_f0_m_113_cart_nodes,
  cmu_us_awb_f0_m_113_feat_table
};

static const cst_cart_node cmu_us_awb_f0_pau_142_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_pau_142_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_pau_142_cart = {
  cmu_us_awb_f0_pau_142_cart_nodes,
  cmu_us_awb_f0_pau_142_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ao_16_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0000, (cst_val *)&val_0945},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_16_NO_0001, (cst_val *)&val_0946},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0947 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0003, (cst_val *)&val_0948},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0004, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0951 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0007, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0953 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_16_NO_0009, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0955 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0012, (cst_val *)&val_0956},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_16_NO_0013, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0960 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ao_16_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ao_16_cart = {
  cmu_us_awb_f0_ao_16_cart_nodes,
  cmu_us_awb_f0_ao_16_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ao_17_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0000, (cst_val *)&val_0961},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0001, (cst_val *)&val_0962},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0002, (cst_val *)&val_0032},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0003, (cst_val *)&val_0963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0965 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0006, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0966 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0008, (cst_val *)&val_0152},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0009, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0970 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0013, (cst_val *)&val_0971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0973 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0016, (cst_val *)&val_0974},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0017, (cst_val *)&val_0142},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0018, (cst_val *)&val_0975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0977 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_17_NO_0021, (cst_val *)&val_0978},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0022, (cst_val *)&val_0434},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0023, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0981 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0027, (cst_val *)&val_0079},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0028, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0983 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_17_NO_0031, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0986 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ao_17_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_ao_17_cart = {
  cmu_us_awb_f0_ao_17_cart_nodes,
  cmu_us_awb_f0_ao_17_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ao_18_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0001, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0002, (cst_val *)&val_0987},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0003, (cst_val *)&val_0988},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0991 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0007, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0994 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0010, (cst_val *)&val_0995},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0011, (cst_val *)&val_0996},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0012, (cst_val *)&val_0079},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0013, (cst_val *)&val_0997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0999 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0016, (cst_val *)&val_1000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1002 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0019, (cst_val *)&val_1003},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0020, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1004 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0022, (cst_val *)&val_1005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1006 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0024, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1009 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0028, (cst_val *)&val_1010},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ao_18_NO_0029, (cst_val *)&val_0025},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0030, (cst_val *)&val_1011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1013 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ao_18_NO_0033, (cst_val *)&val_1014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1017 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ao_18_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_ao_18_cart = {
  cmu_us_awb_f0_ao_18_cart_nodes,
  cmu_us_awb_f0_ao_18_feat_table
};

static const cst_cart_node cmu_us_awb_f0_th_169_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_169_NO_0000, (cst_val *)&val_1018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1019 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_169_NO_0002, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1022 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_th_169_feat_table[] = {
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_th_169_cart = {
  cmu_us_awb_f0_th_169_cart_nodes,
  cmu_us_awb_f0_th_169_feat_table
};

static const cst_cart_node cmu_us_awb_f0_th_170_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_170_NO_0000, (cst_val *)&val_1023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1024 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_170_NO_0002, (cst_val *)&val_1025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_170_NO_0003, (cst_val *)&val_1026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1027 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_th_170_NO_0005, (cst_val *)&val_0079},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_th_170_NO_0006, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1029 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_170_NO_0009, (cst_val *)&val_1030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1033 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_th_170_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_f0_th_170_cart = {
  cmu_us_awb_f0_th_170_cart_nodes,
  cmu_us_awb_f0_th_170_feat_table
};

static const cst_cart_node cmu_us_awb_f0_th_171_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_th_171_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_th_171_NO_0001, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1035 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_171_NO_0004, (cst_val *)&val_1036},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_171_NO_0005, (cst_val *)&val_1037},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_th_171_NO_0006, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1041 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_th_171_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_th_171_cart = {
  cmu_us_awb_f0_th_171_cart_nodes,
  cmu_us_awb_f0_th_171_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ah_11_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_11_NO_0000, (cst_val *)&val_1042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_11_NO_0001, (cst_val *)&val_0079},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_11_NO_0002, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1043 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_11_NO_0004, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1045 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_11_NO_0007, (cst_val *)&val_1046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1048 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_11_NO_0010, (cst_val *)&val_1049},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_11_NO_0011, (cst_val *)&val_0079},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_11_NO_0012, (cst_val *)&val_0553},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_11_NO_0013, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1054 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ah_11_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_f0_ah_11_cart = {
  cmu_us_awb_f0_ah_11_cart_nodes,
  cmu_us_awb_f0_ah_11_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ah_12_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0000, (cst_val *)&val_1055},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0001, (cst_val *)&val_0079},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0002, (cst_val *)&val_1056},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0003, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0004, (cst_val *)&val_1057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1059 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0007, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1060 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0009, (cst_val *)&val_1061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1064 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0013, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1066 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0015, (cst_val *)&val_1067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1069 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0018, (cst_val *)&val_1070},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0019, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0020, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1072 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0023, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1073 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0025, (cst_val *)&val_1074},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0026, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1077 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_12_NO_0030, (cst_val *)&val_1078},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_12_NO_0031, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1081 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ah_12_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_f0_ah_12_cart = {
  cmu_us_awb_f0_ah_12_cart_nodes,
  cmu_us_awb_f0_ah_12_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ah_13_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_13_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1082 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_13_NO_0002, (cst_val *)&val_1083},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_13_NO_0003, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1085 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_13_NO_0006, (cst_val *)&val_0118},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_13_NO_0007, (cst_val *)&val_1086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1088 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_13_NO_0010, (cst_val *)&val_1089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1090 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_13_NO_0012, (cst_val *)&val_1091},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ah_13_NO_0013, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1093 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ah_13_NO_0016, (cst_val *)&val_1094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1096 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ah_13_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_ah_13_cart = {
  cmu_us_awb_f0_ah_13_cart_nodes,
  cmu_us_awb_f0_ah_13_feat_table
};

static const cst_cart_node cmu_us_awb_f0_v_184_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_184_NO_0000, (cst_val *)&val_1097},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_184_NO_0001, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1099 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_184_NO_0004, (cst_val *)&val_1100},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_184_NO_0005, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1101 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_184_NO_0007, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1104 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_v_184_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_awb_f0_v_184_cart = {
  cmu_us_awb_f0_v_184_cart_nodes,
  cmu_us_awb_f0_v_184_feat_table
};

static const cst_cart_node cmu_us_awb_f0_v_185_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_185_NO_0000, (cst_val *)&val_1105},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_185_NO_0001, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1106 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_185_NO_0003, (cst_val *)&val_1107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1109 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_185_NO_0006, (cst_val *)&val_1110},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_185_NO_0007, (cst_val *)&val_1111},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_185_NO_0008, (cst_val *)&val_1112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1116 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_v_185_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_v_185_cart = {
  cmu_us_awb_f0_v_185_cart_nodes,
  cmu_us_awb_f0_v_185_feat_table
};

static const cst_cart_node cmu_us_awb_f0_v_186_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_186_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1117 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0002, (cst_val *)&val_1118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1119 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_186_NO_0004, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0005, (cst_val *)&val_1120},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0006, (cst_val *)&val_0420},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0007, (cst_val *)&val_1121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1123 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0010, (cst_val *)&val_1124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1126 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_v_186_NO_0013, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1127 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_v_186_NO_0015, (cst_val *)&val_1128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1130 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_v_186_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_awb_f0_v_186_cart = {
  cmu_us_awb_f0_v_186_cart_nodes,
  cmu_us_awb_f0_v_186_feat_table
};

static const cst_cart_node cmu_us_awb_f0_dh_51_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_51_NO_0000, (cst_val *)&val_1131},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0001, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0002, (cst_val *)&val_1132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1135 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0006, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1136 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_51_NO_0008, (cst_val *)&val_1137},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0009, (cst_val *)&val_1138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1139 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_51_NO_0011, (cst_val *)&val_1140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1141 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1143 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_51_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1145 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_dh_51_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_f0_dh_51_cart = {
  cmu_us_awb_f0_dh_51_cart_nodes,
  cmu_us_awb_f0_dh_51_feat_table
};

static const cst_cart_node cmu_us_awb_f0_dh_52_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_52_NO_0000, (cst_val *)&val_1146},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_52_NO_0001, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_52_NO_0002, (cst_val *)&val_1147},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_52_NO_0003, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1148 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_52_NO_0005, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1150 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_52_NO_0008, (cst_val *)&val_1151},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_52_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1155 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_52_NO_0014, (cst_val *)&val_0376},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_52_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1156 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_52_NO_0017, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1159 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_dh_52_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_dh_52_cart = {
  cmu_us_awb_f0_dh_52_cart_nodes,
  cmu_us_awb_f0_dh_52_feat_table
};

static const cst_cart_node cmu_us_awb_f0_dh_53_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_53_NO_0000, (cst_val *)&val_1160},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_53_NO_0001, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1161 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_53_NO_0003, (cst_val *)&val_1162},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_53_NO_0004, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1165 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_dh_53_NO_0008, (cst_val *)&val_1166},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_53_NO_0009, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1167 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_dh_53_NO_0011, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_dh_53_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_f0_dh_53_cart = {
  cmu_us_awb_f0_dh_53_cart_nodes,
  cmu_us_awb_f0_dh_53_feat_table
};

static const cst_cart_node cmu_us_awb_f0_d_46_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0001, (cst_val *)&val_1171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1172 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0003, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1174 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0006, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1175 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0008, (cst_val *)&val_1176},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0009, (cst_val *)&val_0032},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0010, (cst_val *)&val_1177},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0011, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1179 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0014, (cst_val *)&val_1180},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1182 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0017, (cst_val *)&val_1183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1185 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0020, (cst_val *)&val_0025},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0021, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1186 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0023, (cst_val *)&val_1187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1189 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0026, (cst_val *)&val_1190},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0027, (cst_val *)&val_1191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1192 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_46_NO_0029, (cst_val *)&val_1193},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0030, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1196 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_46_NO_0034, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1198 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_d_46_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_f0_d_46_cart = {
  cmu_us_awb_f0_d_46_cart_nodes,
  cmu_us_awb_f0_d_46_feat_table
};

static const cst_cart_node cmu_us_awb_f0_d_47_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0001, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0002, (cst_val *)&val_1199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1200 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0004, (cst_val *)&val_1201},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0005, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1204 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1206 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0012, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0013, (cst_val *)&val_1207},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0014, (cst_val *)&val_1208},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0015, (cst_val *)&val_1209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1212 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0019, (cst_val *)&val_0032},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0020, (cst_val *)&val_0431},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0021, (cst_val *)&val_1213},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0022, (cst_val *)&val_1214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1216 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0025, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1218 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0028, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1221 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0032, (cst_val *)&val_0108},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0033, (cst_val *)&val_0032},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0034, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1223 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0037, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0038, (cst_val *)&val_1224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1227 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0042, (cst_val *)&val_1228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0043, (cst_val *)&val_1229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1230 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_47_NO_0045, (cst_val *)&val_1231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1233 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_47_NO_0048, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1235 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_d_47_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_f0_d_47_cart = {
  cmu_us_awb_f0_d_47_cart_nodes,
  cmu_us_awb_f0_d_47_feat_table
};

static const cst_cart_node cmu_us_awb_f0_d_48_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0000, (cst_val *)&val_0252},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0001, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1236 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0003, (cst_val *)&val_0919},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0004, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1239 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0008, (cst_val *)&val_0617},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0009, (cst_val *)&val_1240},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0010, (cst_val *)&val_0501},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1243 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0014, (cst_val *)&val_0397},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0015, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1244 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0017, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1246 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0020, (cst_val *)&val_1247},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0021, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1248 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0023, (cst_val *)&val_1249},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0024, (cst_val *)&val_1250},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1251 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0027, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0028, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1253 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0031, (cst_val *)&val_1254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1255 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0033, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1256 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0035, (cst_val *)&val_1257},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1259 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_d_48_NO_0038, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1260 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_d_48_NO_0040, (cst_val *)&val_1261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1263 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_d_48_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_d_48_cart = {
  cmu_us_awb_f0_d_48_cart_nodes,
  cmu_us_awb_f0_d_48_feat_table
};

static const cst_cart_node cmu_us_awb_f0_n_116_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0001, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1264 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0003, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1266 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0006, (cst_val *)&val_1267},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0007, (cst_val *)&val_0112},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0008, (cst_val *)&val_1268},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0009, (cst_val *)&val_0079},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0010, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1271 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0014, (cst_val *)&val_0108},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0015, (cst_val *)&val_0742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1273 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0018, (cst_val *)&val_1274},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1276 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0021, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0024, (cst_val *)&val_0412},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0025, (cst_val *)&val_0079},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0026, (cst_val *)&val_1279},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0027, (cst_val *)&val_0108},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0028, (cst_val *)&val_1190},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0029, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1281 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0032, (cst_val *)&val_1282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1284 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_116_NO_0035, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1287 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0039, (cst_val *)&val_1288},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0040, (cst_val *)&val_0142},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0041, (cst_val *)&val_1121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1292 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0046, (cst_val *)&val_0413},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0047, (cst_val *)&val_1111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1294 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_116_NO_0050, (cst_val *)&val_1295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1297 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_n_116_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_n_116_cart = {
  cmu_us_awb_f0_n_116_cart_nodes,
  cmu_us_awb_f0_n_116_feat_table
};

static const cst_cart_node cmu_us_awb_f0_n_117_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0000, (cst_val *)&val_1298},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0001, (cst_val *)&val_1299},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0002, (cst_val *)&val_0376},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0003, (cst_val *)&val_1300},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0004, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1302 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0007, (cst_val *)&val_0848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1304 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0010, (cst_val *)&val_1305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1307 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0013, (cst_val *)&val_1308},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0014, (cst_val *)&val_0754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1310 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0017, (cst_val *)&val_0079},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0018, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1311 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0020, (cst_val *)&val_0072},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0021, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1314 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0025, (cst_val *)&val_1315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1317 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0028, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0029, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1318 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0031, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1320 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0034, (cst_val *)&val_0331},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0035, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0036, (cst_val *)&val_1321},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0037, (cst_val *)&val_0079},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0038, (cst_val *)&val_0072},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0039, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0040, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1323 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0043, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1325 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0046, (cst_val *)&val_1326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1327 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0048, (cst_val *)&val_1328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1329 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0050, (cst_val *)&val_1330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1331 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0052, (cst_val *)&val_0024},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0053, (cst_val *)&val_0156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1333 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0056, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1334 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0058, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1336 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0061, (cst_val *)&val_1337},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0062, (cst_val *)&val_1338},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0063, (cst_val *)&val_1339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1341 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0067, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1343 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0070, (cst_val *)&val_0072},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0071, (cst_val *)&val_1330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1345 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_117_NO_0074, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1346 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0076, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1350 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_117_NO_0080, (cst_val *)&val_1295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1352 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_n_117_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_f0_n_117_cart = {
  cmu_us_awb_f0_n_117_cart_nodes,
  cmu_us_awb_f0_n_117_feat_table
};

static const cst_cart_node cmu_us_awb_f0_n_118_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0000, (cst_val *)&val_1353},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0001, (cst_val *)&val_0878},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0002, (cst_val *)&val_1354},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0003, (cst_val *)&val_1355},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0004, (cst_val *)&val_0079},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0005, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1358 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0009, (cst_val *)&val_1359},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0010, (cst_val *)&val_0889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1362 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0014, (cst_val *)&val_0567},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0015, (cst_val *)&val_1363},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0016, (cst_val *)&val_0025},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0017, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1364 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0020, (cst_val *)&val_0079},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0021, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1366 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0024, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0027, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1371 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0030, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1373 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0033, (cst_val *)&val_0032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0034, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0035, (cst_val *)&val_1374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1376 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0038, (cst_val *)&val_0032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0039, (cst_val *)&val_0072},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0040, (cst_val *)&val_1377},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0041, (cst_val *)&val_1111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1380 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0045, (cst_val *)&val_1381},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1383 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0048, (cst_val *)&val_1384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1386 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0051, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1387 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0053, (cst_val *)&val_1388},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0054, (cst_val *)&val_1389},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1392 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0058, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1393 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0060, (cst_val *)&val_0397},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0061, (cst_val *)&val_0436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1394 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_n_118_NO_0063, (cst_val *)&val_1395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1397 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_n_118_NO_0066, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1399 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_n_118_feat_table[] = {
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_f0_n_118_cart = {
  cmu_us_awb_f0_n_118_cart_nodes,
  cmu_us_awb_f0_n_118_feat_table
};

static const cst_cart_node cmu_us_awb_f0_jh_96_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_96_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1400 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_jh_96_NO_0002, (cst_val *)&val_1401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1402 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_jh_96_NO_0004, (cst_val *)&val_1403},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_96_NO_0005, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_96_NO_0006, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1407 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_jh_96_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_f0_jh_96_cart = {
  cmu_us_awb_f0_jh_96_cart_nodes,
  cmu_us_awb_f0_jh_96_feat_table
};

static const cst_cart_node cmu_us_awb_f0_jh_97_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_97_NO_0000, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1408 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_97_NO_0002, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_97_NO_0003, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1409 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_97_NO_0005, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1410 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_jh_97_NO_0007, (cst_val *)&val_0192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1412 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_jh_97_NO_0010, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1414 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_jh_97_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_f0_jh_97_cart = {
  cmu_us_awb_f0_jh_97_cart_nodes,
  cmu_us_awb_f0_jh_97_feat_table
};

static const cst_cart_node cmu_us_awb_f0_jh_98_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_98_NO_0000, (cst_val *)&val_0112},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_jh_98_NO_0001, (cst_val *)&val_1415},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_jh_98_NO_0002, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1418 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_jh_98_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_f0_jh_98_cart = {
  cmu_us_awb_f0_jh_98_cart_nodes,
  cmu_us_awb_f0_jh_98_feat_table
};

static const cst_cart_node cmu_us_awb_f0_r_146_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0001, (cst_val *)&val_0112},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0002, (cst_val *)&val_1419},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0003, (cst_val *)&val_1420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1422 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0006, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1425 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0010, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0011, (cst_val *)&val_1426},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0012, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0014, (cst_val *)&val_1427},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1429 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0017, (cst_val *)&val_1430},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0018, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1431 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0020, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1432 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0022, (cst_val *)&val_0652},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0023, (cst_val *)&val_0514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1433 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0025, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1436 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0029, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1438 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0032, (cst_val *)&val_1439},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_146_NO_0033, (cst_val *)&val_0590},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_146_NO_0034, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1443 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_r_146_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_f0_r_146_cart = {
  cmu_us_awb_f0_r_146_cart_nodes,
  cmu_us_awb_f0_r_146_feat_table
};

static const cst_cart_node cmu_us_awb_f0_r_147_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0000, (cst_val *)&val_1444},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0001, (cst_val *)&val_1445},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0002, (cst_val *)&val_0108},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0003, (cst_val *)&val_1446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1447 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0005, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1450 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0009, (cst_val *)&val_1451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1453 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0012, (cst_val *)&val_0032},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0013, (cst_val *)&val_1454},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0014, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0015, (cst_val *)&val_1455},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1457 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0018, (cst_val *)&val_0032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0019, (cst_val *)&val_0397},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0020, (cst_val *)&val_1458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1460 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0023, (cst_val *)&val_0214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1461 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_147_NO_0025, (cst_val *)&val_1462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1464 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0028, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1466 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0031, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1467 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_147_NO_0033, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1470 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_r_147_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_awb_f0_r_147_cart = {
  cmu_us_awb_f0_r_147_cart_nodes,
  cmu_us_awb_f0_r_147_feat_table
};

static const cst_cart_node cmu_us_awb_f0_r_148_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0001, (cst_val *)&val_0112},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0002, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1472 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0005, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1474 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0008, (cst_val *)&val_0112},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0009, (cst_val *)&val_1475},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0010, (cst_val *)&val_0108},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0011, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1476 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0014, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1477 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0016, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1480 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0019, (cst_val *)&val_1481},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0020, (cst_val *)&val_0108},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0021, (cst_val *)&val_1482},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1484 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0024, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1485 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0026, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1487 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0029, (cst_val *)&val_1488},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0030, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1490 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0033, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1492 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0036, (cst_val *)&val_1493},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_r_148_NO_0037, (cst_val *)&val_1494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1495 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0039, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1497 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_r_148_NO_0042, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1499 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_r_148_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_r_148_cart = {
  cmu_us_awb_f0_r_148_cart_nodes,
  cmu_us_awb_f0_r_148_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ey_66_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_66_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0001, (cst_val *)&val_1500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1502 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0004, (cst_val *)&val_1503},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0005, (cst_val *)&val_1504},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0006, (cst_val *)&val_0553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_66_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1505 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0011, (cst_val *)&val_1506},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0012, (cst_val *)&val_1507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1510 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_66_NO_0016, (cst_val *)&val_1511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1513 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ey_66_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_ey_66_cart = {
  cmu_us_awb_f0_ey_66_cart_nodes,
  cmu_us_awb_f0_ey_66_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ey_67_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0000, (cst_val *)&val_1514},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0001, (cst_val *)&val_0072},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0002, (cst_val *)&val_1515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1517 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0005, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1518 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0007, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1519 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0009, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1521 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0012, (cst_val *)&val_0032},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1522 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0015, (cst_val *)&val_1523},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1525 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0018, (cst_val *)&val_0032},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0019, (cst_val *)&val_1526},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0020, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1528 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0023, (cst_val *)&val_1529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1531 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0026, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0027, (cst_val *)&val_0300},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0028, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1534 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0032, (cst_val *)&val_1535},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0033, (cst_val *)&val_1536},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0035, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1538 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0038, (cst_val *)&val_0025},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0039, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1540 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_67_NO_0042, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1541 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_67_NO_0044, (cst_val *)&val_1542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1544 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ey_67_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_ey_67_cart = {
  cmu_us_awb_f0_ey_67_cart_nodes,
  cmu_us_awb_f0_ey_67_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ey_68_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0001, (cst_val *)&val_0042},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0002, (cst_val *)&val_1545},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0003, (cst_val *)&val_1546},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0004, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1547 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0006, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1553 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0012, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1554 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0014, (cst_val *)&val_1555},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1556 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0017, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1558 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0020, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1559 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0022, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1560 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0024, (cst_val *)&val_0089},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0025, (cst_val *)&val_1561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ey_68_NO_0028, (cst_val *)&val_0032},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ey_68_NO_0029, (cst_val *)&val_1563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1566 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ey_68_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ey_68_cart = {
  cmu_us_awb_f0_ey_68_cart_nodes,
  cmu_us_awb_f0_ey_68_feat_table
};

static const cst_cart_node cmu_us_awb_f0_pau_141_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_pau_141_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_pau_141_cart = {
  cmu_us_awb_f0_pau_141_cart_nodes,
  cmu_us_awb_f0_pau_141_feat_table
};

static const cst_cart_node cmu_us_awb_f0_pau_143_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_pau_143_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_pau_143_cart = {
  cmu_us_awb_f0_pau_143_cart_nodes,
  cmu_us_awb_f0_pau_143_feat_table
};

static const cst_cart_node cmu_us_awb_f0_f_71_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_71_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_71_NO_0001, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1567 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_71_NO_0003, (cst_val *)&val_1568},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_71_NO_0004, (cst_val *)&val_1569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1570 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_71_NO_0006, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1571 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_71_NO_0008, (cst_val *)&val_0079},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_71_NO_0009, (cst_val *)&val_0413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1574 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_71_NO_0013, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1577 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_f_71_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_f_71_cart = {
  cmu_us_awb_f0_f_71_cart_nodes,
  cmu_us_awb_f0_f_71_feat_table
};

static const cst_cart_node cmu_us_awb_f0_f_72_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0001, (cst_val *)&val_0024},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0002, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1578 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0004, (cst_val *)&val_0214},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0005, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1580 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0007, (cst_val *)&val_1581},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0008, (cst_val *)&val_1582},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1585 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0012, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1587 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0015, (cst_val *)&val_0038},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0019, (cst_val *)&val_1590},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0020, (cst_val *)&val_0079},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0021, (cst_val *)&val_0042},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0022, (cst_val *)&val_1591},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0023, (cst_val *)&val_1592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1595 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0027, (cst_val *)&val_0112},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0028, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1597 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0031, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1598 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_72_NO_0033, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1599 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0035, (cst_val *)&val_1337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1602 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_72_NO_0039, (cst_val *)&val_1603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1606 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_f_72_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_f_72_cart = {
  cmu_us_awb_f0_f_72_cart_nodes,
  cmu_us_awb_f0_f_72_feat_table
};

static const cst_cart_node cmu_us_awb_f0_f_73_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0001, (cst_val *)&val_1607},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0002, (cst_val *)&val_1608},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0003, (cst_val *)&val_1609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1611 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0006, (cst_val *)&val_1612},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0007, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0008, (cst_val *)&val_1613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1615 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0011, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1616 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0013, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1619 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0016, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1621 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0019, (cst_val *)&val_0024},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_f_73_NO_0020, (cst_val *)&val_0214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1623 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0023, (cst_val *)&val_0089},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0024, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1625 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0027, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1626 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0029, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1627 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0031, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1629 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_f_73_NO_0034, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1631 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_f_73_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_f0_f_73_cart = {
  cmu_us_awb_f0_f_73_cart_nodes,
  cmu_us_awb_f0_f_73_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ih_86_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0001, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1633 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0004, (cst_val *)&val_0072},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0005, (cst_val *)&val_1634},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0006, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1635 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0008, (cst_val *)&val_1636},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1639 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0012, (cst_val *)&val_0079},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0013, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0014, (cst_val *)&val_1640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1642 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0017, (cst_val *)&val_1643},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0018, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1644 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_86_NO_0020, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1646 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0023, (cst_val *)&val_1647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1648 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0025, (cst_val *)&val_1649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1651 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0028, (cst_val *)&val_1652},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0029, (cst_val *)&val_0425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1654 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0032, (cst_val *)&val_1655},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_86_NO_0033, (cst_val *)&val_1656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1659 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ih_86_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_ih_86_cart = {
  cmu_us_awb_f0_ih_86_cart_nodes,
  cmu_us_awb_f0_ih_86_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ih_87_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0000, (cst_val *)&val_1660},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0001, (cst_val *)&val_0997},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0002, (cst_val *)&val_1661},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0003, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1664 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0007, (cst_val *)&val_0108},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0008, (cst_val *)&val_0079},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0009, (cst_val *)&val_1665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1667 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0012, (cst_val *)&val_0089},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1668 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0015, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1669 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0017, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1672 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0021, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1673 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0023, (cst_val *)&val_0032},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0024, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1674 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0026, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1676 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0029, (cst_val *)&val_1677},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0030, (cst_val *)&val_1678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1680 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0033, (cst_val *)&val_1681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1683 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0036, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0037, (cst_val *)&val_0353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1685 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0040, (cst_val *)&val_1686},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0041, (cst_val *)&val_0179},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0042, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1688 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0045, (cst_val *)&val_0032},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0046, (cst_val *)&val_1689},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0047, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1692 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0051, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1694 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0054, (cst_val *)&val_1695},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0055, (cst_val *)&val_1696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1697 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0057, (cst_val *)&val_0032},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0058, (cst_val *)&val_0079},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0059, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1698 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0061, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1702 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_87_NO_0065, (cst_val *)&val_1703},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1704 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0067, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1705 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_87_NO_0070, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1707 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ih_87_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_ih_87_cart = {
  cmu_us_awb_f0_ih_87_cart_nodes,
  cmu_us_awb_f0_ih_87_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ih_88_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0001, (cst_val *)&val_1708},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0002, (cst_val *)&val_0112},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0003, (cst_val *)&val_1709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1711 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0006, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1712 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0008, (cst_val *)&val_1713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1716 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0012, (cst_val *)&val_0032},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0013, (cst_val *)&val_0443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1718 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0016, (cst_val *)&val_1719},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0017, (cst_val *)&val_1720},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0018, (cst_val *)&val_1721},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1724 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0022, (cst_val *)&val_1686},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0023, (cst_val *)&val_0128},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0024, (cst_val *)&val_0848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1726 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0027, (cst_val *)&val_0179},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0028, (cst_val *)&val_1727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1728 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0030, (cst_val *)&val_1729},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0031, (cst_val *)&val_1730},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0032, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1733 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0036, (cst_val *)&val_1734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1736 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0039, (cst_val *)&val_0032},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0040, (cst_val *)&val_1737},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0041, (cst_val *)&val_1738},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1740 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0044, (cst_val *)&val_1741},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1743 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0047, (cst_val *)&val_0081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1744 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ih_88_NO_0049, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1745 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0051, (cst_val *)&val_1420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1747 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0054, (cst_val *)&val_1748},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0055, (cst_val *)&val_0168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1750 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ih_88_NO_0058, (cst_val *)&val_0265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1752 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ih_88_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_f0_ih_88_cart = {
  cmu_us_awb_f0_ih_88_cart_nodes,
  cmu_us_awb_f0_ih_88_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ax_27_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1753 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0002, (cst_val *)&val_1754},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0003, (cst_val *)&val_0038},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0004, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1755 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0006, (cst_val *)&val_0771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1756 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0009, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1757 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0011, (cst_val *)&val_0928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1759 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0014, (cst_val *)&val_1760},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0015, (cst_val *)&val_0032},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0016, (cst_val *)&val_0032},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0017, (cst_val *)&val_1761},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0018, (cst_val *)&val_0662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1764 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0022, (cst_val *)&val_1765},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0023, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1766 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0025, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1768 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0028, (cst_val *)&val_1769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1772 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0032, (cst_val *)&val_0072},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0033, (cst_val *)&val_1773},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0034, (cst_val *)&val_1774},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0035, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0040, (cst_val *)&val_1065},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0041, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1779 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0044, (cst_val *)&val_0250},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_27_NO_0045, (cst_val *)&val_1780},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_27_NO_0046, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1783 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ax_27_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_ax_27_cart = {
  cmu_us_awb_f0_ax_27_cart_nodes,
  cmu_us_awb_f0_ax_27_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ax_28_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0001, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0002, (cst_val *)&val_0168},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0003, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1785 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0006, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1786 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0008, (cst_val *)&val_0038},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0009, (cst_val *)&val_1787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1790 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1791 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1792 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0017, (cst_val *)&val_0492},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0018, (cst_val *)&val_1793},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1795 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0021, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0023, (cst_val *)&val_1796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1797 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0025, (cst_val *)&val_1798},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0026, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1799 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0028, (cst_val *)&val_1800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1802 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0031, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0032, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1804 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0035, (cst_val *)&val_1805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0584 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0038, (cst_val *)&val_0024},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0039, (cst_val *)&val_0331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1807 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0041, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1809 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0044, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1810 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0046, (cst_val *)&val_1249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1811 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_28_NO_0048, (cst_val *)&val_0112},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_28_NO_0049, (cst_val *)&val_1812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1815 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ax_28_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_awb_f0_ax_28_cart = {
  cmu_us_awb_f0_ax_28_cart_nodes,
  cmu_us_awb_f0_ax_28_feat_table
};

static const cst_cart_node cmu_us_awb_f0_p_136_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0001, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1816 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0003, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1818 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0006, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0007, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_136_NO_0008, (cst_val *)&val_1819},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1820 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_136_NO_0011, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1822 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_136_NO_0013, (cst_val *)&val_1823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1825 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_136_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1829 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_p_136_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_f0_p_136_cart = {
  cmu_us_awb_f0_p_136_cart_nodes,
  cmu_us_awb_f0_p_136_feat_table
};

static const cst_cart_node cmu_us_awb_f0_p_137_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0000, (cst_val *)&val_0040},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0001, (cst_val *)&val_1830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1832 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0004, (cst_val *)&val_0147},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0005, (cst_val *)&val_0032},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0006, (cst_val *)&val_1833},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0007, (cst_val *)&val_1834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1835 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1838 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0013, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1139 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0015, (cst_val *)&val_1582},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1840 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0018, (cst_val *)&val_0376},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0019, (cst_val *)&val_1036},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0020, (cst_val *)&val_0032},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0021, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1843 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0025, (cst_val *)&val_0032},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_137_NO_0026, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1846 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_137_NO_0030, (cst_val *)&val_0250},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1848 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_p_137_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_awb_f0_p_137_cart = {
  cmu_us_awb_f0_p_137_cart_nodes,
  cmu_us_awb_f0_p_137_feat_table
};

static const cst_cart_node cmu_us_awb_f0_p_138_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0000, (cst_val *)&val_1591},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0001, (cst_val *)&val_0576},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_138_NO_0002, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0003, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0712 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0007, (cst_val *)&val_0156},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0008, (cst_val *)&val_1851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1852 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_138_NO_0010, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1853 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_p_138_NO_0012, (cst_val *)&val_1854},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1855 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_138_NO_0014, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1856 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_p_138_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1860 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_p_138_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_p_138_cart = {
  cmu_us_awb_f0_p_138_cart_nodes,
  cmu_us_awb_f0_p_138_feat_table
};

static const cst_cart_node cmu_us_awb_f0_iy_91_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0001, (cst_val *)&val_1861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1863 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0004, (cst_val *)&val_0072},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0005, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1865 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0008, (cst_val *)&val_1866},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0009, (cst_val *)&val_0690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1867 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0011, (cst_val *)&val_1656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1869 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0014, (cst_val *)&val_1870},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1871 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0017, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1872 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0019, (cst_val *)&val_1023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1874 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0022, (cst_val *)&val_0128},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0023, (cst_val *)&val_1643},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0024, (cst_val *)&val_1875},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1878 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_91_NO_0028, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1879 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_91_NO_0030, (cst_val *)&val_1295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1881 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_iy_91_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_f0_iy_91_cart = {
  cmu_us_awb_f0_iy_91_cart_nodes,
  cmu_us_awb_f0_iy_91_feat_table
};

static const cst_cart_node cmu_us_awb_f0_iy_92_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0000, (cst_val *)&val_1882},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0001, (cst_val *)&val_1883},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0002, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0003, (cst_val *)&val_1884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1886 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0006, (cst_val *)&val_0032},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0007, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1889 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0010, (cst_val *)&val_0079},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0011, (cst_val *)&val_1036},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0012, (cst_val *)&val_1890},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0013, (cst_val *)&val_1891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1895 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0018, (cst_val *)&val_0468},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0019, (cst_val *)&val_0210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1898 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0023, (cst_val *)&val_1899},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0024, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1900 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0026, (cst_val *)&val_1901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1902 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0028, (cst_val *)&val_1903},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0029, (cst_val *)&val_0032},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0030, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1905 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0033, (cst_val *)&val_1036},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0034, (cst_val *)&val_0210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1908 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0038, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1910 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0041, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1912 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0044, (cst_val *)&val_0042},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0045, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1913 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0047, (cst_val *)&val_1914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1916 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0050, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0051, (cst_val *)&val_1917},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0052, (cst_val *)&val_1918},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0053, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1919 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0055, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1922 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0059, (cst_val *)&val_0331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1924 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0062, (cst_val *)&val_0032},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0063, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0064, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1926 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0067, (cst_val *)&val_1927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1928 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0069, (cst_val *)&val_0079},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0070, (cst_val *)&val_1929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1932 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0074, (cst_val *)&val_1933},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_92_NO_0075, (cst_val *)&val_0576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1935 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_92_NO_0078, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1937 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_iy_92_feat_table[] = {
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_iy_92_cart = {
  cmu_us_awb_f0_iy_92_cart_nodes,
  cmu_us_awb_f0_iy_92_feat_table
};

static const cst_cart_node cmu_us_awb_f0_iy_93_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0000, (cst_val *)&val_0252},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0001, (cst_val *)&val_1938},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0002, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1939 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0004, (cst_val *)&val_1940},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1942 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0007, (cst_val *)&val_1943},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0008, (cst_val *)&val_1944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1946 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0011, (cst_val *)&val_1947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1949 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0014, (cst_val *)&val_0567},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0015, (cst_val *)&val_1950},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0016, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1952 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0019, (cst_val *)&val_1953},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0020, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1955 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0023, (cst_val *)&val_1956},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0024, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1959 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0028, (cst_val *)&val_0042},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0029, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1960 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0031, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1962 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0034, (cst_val *)&val_1943},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0035, (cst_val *)&val_0079},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0036, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1964 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0038, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1966 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0041, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1967 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0043, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1969 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0046, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1970 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_iy_93_NO_0048, (cst_val *)&val_1971},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0049, (cst_val *)&val_1696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1972 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0051, (cst_val *)&val_0079},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_iy_93_NO_0052, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1976 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_iy_93_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_f0_iy_93_cart = {
  cmu_us_awb_f0_iy_93_cart_nodes,
  cmu_us_awb_f0_iy_93_feat_table
};

static const cst_cart_node cmu_us_awb_f0_l_106_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0001, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1977 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0003, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1979 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0006, (cst_val *)&val_0142},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0007, (cst_val *)&val_0072},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0008, (cst_val *)&val_1980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0011, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1983 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0013, (cst_val *)&val_0701},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0014, (cst_val *)&val_0192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1984 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0016, (cst_val *)&val_1985},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0017, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1987 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0020, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1989 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0023, (cst_val *)&val_1990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1992 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0026, (cst_val *)&val_1993},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0027, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0028, (cst_val *)&val_1994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1996 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0031, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1997 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0033, (cst_val *)&val_0032},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0034, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1999 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0037, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2001 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0040, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2002 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0042, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2003 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0044, (cst_val *)&val_2004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0045, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_106_NO_0046, (cst_val *)&val_0542},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0047, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2006 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_106_NO_0050, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2010 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_l_106_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_f0_l_106_cart = {
  cmu_us_awb_f0_l_106_cart_nodes,
  cmu_us_awb_f0_l_106_feat_table
};

static const cst_cart_node cmu_us_awb_f0_l_107_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0001, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2011 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0003, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2012 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0005, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2014 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0008, (cst_val *)&val_2015},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0009, (cst_val *)&val_2016},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0010, (cst_val *)&val_0042},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0011, (cst_val *)&val_1111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2018 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0014, (cst_val *)&val_2019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0015, (cst_val *)&val_2020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2021 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0017, (cst_val *)&val_2022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2023 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0019, (cst_val *)&val_2024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2027 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0023, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2028 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0025, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2029 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0027, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2030 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0029, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2032 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0032, (cst_val *)&val_2033},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0033, (cst_val *)&val_2034},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0034, (cst_val *)&val_1091},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0035, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2035 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0037, (cst_val *)&val_2036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0040, (cst_val *)&val_2039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2040 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0042, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2041 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0044, (cst_val *)&val_1709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2043 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0047, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2044 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0049, (cst_val *)&val_2045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0050, (cst_val *)&val_2046},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0051, (cst_val *)&val_2047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2050 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0055, (cst_val *)&val_2051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2052 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_107_NO_0057, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1782 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_107_NO_0059, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2055 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_l_107_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_awb_f0_l_107_cart = {
  cmu_us_awb_f0_l_107_cart_nodes,
  cmu_us_awb_f0_l_107_feat_table
};

static const cst_cart_node cmu_us_awb_f0_l_108_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0001, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0002, (cst_val *)&val_2056},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0003, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2057 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0005, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2059 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0008, (cst_val *)&val_0252},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0009, (cst_val *)&val_2060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2063 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0013, (cst_val *)&val_2064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0014, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2066 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0017, (cst_val *)&val_2067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2069 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0020, (cst_val *)&val_0376},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0021, (cst_val *)&val_0397},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0022, (cst_val *)&val_2070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2071 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0024, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2073 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0027, (cst_val *)&val_0079},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0028, (cst_val *)&val_2074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2075 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0030, (cst_val *)&val_2076},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0031, (cst_val *)&val_2077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2078 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0033, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2081 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0037, (cst_val *)&val_2082},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0038, (cst_val *)&val_0832},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0039, (cst_val *)&val_0835},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2084 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0042, (cst_val *)&val_2085},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0043, (cst_val *)&val_0904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2089 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0048, (cst_val *)&val_0032},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0049, (cst_val *)&val_2090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2091 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0051, (cst_val *)&val_2092},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0052, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2093 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0054, (cst_val *)&val_2094},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0055, (cst_val *)&val_2095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2098 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_l_108_NO_0059, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2100 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_l_108_NO_0062, (cst_val *)&val_2101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2103 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_l_108_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_l_108_cart = {
  cmu_us_awb_f0_l_108_cart_nodes,
  cmu_us_awb_f0_l_108_feat_table
};

static const cst_cart_node cmu_us_awb_f0_z_199_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_199_NO_0000, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2104 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_199_NO_0002, (cst_val *)&val_0032},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_199_NO_0003, (cst_val *)&val_2105},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_199_NO_0004, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2106 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_199_NO_0006, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2108 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_199_NO_0009, (cst_val *)&val_2109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2110 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_199_NO_0011, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2111 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_199_NO_0013, (cst_val *)&val_1086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2113 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_199_NO_0016, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2115 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_z_199_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_z_199_cart = {
  cmu_us_awb_f0_z_199_cart_nodes,
  cmu_us_awb_f0_z_199_feat_table
};

static const cst_cart_node cmu_us_awb_f0_z_200_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0001, (cst_val *)&val_2116},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0002, (cst_val *)&val_2117},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0003, (cst_val *)&val_0690},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0004, (cst_val *)&val_2118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2121 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0008, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2122 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0010, (cst_val *)&val_2123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2125 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0013, (cst_val *)&val_2126},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0014, (cst_val *)&val_2127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2128 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0016, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2129 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0018, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2131 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0021, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2133 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0024, (cst_val *)&val_0032},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0025, (cst_val *)&val_2134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2135 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_200_NO_0027, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2137 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_200_NO_0030, (cst_val *)&val_0520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2139 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_z_200_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_f0_z_200_cart = {
  cmu_us_awb_f0_z_200_cart_nodes,
  cmu_us_awb_f0_z_200_feat_table
};

static const cst_cart_node cmu_us_awb_f0_z_201_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0001, (cst_val *)&val_0252},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0002, (cst_val *)&val_0038},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0003, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2141 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0006, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2142 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0008, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2143 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0010, (cst_val *)&val_2144},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0011, (cst_val *)&val_2145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2146 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0013, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2148 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0016, (cst_val *)&val_2149},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0017, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2150 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0019, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2153 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0023, (cst_val *)&val_0645},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0024, (cst_val *)&val_2154},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0025, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2156 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0028, (cst_val *)&val_0331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2158 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0031, (cst_val *)&val_2159},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0032, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2162 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0036, (cst_val *)&val_0329},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_z_201_NO_0037, (cst_val *)&val_2163},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0038, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2164 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0041, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2166 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0044, (cst_val *)&val_2167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2168 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0046, (cst_val *)&val_0025},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_z_201_NO_0047, (cst_val *)&val_2169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2172 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_z_201_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_f0_z_201_cart = {
  cmu_us_awb_f0_z_201_cart_nodes,
  cmu_us_awb_f0_z_201_feat_table
};

static const cst_cart_node cmu_us_awb_f0_pau_161_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_pau_161_feat_table[] = {
NULL };

const cst_cart cmu_us_awb_f0_pau_161_cart = {
  cmu_us_awb_f0_pau_161_cart_nodes,
  cmu_us_awb_f0_pau_161_feat_table
};

static const cst_cart_node cmu_us_awb_f0_s_151_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0001, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0002, (cst_val *)&val_0501},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2174 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0005, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2176 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0008, (cst_val *)&val_0375},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0009, (cst_val *)&val_0376},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0010, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2177 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0012, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0013, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2178 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0015, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2180 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0018, (cst_val *)&val_2082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2181 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0020, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2183 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0023, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2184 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0025, (cst_val *)&val_1190},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2186 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0028, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2187 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0030, (cst_val *)&val_0136},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_151_NO_0031, (cst_val *)&val_2188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2189 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0034, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2190 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0036, (cst_val *)&val_0079},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0037, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2191 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0039, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2193 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0042, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2194 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0044, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2195 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_151_NO_0046, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2197 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_s_151_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_s_151_cart = {
  cmu_us_awb_f0_s_151_cart_nodes,
  cmu_us_awb_f0_s_151_feat_table
};

static const cst_cart_node cmu_us_awb_f0_s_152_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0001, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2198 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0003, (cst_val *)&val_1209},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0004, (cst_val *)&val_2199},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0005, (cst_val *)&val_1308},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0006, (cst_val *)&val_2060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2201 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0009, (cst_val *)&val_2202},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0010, (cst_val *)&val_2203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2204 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0012, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2206 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0015, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2207 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0017, (cst_val *)&val_2208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2210 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0020, (cst_val *)&val_2211},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0021, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0022, (cst_val *)&val_1308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2213 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0025, (cst_val *)&val_2214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2218 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0030, (cst_val *)&val_0032},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0031, (cst_val *)&val_0079},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0032, (cst_val *)&val_2219},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0033, (cst_val *)&val_2220},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2222 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0036, (cst_val *)&val_0072},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0037, (cst_val *)&val_2223},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0038, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0039, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2224 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0041, (cst_val *)&val_2225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2227 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0044, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2228 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0047, (cst_val *)&val_2229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2230 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0049, (cst_val *)&val_0376},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0050, (cst_val *)&val_2167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2233 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0054, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0055, (cst_val *)&val_2234},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0056, (cst_val *)&val_2235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2236 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0058, (cst_val *)&val_0038},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0059, (cst_val *)&val_0434},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0060, (cst_val *)&val_2237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2239 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0064, (cst_val *)&val_0112},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0065, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0881 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0067, (cst_val *)&val_0436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2241 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0070, (cst_val *)&val_2242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2243 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0072, (cst_val *)&val_2244},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0073, (cst_val *)&val_0108},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0074, (cst_val *)&val_0434},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0075, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2245 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0077, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2246 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0079, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2248 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0082, (cst_val *)&val_2249},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0083, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2252 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0087, (cst_val *)&val_0089},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0088, (cst_val *)&val_2253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2257 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0093, (cst_val *)&val_2127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2258 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0095, (cst_val *)&val_2259},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0096, (cst_val *)&val_0025},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0097, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2261 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0100, (cst_val *)&val_2262},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0101, (cst_val *)&val_1065},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0102, (cst_val *)&val_2263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0105, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2265 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0107, (cst_val *)&val_2266},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0108, (cst_val *)&val_2267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2269 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0111, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2271 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0114, (cst_val *)&val_2272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2274 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0117, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0118, (cst_val *)&val_2275},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0119, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2278 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0123, (cst_val *)&val_2279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2280 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0125, (cst_val *)&val_0025},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0126, (cst_val *)&val_2281},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0127, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2284 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0131, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2285 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0133, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2286 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0135, (cst_val *)&val_2060},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0136, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2289 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0140, (cst_val *)&val_1330},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0141, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2292 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0145, (cst_val *)&val_2293},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2295 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0148, (cst_val *)&val_2296},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0149, (cst_val *)&val_0079},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0150, (cst_val *)&val_1821},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0151, (cst_val *)&val_2297},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_152_NO_0152, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2302 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_152_NO_0158, (cst_val *)&val_2303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2305 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_s_152_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_s_152_cart = {
  cmu_us_awb_f0_s_152_cart_nodes,
  cmu_us_awb_f0_s_152_feat_table
};

static const cst_cart_node cmu_us_awb_f0_s_153_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0000, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0001, (cst_val *)&val_2306},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0002, (cst_val *)&val_0576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2307 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0004, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2309 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0007, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0008, (cst_val *)&val_2310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2312 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0011, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0012, (cst_val *)&val_2313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2316 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0016, (cst_val *)&val_2317},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0017, (cst_val *)&val_0032},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0018, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0021, (cst_val *)&val_0025},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0022, (cst_val *)&val_0576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2321 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_s_153_NO_0025, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2322 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0027, (cst_val *)&val_2323},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0028, (cst_val *)&val_2324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2327 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_s_153_NO_0032, (cst_val *)&val_2328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2330 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_s_153_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_s_153_cart = {
  cmu_us_awb_f0_s_153_cart_nodes,
  cmu_us_awb_f0_s_153_feat_table
};

static const cst_cart_node cmu_us_awb_f0_eh_56_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0001, (cst_val *)&val_0300},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0002, (cst_val *)&val_2331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2333 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0005, (cst_val *)&val_2334},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0006, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2337 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0010, (cst_val *)&val_2338},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0011, (cst_val *)&val_2339},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0012, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2341 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0015, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2342 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0017, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0019, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2345 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0022, (cst_val *)&val_0424},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0023, (cst_val *)&val_2346},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0024, (cst_val *)&val_0089},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0025, (cst_val *)&val_0659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2349 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_56_NO_0029, (cst_val *)&val_2350},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_56_NO_0030, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2354 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_eh_56_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_eh_56_cart = {
  cmu_us_awb_f0_eh_56_cart_nodes,
  cmu_us_awb_f0_eh_56_feat_table
};

static const cst_cart_node cmu_us_awb_f0_eh_57_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0001, (cst_val *)&val_0136},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0002, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2357 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0006, (cst_val *)&val_2358},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0007, (cst_val *)&val_0089},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0008, (cst_val *)&val_2199},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0009, (cst_val *)&val_0690},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0010, (cst_val *)&val_2359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2361 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0013, (cst_val *)&val_2362},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0014, (cst_val *)&val_2363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2365 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0017, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2368 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0021, (cst_val *)&val_2369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2371 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0024, (cst_val *)&val_2372},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2373 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0026, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2374 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0028, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2375 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0030, (cst_val *)&val_2376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2377 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0032, (cst_val *)&val_0581},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0033, (cst_val *)&val_2378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2379 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0035, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2380 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0037, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2382 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_57_NO_0040, (cst_val *)&val_0108},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0041, (cst_val *)&val_2383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2385 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_57_NO_0044, (cst_val *)&val_2386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2388 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_eh_57_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_f0_eh_57_cart = {
  cmu_us_awb_f0_eh_57_cart_nodes,
  cmu_us_awb_f0_eh_57_feat_table
};

static const cst_cart_node cmu_us_awb_f0_eh_58_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0001, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0002, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2391 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0006, (cst_val *)&val_2392},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0007, (cst_val *)&val_0089},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0008, (cst_val *)&val_2393},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2396 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0013, (cst_val *)&val_0434},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0014, (cst_val *)&val_0118},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0015, (cst_val *)&val_2397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2399 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0018, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2401 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0021, (cst_val *)&val_2402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2403 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0023, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2405 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0026, (cst_val *)&val_0992},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0027, (cst_val *)&val_0220},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0028, (cst_val *)&val_2406},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0029, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2408 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0032, (cst_val *)&val_2409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2411 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0035, (cst_val *)&val_0032},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0036, (cst_val *)&val_2412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2413 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0038, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2415 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0041, (cst_val *)&val_2416},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0042, (cst_val *)&val_0072},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_eh_58_NO_0043, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2418 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0046, (cst_val *)&val_2419},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0047, (cst_val *)&val_2420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2424 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_eh_58_NO_0052, (cst_val *)&val_2425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2427 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_eh_58_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_awb_f0_eh_58_cart = {
  cmu_us_awb_f0_eh_58_cart_nodes,
  cmu_us_awb_f0_eh_58_feat_table
};

static const cst_cart_node cmu_us_awb_f0_t_164_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0001, (cst_val *)&val_0025},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0002, (cst_val *)&val_2428},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0047 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0006, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0007, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2431 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0009, (cst_val *)&val_0397},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0010, (cst_val *)&val_2432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2434 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0013, (cst_val *)&val_2435},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0014, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2438 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0018, (cst_val *)&val_0112},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0019, (cst_val *)&val_2439},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0020, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2441 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0023, (cst_val *)&val_1821},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0024, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2442 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0026, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2443 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0028, (cst_val *)&val_2444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0031, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2447 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0034, (cst_val *)&val_0156},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0035, (cst_val *)&val_0079},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0036, (cst_val *)&val_1478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2448 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0038, (cst_val *)&val_2449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2450 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0040, (cst_val *)&val_1187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2452 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0043, (cst_val *)&val_0079},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0044, (cst_val *)&val_0957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2454 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_164_NO_0047, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2456 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_164_NO_0050, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2458 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_t_164_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_awb_f0_t_164_cart = {
  cmu_us_awb_f0_t_164_cart_nodes,
  cmu_us_awb_f0_t_164_feat_table
};

static const cst_cart_node cmu_us_awb_f0_t_165_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0001, (cst_val *)&val_2459},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0002, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2460 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0004, (cst_val *)&val_2461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2462 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0006, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2464 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0009, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2465 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0011, (cst_val *)&val_2466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2468 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0014, (cst_val *)&val_0025},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0015, (cst_val *)&val_2469},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0016, (cst_val *)&val_0024},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0017, (cst_val *)&val_2470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2472 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0020, (cst_val *)&val_1446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2473 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0022, (cst_val *)&val_2474},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0023, (cst_val *)&val_2475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2477 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0026, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2479 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0029, (cst_val *)&val_0089},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0030, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2481 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0033, (cst_val *)&val_0032},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0034, (cst_val *)&val_0079},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0035, (cst_val *)&val_2359},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0036, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2483 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0040, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2485 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0043, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2486 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0045, (cst_val *)&val_0376},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0046, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2489 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0050, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0051, (cst_val *)&val_0152},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0052, (cst_val *)&val_0108},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0053, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2490 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0055, (cst_val *)&val_2491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2493 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0059, (cst_val *)&val_2494},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0060, (cst_val *)&val_2495},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0061, (cst_val *)&val_0397},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0062, (cst_val *)&val_2496},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2499 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0066, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2502 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0070, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2503 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0072, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_165_NO_0073, (cst_val *)&val_2504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2505 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0075, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2506 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_165_NO_0077, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2509 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_t_165_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_awb_f0_t_165_cart = {
  cmu_us_awb_f0_t_165_cart_nodes,
  cmu_us_awb_f0_t_165_feat_table
};

static const cst_cart_node cmu_us_awb_f0_t_166_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0000, (cst_val *)&val_0252},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0001, (cst_val *)&val_2510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2511 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0003, (cst_val *)&val_2512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2513 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0005, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2514 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0007, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2516 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0010, (cst_val *)&val_0089},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0011, (cst_val *)&val_0108},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0012, (cst_val *)&val_0079},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0013, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2518 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2519 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0018, (cst_val *)&val_2470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2521 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0021, (cst_val *)&val_2522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2524 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0024, (cst_val *)&val_2525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2526 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0026, (cst_val *)&val_2527},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0027, (cst_val *)&val_2528},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0028, (cst_val *)&val_0873},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0029, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2529 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0031, (cst_val *)&val_0128},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0032, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0033, (cst_val *)&val_2530},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0034, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2532 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0037, (cst_val *)&val_2533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2536 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0041, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2537 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0043, (cst_val *)&val_2538},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0044, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2539 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0046, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2540 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0048, (cst_val *)&val_2541},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2542 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0050, (cst_val *)&val_0355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2544 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0053, (cst_val *)&val_0112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2545 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0055, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2547 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0058, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2548 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0060, (cst_val *)&val_2549},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0061, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2552 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0065, (cst_val *)&val_0025},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0066, (cst_val *)&val_0136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2553 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0068, (cst_val *)&val_0908},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0069, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2556 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0073, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2557 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0075, (cst_val *)&val_2558},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0076, (cst_val *)&val_0397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2561 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0080, (cst_val *)&val_2562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2563 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0082, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0083, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2564 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0085, (cst_val *)&val_2565},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0086, (cst_val *)&val_0079},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0087, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2566 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_t_166_NO_0089, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2569 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_t_166_NO_0093, (cst_val *)&val_2570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2573 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_t_166_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_f0_t_166_cart = {
  cmu_us_awb_f0_t_166_cart_nodes,
  cmu_us_awb_f0_t_166_feat_table
};

static const cst_cart_node cmu_us_awb_f0_er_61_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0001, (cst_val *)&val_2574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2576 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0004, (cst_val *)&val_2577},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0005, (cst_val *)&val_2578},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0006, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2579 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0008, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2581 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0011, (cst_val *)&val_2582},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0012, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2583 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0014, (cst_val *)&val_2584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2586 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0017, (cst_val *)&val_0032},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0018, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0019, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2587 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0021, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2590 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0025, (cst_val *)&val_2591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2593 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0028, (cst_val *)&val_1430},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0029, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2595 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_61_NO_0032, (cst_val *)&val_2596},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0033, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2598 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_61_NO_0036, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2600 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_er_61_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_f0_er_61_cart = {
  cmu_us_awb_f0_er_61_cart_nodes,
  cmu_us_awb_f0_er_61_feat_table
};

static const cst_cart_node cmu_us_awb_f0_er_62_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0001, (cst_val *)&val_2601},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0002, (cst_val *)&val_0528},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0003, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2604 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0007, (cst_val *)&val_2605},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0008, (cst_val *)&val_2606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2609 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0012, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0013, (cst_val *)&val_2610},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0014, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0015, (cst_val *)&val_2611},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0016, (cst_val *)&val_2562},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0017, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2613 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0021, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2615 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0024, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2616 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0026, (cst_val *)&val_1709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2618 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0029, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0030, (cst_val *)&val_2619},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0031, (cst_val *)&val_2620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2621 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0033, (cst_val *)&val_1330},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0034, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2623 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0037, (cst_val *)&val_2474},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0038, (cst_val *)&val_0152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2627 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0043, (cst_val *)&val_2628},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0044, (cst_val *)&val_0311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2629 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0046, (cst_val *)&val_2630},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0047, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2633 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_62_NO_0051, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2635 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0054, (cst_val *)&val_1943},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2636 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_62_NO_0056, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2638 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_er_62_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_awb_f0_er_62_cart = {
  cmu_us_awb_f0_er_62_cart_nodes,
  cmu_us_awb_f0_er_62_feat_table
};

static const cst_cart_node cmu_us_awb_f0_er_63_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0001, (cst_val *)&val_0089},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0002, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2640 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0005, (cst_val *)&val_0416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2642 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0008, (cst_val *)&val_0032},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0009, (cst_val *)&val_2643},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0010, (cst_val *)&val_0179},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0011, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2645 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0014, (cst_val *)&val_2646},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0015, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0016, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2647 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0018, (cst_val *)&val_2648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2652 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0023, (cst_val *)&val_2653},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0024, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2654 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0026, (cst_val *)&val_2655},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0027, (cst_val *)&val_0567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2656 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_er_63_NO_0029, (cst_val *)&val_0079},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0030, (cst_val *)&val_0224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2661 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_er_63_NO_0036, (cst_val *)&val_2662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2664 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_er_63_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_f0_er_63_cart = {
  cmu_us_awb_f0_er_63_cart_nodes,
  cmu_us_awb_f0_er_63_feat_table
};

static const cst_cart_node cmu_us_awb_f0_ax_26_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0000, (cst_val *)&val_0032},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0001, (cst_val *)&val_2665},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0002, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2666 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0004, (cst_val *)&val_0032},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0005, (cst_val *)&val_0118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2667 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0007, (cst_val *)&val_0032},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0008, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2669 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0011, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2670 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0013, (cst_val *)&val_2671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2673 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0016, (cst_val *)&val_1288},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0017, (cst_val *)&val_2674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2675 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0019, (cst_val *)&val_1065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2676 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0021, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2678 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0024, (cst_val *)&val_2679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2680 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0026, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2681 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_f0_ax_26_NO_0028, (cst_val *)&val_0079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2683 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0031, (cst_val *)&val_2684},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0032, (cst_val *)&val_2685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2688 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_f0_ax_26_NO_0036, (cst_val *)&val_2689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2691 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_f0_ax_26_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_f0_ax_26_cart = {
  cmu_us_awb_f0_ax_26_cart_nodes,
  cmu_us_awb_f0_ax_26_feat_table
};


const cst_cart * const cmu_us_awb_f0_carts[] = {
 &cmu_us_awb_f0_zh_204_cart,
 &cmu_us_awb_f0_zh_205_cart,
 &cmu_us_awb_f0_zh_206_cart,
 &cmu_us_awb_f0_oy_131_cart,
 &cmu_us_awb_f0_oy_132_cart,
 &cmu_us_awb_f0_oy_133_cart,
 &cmu_us_awb_f0_ch_41_cart,
 &cmu_us_awb_f0_ch_42_cart,
 &cmu_us_awb_f0_ch_43_cart,
 &cmu_us_awb_f0_aw_21_cart,
 &cmu_us_awb_f0_aw_22_cart,
 &cmu_us_awb_f0_aw_23_cart,
 &cmu_us_awb_f0_ow_126_cart,
 &cmu_us_awb_f0_ow_127_cart,
 &cmu_us_awb_f0_ow_128_cart,
 &cmu_us_awb_f0_b_36_cart,
 &cmu_us_awb_f0_b_37_cart,
 &cmu_us_awb_f0_b_38_cart,
 &cmu_us_awb_f0_g_76_cart,
 &cmu_us_awb_f0_g_77_cart,
 &cmu_us_awb_f0_g_78_cart,
 &cmu_us_awb_f0_ng_121_cart,
 &cmu_us_awb_f0_ng_122_cart,
 &cmu_us_awb_f0_ng_123_cart,
 &cmu_us_awb_f0_uw_179_cart,
 &cmu_us_awb_f0_uw_180_cart,
 &cmu_us_awb_f0_uw_181_cart,
 &cmu_us_awb_f0_sh_156_cart,
 &cmu_us_awb_f0_sh_157_cart,
 &cmu_us_awb_f0_sh_158_cart,
 &cmu_us_awb_f0_uh_174_cart,
 &cmu_us_awb_f0_uh_175_cart,
 &cmu_us_awb_f0_uh_176_cart,
 &cmu_us_awb_f0_hh_81_cart,
 &cmu_us_awb_f0_hh_82_cart,
 &cmu_us_awb_f0_hh_83_cart,
 &cmu_us_awb_f0_ae_6_cart,
 &cmu_us_awb_f0_ae_7_cart,
 &cmu_us_awb_f0_ae_8_cart,
 &cmu_us_awb_f0_y_194_cart,
 &cmu_us_awb_f0_y_195_cart,
 &cmu_us_awb_f0_y_196_cart,
 &cmu_us_awb_f0_k_101_cart,
 &cmu_us_awb_f0_k_102_cart,
 &cmu_us_awb_f0_k_103_cart,
 &cmu_us_awb_f0_aa_1_cart,
 &cmu_us_awb_f0_aa_2_cart,
 &cmu_us_awb_f0_aa_3_cart,
 &cmu_us_awb_f0_ay_31_cart,
 &cmu_us_awb_f0_ay_32_cart,
 &cmu_us_awb_f0_ay_33_cart,
 &cmu_us_awb_f0_w_189_cart,
 &cmu_us_awb_f0_w_190_cart,
 &cmu_us_awb_f0_w_191_cart,
 &cmu_us_awb_f0_m_111_cart,
 &cmu_us_awb_f0_m_112_cart,
 &cmu_us_awb_f0_m_113_cart,
 &cmu_us_awb_f0_pau_142_cart,
 &cmu_us_awb_f0_ao_16_cart,
 &cmu_us_awb_f0_ao_17_cart,
 &cmu_us_awb_f0_ao_18_cart,
 &cmu_us_awb_f0_th_169_cart,
 &cmu_us_awb_f0_th_170_cart,
 &cmu_us_awb_f0_th_171_cart,
 &cmu_us_awb_f0_ah_11_cart,
 &cmu_us_awb_f0_ah_12_cart,
 &cmu_us_awb_f0_ah_13_cart,
 &cmu_us_awb_f0_v_184_cart,
 &cmu_us_awb_f0_v_185_cart,
 &cmu_us_awb_f0_v_186_cart,
 &cmu_us_awb_f0_dh_51_cart,
 &cmu_us_awb_f0_dh_52_cart,
 &cmu_us_awb_f0_dh_53_cart,
 &cmu_us_awb_f0_d_46_cart,
 &cmu_us_awb_f0_d_47_cart,
 &cmu_us_awb_f0_d_48_cart,
 &cmu_us_awb_f0_n_116_cart,
 &cmu_us_awb_f0_n_117_cart,
 &cmu_us_awb_f0_n_118_cart,
 &cmu_us_awb_f0_jh_96_cart,
 &cmu_us_awb_f0_jh_97_cart,
 &cmu_us_awb_f0_jh_98_cart,
 &cmu_us_awb_f0_r_146_cart,
 &cmu_us_awb_f0_r_147_cart,
 &cmu_us_awb_f0_r_148_cart,
 &cmu_us_awb_f0_ey_66_cart,
 &cmu_us_awb_f0_ey_67_cart,
 &cmu_us_awb_f0_ey_68_cart,
 &cmu_us_awb_f0_pau_141_cart,
 &cmu_us_awb_f0_pau_143_cart,
 &cmu_us_awb_f0_f_71_cart,
 &cmu_us_awb_f0_f_72_cart,
 &cmu_us_awb_f0_f_73_cart,
 &cmu_us_awb_f0_ih_86_cart,
 &cmu_us_awb_f0_ih_87_cart,
 &cmu_us_awb_f0_ih_88_cart,
 &cmu_us_awb_f0_ax_27_cart,
 &cmu_us_awb_f0_ax_28_cart,
 &cmu_us_awb_f0_p_136_cart,
 &cmu_us_awb_f0_p_137_cart,
 &cmu_us_awb_f0_p_138_cart,
 &cmu_us_awb_f0_iy_91_cart,
 &cmu_us_awb_f0_iy_92_cart,
 &cmu_us_awb_f0_iy_93_cart,
 &cmu_us_awb_f0_l_106_cart,
 &cmu_us_awb_f0_l_107_cart,
 &cmu_us_awb_f0_l_108_cart,
 &cmu_us_awb_f0_z_199_cart,
 &cmu_us_awb_f0_z_200_cart,
 &cmu_us_awb_f0_z_201_cart,
 &cmu_us_awb_f0_pau_161_cart,
 &cmu_us_awb_f0_s_151_cart,
 &cmu_us_awb_f0_s_152_cart,
 &cmu_us_awb_f0_s_153_cart,
 &cmu_us_awb_f0_eh_56_cart,
 &cmu_us_awb_f0_eh_57_cart,
 &cmu_us_awb_f0_eh_58_cart,
 &cmu_us_awb_f0_t_164_cart,
 &cmu_us_awb_f0_t_165_cart,
 &cmu_us_awb_f0_t_166_cart,
 &cmu_us_awb_f0_er_61_cart,
 &cmu_us_awb_f0_er_62_cart,
 &cmu_us_awb_f0_er_63_cart,
 &cmu_us_awb_f0_ax_26_cart,
 0 };
