/*****************************************************/
/**  Autogenerated cmu_us_awb single_mcep carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_awb_cg_single_mcep_trees.h"

static const cst_cart_node cmu_us_awb_single_mcep_zh_204_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_zh_204_NO_0000, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0002 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_zh_204_feat_table[] = {
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_single_mcep_zh_204_cart = {
  cmu_us_awb_single_mcep_zh_204_cart_nodes,
  cmu_us_awb_single_mcep_zh_204_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_zh_205_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_zh_205_NO_0000, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0005 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_zh_205_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_single_mcep_zh_205_cart = {
  cmu_us_awb_single_mcep_zh_205_cart_nodes,
  cmu_us_awb_single_mcep_zh_205_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_zh_206_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_zh_206_NO_0000, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_zh_206_NO_0001, (cst_val *)&val_0006},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_zh_206_NO_0002, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0008 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_zh_206_NO_0004, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_zh_206_NO_0008, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_zh_206_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_zh_206_cart = {
  cmu_us_awb_single_mcep_zh_206_cart_nodes,
  cmu_us_awb_single_mcep_zh_206_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_oy_131_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0000, (cst_val *)&val_0016},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0001, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0018 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0003, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0021 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0006, (cst_val *)&val_0022},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0007, (cst_val *)&val_0023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0008, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0011, (cst_val *)&val_0027},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0012, (cst_val *)&val_0028},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0013, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0032 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0017, (cst_val *)&val_0033},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0018, (cst_val *)&val_0034},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0019, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0019 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0021, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0025, (cst_val *)&val_0040},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0026, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0029, (cst_val *)&val_0044},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0030, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0022 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0033, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0048 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_131_NO_0035, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_oy_131_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_oy_131_cart = {
  cmu_us_awb_single_mcep_oy_131_cart_nodes,
  cmu_us_awb_single_mcep_oy_131_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_oy_132_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0000, (cst_val *)&val_0012},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0001, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0002, (cst_val *)&val_0053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0054 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0004, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0057 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0007, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0058 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0009, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0011, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0014, (cst_val *)&val_0064},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0015, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0018, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_132_NO_0020, (cst_val *)&val_0070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0072 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_oy_132_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_single_mcep_oy_132_cart = {
  cmu_us_awb_single_mcep_oy_132_cart_nodes,
  cmu_us_awb_single_mcep_oy_132_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_oy_133_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0000, (cst_val *)&val_0012},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0001, (cst_val *)&val_0073},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0002, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0076 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0005, (cst_val *)&val_0027},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0006, (cst_val *)&val_0061},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0007, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0011, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0082 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0014, (cst_val *)&val_0083},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0015, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0084 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0017, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0020, (cst_val *)&val_0073},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0021, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_oy_133_NO_0024, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_oy_133_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_single_mcep_oy_133_cart = {
  cmu_us_awb_single_mcep_oy_133_cart_nodes,
  cmu_us_awb_single_mcep_oy_133_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ch_41_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0001, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0002, (cst_val *)&val_0016},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0003, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0007, (cst_val *)&val_0097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0099 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0010, (cst_val *)&val_0003},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0011, (cst_val *)&val_0100},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0012, (cst_val *)&val_0101},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0013, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0104 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0016, (cst_val *)&val_0009},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0017, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0019, (cst_val *)&val_0107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0022, (cst_val *)&val_0035},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0025, (cst_val *)&val_0049},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0026, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0028, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0114 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0031, (cst_val *)&val_0003},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0032, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0115 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0034, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0119 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0038, (cst_val *)&val_0120},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0039, (cst_val *)&val_0121},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0040, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0125 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_41_NO_0044, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0128 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ch_41_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_ch_41_cart = {
  cmu_us_awb_single_mcep_ch_41_cart_nodes,
  cmu_us_awb_single_mcep_ch_41_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ch_42_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0000, (cst_val *)&val_0129},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0001, (cst_val *)&val_0130},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0002, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0003, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0007, (cst_val *)&val_0135},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0008, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0009, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0138 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0013, (cst_val *)&val_0139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0140 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0015, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0142 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0018, (cst_val *)&val_0143},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0019, (cst_val *)&val_0144},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0020, (cst_val *)&val_0145},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0021, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0146 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0023, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0026, (cst_val *)&val_0147},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0027, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0031, (cst_val *)&val_0153},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0032, (cst_val *)&val_0154},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0033, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0156 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0036, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0039, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0040, (cst_val *)&val_0159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0161 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0046, (cst_val *)&val_0017},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0047, (cst_val *)&val_0164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0049, (cst_val *)&val_0166},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0052, (cst_val *)&val_0169},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0053, (cst_val *)&val_0009},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0054, (cst_val *)&val_0170},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0172 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0057, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0174 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0059, (cst_val *)&val_0175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0177 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0062, (cst_val *)&val_0178},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0063, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_42_NO_0065, (cst_val *)&val_0181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ch_42_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_single_mcep_ch_42_cart = {
  cmu_us_awb_single_mcep_ch_42_cart_nodes,
  cmu_us_awb_single_mcep_ch_42_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ch_43_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0000, (cst_val *)&val_0185},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0001, (cst_val *)&val_0186},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0002, (cst_val *)&val_0187},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0003, (cst_val *)&val_0188},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0004, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0008, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0192 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0010, (cst_val *)&val_0147},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0011, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0195 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0015, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0016, (cst_val *)&val_0196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0199 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0020, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ch_43_NO_0021, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ch_43_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_ch_43_cart = {
  cmu_us_awb_single_mcep_ch_43_cart_nodes,
  cmu_us_awb_single_mcep_ch_43_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aw_21_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0000, (cst_val *)&val_0129},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0001, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0003, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0004, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0007, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0207 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0009, (cst_val *)&val_0147},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0010, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0014, (cst_val *)&val_0040},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0015, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0018, (cst_val *)&val_0214},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0019, (cst_val *)&val_0215},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0217 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0022, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0218 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0024, (cst_val *)&val_0219},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0025, (cst_val *)&val_0220},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0026, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0027, (cst_val *)&val_0221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0223 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0030, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0032, (cst_val *)&val_0225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0034, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0227 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_21_NO_0036, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0231 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aw_21_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_aw_21_cart = {
  cmu_us_awb_single_mcep_aw_21_cart_nodes,
  cmu_us_awb_single_mcep_aw_21_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aw_22_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0001, (cst_val *)&val_0233},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0002, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0234 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0004, (cst_val *)&val_0235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0006, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0239 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0009, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0241 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0012, (cst_val *)&val_0011},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0013, (cst_val *)&val_0065},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0014, (cst_val *)&val_0242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0243 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0016, (cst_val *)&val_0244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0246 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0019, (cst_val *)&val_0003},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0020, (cst_val *)&val_0247},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0021, (cst_val *)&val_0248},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0251 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0025, (cst_val *)&val_0252},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0026, (cst_val *)&val_0253},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0027, (cst_val *)&val_0254},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0028, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0031, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0032, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0260 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0037, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0040, (cst_val *)&val_0264},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0041, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0265 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0043, (cst_val *)&val_0266},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0046, (cst_val *)&val_0269},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0047, (cst_val *)&val_0003},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0048, (cst_val *)&val_0270},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0051, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0053, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0055, (cst_val *)&val_0276},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0056, (cst_val *)&val_0277},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0057, (cst_val *)&val_0278},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0058, (cst_val *)&val_0279},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0059, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0064, (cst_val *)&val_0284},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0065, (cst_val *)&val_0285},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0286 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0067, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0287 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0069, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0290 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0073, (cst_val *)&val_0291},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0075, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0293 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0077, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0295 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_22_NO_0080, (cst_val *)&val_0296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aw_22_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_aw_22_cart = {
  cmu_us_awb_single_mcep_aw_22_cart_nodes,
  cmu_us_awb_single_mcep_aw_22_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aw_23_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0001, (cst_val *)&val_0299},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0002, (cst_val *)&val_0232},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0003, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0006, (cst_val *)&val_0017},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0007, (cst_val *)&val_0131},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0008, (cst_val *)&val_0303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0011, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0308 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0015, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0016, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0309 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0018, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0311 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0021, (cst_val *)&val_0312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0314 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0024, (cst_val *)&val_0315},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0025, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0026, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0318 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0029, (cst_val *)&val_0065},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0030, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0032, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0035, (cst_val *)&val_0323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0038, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0040, (cst_val *)&val_0065},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0041, (cst_val *)&val_0327},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0329 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0044, (cst_val *)&val_0330},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aw_23_NO_0045, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0333 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aw_23_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_awb_single_mcep_aw_23_cart = {
  cmu_us_awb_single_mcep_aw_23_cart_nodes,
  cmu_us_awb_single_mcep_aw_23_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ow_126_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0000, (cst_val *)&val_0204},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0001, (cst_val *)&val_0027},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0002, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0004, (cst_val *)&val_0335},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0005, (cst_val *)&val_0336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0339 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0009, (cst_val *)&val_0340},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0010, (cst_val *)&val_0341},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0011, (cst_val *)&val_0342},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0345 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0015, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0018, (cst_val *)&val_0349},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0019, (cst_val *)&val_0121},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0020, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0351 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0022, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0025, (cst_val *)&val_0130},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0026, (cst_val *)&val_0147},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0027, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0355 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0030, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0032, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0358 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0035, (cst_val *)&val_0359},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0036, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0037, (cst_val *)&val_0360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0362 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0040, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0364 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0042, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0367 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0045, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0369 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0048, (cst_val *)&val_0370},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0049, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0372 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0052, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0374 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_126_NO_0054, (cst_val *)&val_0375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0377 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ow_126_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_single_mcep_ow_126_cart = {
  cmu_us_awb_single_mcep_ow_126_cart_nodes,
  cmu_us_awb_single_mcep_ow_126_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ow_127_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0000, (cst_val *)&val_0378},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0001, (cst_val *)&val_0379},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0002, (cst_val *)&val_0380},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0003, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0004, (cst_val *)&val_0381},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0383 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0007, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0384 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0009, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0385 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0011, (cst_val *)&val_0386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0388 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0014, (cst_val *)&val_0147},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0015, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0390 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0018, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0391 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0020, (cst_val *)&val_0392},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0021, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0393 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0023, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0395 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0026, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0397 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0029, (cst_val *)&val_0398},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0030, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0031, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0401 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0034, (cst_val *)&val_0402},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0035, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0405 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0038, (cst_val *)&val_0147},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0039, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0407 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0042, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0410 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0045, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0411 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0047, (cst_val *)&val_0412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0414 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0050, (cst_val *)&val_0379},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0051, (cst_val *)&val_0264},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0052, (cst_val *)&val_0065},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0053, (cst_val *)&val_0415},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0416 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0055, (cst_val *)&val_0417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0419 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0058, (cst_val *)&val_0007},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0059, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0422 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0062, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0423 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0064, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0424 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0066, (cst_val *)&val_0425},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0067, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0427 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0070, (cst_val *)&val_0428},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0429 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0072, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0431 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0075, (cst_val *)&val_0432},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0076, (cst_val *)&val_0065},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0077, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0433 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0079, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0434 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0081, (cst_val *)&val_0435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0437 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0084, (cst_val *)&val_0438},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0085, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0439 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0087, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0088, (cst_val *)&val_0440},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0089, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0443 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0093, (cst_val *)&val_0444},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0094, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0447 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0098, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0099, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0450 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0102, (cst_val *)&val_0049},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0103, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0453 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0107, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0454 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0109, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0110, (cst_val *)&val_0455},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0456 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0112, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0459 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0116, (cst_val *)&val_0131},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0117, (cst_val *)&val_0264},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0118, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0460 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0120, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0462 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0123, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0463 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0125, (cst_val *)&val_0464},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0126, (cst_val *)&val_0465},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0127, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0468 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0131, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0470 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0134, (cst_val *)&val_0315},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0135, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0473 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_127_NO_0138, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0476 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ow_127_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_ow_127_cart = {
  cmu_us_awb_single_mcep_ow_127_cart_nodes,
  cmu_us_awb_single_mcep_ow_127_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ow_128_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0000, (cst_val *)&val_0477},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0001, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0002, (cst_val *)&val_0478},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0003, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0004, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0481 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0007, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0482 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0009, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0484 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0012, (cst_val *)&val_0485},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0013, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0486 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0015, (cst_val *)&val_0487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0490 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0019, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0020, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0493 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0023, (cst_val *)&val_0379},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0024, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0495 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0026, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0496 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0028, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0497 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0030, (cst_val *)&val_0498},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0031, (cst_val *)&val_0064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0032, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0502 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0037, (cst_val *)&val_0049},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0038, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0503 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0040, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0041, (cst_val *)&val_0504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0506 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0044, (cst_val *)&val_0064},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0045, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0509 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0049, (cst_val *)&val_0510},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0050, (cst_val *)&val_0511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0512 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0052, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0513 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0054, (cst_val *)&val_0054},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0055, (cst_val *)&val_0514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0518 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0060, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0061, (cst_val *)&val_0232},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0062, (cst_val *)&val_0519},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0063, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0064, (cst_val *)&val_0520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0524 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0069, (cst_val *)&val_0525},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0070, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0528 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0073, (cst_val *)&val_0529},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0074, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0531 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0076, (cst_val *)&val_0532},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0077, (cst_val *)&val_0485},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0078, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0536 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0082, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0083, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0537 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0085, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0539 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0088, (cst_val *)&val_0540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0541 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0090, (cst_val *)&val_0542},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0091, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0545 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0094, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0548 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0098, (cst_val *)&val_0147},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0099, (cst_val *)&val_0549},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0100, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0551 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0102, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0552 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0104, (cst_val *)&val_0553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0554 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0106, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0555 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0108, (cst_val *)&val_0556},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0559 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0112, (cst_val *)&val_0560},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0113, (cst_val *)&val_0561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0562 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0115, (cst_val *)&val_0035},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0116, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0117, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0563 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0119, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0565 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0122, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0566 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0124, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0567 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0126, (cst_val *)&val_0568},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0569 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0128, (cst_val *)&val_0570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0572 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0131, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0574 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ow_128_NO_0134, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0577 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ow_128_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_ow_128_cart = {
  cmu_us_awb_single_mcep_ow_128_cart_nodes,
  cmu_us_awb_single_mcep_ow_128_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_b_36_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0000, (cst_val *)&val_0578},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0002, (cst_val *)&val_0579},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0003, (cst_val *)&val_0580},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0004, (cst_val *)&val_0581},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0005, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0583 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0008, (cst_val *)&val_0477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0586 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0012, (cst_val *)&val_0587},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0589 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0015, (cst_val *)&val_0590},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0016, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0591 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0018, (cst_val *)&val_0592},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0019, (cst_val *)&val_0593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0595 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0022, (cst_val *)&val_0596},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0023, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0598 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0025, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0600 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0028, (cst_val *)&val_0147},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0029, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0604 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0033, (cst_val *)&val_0580},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0034, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0035, (cst_val *)&val_0605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0607 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0038, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0608 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0040, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0611 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0044, (cst_val *)&val_0147},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0045, (cst_val *)&val_0612},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0046, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0614 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0048, (cst_val *)&val_0615},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0049, (cst_val *)&val_0616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0618 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0052, (cst_val *)&val_0619},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0621 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0055, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0056, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0623 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0058, (cst_val *)&val_0624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0627 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0062, (cst_val *)&val_0628},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0063, (cst_val *)&val_0629},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0064, (cst_val *)&val_0045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0065, (cst_val *)&val_0630},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0066, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0632 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0069, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0635 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0073, (cst_val *)&val_0175},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0074, (cst_val *)&val_0636},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0075, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0639 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0078, (cst_val *)&val_0640},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0079, (cst_val *)&val_0641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0644 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0083, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0645 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0085, (cst_val *)&val_0116},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0086, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0647 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0089, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0649 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0092, (cst_val *)&val_0000},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0093, (cst_val *)&val_0015},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0094, (cst_val *)&val_0650},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0095, (cst_val *)&val_0296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0651 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0097, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0652 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0099, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0102, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0657 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0106, (cst_val *)&val_0658},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0107, (cst_val *)&val_0659},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0108, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0661 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0110, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0662 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0112, (cst_val *)&val_0663},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0113, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0666 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0117, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0668 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_36_NO_0120, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0671 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_b_36_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_single_mcep_b_36_cart = {
  cmu_us_awb_single_mcep_b_36_cart_nodes,
  cmu_us_awb_single_mcep_b_36_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_b_37_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0000, (cst_val *)&val_0672},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0001, (cst_val *)&val_0673},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0002, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0003, (cst_val *)&val_0674},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0004, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0678 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0008, (cst_val *)&val_0679},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0009, (cst_val *)&val_0680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0681 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0011, (cst_val *)&val_0682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0684 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0014, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0686 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0017, (cst_val *)&val_0687},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0018, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0689 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0021, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0690 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0023, (cst_val *)&val_0135},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0024, (cst_val *)&val_0691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0692 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0026, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0694 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0029, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0696 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0032, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0033, (cst_val *)&val_0697},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0034, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0699 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0037, (cst_val *)&val_0700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0702 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0040, (cst_val *)&val_0703},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0041, (cst_val *)&val_0704},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0042, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0043, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0045, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0707 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0047, (cst_val *)&val_0708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0710 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0050, (cst_val *)&val_0116},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0051, (cst_val *)&val_0711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0713 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0054, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0715 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0056, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0719 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0060, (cst_val *)&val_0000},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0061, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0720 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_37_NO_0063, (cst_val *)&val_0721},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0724 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_b_37_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_awb_single_mcep_b_37_cart = {
  cmu_us_awb_single_mcep_b_37_cart_nodes,
  cmu_us_awb_single_mcep_b_37_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_b_38_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0000, (cst_val *)&val_0725},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0001, (cst_val *)&val_0130},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0002, (cst_val *)&val_0580},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0003, (cst_val *)&val_0726},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0004, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0727 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0006, (cst_val *)&val_0659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0728 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0008, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0729 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0010, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0731 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0013, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0733 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0016, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0736 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0019, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0737 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0021, (cst_val *)&val_0131},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0022, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0738 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0024, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0740 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0026, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0742 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0029, (cst_val *)&val_0743},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_b_38_NO_0030, (cst_val *)&val_0744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0748 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_b_38_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_single_mcep_b_38_cart = {
  cmu_us_awb_single_mcep_b_38_cart_nodes,
  cmu_us_awb_single_mcep_b_38_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_g_76_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0000, (cst_val *)&val_0399},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0001, (cst_val *)&val_0673},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0002, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0749 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0004, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0005, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0751 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0008, (cst_val *)&val_0752},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0009, (cst_val *)&val_0753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0756 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0013, (cst_val *)&val_0757},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0014, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0758 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0759 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0018, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0760 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0020, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0761 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0022, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0763 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0025, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0764 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0027, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0766 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0030, (cst_val *)&val_0767},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0031, (cst_val *)&val_0017},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0032, (cst_val *)&val_0768},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0770 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0035, (cst_val *)&val_0116},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0036, (cst_val *)&val_0771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0773 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0039, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0774 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0041, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0776 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0044, (cst_val *)&val_0144},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0045, (cst_val *)&val_0658},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0046, (cst_val *)&val_0777},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0047, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0779 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0050, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0780 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0052, (cst_val *)&val_0781},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0783 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0055, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0785 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0058, (cst_val *)&val_0147},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0059, (cst_val *)&val_0786},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0060, (cst_val *)&val_0787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0788 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0062, (cst_val *)&val_0175},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0063, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0792 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0068, (cst_val *)&val_0153},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0069, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0794 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_76_NO_0072, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0796 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_g_76_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_g_76_cart = {
  cmu_us_awb_single_mcep_g_76_cart_nodes,
  cmu_us_awb_single_mcep_g_76_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_g_77_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0000, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0001, (cst_val *)&val_0797},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0002, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0800 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0005, (cst_val *)&val_0801},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0006, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0804 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0010, (cst_val *)&val_0360},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0011, (cst_val *)&val_0672},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0012, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0806 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0015, (cst_val *)&val_0016},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0016, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0809 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0020, (cst_val *)&val_0154},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0021, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0022, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0811 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0025, (cst_val *)&val_0812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0814 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_77_NO_0028, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0816 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_g_77_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_g_77_cart = {
  cmu_us_awb_single_mcep_g_77_cart_nodes,
  cmu_us_awb_single_mcep_g_77_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_g_78_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0000, (cst_val *)&val_0027},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0001, (cst_val *)&val_0009},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0002, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0003, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0819 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0007, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0008, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0821 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0011, (cst_val *)&val_0130},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0012, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0822 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0014, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0825 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0017, (cst_val *)&val_0004},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0018, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0826 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0020, (cst_val *)&val_0131},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0021, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0828 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0024, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0830 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0027, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0832 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0030, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0833 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0032, (cst_val *)&val_0154},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0033, (cst_val *)&val_0009},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0034, (cst_val *)&val_0834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0836 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0037, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0838 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0040, (cst_val *)&val_0003},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0041, (cst_val *)&val_0834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0839 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_g_78_NO_0043, (cst_val *)&val_0840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0843 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_g_78_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_single_mcep_g_78_cart = {
  cmu_us_awb_single_mcep_g_78_cart_nodes,
  cmu_us_awb_single_mcep_g_78_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ng_121_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0001, (cst_val *)&val_0844},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0845 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0003, (cst_val *)&val_0846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0848 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0006, (cst_val *)&val_0849},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0007, (cst_val *)&val_0009},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0008, (cst_val *)&val_0130},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0009, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0851 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0012, (cst_val *)&val_0316},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0013, (cst_val *)&val_0852},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0014, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0855 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0017, (cst_val *)&val_0856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0858 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0020, (cst_val *)&val_0525},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0021, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0860 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0024, (cst_val *)&val_0861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0863 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0027, (cst_val *)&val_0864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0866 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0030, (cst_val *)&val_0867},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0031, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0032, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0871 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0036, (cst_val *)&val_0872},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0037, (cst_val *)&val_0873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0875 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0040, (cst_val *)&val_0876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0877 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0042, (cst_val *)&val_0878},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0043, (cst_val *)&val_0556},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0880 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0046, (cst_val *)&val_0196},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0047, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0881 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0049, (cst_val *)&val_0660},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_121_NO_0050, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0886 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ng_121_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_single_mcep_ng_121_cart = {
  cmu_us_awb_single_mcep_ng_121_cart_nodes,
  cmu_us_awb_single_mcep_ng_121_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ng_122_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0000, (cst_val *)&val_0887},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0001, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0888 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0003, (cst_val *)&val_0592},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0004, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0005, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0890 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0008, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0009, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0893 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0013, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0014, (cst_val *)&val_0894},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0015, (cst_val *)&val_0895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0897 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0018, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0019, (cst_val *)&val_0898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0900 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0022, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0903 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0026, (cst_val *)&val_0904},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0027, (cst_val *)&val_0905},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0028, (cst_val *)&val_0009},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0029, (cst_val *)&val_0130},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0030, (cst_val *)&val_0906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0908 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0033, (cst_val *)&val_0909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0912 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0037, (cst_val *)&val_0009},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0038, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0039, (cst_val *)&val_0913},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0040, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0914 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0042, (cst_val *)&val_0915},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0043, (cst_val *)&val_0916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0920 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0048, (cst_val *)&val_0921},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0049, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0923 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0052, (cst_val *)&val_0511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0925 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_122_NO_0055, (cst_val *)&val_0926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0929 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ng_122_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_ng_122_cart = {
  cmu_us_awb_single_mcep_ng_122_cart_nodes,
  cmu_us_awb_single_mcep_ng_122_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ng_123_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0000, (cst_val *)&val_0930},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0001, (cst_val *)&val_0931},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0002, (cst_val *)&val_0147},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0003, (cst_val *)&val_0932},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0004, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0005, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0934 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0007, (cst_val *)&val_0935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0937 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0010, (cst_val *)&val_0938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0941 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0014, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0942 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0016, (cst_val *)&val_0658},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0017, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0943 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0019, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0021, (cst_val *)&val_0945},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0948 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0025, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0951 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0028, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0029, (cst_val *)&val_0952},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0030, (cst_val *)&val_0953},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0031, (cst_val *)&val_0954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0956 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0034, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0035, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0959 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0039, (cst_val *)&val_0953},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0040, (cst_val *)&val_0342},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0961 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0043, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0962 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0045, (cst_val *)&val_0963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0965 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0048, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0049, (cst_val *)&val_0966},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0050, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0968 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0052, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0970 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0054, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0972 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0057, (cst_val *)&val_0049},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0058, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0975 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ng_123_NO_0062, (cst_val *)&val_0976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0978 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ng_123_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_ng_123_cart = {
  cmu_us_awb_single_mcep_ng_123_cart_nodes,
  cmu_us_awb_single_mcep_ng_123_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uw_179_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0000, (cst_val *)&val_0204},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0001, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0979 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0003, (cst_val *)&val_0042},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0004, (cst_val *)&val_0980},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0005, (cst_val *)&val_0981},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0982 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0007, (cst_val *)&val_0983},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0985 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0010, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0988 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0014, (cst_val *)&val_0989},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0015, (cst_val *)&val_0990},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0016, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0991 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0018, (cst_val *)&val_0992},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0019, (cst_val *)&val_0993},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0020, (cst_val *)&val_0994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0996 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0023, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0998 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0026, (cst_val *)&val_0615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1000 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0029, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1002 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0032, (cst_val *)&val_1003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0033, (cst_val *)&val_1004},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0034, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0035, (cst_val *)&val_1005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1007 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0038, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1008 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0040, (cst_val *)&val_1009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1011 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1012 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0045, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1014 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0048, (cst_val *)&val_0131},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_179_NO_0049, (cst_val *)&val_1015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1018 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uw_179_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_uw_179_cart = {
  cmu_us_awb_single_mcep_uw_179_cart_nodes,
  cmu_us_awb_single_mcep_uw_179_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uw_180_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0000, (cst_val *)&val_0725},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0002, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1019 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0004, (cst_val *)&val_1020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1022 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0007, (cst_val *)&val_1023},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0008, (cst_val *)&val_0373},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0009, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1025 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0012, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1026 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0014, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0015, (cst_val *)&val_1027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1030 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0019, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0020, (cst_val *)&val_0904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1032 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0023, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1033 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0025, (cst_val *)&val_1034},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0026, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1035 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0028, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1037 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0031, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1039 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0034, (cst_val *)&val_1040},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0035, (cst_val *)&val_1041},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0036, (cst_val *)&val_0017},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0037, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1042 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0039, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1043 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0041, (cst_val *)&val_1044},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0042, (cst_val *)&val_1045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1048 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0046, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0047, (cst_val *)&val_1049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1051 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0050, (cst_val *)&val_1052},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0051, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1054 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0054, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1055 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0056, (cst_val *)&val_1056},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0057, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1058 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0060, (cst_val *)&val_1059},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0061, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1062 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0065, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1063 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0067, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1064 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0069, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1065 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_180_NO_0071, (cst_val *)&val_1066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1069 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uw_180_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_single_mcep_uw_180_cart = {
  cmu_us_awb_single_mcep_uw_180_cart_nodes,
  cmu_us_awb_single_mcep_uw_180_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uw_181_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0001, (cst_val *)&val_1070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1071 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0003, (cst_val *)&val_1072},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0004, (cst_val *)&val_1073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0005, (cst_val *)&val_1074},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0006, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1077 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0010, (cst_val *)&val_1078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1080 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0013, (cst_val *)&val_1081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1082 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0015, (cst_val *)&val_1083},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0016, (cst_val *)&val_1084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1087 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0020, (cst_val *)&val_0378},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0021, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0022, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1089 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0024, (cst_val *)&val_1090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1091 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0026, (cst_val *)&val_1092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1093 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0028, (cst_val *)&val_1094},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0029, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1096 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0032, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1098 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0035, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1100 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0037, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0038, (cst_val *)&val_1101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1103 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0041, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1104 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0043, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1106 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0046, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0047, (cst_val *)&val_0953},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0048, (cst_val *)&val_1107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1109 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0051, (cst_val *)&val_1110},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1111 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0053, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1113 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0056, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1114 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0058, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0059, (cst_val *)&val_1115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1116 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0061, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1118 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0064, (cst_val *)&val_0049},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0065, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1119 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0067, (cst_val *)&val_1120},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uw_181_NO_0068, (cst_val *)&val_1121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1125 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uw_181_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_uw_181_cart = {
  cmu_us_awb_single_mcep_uw_181_cart_nodes,
  cmu_us_awb_single_mcep_uw_181_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_sh_156_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0001, (cst_val *)&val_0057},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0002, (cst_val *)&val_0373},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1127 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0006, (cst_val *)&val_1128},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0007, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1130 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0010, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1134 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0014, (cst_val *)&val_0952},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0015, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0016, (cst_val *)&val_1135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1137 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0019, (cst_val *)&val_1138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1140 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_156_NO_0022, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1142 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_sh_156_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_single_mcep_sh_156_cart = {
  cmu_us_awb_single_mcep_sh_156_cart_nodes,
  cmu_us_awb_single_mcep_sh_156_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_sh_157_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0000, (cst_val *)&val_0525},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0001, (cst_val *)&val_0247},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0002, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0003, (cst_val *)&val_0592},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0004, (cst_val *)&val_0135},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0005, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1145 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0009, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0010, (cst_val *)&val_1146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1148 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0013, (cst_val *)&val_0009},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0014, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1151 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0018, (cst_val *)&val_1152},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0019, (cst_val *)&val_1153},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0020, (cst_val *)&val_1154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1156 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0023, (cst_val *)&val_1157},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0024, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1161 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0028, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0029, (cst_val *)&val_1162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1165 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0033, (cst_val *)&val_1166},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0034, (cst_val *)&val_1167},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0035, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0036, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1169 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0039, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0041, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1171 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0043, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1172 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0045, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1173 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0047, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1175 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0050, (cst_val *)&val_0064},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0051, (cst_val *)&val_1176},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0052, (cst_val *)&val_1177},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0053, (cst_val *)&val_1178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1181 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0057, (cst_val *)&val_1182},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0058, (cst_val *)&val_1183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1186 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0062, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0063, (cst_val *)&val_1187},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0064, (cst_val *)&val_1188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1189 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0066, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1192 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0070, (cst_val *)&val_0882},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0071, (cst_val *)&val_1193},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0072, (cst_val *)&val_0009},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0073, (cst_val *)&val_0009},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0074, (cst_val *)&val_1194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1199 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0080, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1200 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0082, (cst_val *)&val_0270},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0083, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1203 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0087, (cst_val *)&val_0399},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0088, (cst_val *)&val_0009},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0089, (cst_val *)&val_1204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1206 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0092, (cst_val *)&val_1207},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0093, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1209 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0095, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1212 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0099, (cst_val *)&val_0007},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0100, (cst_val *)&val_1213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1215 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0103, (cst_val *)&val_1216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1217 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0105, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1219 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0108, (cst_val *)&val_1220},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0109, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1221 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0111, (cst_val *)&val_0045},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0112, (cst_val *)&val_1222},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0113, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1226 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0118, (cst_val *)&val_0008},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0119, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1228 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_157_NO_0122, (cst_val *)&val_1229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1231 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_sh_157_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_single_mcep_sh_157_cart = {
  cmu_us_awb_single_mcep_sh_157_cart_nodes,
  cmu_us_awb_single_mcep_sh_157_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_sh_158_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0000, (cst_val *)&val_1232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0001, (cst_val *)&val_0046},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0002, (cst_val *)&val_1233},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0003, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0004, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1235 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0007, (cst_val *)&val_1236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1237 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0009, (cst_val *)&val_0009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0010, (cst_val *)&val_1238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1240 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0013, (cst_val *)&val_1241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1242 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0015, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1243 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1245 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0020, (cst_val *)&val_0017},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0021, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1247 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0024, (cst_val *)&val_0153},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0025, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1248 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0027, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1250 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0030, (cst_val *)&val_0003},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0031, (cst_val *)&val_1251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1253 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0034, (cst_val *)&val_0009},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0035, (cst_val *)&val_1254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1258 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0040, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0041, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1260 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0044, (cst_val *)&val_1261},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0045, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1262 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0047, (cst_val *)&val_1263},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0048, (cst_val *)&val_1264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1267 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_sh_158_NO_0052, (cst_val *)&val_1268},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1270 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_sh_158_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_single_mcep_sh_158_cart = {
  cmu_us_awb_single_mcep_sh_158_cart_nodes,
  cmu_us_awb_single_mcep_sh_158_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uh_174_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0000, (cst_val *)&val_1271},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0001, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1272 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0003, (cst_val *)&val_1273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1275 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0006, (cst_val *)&val_1276},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0007, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0010, (cst_val *)&val_1052},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0011, (cst_val *)&val_1279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1281 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0014, (cst_val *)&val_1282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1283 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_174_NO_0016, (cst_val *)&val_1284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1286 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uh_174_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_single_mcep_uh_174_cart = {
  cmu_us_awb_single_mcep_uh_174_cart_nodes,
  cmu_us_awb_single_mcep_uh_174_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uh_175_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0000, (cst_val *)&val_0010},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0001, (cst_val *)&val_1287},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0002, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0003, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0004, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1291 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0009, (cst_val *)&val_0121},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0010, (cst_val *)&val_1292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1294 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0013, (cst_val *)&val_1295},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0014, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1297 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0017, (cst_val *)&val_1298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1300 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0020, (cst_val *)&val_1301},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0021, (cst_val *)&val_1302},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0022, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1304 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0025, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0026, (cst_val *)&val_1305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1308 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0030, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1309 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_175_NO_0032, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1311 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uh_175_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_uh_175_cart = {
  cmu_us_awb_single_mcep_uh_175_cart_nodes,
  cmu_us_awb_single_mcep_uh_175_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_uh_176_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0001, (cst_val *)&val_0005},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0003, (cst_val *)&val_1312},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1316 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0008, (cst_val *)&val_1317},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0009, (cst_val *)&val_1318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1319 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_uh_176_NO_0011, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1322 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_uh_176_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_single_mcep_uh_176_cart = {
  cmu_us_awb_single_mcep_uh_176_cart_nodes,
  cmu_us_awb_single_mcep_uh_176_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_hh_81_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0001, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0002, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0003, (cst_val *)&val_0005},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0004, (cst_val *)&val_1323},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0005, (cst_val *)&val_0020},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0006, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1324 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0008, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1328 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0013, (cst_val *)&val_1329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1332 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0017, (cst_val *)&val_0533},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0018, (cst_val *)&val_0049},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0019, (cst_val *)&val_1284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1335 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0023, (cst_val *)&val_1336},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0024, (cst_val *)&val_0952},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0025, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1337 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0027, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1340 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0030, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1342 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0033, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1344 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0036, (cst_val *)&val_0073},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0037, (cst_val *)&val_1345},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0038, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1347 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0041, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1349 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0044, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0045, (cst_val *)&val_0725},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0046, (cst_val *)&val_0853},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0047, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1353 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0052, (cst_val *)&val_0121},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0053, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1355 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0056, (cst_val *)&val_1356},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0057, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1358 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0060, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0061, (cst_val *)&val_0398},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0062, (cst_val *)&val_1359},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0063, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1361 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0066, (cst_val *)&val_0921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1363 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0069, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1364 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0071, (cst_val *)&val_1365},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0072, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1367 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0075, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0077, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1370 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0080, (cst_val *)&val_0116},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0081, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1372 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_81_NO_0084, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1374 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_hh_81_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_hh_81_cart = {
  cmu_us_awb_single_mcep_hh_81_cart_nodes,
  cmu_us_awb_single_mcep_hh_81_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_hh_82_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0001, (cst_val *)&val_1302},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0002, (cst_val *)&val_0009},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0003, (cst_val *)&val_0007},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0004, (cst_val *)&val_0590},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0005, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1376 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0008, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1378 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0011, (cst_val *)&val_1379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1381 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0014, (cst_val *)&val_1382},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1384 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0017, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0018, (cst_val *)&val_1385},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0019, (cst_val *)&val_1386},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0020, (cst_val *)&val_1387},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0021, (cst_val *)&val_0007},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0022, (cst_val *)&val_0994},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0023, (cst_val *)&val_1388},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0024, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1393 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0030, (cst_val *)&val_0027},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0031, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1395 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0034, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1399 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0039, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1401 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0042, (cst_val *)&val_1402},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0043, (cst_val *)&val_1403},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0044, (cst_val *)&val_1356},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0045, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1405 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0048, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1406 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0050, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1407 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0052, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1409 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0055, (cst_val *)&val_0073},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0056, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1411 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0059, (cst_val *)&val_0175},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0060, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1412 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0062, (cst_val *)&val_1413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1414 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0064, (cst_val *)&val_0049},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0065, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1417 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0069, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1419 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_82_NO_0072, (cst_val *)&val_1420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1422 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_hh_82_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_hh_82_cart = {
  cmu_us_awb_single_mcep_hh_82_cart_nodes,
  cmu_us_awb_single_mcep_hh_82_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_hh_83_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0000, (cst_val *)&val_0009},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0001, (cst_val *)&val_1423},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0002, (cst_val *)&val_1424},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0003, (cst_val *)&val_0533},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0004, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1426 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0007, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1429 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0011, (cst_val *)&val_0232},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0012, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1431 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0015, (cst_val *)&val_0004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0016, (cst_val *)&val_0992},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0017, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1432 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0019, (cst_val *)&val_1433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1436 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0023, (cst_val *)&val_1437},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1439 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0026, (cst_val *)&val_0175},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0027, (cst_val *)&val_0003},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0028, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1441 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0031, (cst_val *)&val_0679},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0032, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0033, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1444 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0037, (cst_val *)&val_0065},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0038, (cst_val *)&val_1445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1447 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0041, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1448 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1449 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0045, (cst_val *)&val_0003},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0046, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1451 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0049, (cst_val *)&val_0027},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0050, (cst_val *)&val_1452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1455 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0054, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0055, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1456 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0057, (cst_val *)&val_1236},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0058, (cst_val *)&val_1457},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0059, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1458 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0061, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1461 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0064, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1462 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0066, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1464 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0069, (cst_val *)&val_1465},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0070, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1469 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0074, (cst_val *)&val_1470},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0075, (cst_val *)&val_0375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1472 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0078, (cst_val *)&val_1473},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0079, (cst_val *)&val_0561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1474 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0081, (cst_val *)&val_1475},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0082, (cst_val *)&val_0510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1476 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_hh_83_NO_0084, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1480 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_hh_83_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_hh_83_cart = {
  cmu_us_awb_single_mcep_hh_83_cart_nodes,
  cmu_us_awb_single_mcep_hh_83_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ae_6_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0000, (cst_val *)&val_0533},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0001, (cst_val *)&val_0887},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0002, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0003, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1482 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0006, (cst_val *)&val_0673},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0007, (cst_val *)&val_1483},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1484 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0009, (cst_val *)&val_1485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1487 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0012, (cst_val *)&val_0019},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0013, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1489 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0016, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1491 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0019, (cst_val *)&val_0613},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0020, (cst_val *)&val_0797},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0021, (cst_val *)&val_1492},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0022, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1496 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0026, (cst_val *)&val_1497},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1499 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0029, (cst_val *)&val_1500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1502 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0032, (cst_val *)&val_1503},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0033, (cst_val *)&val_1504},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0034, (cst_val *)&val_1505},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0035, (cst_val *)&val_1506},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0036, (cst_val *)&val_1507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1509 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0039, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1510 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0041, (cst_val *)&val_1511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1512 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0043, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1514 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0046, (cst_val *)&val_0065},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0047, (cst_val *)&val_1515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1517 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0050, (cst_val *)&val_1518},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0051, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1519 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0053, (cst_val *)&val_1520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1522 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0056, (cst_val *)&val_0214},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0057, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1523 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0059, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1525 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0062, (cst_val *)&val_0028},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0063, (cst_val *)&val_1336},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0064, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1526 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0066, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1529 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0070, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1531 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0073, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1534 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0076, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0077, (cst_val *)&val_1535},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0078, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1537 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0081, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0082, (cst_val *)&val_1538},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0083, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1542 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0088, (cst_val *)&val_1543},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0089, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1545 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0092, (cst_val *)&val_0130},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0093, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1546 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0095, (cst_val *)&val_0073},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0096, (cst_val *)&val_0214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1548 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0099, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1550 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0102, (cst_val *)&val_0045},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0103, (cst_val *)&val_1551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1552 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0105, (cst_val *)&val_1532},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0106, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1554 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0109, (cst_val *)&val_1555},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1557 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0112, (cst_val *)&val_0214},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0113, (cst_val *)&val_1558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1560 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0116, (cst_val *)&val_1153},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_6_NO_0117, (cst_val *)&val_1561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1564 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ae_6_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_ae_6_cart = {
  cmu_us_awb_single_mcep_ae_6_cart_nodes,
  cmu_us_awb_single_mcep_ae_6_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ae_7_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0000, (cst_val *)&val_0556},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0001, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0002, (cst_val *)&val_1565},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0003, (cst_val *)&val_0533},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0004, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1566 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0006, (cst_val *)&val_1567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1569 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0009, (cst_val *)&val_1570},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0010, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1571 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0012, (cst_val *)&val_1572},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1575 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0016, (cst_val *)&val_0264},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1577 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0020, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1578 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0022, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1581 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0025, (cst_val *)&val_0264},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0026, (cst_val *)&val_0017},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0027, (cst_val *)&val_0007},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0028, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1583 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0031, (cst_val *)&val_0525},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0032, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1585 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0035, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1587 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0038, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0039, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1590 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0042, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1592 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0045, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0046, (cst_val *)&val_1593},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0047, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1596 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0050, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1597 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0052, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1599 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0055, (cst_val *)&val_0073},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0056, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1601 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0059, (cst_val *)&val_0185},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0060, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1603 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0063, (cst_val *)&val_0041},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0064, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1606 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0068, (cst_val *)&val_0592},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0069, (cst_val *)&val_0533},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0070, (cst_val *)&val_0130},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0071, (cst_val *)&val_1607},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1608 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0073, (cst_val *)&val_1609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1611 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0076, (cst_val *)&val_1607},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0077, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1613 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0080, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1614 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0082, (cst_val *)&val_0019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0083, (cst_val *)&val_1615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1618 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0087, (cst_val *)&val_0130},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0088, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1620 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0091, (cst_val *)&val_0525},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0092, (cst_val *)&val_1621},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0093, (cst_val *)&val_0009},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0094, (cst_val *)&val_0039},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0095, (cst_val *)&val_1081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1625 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0100, (cst_val *)&val_0007},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0101, (cst_val *)&val_1626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1628 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0104, (cst_val *)&val_0007},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0105, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1630 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0108, (cst_val *)&val_1271},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0109, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1632 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0112, (cst_val *)&val_1633},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0113, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0114, (cst_val *)&val_1634},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0115, (cst_val *)&val_1635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1638 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0119, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1640 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0122, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1641 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0124, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1643 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0126, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1644 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0128, (cst_val *)&val_0064},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0129, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1647 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0133, (cst_val *)&val_1648},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0134, (cst_val *)&val_1649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1650 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0136, (cst_val *)&val_0674},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0137, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1653 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0141, (cst_val *)&val_0147},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0142, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1654 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0144, (cst_val *)&val_1655},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1657 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0147, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0148, (cst_val *)&val_1658},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1661 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0152, (cst_val *)&val_1662},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0153, (cst_val *)&val_1663},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0154, (cst_val *)&val_1459},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0155, (cst_val *)&val_1664},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1666 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0158, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1667 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0160, (cst_val *)&val_1668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1670 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0163, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0164, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0165, (cst_val *)&val_1671},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0166, (cst_val *)&val_0030},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0167, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1672 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0169, (cst_val *)&val_1673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1674 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0171, (cst_val *)&val_1675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1677 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0174, (cst_val *)&val_1678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1680 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0177, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1682 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0180, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1683 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0182, (cst_val *)&val_1684},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0183, (cst_val *)&val_1413},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0184, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1685 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0186, (cst_val *)&val_1686},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1690 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0191, (cst_val *)&val_0012},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0192, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1691 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0194, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1693 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0197, (cst_val *)&val_1694},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0198, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1695 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0200, (cst_val *)&val_0077},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0201, (cst_val *)&val_0007},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0202, (cst_val *)&val_1696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1698 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0205, (cst_val *)&val_0064},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0206, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1700 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0209, (cst_val *)&val_0041},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0210, (cst_val *)&val_0049},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0211, (cst_val *)&val_1701},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0212, (cst_val *)&val_1702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1705 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0216, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1710 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0222, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0223, (cst_val *)&val_1711},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0224, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1712 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0226, (cst_val *)&val_1713},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0227, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1714 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0229, (cst_val *)&val_1715},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0230, (cst_val *)&val_1716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1717 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0232, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1720 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0236, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1721 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0238, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1723 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0241, (cst_val *)&val_1724},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0242, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1726 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0245, (cst_val *)&val_1727},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0246, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1728 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0248, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1729 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0250, (cst_val *)&val_1730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1732 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0253, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0254, (cst_val *)&val_1668},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0255, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1735 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0259, (cst_val *)&val_0624},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0260, (cst_val *)&val_1736},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1738 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0263, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1740 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0266, (cst_val *)&val_1741},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0267, (cst_val *)&val_1742},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0268, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1745 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0272, (cst_val *)&val_0073},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0273, (cst_val *)&val_0966},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0274, (cst_val *)&val_1746},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0275, (cst_val *)&val_0049},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0276, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0277, (cst_val *)&val_1747},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0278, (cst_val *)&val_1748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1751 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0282, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1754 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0286, (cst_val *)&val_1755},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0287, (cst_val *)&val_1756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1759 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0291, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1761 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0294, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1762 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0296, (cst_val *)&val_1763},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0297, (cst_val *)&val_0533},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0298, (cst_val *)&val_1764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1765 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0300, (cst_val *)&val_1766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1768 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0303, (cst_val *)&val_0077},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0304, (cst_val *)&val_1769},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0305, (cst_val *)&val_0041},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0306, (cst_val *)&val_1770},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0307, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1773 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0311, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0312, (cst_val *)&val_1774},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0313, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1778 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0318, (cst_val *)&val_1779},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0319, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1780 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0321, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1781 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0323, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1782 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0325, (cst_val *)&val_1783},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0326, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1788 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_7_NO_0332, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1790 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ae_7_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_ae_7_cart = {
  cmu_us_awb_single_mcep_ae_7_cart_nodes,
  cmu_us_awb_single_mcep_ae_7_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ae_8_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0000, (cst_val *)&val_0065},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0001, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0002, (cst_val *)&val_1791},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0003, (cst_val *)&val_1792},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0004, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1793 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0006, (cst_val *)&val_1794},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1795 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0008, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1797 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0011, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1798 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0013, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1799 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0015, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1800 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0017, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1802 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0020, (cst_val *)&val_1803},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1805 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0023, (cst_val *)&val_0801},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0024, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1807 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0026, (cst_val *)&val_0673},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0027, (cst_val *)&val_0130},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0028, (cst_val *)&val_1808},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1810 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0031, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0032, (cst_val *)&val_0011},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0033, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1812 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0036, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1816 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0040, (cst_val *)&val_1817},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0041, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1818 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0043, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1820 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0046, (cst_val *)&val_1821},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0047, (cst_val *)&val_0650},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0048, (cst_val *)&val_0378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1823 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0051, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1825 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0054, (cst_val *)&val_0135},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0055, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1828 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0059, (cst_val *)&val_1829},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0060, (cst_val *)&val_1830},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0061, (cst_val *)&val_1831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1832 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0063, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1834 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0066, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0067, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1835 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0069, (cst_val *)&val_1836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1838 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0072, (cst_val *)&val_0003},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0073, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1841 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0077, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1842 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0079, (cst_val *)&val_0905},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0080, (cst_val *)&val_1843},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0081, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1845 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0084, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1847 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0087, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1848 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0089, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1849 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0091, (cst_val *)&val_0049},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0092, (cst_val *)&val_1850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1852 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0095, (cst_val *)&val_1853},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0096, (cst_val *)&val_1769},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0097, (cst_val *)&val_1854},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1857 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0101, (cst_val *)&val_1858},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1860 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0104, (cst_val *)&val_1861},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0105, (cst_val *)&val_0232},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0106, (cst_val *)&val_1862},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0107, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1863 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0109, (cst_val *)&val_0370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1866 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0113, (cst_val *)&val_0027},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0114, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1867 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0116, (cst_val *)&val_1868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1870 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0119, (cst_val *)&val_1871},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0120, (cst_val *)&val_1872},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0121, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1874 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0124, (cst_val *)&val_1875},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0125, (cst_val *)&val_1876},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0126, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1877 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0128, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1880 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0131, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1882 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0134, (cst_val *)&val_1883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1885 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0137, (cst_val *)&val_1271},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0138, (cst_val *)&val_1886},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0139, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1890 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0143, (cst_val *)&val_0045},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0144, (cst_val *)&val_1891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1893 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0147, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1894 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0149, (cst_val *)&val_1895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1897 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0152, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0153, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1898 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0155, (cst_val *)&val_0073},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0156, (cst_val *)&val_1088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0157, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1901 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0161, (cst_val *)&val_0004},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0162, (cst_val *)&val_1902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1903 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0164, (cst_val *)&val_0530},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0165, (cst_val *)&val_1904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1907 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0169, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1909 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0172, (cst_val *)&val_1910},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0173, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1911 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0175, (cst_val *)&val_1912},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0176, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1914 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0179, (cst_val *)&val_0049},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0180, (cst_val *)&val_1915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1917 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0183, (cst_val *)&val_1609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1919 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0186, (cst_val *)&val_0073},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0187, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1921 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0190, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1922 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0192, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1923 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0194, (cst_val *)&val_1924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1925 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0196, (cst_val *)&val_0673},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ae_8_NO_0197, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1928 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ae_8_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_single_mcep_ae_8_cart = {
  cmu_us_awb_single_mcep_ae_8_cart_nodes,
  cmu_us_awb_single_mcep_ae_8_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_y_194_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0000, (cst_val *)&val_0065},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0001, (cst_val *)&val_1929},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0002, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1930 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0004, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1932 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0007, (cst_val *)&val_1933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1935 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0010, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0011, (cst_val *)&val_1936},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0012, (cst_val *)&val_0533},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0013, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1937 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0015, (cst_val *)&val_1938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1940 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0018, (cst_val *)&val_1941},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1943 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0021, (cst_val *)&val_0864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1945 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0024, (cst_val *)&val_1292},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0025, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1947 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0028, (cst_val *)&val_0864},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0029, (cst_val *)&val_0360},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0030, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1949 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0033, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0034, (cst_val *)&val_1950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1952 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0037, (cst_val *)&val_0049},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0038, (cst_val *)&val_1953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1954 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0040, (cst_val *)&val_1955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1957 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1959 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0046, (cst_val *)&val_0073},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_194_NO_0047, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1962 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_y_194_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_single_mcep_y_194_cart = {
  cmu_us_awb_single_mcep_y_194_cart_nodes,
  cmu_us_awb_single_mcep_y_194_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_y_195_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0000, (cst_val *)&val_1963},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0002, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1965 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0005, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1966 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0007, (cst_val *)&val_1424},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0008, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1969 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0012, (cst_val *)&val_0798},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0013, (cst_val *)&val_1970},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0014, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0015, (cst_val *)&val_1971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1973 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0018, (cst_val *)&val_1183},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0019, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1974 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0021, (cst_val *)&val_1975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1977 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0024, (cst_val *)&val_0070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1978 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0026, (cst_val *)&val_1979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1981 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0029, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1983 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0032, (cst_val *)&val_1984},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0033, (cst_val *)&val_1985},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0034, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1986 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0036, (cst_val *)&val_1987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1989 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0039, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_195_NO_0040, (cst_val *)&val_1990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1994 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_y_195_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_y_195_cart = {
  cmu_us_awb_single_mcep_y_195_cart_nodes,
  cmu_us_awb_single_mcep_y_195_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_y_196_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0000, (cst_val *)&val_0116},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0001, (cst_val *)&val_1995},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0002, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0003, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1998 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0007, (cst_val *)&val_0680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1999 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0009, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2001 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0012, (cst_val *)&val_2002},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0013, (cst_val *)&val_2003},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0014, (cst_val *)&val_0073},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0015, (cst_val *)&val_2004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2006 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0018, (cst_val *)&val_0373},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0019, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2008 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0022, (cst_val *)&val_2009},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0023, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2010 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0025, (cst_val *)&val_2011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2014 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0029, (cst_val *)&val_0068},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0030, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2017 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0034, (cst_val *)&val_0002},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0035, (cst_val *)&val_0330},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0036, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0037, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2019 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0040, (cst_val *)&val_1387},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0041, (cst_val *)&val_2020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2023 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0045, (cst_val *)&val_2024},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0046, (cst_val *)&val_0592},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0047, (cst_val *)&val_2025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2027 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0050, (cst_val *)&val_2028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2031 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_y_196_NO_0054, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2033 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_y_196_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
NULL };

const cst_cart cmu_us_awb_single_mcep_y_196_cart = {
  cmu_us_awb_single_mcep_y_196_cart_nodes,
  cmu_us_awb_single_mcep_y_196_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_k_101_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0001, (cst_val *)&val_2034},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0002, (cst_val *)&val_0068},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0003, (cst_val *)&val_0363},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0004, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2035 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0006, (cst_val *)&val_0147},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0007, (cst_val *)&val_2036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2039 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0011, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0012, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2043 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2044 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0019, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2046 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0022, (cst_val *)&val_0004},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0023, (cst_val *)&val_0121},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0024, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2048 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0027, (cst_val *)&val_0065},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0028, (cst_val *)&val_2049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2051 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0031, (cst_val *)&val_0009},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0032, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0033, (cst_val *)&val_2052},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0034, (cst_val *)&val_2053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2055 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0037, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2057 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0040, (cst_val *)&val_1284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2059 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0043, (cst_val *)&val_2060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2061 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0045, (cst_val *)&val_2062},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0046, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2063 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0048, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2065 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0051, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2067 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0054, (cst_val *)&val_0360},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0055, (cst_val *)&val_2068},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0056, (cst_val *)&val_2069},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0057, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2072 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0061, (cst_val *)&val_0726},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0062, (cst_val *)&val_0525},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0063, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2074 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0066, (cst_val *)&val_0580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2076 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0069, (cst_val *)&val_1792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2078 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0072, (cst_val *)&val_0045},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0073, (cst_val *)&val_1222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2080 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0076, (cst_val *)&val_0578},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0077, (cst_val *)&val_0179},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0078, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2082 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0081, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2084 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0083, (cst_val *)&val_0116},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0084, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2086 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0087, (cst_val *)&val_2087},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_101_NO_0088, (cst_val *)&val_2088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2092 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_k_101_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_k_101_cart = {
  cmu_us_awb_single_mcep_k_101_cart_nodes,
  cmu_us_awb_single_mcep_k_101_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_k_102_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0000, (cst_val *)&val_0525},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0001, (cst_val *)&val_0980},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0002, (cst_val *)&val_0932},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0003, (cst_val *)&val_2093},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0004, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2096 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0008, (cst_val *)&val_1208},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0009, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2098 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0011, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2100 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0014, (cst_val *)&val_0121},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0015, (cst_val *)&val_2101},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0016, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2104 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0020, (cst_val *)&val_0064},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0021, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2106 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0024, (cst_val *)&val_0009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0025, (cst_val *)&val_2107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2108 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0027, (cst_val *)&val_2109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2111 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0030, (cst_val *)&val_0232},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0031, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2112 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0033, (cst_val *)&val_2113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2115 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0036, (cst_val *)&val_2116},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0037, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0038, (cst_val *)&val_0179},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0039, (cst_val *)&val_0624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2118 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0042, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2120 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0044, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2123 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0047, (cst_val *)&val_2124},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2127 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0052, (cst_val *)&val_0045},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0053, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2129 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0056, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2131 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0059, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0060, (cst_val *)&val_2132},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0061, (cst_val *)&val_2133},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0062, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2134 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0064, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2136 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0067, (cst_val *)&val_0932},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0068, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2138 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0071, (cst_val *)&val_0015},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0072, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2139 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0074, (cst_val *)&val_0147},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0075, (cst_val *)&val_2140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2143 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0079, (cst_val *)&val_2144},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0080, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2145 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0082, (cst_val *)&val_2146},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0083, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2148 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0086, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2151 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0090, (cst_val *)&val_0872},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0091, (cst_val *)&val_0045},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0092, (cst_val *)&val_2140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2153 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0095, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2154 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0097, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2157 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0101, (cst_val *)&val_0049},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0102, (cst_val *)&val_2158},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0103, (cst_val *)&val_2159},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0104, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2160 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0106, (cst_val *)&val_2161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2165 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0111, (cst_val *)&val_0622},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0112, (cst_val *)&val_2166},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2168 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0115, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2169 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0117, (cst_val *)&val_0921},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0118, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2170 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0120, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2173 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0124, (cst_val *)&val_0849},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0125, (cst_val *)&val_0154},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0126, (cst_val *)&val_0049},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0127, (cst_val *)&val_2174},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2176 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0130, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2178 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0133, (cst_val *)&val_0147},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0134, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0135, (cst_val *)&val_2179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2181 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0138, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2183 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0141, (cst_val *)&val_2184},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0142, (cst_val *)&val_0147},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0143, (cst_val *)&val_1345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2186 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0146, (cst_val *)&val_2187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2189 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0149, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2191 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0152, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2192 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0154, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2193 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0156, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2194 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0158, (cst_val *)&val_0009},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0159, (cst_val *)&val_2195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2197 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0162, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2198 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0164, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2199 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_102_NO_0166, (cst_val *)&val_1741},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2201 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_k_102_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_k_102_cart = {
  cmu_us_awb_single_mcep_k_102_cart_nodes,
  cmu_us_awb_single_mcep_k_102_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_k_103_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0000, (cst_val *)&val_1365},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0001, (cst_val *)&val_0130},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0002, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0003, (cst_val *)&val_0147},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0004, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2202 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0006, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2205 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0010, (cst_val *)&val_0009},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0011, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2207 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0014, (cst_val *)&val_0147},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0015, (cst_val *)&val_2208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2210 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0018, (cst_val *)&val_2211},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0019, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2214 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0023, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0024, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2215 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0026, (cst_val *)&val_0135},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0027, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2217 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0030, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2219 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0033, (cst_val *)&val_2220},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0034, (cst_val *)&val_0147},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0035, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2223 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0038, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2225 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0041, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0042, (cst_val *)&val_0402},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0043, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2226 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0045, (cst_val *)&val_0116},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0046, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2229 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0050, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2231 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0053, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2232 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0055, (cst_val *)&val_0479},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0056, (cst_val *)&val_2233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2235 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0059, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0060, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2237 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0063, (cst_val *)&val_2238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2240 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0066, (cst_val *)&val_2241},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0067, (cst_val *)&val_0009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0068, (cst_val *)&val_2242},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0069, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0070, (cst_val *)&val_2243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2245 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0073, (cst_val *)&val_2246},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0074, (cst_val *)&val_0017},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0075, (cst_val *)&val_0380},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0076, (cst_val *)&val_2247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2249 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0079, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2253 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0084, (cst_val *)&val_1236},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0085, (cst_val *)&val_2254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2256 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0088, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2258 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0091, (cst_val *)&val_2259},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0092, (cst_val *)&val_2260},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0093, (cst_val *)&val_2261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2263 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0096, (cst_val *)&val_0403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2265 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0099, (cst_val *)&val_0147},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0100, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2266 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0102, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2268 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0105, (cst_val *)&val_0116},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0106, (cst_val *)&val_2269},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0107, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2271 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0110, (cst_val *)&val_0315},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0111, (cst_val *)&val_2272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2274 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0114, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2275 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0116, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2277 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0119, (cst_val *)&val_0494},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0120, (cst_val *)&val_2049},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0121, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2279 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0124, (cst_val *)&val_0637},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0125, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2282 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0129, (cst_val *)&val_1808},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0130, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2284 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0133, (cst_val *)&val_2285},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0134, (cst_val *)&val_0823},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0135, (cst_val *)&val_2286},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2287 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0137, (cst_val *)&val_2288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2292 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0142, (cst_val *)&val_1236},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0143, (cst_val *)&val_2293},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2295 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0146, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0147, (cst_val *)&val_0525},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0148, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2296 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0150, (cst_val *)&val_2297},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0151, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2300 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0155, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2301 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0157, (cst_val *)&val_2269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2302 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0159, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2304 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0162, (cst_val *)&val_0494},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0163, (cst_val *)&val_2305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2307 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0166, (cst_val *)&val_0525},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0167, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2309 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_k_103_NO_0170, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2311 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_k_103_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_single_mcep_k_103_cart = {
  cmu_us_awb_single_mcep_k_103_cart_nodes,
  cmu_us_awb_single_mcep_k_103_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aa_1_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0001, (cst_val *)&val_1543},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0002, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2313 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0005, (cst_val *)&val_0673},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0006, (cst_val *)&val_0906},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0007, (cst_val *)&val_1794},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2316 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0011, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2317 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0013, (cst_val *)&val_2318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2320 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0016, (cst_val *)&val_2321},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0017, (cst_val *)&val_0073},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0018, (cst_val *)&val_0135},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0019, (cst_val *)&val_1379},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0020, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2322 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0022, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2324 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0025, (cst_val *)&val_2325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2326 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0027, (cst_val *)&val_2327},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2329 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0030, (cst_val *)&val_2330},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0031, (cst_val *)&val_2331},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0032, (cst_val *)&val_0187},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0033, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2334 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0037, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2337 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0041, (cst_val *)&val_2338},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0042, (cst_val *)&val_2339},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0043, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2340 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0045, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2341 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0047, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0050, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2344 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0052, (cst_val *)&val_1950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2345 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0054, (cst_val *)&val_2346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2348 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0057, (cst_val *)&val_2349},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0058, (cst_val *)&val_0065},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0059, (cst_val *)&val_2350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2352 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0062, (cst_val *)&val_2353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2354 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0064, (cst_val *)&val_0360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2356 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0067, (cst_val *)&val_0743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2357 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_1_NO_0069, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2360 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aa_1_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_aa_1_cart = {
  cmu_us_awb_single_mcep_aa_1_cart_nodes,
  cmu_us_awb_single_mcep_aa_1_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aa_2_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0000, (cst_val *)&val_0153},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0001, (cst_val *)&val_1356},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0002, (cst_val *)&val_0264},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0003, (cst_val *)&val_2361},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0004, (cst_val *)&val_0673},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0005, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2365 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0010, (cst_val *)&val_2366},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0011, (cst_val *)&val_2367},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0012, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2371 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0017, (cst_val *)&val_0147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0018, (cst_val *)&val_0261},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0019, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2372 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0021, (cst_val *)&val_1924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2374 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0024, (cst_val *)&val_0064},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0025, (cst_val *)&val_2375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2376 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0027, (cst_val *)&val_2377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2380 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0031, (cst_val *)&val_0017},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0032, (cst_val *)&val_2381},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2383 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0035, (cst_val *)&val_2384},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0036, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2385 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0038, (cst_val *)&val_2386},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0039, (cst_val *)&val_0065},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0040, (cst_val *)&val_0612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2389 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0044, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2391 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0047, (cst_val *)&val_0590},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0048, (cst_val *)&val_0041},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0049, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2394 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0053, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2396 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0056, (cst_val *)&val_2397},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0057, (cst_val *)&val_0017},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0058, (cst_val *)&val_0016},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0059, (cst_val *)&val_2398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2399 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0061, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2401 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0064, (cst_val *)&val_2402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2403 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0066, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2405 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0069, (cst_val *)&val_0065},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0070, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2407 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0073, (cst_val *)&val_0147},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0074, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2408 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0076, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2410 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0079, (cst_val *)&val_2411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2412 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0081, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2413 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0083, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2415 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0086, (cst_val *)&val_0027},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0087, (cst_val *)&val_0121},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0088, (cst_val *)&val_2416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2417 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0090, (cst_val *)&val_0276},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0091, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2420 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0095, (cst_val *)&val_2421},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0096, (cst_val *)&val_2422},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0097, (cst_val *)&val_1183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2424 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0100, (cst_val *)&val_2425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2428 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0104, (cst_val *)&val_1052},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0105, (cst_val *)&val_0003},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0106, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2430 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0109, (cst_val *)&val_2431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2433 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0112, (cst_val *)&val_0049},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0113, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2434 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0115, (cst_val *)&val_2435},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0116, (cst_val *)&val_0065},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0117, (cst_val *)&val_2436},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0118, (cst_val *)&val_2437},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0119, (cst_val *)&val_2438},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2440 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0122, (cst_val *)&val_0700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2441 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0124, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2445 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0128, (cst_val *)&val_0007},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0129, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2447 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0132, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0133, (cst_val *)&val_2448},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0134, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2449 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0136, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2450 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0138, (cst_val *)&val_2451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2453 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0141, (cst_val *)&val_2454},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2456 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0144, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2457 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0146, (cst_val *)&val_2458},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0147, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2459 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0149, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2461 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0152, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2463 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0155, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2464 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0157, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2466 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0160, (cst_val *)&val_0121},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0161, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2467 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0163, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2468 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0165, (cst_val *)&val_0526},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0166, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2470 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0169, (cst_val *)&val_2471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2473 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0172, (cst_val *)&val_1792},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0173, (cst_val *)&val_0065},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0174, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0175, (cst_val *)&val_2474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2477 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0179, (cst_val *)&val_0485},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0180, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2478 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0182, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2479 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0184, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2480 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0186, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2482 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0189, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2484 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0192, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2485 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0194, (cst_val *)&val_0065},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0195, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2487 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0198, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2488 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0200, (cst_val *)&val_2489},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0201, (cst_val *)&val_1774},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_2_NO_0202, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2493 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aa_2_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_awb_single_mcep_aa_2_cart = {
  cmu_us_awb_single_mcep_aa_2_cart_nodes,
  cmu_us_awb_single_mcep_aa_2_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_aa_3_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0000, (cst_val *)&val_2260},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0001, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0002, (cst_val *)&val_0478},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0003, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0004, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2494 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0006, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2495 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0008, (cst_val *)&val_2496},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2498 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0011, (cst_val *)&val_1465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2500 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0014, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2501 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0016, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2503 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0019, (cst_val *)&val_1088},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0020, (cst_val *)&val_0261},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0021, (cst_val *)&val_0173},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0022, (cst_val *)&val_0130},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0023, (cst_val *)&val_2504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2507 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0027, (cst_val *)&val_2508},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2510 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0030, (cst_val *)&val_2511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2513 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0033, (cst_val *)&val_0823},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0034, (cst_val *)&val_2514},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0035, (cst_val *)&val_0261},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0036, (cst_val *)&val_2515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2516 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0038, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2518 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0041, (cst_val *)&val_0055},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0042, (cst_val *)&val_0402},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0043, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2522 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0048, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2523 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0050, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2524 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0052, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2526 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0055, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0056, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2528 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0059, (cst_val *)&val_0526},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0060, (cst_val *)&val_2529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2531 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0063, (cst_val *)&val_2532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2533 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0065, (cst_val *)&val_1287},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0066, (cst_val *)&val_0065},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0067, (cst_val *)&val_2534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2537 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0071, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2538 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0073, (cst_val *)&val_0520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2540 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0076, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0077, (cst_val *)&val_0045},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0078, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2541 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0080, (cst_val *)&val_0064},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0081, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2543 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0084, (cst_val *)&val_2544},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0085, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2545 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0087, (cst_val *)&val_2546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2549 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0091, (cst_val *)&val_2550},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0092, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2553 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0096, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0097, (cst_val *)&val_0823},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0098, (cst_val *)&val_2554},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0099, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2555 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0101, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2557 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0104, (cst_val *)&val_2558},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0105, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2561 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0109, (cst_val *)&val_0003},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0110, (cst_val *)&val_2562},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0111, (cst_val *)&val_2563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2566 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0115, (cst_val *)&val_0065},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0116, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2568 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0119, (cst_val *)&val_2569},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0120, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2572 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0124, (cst_val *)&val_2573},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0125, (cst_val *)&val_0017},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0126, (cst_val *)&val_2574},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0127, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2575 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0129, (cst_val *)&val_2576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2578 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0132, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2580 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0135, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2582 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0138, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2583 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_aa_3_NO_0140, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2585 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_aa_3_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_aa_3_cart = {
  cmu_us_awb_single_mcep_aa_3_cart_nodes,
  cmu_us_awb_single_mcep_aa_3_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ay_31_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0000, (cst_val *)&val_2586},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0001, (cst_val *)&val_0533},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0002, (cst_val *)&val_0077},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0003, (cst_val *)&val_1971},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0004, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2589 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0008, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2591 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0011, (cst_val *)&val_0121},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0012, (cst_val *)&val_1276},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0013, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2593 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0016, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2594 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0018, (cst_val *)&val_2595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2597 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0021, (cst_val *)&val_0525},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0022, (cst_val *)&val_2598},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0023, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2599 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0025, (cst_val *)&val_2600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2602 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0028, (cst_val *)&val_1532},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0029, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2604 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0032, (cst_val *)&val_2605},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0033, (cst_val *)&val_2606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2608 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0036, (cst_val *)&val_0064},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0037, (cst_val *)&val_2609},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0038, (cst_val *)&val_2610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2612 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0041, (cst_val *)&val_2613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2615 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0044, (cst_val *)&val_1302},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0045, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2617 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0048, (cst_val *)&val_2618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2619 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0050, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2620 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0052, (cst_val *)&val_2621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2623 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0055, (cst_val *)&val_1532},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0056, (cst_val *)&val_2624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2626 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0059, (cst_val *)&val_2627},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0060, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2628 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0062, (cst_val *)&val_2629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2631 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0065, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2632 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0067, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2634 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0070, (cst_val *)&val_0003},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0071, (cst_val *)&val_2635},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0072, (cst_val *)&val_1284},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0073, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2637 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0076, (cst_val *)&val_1188},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0077, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2640 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0081, (cst_val *)&val_0039},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0082, (cst_val *)&val_2641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2642 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0084, (cst_val *)&val_0159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2643 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0086, (cst_val *)&val_0342},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2646 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0090, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0091, (cst_val *)&val_0147},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0092, (cst_val *)&val_0028},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0093, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2647 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0095, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2650 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0099, (cst_val *)&val_2651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2652 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0101, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2653 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0103, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2654 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0105, (cst_val *)&val_2655},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0106, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2656 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0108, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0109, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2658 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0112, (cst_val *)&val_2659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2661 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0115, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2662 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0117, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2664 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0120, (cst_val *)&val_2665},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0121, (cst_val *)&val_0340},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0122, (cst_val *)&val_2618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2666 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0124, (cst_val *)&val_2667},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0125, (cst_val *)&val_1276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2668 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0127, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2669 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0129, (cst_val *)&val_2598},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0130, (cst_val *)&val_1955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2671 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0133, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0134, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2672 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0136, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2675 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0140, (cst_val *)&val_0064},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0141, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2677 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0144, (cst_val *)&val_0679},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0145, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2679 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0148, (cst_val *)&val_2680},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0149, (cst_val *)&val_2451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2683 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0153, (cst_val *)&val_2684},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0154, (cst_val *)&val_0131},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0155, (cst_val *)&val_1276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2685 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0157, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2686 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0159, (cst_val *)&val_0041},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0160, (cst_val *)&val_2687},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2689 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0163, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2691 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0166, (cst_val *)&val_2618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2692 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0168, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2694 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0171, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0172, (cst_val *)&val_1783},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0173, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2697 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0177, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0178, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2698 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0180, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2701 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0184, (cst_val *)&val_0040},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0185, (cst_val *)&val_2702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2704 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0188, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0189, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2705 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0191, (cst_val *)&val_2706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2707 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0193, (cst_val *)&val_2708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2710 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0196, (cst_val *)&val_2711},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0197, (cst_val *)&val_2712},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0198, (cst_val *)&val_0046},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0199, (cst_val *)&val_0065},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0200, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2714 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0203, (cst_val *)&val_1276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2715 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0205, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2716 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0207, (cst_val *)&val_0041},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0208, (cst_val *)&val_0064},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0209, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2719 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_31_NO_0213, (cst_val *)&val_2720},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2725 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ay_31_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_ay_31_cart = {
  cmu_us_awb_single_mcep_ay_31_cart_nodes,
  cmu_us_awb_single_mcep_ay_31_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ay_32_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0000, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0001, (cst_val *)&val_2726},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0002, (cst_val *)&val_2727},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0003, (cst_val *)&val_2728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2729 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0005, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2731 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0008, (cst_val *)&val_2732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2734 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0011, (cst_val *)&val_2735},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0012, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2736 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0014, (cst_val *)&val_2737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2740 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0018, (cst_val *)&val_2741},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0019, (cst_val *)&val_0533},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0020, (cst_val *)&val_2742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2743 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0022, (cst_val *)&val_2049},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0023, (cst_val *)&val_0247},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0024, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2744 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0026, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2746 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0029, (cst_val *)&val_0020},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0030, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2748 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0033, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2750 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0036, (cst_val *)&val_2751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2752 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0038, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2753 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0040, (cst_val *)&val_0070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2755 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0043, (cst_val *)&val_0000},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0044, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0045, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2756 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0047, (cst_val *)&val_0340},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2758 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0050, (cst_val *)&val_2759},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0051, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2761 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0054, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2762 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0056, (cst_val *)&val_2763},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0057, (cst_val *)&val_0330},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0058, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2765 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0061, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2767 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0064, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2769 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0067, (cst_val *)&val_2770},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0068, (cst_val *)&val_2771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2773 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0071, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2774 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0073, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2775 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0075, (cst_val *)&val_0046},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0076, (cst_val *)&val_1792},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0077, (cst_val *)&val_0037},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0078, (cst_val *)&val_0049},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0079, (cst_val *)&val_0370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2776 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0081, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2780 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0086, (cst_val *)&val_2781},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0087, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0088, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2786 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0094, (cst_val *)&val_0474},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0095, (cst_val *)&val_2787},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0096, (cst_val *)&val_0045},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0097, (cst_val *)&val_0798},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0098, (cst_val *)&val_2788},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2790 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0101, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2792 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0104, (cst_val *)&val_2793},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0105, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2796 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0109, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2797 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0111, (cst_val *)&val_0904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2799 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0114, (cst_val *)&val_1287},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0115, (cst_val *)&val_0065},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0116, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2801 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0119, (cst_val *)&val_1287},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0120, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2802 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0122, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2804 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0125, (cst_val *)&val_2805},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0126, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2808 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0130, (cst_val *)&val_2809},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0131, (cst_val *)&val_1264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2810 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0133, (cst_val *)&val_0016},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0134, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2812 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0137, (cst_val *)&val_2813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2815 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0140, (cst_val *)&val_1403},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0141, (cst_val *)&val_0049},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0142, (cst_val *)&val_2816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2818 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0145, (cst_val *)&val_2436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2820 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0148, (cst_val *)&val_2821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2822 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0150, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2823 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0152, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2824 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0154, (cst_val *)&val_1668},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0155, (cst_val *)&val_2825},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2826 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0157, (cst_val *)&val_1565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2828 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_32_NO_0160, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2830 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ay_32_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_ay_32_cart = {
  cmu_us_awb_single_mcep_ay_32_cart_nodes,
  cmu_us_awb_single_mcep_ay_32_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ay_33_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0000, (cst_val *)&val_1424},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0001, (cst_val *)&val_0232},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0002, (cst_val *)&val_2831},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0003, (cst_val *)&val_2832},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0004, (cst_val *)&val_2833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2836 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0008, (cst_val *)&val_0276},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0009, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2837 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0011, (cst_val *)&val_2838},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2839 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0013, (cst_val *)&val_2840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2843 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0017, (cst_val *)&val_1287},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0018, (cst_val *)&val_2844},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0019, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0020, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2845 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0022, (cst_val *)&val_2846},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0023, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2849 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0027, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2850 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0029, (cst_val *)&val_0077},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0030, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2851 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0032, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2852 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0034, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2854 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0037, (cst_val *)&val_2855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2856 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0039, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2858 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0042, (cst_val *)&val_0065},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0043, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2859 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0045, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2861 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0048, (cst_val *)&val_0102},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0049, (cst_val *)&val_2862},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0050, (cst_val *)&val_0028},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0051, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2863 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0053, (cst_val *)&val_0049},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0054, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2865 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0057, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2867 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0060, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2868 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0062, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2871 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0066, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2872 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0068, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2873 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0070, (cst_val *)&val_2874},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0071, (cst_val *)&val_2451},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0072, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2876 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0075, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2879 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0079, (cst_val *)&val_0147},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0080, (cst_val *)&val_0000},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0081, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2880 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0083, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2881 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0085, (cst_val *)&val_2882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2884 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0088, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2885 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0090, (cst_val *)&val_0154},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0091, (cst_val *)&val_2886},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0092, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2888 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0095, (cst_val *)&val_0064},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0096, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2891 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0100, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2892 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0102, (cst_val *)&val_2893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2895 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0105, (cst_val *)&val_2896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2897 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0107, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0108, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0109, (cst_val *)&val_2898},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0110, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2901 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0114, (cst_val *)&val_2902},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2904 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0117, (cst_val *)&val_2905},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0118, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2906 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0120, (cst_val *)&val_2907},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0121, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2908 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0123, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2910 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0126, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2911 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0128, (cst_val *)&val_0065},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0129, (cst_val *)&val_2912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2915 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0133, (cst_val *)&val_2916},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0134, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2918 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0137, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2920 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0140, (cst_val *)&val_0147},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0141, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2921 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0143, (cst_val *)&val_2922},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0144, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2923 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0146, (cst_val *)&val_0578},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0147, (cst_val *)&val_1336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2924 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0149, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2926 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0152, (cst_val *)&val_1188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2928 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0155, (cst_val *)&val_0073},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0156, (cst_val *)&val_2929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2931 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0159, (cst_val *)&val_2550},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0160, (cst_val *)&val_0041},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0161, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2932 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0163, (cst_val *)&val_2933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2935 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0166, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2938 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0170, (cst_val *)&val_0065},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0171, (cst_val *)&val_0041},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0172, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0173, (cst_val *)&val_2325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2942 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0178, (cst_val *)&val_0045},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0179, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2943 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0181, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2945 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0184, (cst_val *)&val_1090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2946 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0186, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2947 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0188, (cst_val *)&val_0004},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0189, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0190, (cst_val *)&val_2948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2950 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0193, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2952 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0196, (cst_val *)&val_0027},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0197, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2953 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ay_33_NO_0199, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2956 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ay_33_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_ay_33_cart = {
  cmu_us_awb_single_mcep_ay_33_cart_nodes,
  cmu_us_awb_single_mcep_ay_33_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_w_189_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0001, (cst_val *)&val_0533},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0002, (cst_val *)&val_2957},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0003, (cst_val *)&val_1387},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0004, (cst_val *)&val_2958},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0005, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0006, (cst_val *)&val_0976},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0007, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2961 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0011, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2963 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0014, (cst_val *)&val_2964},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2967 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0018, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0019, (cst_val *)&val_2968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2971 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0023, (cst_val *)&val_0905},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0024, (cst_val *)&val_1561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2972 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0026, (cst_val *)&val_0905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2973 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0028, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2975 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0031, (cst_val *)&val_1561},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0032, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2976 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0034, (cst_val *)&val_2977},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0035, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2980 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0039, (cst_val *)&val_2981},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0040, (cst_val *)&val_1702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2983 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0043, (cst_val *)&val_1287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2984 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0045, (cst_val *)&val_1987},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0046, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2987 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0050, (cst_val *)&val_2988},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0051, (cst_val *)&val_0073},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0052, (cst_val *)&val_0116},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0053, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2991 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0057, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0058, (cst_val *)&val_2003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2993 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0061, (cst_val *)&val_0121},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0062, (cst_val *)&val_2458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2994 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0064, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2996 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0067, (cst_val *)&val_0009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0068, (cst_val *)&val_2997},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0069, (cst_val *)&val_2998},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0070, (cst_val *)&val_2999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3001 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0073, (cst_val *)&val_3002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3005 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0077, (cst_val *)&val_3006},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0078, (cst_val *)&val_0906},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0079, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3009 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0083, (cst_val *)&val_2529},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0084, (cst_val *)&val_0601},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0085, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3011 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0088, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3014 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0092, (cst_val *)&val_3015},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0093, (cst_val *)&val_3016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3018 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0096, (cst_val *)&val_0049},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0097, (cst_val *)&val_3019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3021 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_189_NO_0100, (cst_val *)&val_3022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3024 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_w_189_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_w_189_cart = {
  cmu_us_awb_single_mcep_w_189_cart_nodes,
  cmu_us_awb_single_mcep_w_189_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_w_190_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0000, (cst_val *)&val_3006},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0002, (cst_val *)&val_0007},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0003, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3026 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0006, (cst_val *)&val_0130},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0007, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3027 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0009, (cst_val *)&val_3028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3031 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0013, (cst_val *)&val_3032},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0014, (cst_val *)&val_3033},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0015, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3036 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0019, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3038 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0022, (cst_val *)&val_1424},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0023, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0024, (cst_val *)&val_3039},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0025, (cst_val *)&val_3040},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0026, (cst_val *)&val_1356},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0027, (cst_val *)&val_1336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3042 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0030, (cst_val *)&val_3043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3044 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0032, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3045 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0034, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3047 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0037, (cst_val *)&val_0116},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0038, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3049 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0041, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3050 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0043, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3052 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0046, (cst_val *)&val_0049},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0047, (cst_val *)&val_3053},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3054 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0050, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3056 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0053, (cst_val *)&val_3057},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0054, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3058 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0056, (cst_val *)&val_2297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3059 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0058, (cst_val *)&val_3060},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0059, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3064 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0063, (cst_val *)&val_3065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3067 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0066, (cst_val *)&val_3068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0067, (cst_val *)&val_0680},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0068, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3069 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0070, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3071 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0073, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3073 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0076, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3075 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0079, (cst_val *)&val_0121},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0080, (cst_val *)&val_1356},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0081, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3078 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0085, (cst_val *)&val_3053},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0086, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3079 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0088, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3080 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0090, (cst_val *)&val_3081},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0091, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3083 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0094, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3085 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0097, (cst_val *)&val_3086},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0098, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3088 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0101, (cst_val *)&val_1208},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0102, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3090 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0105, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0106, (cst_val *)&val_3091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3093 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0109, (cst_val *)&val_3094},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0110, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3095 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0112, (cst_val *)&val_0714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3096 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0114, (cst_val *)&val_0009},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0115, (cst_val *)&val_3097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3101 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0120, (cst_val *)&val_1887},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0121, (cst_val *)&val_3102},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0122, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3103 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0124, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3104 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0126, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3105 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0128, (cst_val *)&val_3106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3108 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0131, (cst_val *)&val_3094},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0132, (cst_val *)&val_3109},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0133, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3110 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0135, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3114 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0140, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0141, (cst_val *)&val_3115},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0142, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3117 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0145, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3119 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0148, (cst_val *)&val_3120},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0149, (cst_val *)&val_3121},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0150, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3123 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0153, (cst_val *)&val_3124},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3125 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0155, (cst_val *)&val_0704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3127 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0158, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0159, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3129 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_190_NO_0162, (cst_val *)&val_3130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3132 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_w_190_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_w_190_cart = {
  cmu_us_awb_single_mcep_w_190_cart_nodes,
  cmu_us_awb_single_mcep_w_190_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_w_191_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0000, (cst_val *)&val_0578},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0001, (cst_val *)&val_3133},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0002, (cst_val *)&val_3134},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0003, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3136 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0006, (cst_val *)&val_0007},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0007, (cst_val *)&val_3137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0008, (cst_val *)&val_0952},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0009, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3140 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0012, (cst_val *)&val_0856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3142 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0015, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3143 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0017, (cst_val *)&val_3144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3146 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0020, (cst_val *)&val_0009},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0021, (cst_val *)&val_0659},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0022, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3148 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0025, (cst_val *)&val_1764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3150 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0028, (cst_val *)&val_0130},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0029, (cst_val *)&val_0726},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0030, (cst_val *)&val_3151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3154 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0034, (cst_val *)&val_0131},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0035, (cst_val *)&val_3155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3158 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0039, (cst_val *)&val_3159},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0040, (cst_val *)&val_0049},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0041, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0042, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3161 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0045, (cst_val *)&val_2896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3162 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0047, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3163 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0049, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3165 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0052, (cst_val *)&val_0008},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0053, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3169 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0058, (cst_val *)&val_1092},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0059, (cst_val *)&val_3170},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0060, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3171 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0062, (cst_val *)&val_0010},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0063, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3173 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0066, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3174 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0068, (cst_val *)&val_1356},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0069, (cst_val *)&val_3175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3177 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0072, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3180 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0076, (cst_val *)&val_3181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3182 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0078, (cst_val *)&val_1356},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0079, (cst_val *)&val_3183},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0080, (cst_val *)&val_3184},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0081, (cst_val *)&val_3185},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0082, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3190 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0088, (cst_val *)&val_2550},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0089, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0090, (cst_val *)&val_3191},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3193 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0093, (cst_val *)&val_3194},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0094, (cst_val *)&val_3195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3196 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0096, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3197 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_w_191_NO_0098, (cst_val *)&val_2896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3201 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_w_191_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_awb_single_mcep_w_191_cart = {
  cmu_us_awb_single_mcep_w_191_cart_nodes,
  cmu_us_awb_single_mcep_w_191_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_m_111_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0002, (cst_val *)&val_0905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3202 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0004, (cst_val *)&val_0935},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0005, (cst_val *)&val_3203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3204 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0007, (cst_val *)&val_3205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3207 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0010, (cst_val *)&val_3208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3210 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0013, (cst_val *)&val_1003},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0014, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0015, (cst_val *)&val_3211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3213 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0018, (cst_val *)&val_3214},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0019, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3217 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0023, (cst_val *)&val_3218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3220 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0026, (cst_val *)&val_0147},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0027, (cst_val *)&val_0533},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0028, (cst_val *)&val_0130},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0029, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3222 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0032, (cst_val *)&val_1379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3223 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0034, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3226 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0038, (cst_val *)&val_1715},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0039, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0040, (cst_val *)&val_0856},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0041, (cst_val *)&val_0101},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0042, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3228 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0045, (cst_val *)&val_0526},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0046, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3230 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0049, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3231 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0051, (cst_val *)&val_0009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0052, (cst_val *)&val_3232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3233 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0054, (cst_val *)&val_2052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3235 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0057, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3236 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0059, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0060, (cst_val *)&val_0650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3239 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0064, (cst_val *)&val_0402},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0065, (cst_val *)&val_2060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3240 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0067, (cst_val *)&val_0116},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0068, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3242 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0071, (cst_val *)&val_3243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3244 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0073, (cst_val *)&val_1345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3245 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0075, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3247 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0078, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3249 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0081, (cst_val *)&val_1551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3250 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0083, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3251 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0085, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3252 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0087, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3254 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0090, (cst_val *)&val_0003},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0091, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3255 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0093, (cst_val *)&val_0185},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0094, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3258 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_111_NO_0098, (cst_val *)&val_3259},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3261 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_m_111_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_awb_single_mcep_m_111_cart = {
  cmu_us_awb_single_mcep_m_111_cart_nodes,
  cmu_us_awb_single_mcep_m_111_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_m_112_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0000, (cst_val *)&val_0578},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0001, (cst_val *)&val_3006},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0002, (cst_val *)&val_0525},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0003, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3262 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0005, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3263 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0007, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0008, (cst_val *)&val_0578},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0009, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3264 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0011, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3266 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0014, (cst_val *)&val_3267},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0015, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3269 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0018, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3271 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0021, (cst_val *)&val_0009},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0022, (cst_val *)&val_3272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3275 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0026, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0027, (cst_val *)&val_3276},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0028, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3277 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0030, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3278 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0032, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3280 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0035, (cst_val *)&val_3281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3282 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0037, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3284 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0040, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3285 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0042, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3286 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0044, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3288 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0047, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3289 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0050, (cst_val *)&val_0147},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0051, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3291 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0054, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3292 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0056, (cst_val *)&val_3293},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0057, (cst_val *)&val_2999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3295 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0060, (cst_val *)&val_3296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3299 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0064, (cst_val *)&val_0003},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0065, (cst_val *)&val_3300},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0066, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0067, (cst_val *)&val_0147},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0068, (cst_val *)&val_3301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3304 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0072, (cst_val *)&val_0049},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0073, (cst_val *)&val_3305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3307 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0076, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3308 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0078, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3310 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0081, (cst_val *)&val_0077},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0082, (cst_val *)&val_3311},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0083, (cst_val *)&val_0232},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0084, (cst_val *)&val_3312},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0085, (cst_val *)&val_2101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3315 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0089, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3316 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0091, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3317 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0093, (cst_val *)&val_3318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3320 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0096, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0097, (cst_val *)&val_3321},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0098, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3323 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0101, (cst_val *)&val_3324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3325 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0103, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3327 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0106, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3328 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0108, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3330 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0111, (cst_val *)&val_0009},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0112, (cst_val *)&val_0153},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0113, (cst_val *)&val_3331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3335 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0118, (cst_val *)&val_0933},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0119, (cst_val *)&val_3336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3337 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0121, (cst_val *)&val_0009},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0122, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3340 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0126, (cst_val *)&val_3336},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0127, (cst_val *)&val_3341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3343 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0130, (cst_val *)&val_0009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0131, (cst_val *)&val_3344},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0132, (cst_val *)&val_3345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3348 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_112_NO_0136, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3350 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_m_112_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_m_112_cart = {
  cmu_us_awb_single_mcep_m_112_cart_nodes,
  cmu_us_awb_single_mcep_m_112_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_m_113_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0000, (cst_val *)&val_3351},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0001, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0002, (cst_val *)&val_3352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3353 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0004, (cst_val *)&val_0041},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0005, (cst_val *)&val_3354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3355 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0007, (cst_val *)&val_3356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3358 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0010, (cst_val *)&val_3359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3361 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0013, (cst_val *)&val_3362},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0014, (cst_val *)&val_2003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3363 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0016, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3364 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0018, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3365 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0020, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0021, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3367 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0024, (cst_val *)&val_0116},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0025, (cst_val *)&val_3368},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3370 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0028, (cst_val *)&val_3371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3372 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0030, (cst_val *)&val_2325},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0031, (cst_val *)&val_3373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3376 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0035, (cst_val *)&val_1473},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0036, (cst_val *)&val_0526},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0037, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3378 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0040, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3379 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0042, (cst_val *)&val_3380},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3381 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0045, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3383 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0048, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3386 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0052, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0053, (cst_val *)&val_0003},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0054, (cst_val *)&val_0008},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0055, (cst_val *)&val_0798},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0056, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3389 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0060, (cst_val *)&val_0966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3391 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0063, (cst_val *)&val_0894},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0064, (cst_val *)&val_0232},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0065, (cst_val *)&val_3392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3394 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0068, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3396 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0071, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3398 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0074, (cst_val *)&val_0872},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0075, (cst_val *)&val_0232},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0076, (cst_val *)&val_1236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3399 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0078, (cst_val *)&val_1208},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0079, (cst_val *)&val_3400},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3402 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0082, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3404 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0085, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3405 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0087, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0088, (cst_val *)&val_0009},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0089, (cst_val *)&val_0834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3406 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0091, (cst_val *)&val_0435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3408 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0094, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0095, (cst_val *)&val_3409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3411 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0098, (cst_val *)&val_3412},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3414 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0101, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3415 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0103, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3417 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0106, (cst_val *)&val_3418},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0107, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0108, (cst_val *)&val_2003},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0109, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3421 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0113, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3423 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0116, (cst_val *)&val_0077},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0117, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3424 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_m_113_NO_0119, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3427 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_m_113_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
NULL };

const cst_cart cmu_us_awb_single_mcep_m_113_cart = {
  cmu_us_awb_single_mcep_m_113_cart_nodes,
  cmu_us_awb_single_mcep_m_113_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_pau_142_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0000, (cst_val *)&val_1379},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0002, (cst_val *)&val_2742},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0003, (cst_val *)&val_3428},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0004, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0005, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3429 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0007, (cst_val *)&val_0073},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0008, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3431 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0011, (cst_val *)&val_3432},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3434 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0014, (cst_val *)&val_0491},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0015, (cst_val *)&val_3435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3437 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0018, (cst_val *)&val_3438},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0019, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3439 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0021, (cst_val *)&val_3440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3441 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0023, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3442 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0025, (cst_val *)&val_3443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3444 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0027, (cst_val *)&val_0082},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0028, (cst_val *)&val_3445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3446 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0030, (cst_val *)&val_0081},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0031, (cst_val *)&val_3447},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3452 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0037, (cst_val *)&val_3453},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0038, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0039, (cst_val *)&val_3454},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3458 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0044, (cst_val *)&val_1503},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0045, (cst_val *)&val_0556},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0046, (cst_val *)&val_0007},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0047, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3461 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0050, (cst_val *)&val_3462},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0051, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3464 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0054, (cst_val *)&val_3465},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0055, (cst_val *)&val_3466},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0056, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3471 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0061, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3472 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0063, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3473 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0065, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3474 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0067, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0068, (cst_val *)&val_3475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3478 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0072, (cst_val *)&val_0525},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0073, (cst_val *)&val_3479},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0074, (cst_val *)&val_0005},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0075, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3481 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0078, (cst_val *)&val_0233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3483 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0081, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3486 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0085, (cst_val *)&val_0261},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0086, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0087, (cst_val *)&val_0116},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0088, (cst_val *)&val_0967},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0089, (cst_val *)&val_3487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3489 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0092, (cst_val *)&val_3490},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3492 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0095, (cst_val *)&val_1273},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0096, (cst_val *)&val_3493},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0097, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3494 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0099, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3498 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0104, (cst_val *)&val_3499},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0105, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3500 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0107, (cst_val *)&val_0016},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0108, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3501 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0110, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0111, (cst_val *)&val_0691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3504 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0115, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3505 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0117, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3506 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0119, (cst_val *)&val_0691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3508 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0122, (cst_val *)&val_3509},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0123, (cst_val *)&val_3510},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0124, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3514 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0129, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0130, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0131, (cst_val *)&val_1236},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0132, (cst_val *)&val_3515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3517 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0135, (cst_val *)&val_1365},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0136, (cst_val *)&val_0009},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0137, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3519 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0140, (cst_val *)&val_3520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3522 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0143, (cst_val *)&val_2968},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0144, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3524 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0147, (cst_val *)&val_3525},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0148, (cst_val *)&val_3526},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0149, (cst_val *)&val_3527},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0150, (cst_val *)&val_3528},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0151, (cst_val *)&val_3529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3530 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0153, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3532 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0156, (cst_val *)&val_3533},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0157, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3538 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0163, (cst_val *)&val_2968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3540 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0166, (cst_val *)&val_3459},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0167, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0168, (cst_val *)&val_3541},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0169, (cst_val *)&val_1791},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3543 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0172, (cst_val *)&val_1668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3544 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0174, (cst_val *)&val_0856},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0175, (cst_val *)&val_3545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3549 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0180, (cst_val *)&val_3550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3551 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0182, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3552 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0184, (cst_val *)&val_3553},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0185, (cst_val *)&val_3554},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3555 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0187, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3558 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0191, (cst_val *)&val_0725},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0192, (cst_val *)&val_0797},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0193, (cst_val *)&val_3559},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0194, (cst_val *)&val_0073},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0195, (cst_val *)&val_3560},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0196, (cst_val *)&val_3561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3562 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0198, (cst_val *)&val_3563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3568 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0204, (cst_val *)&val_3569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3571 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0207, (cst_val *)&val_1183},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0208, (cst_val *)&val_3459},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0209, (cst_val *)&val_3572},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3573 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0211, (cst_val *)&val_0075},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0212, (cst_val *)&val_3574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3577 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0216, (cst_val *)&val_3578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3580 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0219, (cst_val *)&val_3581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3583 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0222, (cst_val *)&val_3526},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0223, (cst_val *)&val_0435},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0224, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0225, (cst_val *)&val_3584},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0226, (cst_val *)&val_3138},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0227, (cst_val *)&val_0797},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0228, (cst_val *)&val_3585},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0229, (cst_val *)&val_0953},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0230, (cst_val *)&val_3586},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0231, (cst_val *)&val_3587},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3590 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0235, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0236, (cst_val *)&val_3586},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0237, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3591 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0239, (cst_val *)&val_3592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3593 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0241, (cst_val *)&val_3594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3596 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0244, (cst_val *)&val_3597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3599 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0247, (cst_val *)&val_0009},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0248, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3601 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0251, (cst_val *)&val_3466},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0252, (cst_val *)&val_3586},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0253, (cst_val *)&val_3602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3603 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0255, (cst_val *)&val_3604},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0256, (cst_val *)&val_3605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3608 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0260, (cst_val *)&val_3528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3610 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0263, (cst_val *)&val_3559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3612 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0266, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3613 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0268, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0269, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3615 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0272, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3616 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0274, (cst_val *)&val_0244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3618 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0277, (cst_val *)&val_1208},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0278, (cst_val *)&val_3619},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3620 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0280, (cst_val *)&val_3621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3623 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0283, (cst_val *)&val_3586},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0284, (cst_val *)&val_3624},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0285, (cst_val *)&val_3585},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0286, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3625 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0288, (cst_val *)&val_3626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3628 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0291, (cst_val *)&val_3629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3631 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0294, (cst_val *)&val_3592},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0295, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3632 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0297, (cst_val *)&val_3633},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0298, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3635 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0301, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3636 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0303, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3637 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0305, (cst_val *)&val_3638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3639 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0307, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3642 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0310, (cst_val *)&val_3594},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0311, (cst_val *)&val_0073},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0312, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3645 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0316, (cst_val *)&val_3646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3648 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0319, (cst_val *)&val_3649},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0320, (cst_val *)&val_1506},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0321, (cst_val *)&val_3650},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0322, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3651 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0324, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3652 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0326, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3656 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0331, (cst_val *)&val_3657},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0332, (cst_val *)&val_1878},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0333, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3658 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0335, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3659 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0337, (cst_val *)&val_3605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3663 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0342, (cst_val *)&val_0004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0343, (cst_val *)&val_3664},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0344, (cst_val *)&val_3665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3667 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0347, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3668 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0349, (cst_val *)&val_0074},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0350, (cst_val *)&val_3669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3671 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0353, (cst_val *)&val_3563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3673 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0356, (cst_val *)&val_1387},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0357, (cst_val *)&val_3674},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0358, (cst_val *)&val_3459},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0359, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3675 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0361, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0362, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3677 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0364, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3679 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0367, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0368, (cst_val *)&val_3680},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0369, (cst_val *)&val_3681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3682 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0371, (cst_val *)&val_3683},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0372, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3686 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0376, (cst_val *)&val_3053},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0377, (cst_val *)&val_3687},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3688 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0379, (cst_val *)&val_3689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3690 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0381, (cst_val *)&val_3691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3693 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0384, (cst_val *)&val_3694},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0385, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3696 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0388, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3698 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0391, (cst_val *)&val_0543},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0392, (cst_val *)&val_1074},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0393, (cst_val *)&val_3699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3703 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0398, (cst_val *)&val_1074},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0399, (cst_val *)&val_3704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3705 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0401, (cst_val *)&val_3706},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0402, (cst_val *)&val_3707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3708 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0404, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3710 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0407, (cst_val *)&val_3711},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0408, (cst_val *)&val_3712},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0409, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3714 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0412, (cst_val *)&val_3715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3718 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0416, (cst_val *)&val_3719},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3720 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0418, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3721 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0420, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3725 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0425, (cst_val *)&val_3479},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0426, (cst_val *)&val_0232},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0427, (cst_val *)&val_3726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3728 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0430, (cst_val *)&val_3729},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0431, (cst_val *)&val_0007},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0432, (cst_val *)&val_1465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3730 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0434, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3732 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0437, (cst_val *)&val_3586},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0438, (cst_val *)&val_1887},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0439, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3734 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0442, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0443, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3736 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0446, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3738 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0449, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3739 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0451, (cst_val *)&val_3699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3741 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0454, (cst_val *)&val_3742},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0455, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3743 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0457, (cst_val *)&val_3744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3746 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0460, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3747 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0462, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3748 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0464, (cst_val *)&val_3749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3751 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0467, (cst_val *)&val_3752},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0468, (cst_val *)&val_3753},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0469, (cst_val *)&val_3754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3757 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0473, (cst_val *)&val_3699},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0474, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3760 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0478, (cst_val *)&val_0130},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0479, (cst_val *)&val_1403},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0480, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3763 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0484, (cst_val *)&val_3764},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0485, (cst_val *)&val_3467},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0486, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3766 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0489, (cst_val *)&val_0116},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0490, (cst_val *)&val_3559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3768 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0493, (cst_val *)&val_0147},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0494, (cst_val *)&val_3769},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0495, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3772 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0499, (cst_val *)&val_3704},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0500, (cst_val *)&val_0147},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0501, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3774 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0504, (cst_val *)&val_3459},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0505, (cst_val *)&val_2458},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0506, (cst_val *)&val_0926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3777 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0510, (cst_val *)&val_1073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3778 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0512, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3780 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0515, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3781 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0517, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3783 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0520, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3785 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0523, (cst_val *)&val_3786},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0524, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0525, (cst_val *)&val_3459},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0526, (cst_val *)&val_3787},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0527, (cst_val *)&val_0009},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0528, (cst_val *)&val_1238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3789 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0531, (cst_val *)&val_0147},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0532, (cst_val *)&val_3742},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0533, (cst_val *)&val_3790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3792 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0536, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3793 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0538, (cst_val *)&val_3794},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3796 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0541, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0542, (cst_val *)&val_3797},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0543, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3800 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0547, (cst_val *)&val_3801},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0548, (cst_val *)&val_1891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3802 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0550, (cst_val *)&val_1497},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0551, (cst_val *)&val_3586},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0552, (cst_val *)&val_1146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3805 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0556, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3807 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0558, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3809 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0561, (cst_val *)&val_2049},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0562, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3810 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0564, (cst_val *)&val_3811},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3813 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0567, (cst_val *)&val_3814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3816 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0570, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3817 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0572, (cst_val *)&val_3818},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0573, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3820 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0576, (cst_val *)&val_3821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3822 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0578, (cst_val *)&val_2325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3824 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0581, (cst_val *)&val_0533},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0582, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0583, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3826 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0586, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3827 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0588, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3828 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0590, (cst_val *)&val_3829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3832 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0594, (cst_val *)&val_3541},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0595, (cst_val *)&val_2529},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0596, (cst_val *)&val_3833},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0597, (cst_val *)&val_1045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3835 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0600, (cst_val *)&val_3466},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0601, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3839 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0606, (cst_val *)&val_3840},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0607, (cst_val *)&val_3841},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0608, (cst_val *)&val_3842},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0609, (cst_val *)&val_3712},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0610, (cst_val *)&val_3138},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0611, (cst_val *)&val_2435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3844 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0614, (cst_val *)&val_3845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3847 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0617, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3851 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0622, (cst_val *)&val_3818},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0623, (cst_val *)&val_3852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3853 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0625, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3855 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0628, (cst_val *)&val_3856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3858 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0631, (cst_val *)&val_0054},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0632, (cst_val *)&val_0116},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0633, (cst_val *)&val_0291},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0634, (cst_val *)&val_3859},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0635, (cst_val *)&val_1045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0636, (cst_val *)&val_3435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3861 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0639, (cst_val *)&val_3862},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0640, (cst_val *)&val_1558},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0641, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3865 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0645, (cst_val *)&val_3866},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3867 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0647, (cst_val *)&val_3462},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3869 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0650, (cst_val *)&val_0170},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0651, (cst_val *)&val_3870},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0652, (cst_val *)&val_3683},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0653, (cst_val *)&val_1045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0654, (cst_val *)&val_3856},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0655, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3876 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0662, (cst_val *)&val_1045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0663, (cst_val *)&val_3683},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0664, (cst_val *)&val_3877},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0665, (cst_val *)&val_3878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3881 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0669, (cst_val *)&val_3882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3886 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0674, (cst_val *)&val_3887},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0675, (cst_val *)&val_3689},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0676, (cst_val *)&val_0550},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0677, (cst_val *)&val_1387},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0678, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3890 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0682, (cst_val *)&val_3559},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0683, (cst_val *)&val_3891},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0684, (cst_val *)&val_3585},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3892 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0686, (cst_val *)&val_3893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3895 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0689, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3897 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0692, (cst_val *)&val_0147},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0693, (cst_val *)&val_1452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3899 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0696, (cst_val *)&val_0121},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0697, (cst_val *)&val_3900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3902 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0700, (cst_val *)&val_3903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3905 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0703, (cst_val *)&val_3459},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0704, (cst_val *)&val_0055},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0705, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0706, (cst_val *)&val_0066},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0707, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3906 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0709, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3907 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0711, (cst_val *)&val_3908},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0712, (cst_val *)&val_3842},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0713, (cst_val *)&val_3574},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0714, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3912 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0719, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3913 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0721, (cst_val *)&val_3914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3916 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0724, (cst_val *)&val_3814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3918 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0727, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3920 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0730, (cst_val *)&val_0550},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0731, (cst_val *)&val_3586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3923 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0735, (cst_val *)&val_0953},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0736, (cst_val *)&val_3587},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0737, (cst_val *)&val_3924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3927 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0741, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3928 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0743, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3930 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0746, (cst_val *)&val_3931},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0747, (cst_val *)&val_3932},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0748, (cst_val *)&val_0073},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0749, (cst_val *)&val_3933},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0750, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3935 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0753, (cst_val *)&val_3936},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0754, (cst_val *)&val_3937},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3940 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0758, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0759, (cst_val *)&val_3754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3942 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0762, (cst_val *)&val_3459},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0763, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3944 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0766, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3946 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0769, (cst_val *)&val_3947},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0770, (cst_val *)&val_0064},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0771, (cst_val *)&val_3948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3949 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0773, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3950 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0775, (cst_val *)&val_0520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3952 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0778, (cst_val *)&val_3953},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0779, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0780, (cst_val *)&val_3466},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0781, (cst_val *)&val_3954},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0782, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3955 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0784, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3956 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0786, (cst_val *)&val_3957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3961 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0791, (cst_val *)&val_3948},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0792, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0793, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3964 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0797, (cst_val *)&val_3965},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0798, (cst_val *)&val_3694},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0799, (cst_val *)&val_3466},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0800, (cst_val *)&val_3966},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3969 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0804, (cst_val *)&val_1763},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0805, (cst_val *)&val_1208},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0806, (cst_val *)&val_3545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3971 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0809, (cst_val *)&val_3878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3973 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0812, (cst_val *)&val_1208},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0813, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3975 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0816, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3976 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0818, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3978 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0821, (cst_val *)&val_3459},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0822, (cst_val *)&val_1506},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0823, (cst_val *)&val_3466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3981 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0827, (cst_val *)&val_3957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3983 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0830, (cst_val *)&val_3459},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0831, (cst_val *)&val_3559},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0832, (cst_val *)&val_3550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3984 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0834, (cst_val *)&val_0550},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0835, (cst_val *)&val_3985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3989 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0840, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3990 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0842, (cst_val *)&val_3706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3992 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0845, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3993 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0847, (cst_val *)&val_3994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3995 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0849, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3996 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0851, (cst_val *)&val_3997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3999 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0854, (cst_val *)&val_4000},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0855, (cst_val *)&val_3657},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0856, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4001 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0858, (cst_val *)&val_3459},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0859, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4002 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0861, (cst_val *)&val_3948},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0862, (cst_val *)&val_3574},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0863, (cst_val *)&val_0073},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0864, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4005 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0868, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4008 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0872, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0873, (cst_val *)&val_3467},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0874, (cst_val *)&val_3138},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0875, (cst_val *)&val_0514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4012 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0880, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4014 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0883, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4015 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0885, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0886, (cst_val *)&val_3594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4016 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0888, (cst_val *)&val_3821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4018 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0891, (cst_val *)&val_4019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4021 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0894, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0895, (cst_val *)&val_4022},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0896, (cst_val *)&val_3592},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0897, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4023 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0899, (cst_val *)&val_0550},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0900, (cst_val *)&val_3586},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0901, (cst_val *)&val_3560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4024 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0903, (cst_val *)&val_4025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4028 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0907, (cst_val *)&val_0543},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0908, (cst_val *)&val_3559},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0909, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4029 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0911, (cst_val *)&val_3586},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0912, (cst_val *)&val_3585},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0913, (cst_val *)&val_3467},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0914, (cst_val *)&val_3560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4031 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0917, (cst_val *)&val_4032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4035 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0921, (cst_val *)&val_3467},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0922, (cst_val *)&val_3560},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0923, (cst_val *)&val_4036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4038 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0926, (cst_val *)&val_4039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4043 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0931, (cst_val *)&val_4044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4046 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0934, (cst_val *)&val_3467},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0935, (cst_val *)&val_3138},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0936, (cst_val *)&val_3586},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0937, (cst_val *)&val_3594},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0938, (cst_val *)&val_4047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4049 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0941, (cst_val *)&val_4050},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0942, (cst_val *)&val_4051},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0943, (cst_val *)&val_3646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4057 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0950, (cst_val *)&val_3466},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0951, (cst_val *)&val_0550},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0952, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4059 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0955, (cst_val *)&val_4032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4063 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0960, (cst_val *)&val_4064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0961, (cst_val *)&val_4065},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0962, (cst_val *)&val_3665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4066 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0964, (cst_val *)&val_3466},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0965, (cst_val *)&val_3459},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0966, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4068 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0969, (cst_val *)&val_4069},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0970, (cst_val *)&val_4070},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0971, (cst_val *)&val_3605},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4071 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0973, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4076 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0979, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4077 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0981, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4079 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0984, (cst_val *)&val_3657},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0985, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4080 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0987, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0988, (cst_val *)&val_3459},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0989, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4083 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0993, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4085 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0996, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4086 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_0998, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4088 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1001, (cst_val *)&val_3657},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1002, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4089 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1004, (cst_val *)&val_0491},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1005, (cst_val *)&val_4090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4092 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1008, (cst_val *)&val_3932},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1009, (cst_val *)&val_2442},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1010, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4093 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1012, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1013, (cst_val *)&val_3711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4095 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1016, (cst_val *)&val_3459},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1017, (cst_val *)&val_3138},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1018, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4096 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1020, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4101 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1026, (cst_val *)&val_1208},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1027, (cst_val *)&val_4102},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1028, (cst_val *)&val_3948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4103 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1030, (cst_val *)&val_4090},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1031, (cst_val *)&val_4104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4108 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1036, (cst_val *)&val_3574},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1037, (cst_val *)&val_3706},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1038, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4109 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1040, (cst_val *)&val_3459},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1041, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4111 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1044, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4113 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1047, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4115 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1050, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4116 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1052, (cst_val *)&val_4117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4119 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1055, (cst_val *)&val_4120},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1056, (cst_val *)&val_3459},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1057, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4122 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1060, (cst_val *)&val_1878},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1061, (cst_val *)&val_0045},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1062, (cst_val *)&val_4123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4124 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1064, (cst_val *)&val_4125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4127 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1067, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4129 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1070, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4132 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1074, (cst_val *)&val_3764},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1075, (cst_val *)&val_3467},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1076, (cst_val *)&val_4133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4135 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1079, (cst_val *)&val_0014},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1080, (cst_val *)&val_0533},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1081, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4137 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1084, (cst_val *)&val_0077},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1085, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4139 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1088, (cst_val *)&val_4140},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1089, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4143 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1093, (cst_val *)&val_0478},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1094, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4145 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1097, (cst_val *)&val_0045},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1098, (cst_val *)&val_0007},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1099, (cst_val *)&val_1500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4148 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1103, (cst_val *)&val_4149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4150 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1105, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4151 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1107, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4152 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1109, (cst_val *)&val_4153},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1110, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4154 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1112, (cst_val *)&val_1783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4157 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1116, (cst_val *)&val_4158},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1117, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4160 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1120, (cst_val *)&val_4161},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1121, (cst_val *)&val_0007},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1122, (cst_val *)&val_4162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4164 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1125, (cst_val *)&val_4165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4166 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1127, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4168 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1130, (cst_val *)&val_3553},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1131, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4170 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1134, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4171 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1136, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4172 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1138, (cst_val *)&val_4173},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1139, (cst_val *)&val_3914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4175 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1142, (cst_val *)&val_4176},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1143, (cst_val *)&val_4177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4178 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_142_NO_1145, (cst_val *)&val_3459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4181 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_pau_142_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_pau_142_cart = {
  cmu_us_awb_single_mcep_pau_142_cart_nodes,
  cmu_us_awb_single_mcep_pau_142_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ao_16_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0000, (cst_val *)&val_0989},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0001, (cst_val *)&val_4182},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4183 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0003, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4185 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0006, (cst_val *)&val_0064},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0007, (cst_val *)&val_0007},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0008, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4187 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0011, (cst_val *)&val_0211},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0012, (cst_val *)&val_1292},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0013, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4189 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0016, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4190 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0018, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4192 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0021, (cst_val *)&val_4193},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0022, (cst_val *)&val_4194},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0023, (cst_val *)&val_0399},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0024, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4197 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0028, (cst_val *)&val_0014},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0029, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4199 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0032, (cst_val *)&val_4200},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0033, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4204 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0038, (cst_val *)&val_2598},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0039, (cst_val *)&val_0905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4205 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0041, (cst_val *)&val_1115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4207 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0044, (cst_val *)&val_0533},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0045, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4209 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0048, (cst_val *)&val_0130},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0049, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4211 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0052, (cst_val *)&val_4212},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0053, (cst_val *)&val_4213},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0054, (cst_val *)&val_0147},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0055, (cst_val *)&val_4214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4218 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0060, (cst_val *)&val_3218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4219 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0062, (cst_val *)&val_0175},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0063, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4220 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_16_NO_0065, (cst_val *)&val_1222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4223 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ao_16_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_awb_single_mcep_ao_16_cart = {
  cmu_us_awb_single_mcep_ao_16_cart_nodes,
  cmu_us_awb_single_mcep_ao_16_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ao_17_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0000, (cst_val *)&val_0637},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0002, (cst_val *)&val_0478},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0003, (cst_val *)&val_4224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4227 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0007, (cst_val *)&val_0007},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0008, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4228 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0010, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4230 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0013, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0014, (cst_val *)&val_4231},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4232 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0016, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4234 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0019, (cst_val *)&val_2088},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0020, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4235 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0022, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4237 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0025, (cst_val *)&val_4238},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0026, (cst_val *)&val_4239},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0027, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4243 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0032, (cst_val *)&val_1131},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0033, (cst_val *)&val_0041},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0034, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0035, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4245 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0038, (cst_val *)&val_4246},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0039, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4248 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0042, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4250 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0045, (cst_val *)&val_0525},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0046, (cst_val *)&val_0904},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0047, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4252 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0050, (cst_val *)&val_0007},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0051, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4254 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0054, (cst_val *)&val_0121},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0055, (cst_val *)&val_3936},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0056, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4256 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0059, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4257 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0061, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4259 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0064, (cst_val *)&val_0064},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0065, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4261 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0068, (cst_val *)&val_4262},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4264 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0071, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4265 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0073, (cst_val *)&val_0005},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0074, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4267 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0077, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4269 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0080, (cst_val *)&val_4270},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0081, (cst_val *)&val_0121},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0082, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4271 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0084, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4272 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0086, (cst_val *)&val_3527},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0087, (cst_val *)&val_4273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4274 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0089, (cst_val *)&val_4275},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4278 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0093, (cst_val *)&val_0003},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0094, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4280 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0097, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0098, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4282 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0101, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4284 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0104, (cst_val *)&val_0065},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0105, (cst_val *)&val_0007},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0106, (cst_val *)&val_4285},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4288 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0110, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0111, (cst_val *)&val_4289},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0112, (cst_val *)&val_4290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4292 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0115, (cst_val *)&val_4293},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0116, (cst_val *)&val_4294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4295 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0118, (cst_val *)&val_4296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4297 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0120, (cst_val *)&val_4298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4301 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0124, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4302 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0126, (cst_val *)&val_0121},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0127, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0128, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4304 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0131, (cst_val *)&val_3550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4305 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0133, (cst_val *)&val_4306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4308 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0136, (cst_val *)&val_4309},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0137, (cst_val *)&val_0049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0138, (cst_val *)&val_2272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4310 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_17_NO_0140, (cst_val *)&val_4311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4315 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ao_17_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_ao_17_cart = {
  cmu_us_awb_single_mcep_ao_17_cart_nodes,
  cmu_us_awb_single_mcep_ao_17_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ao_18_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0000, (cst_val *)&val_3440},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0001, (cst_val *)&val_4316},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0002, (cst_val *)&val_0007},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0003, (cst_val *)&val_0030},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0004, (cst_val *)&val_0232},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0005, (cst_val *)&val_0823},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0006, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4319 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0010, (cst_val *)&val_4320},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0011, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4321 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0013, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4325 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0018, (cst_val *)&val_0130},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0019, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4326 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0021, (cst_val *)&val_4327},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0022, (cst_val *)&val_4328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4329 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0024, (cst_val *)&val_3665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4331 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0027, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4333 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0030, (cst_val *)&val_4334},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0031, (cst_val *)&val_0007},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0032, (cst_val *)&val_3626},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0033, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4336 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0036, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4338 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0039, (cst_val *)&val_0003},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0040, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4340 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0043, (cst_val *)&val_1009},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0044, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4341 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0046, (cst_val *)&val_4342},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0047, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4345 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0051, (cst_val *)&val_0017},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0052, (cst_val *)&val_4346},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0053, (cst_val *)&val_4347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4350 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0057, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4352 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0060, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4353 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0062, (cst_val *)&val_4354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4356 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0065, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0066, (cst_val *)&val_4357},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0067, (cst_val *)&val_0823},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0068, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4358 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0070, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4359 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0072, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4361 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0075, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4363 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0078, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0079, (cst_val *)&val_4364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4366 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0082, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0083, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4369 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0087, (cst_val *)&val_4370},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0088, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4373 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0092, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0093, (cst_val *)&val_0494},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0094, (cst_val *)&val_3821},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0095, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4375 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0098, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4376 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0100, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4378 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0103, (cst_val *)&val_4379},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0104, (cst_val *)&val_4380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4381 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0106, (cst_val *)&val_0952},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0107, (cst_val *)&val_0823},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0108, (cst_val *)&val_4382},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0109, (cst_val *)&val_1963},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0110, (cst_val *)&val_4383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4385 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0113, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4387 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0116, (cst_val *)&val_4388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4391 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0120, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4392 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0122, (cst_val *)&val_4393},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4394 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0124, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4396 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0127, (cst_val *)&val_4397},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0128, (cst_val *)&val_4398},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0129, (cst_val *)&val_4399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4401 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0132, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4403 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0135, (cst_val *)&val_1070},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0136, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4406 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0140, (cst_val *)&val_0003},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0141, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4408 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0144, (cst_val *)&val_4409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4410 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0146, (cst_val *)&val_0049},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ao_18_NO_0147, (cst_val *)&val_4411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4414 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ao_18_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_single_mcep_ao_18_cart = {
  cmu_us_awb_single_mcep_ao_18_cart_nodes,
  cmu_us_awb_single_mcep_ao_18_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_th_169_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0000, (cst_val *)&val_1222},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0001, (cst_val *)&val_0264},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0002, (cst_val *)&val_0147},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4415 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0005, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4417 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0008, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0009, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4419 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0012, (cst_val *)&val_4420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4423 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0016, (cst_val *)&val_0622},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_169_NO_0017, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4426 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_th_169_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_awb_single_mcep_th_169_cart = {
  cmu_us_awb_single_mcep_th_169_cart_nodes,
  cmu_us_awb_single_mcep_th_169_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_th_170_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0000, (cst_val *)&val_0533},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0001, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4427 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0003, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4429 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0006, (cst_val *)&val_0878},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0007, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4430 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0009, (cst_val *)&val_4431},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0010, (cst_val *)&val_0864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4432 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0012, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4435 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0016, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0017, (cst_val *)&val_0525},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0018, (cst_val *)&val_0077},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0019, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4436 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0021, (cst_val *)&val_4437},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4439 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0024, (cst_val *)&val_4440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4442 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0027, (cst_val *)&val_4443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4445 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0030, (cst_val *)&val_0147},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0031, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4446 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0033, (cst_val *)&val_0264},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0034, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4449 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0038, (cst_val *)&val_4450},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0039, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4451 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0041, (cst_val *)&val_3527},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0042, (cst_val *)&val_4452},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0043, (cst_val *)&val_0154},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_170_NO_0044, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4458 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_th_170_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_awb_single_mcep_th_170_cart = {
  cmu_us_awb_single_mcep_th_170_cart_nodes,
  cmu_us_awb_single_mcep_th_170_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_th_171_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0000, (cst_val *)&val_0002},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0001, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0002, (cst_val *)&val_1987},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0003, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4461 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0007, (cst_val *)&val_4462},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0008, (cst_val *)&val_0003},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0009, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4463 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0011, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4464 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0013, (cst_val *)&val_0882},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0014, (cst_val *)&val_4465},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0015, (cst_val *)&val_0009},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4468 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0020, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4470 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0023, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0024, (cst_val *)&val_4471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4472 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0026, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4475 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0030, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4477 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0033, (cst_val *)&val_4478},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0034, (cst_val *)&val_0003},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0035, (cst_val *)&val_4479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4481 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0038, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4484 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0042, (cst_val *)&val_0045},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_th_171_NO_0043, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4487 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_th_171_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_th_171_cart = {
  cmu_us_awb_single_mcep_th_171_cart_nodes,
  cmu_us_awb_single_mcep_th_171_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ah_11_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0000, (cst_val *)&val_4488},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0001, (cst_val *)&val_0121},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0002, (cst_val *)&val_1276},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0003, (cst_val *)&val_1074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4490 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0006, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4492 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0009, (cst_val *)&val_0085},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0010, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4493 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0012, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4494 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0014, (cst_val *)&val_0147},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0015, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4495 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0017, (cst_val *)&val_1049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4496 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0019, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4498 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0022, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4499 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0024, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4501 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0027, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4502 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0029, (cst_val *)&val_0041},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0030, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4505 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0034, (cst_val *)&val_0007},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0035, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0036, (cst_val *)&val_1329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4507 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0039, (cst_val *)&val_0872},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0040, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4509 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0043, (cst_val *)&val_1276},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0044, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4511 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0047, (cst_val *)&val_4512},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4514 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0050, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0051, (cst_val *)&val_0049},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0052, (cst_val *)&val_4515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4516 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0054, (cst_val *)&val_0073},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0055, (cst_val *)&val_4517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4519 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0058, (cst_val *)&val_2448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4521 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0061, (cst_val *)&val_4522},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0062, (cst_val *)&val_4523},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0063, (cst_val *)&val_4524},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0064, (cst_val *)&val_0064},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0065, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4528 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0070, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4529 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0072, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4531 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0075, (cst_val *)&val_4532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4533 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0077, (cst_val *)&val_4534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4535 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0079, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4537 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_11_NO_0082, (cst_val *)&val_1532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4539 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ah_11_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_ah_11_cart = {
  cmu_us_awb_single_mcep_ah_11_cart_nodes,
  cmu_us_awb_single_mcep_ah_11_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ah_12_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0000, (cst_val *)&val_0399},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0002, (cst_val *)&val_0065},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0003, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0004, (cst_val *)&val_4540},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0005, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4541 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0007, (cst_val *)&val_2361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4544 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0011, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4545 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0013, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4547 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0016, (cst_val *)&val_0130},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0017, (cst_val *)&val_2451},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0018, (cst_val *)&val_3138},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0019, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4548 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0021, (cst_val *)&val_0887},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0022, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4552 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0027, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4554 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0030, (cst_val *)&val_1273},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0031, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4557 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0035, (cst_val *)&val_4558},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0036, (cst_val *)&val_0153},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0037, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4559 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0039, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4562 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0043, (cst_val *)&val_4563},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0044, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4564 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0046, (cst_val *)&val_4565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4568 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0050, (cst_val *)&val_0045},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0051, (cst_val *)&val_2361},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0052, (cst_val *)&val_0024},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0053, (cst_val *)&val_4569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4571 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0056, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4573 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0059, (cst_val *)&val_1009},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0060, (cst_val *)&val_4574},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0061, (cst_val *)&val_0147},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0062, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4575 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0064, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4578 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0068, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0069, (cst_val *)&val_4579},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0070, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4580 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0072, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4582 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0075, (cst_val *)&val_4583},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4585 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0078, (cst_val *)&val_4194},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0079, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4586 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0081, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4588 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0084, (cst_val *)&val_0049},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0085, (cst_val *)&val_4589},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0086, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4592 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0090, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0091, (cst_val *)&val_4593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4595 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0094, (cst_val *)&val_0003},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0095, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4598 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0099, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4599 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0101, (cst_val *)&val_4600},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0102, (cst_val *)&val_4601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4604 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0106, (cst_val *)&val_0130},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0107, (cst_val *)&val_1365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4605 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0109, (cst_val *)&val_0375},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0110, (cst_val *)&val_1955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4606 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0112, (cst_val *)&val_1792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4609 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0116, (cst_val *)&val_0147},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0117, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4610 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0119, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4611 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0121, (cst_val *)&val_4612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4613 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0123, (cst_val *)&val_4614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4616 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0126, (cst_val *)&val_4617},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0127, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4618 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0129, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4619 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0131, (cst_val *)&val_2912},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0132, (cst_val *)&val_4620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4621 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0134, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4624 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0138, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4625 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_12_NO_0140, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4627 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ah_12_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_awb_single_mcep_ah_12_cart = {
  cmu_us_awb_single_mcep_ah_12_cart_nodes,
  cmu_us_awb_single_mcep_ah_12_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ah_13_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0001, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0002, (cst_val *)&val_2988},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0003, (cst_val *)&val_0520},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0004, (cst_val *)&val_0498},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0005, (cst_val *)&val_4628},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4630 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0008, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4632 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0011, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4633 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0013, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4635 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0016, (cst_val *)&val_4380},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0017, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4638 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0021, (cst_val *)&val_0027},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0022, (cst_val *)&val_2451},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0023, (cst_val *)&val_0073},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0024, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4639 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0026, (cst_val *)&val_0373},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0027, (cst_val *)&val_4640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4642 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0030, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4645 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0034, (cst_val *)&val_0077},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0035, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4647 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0038, (cst_val *)&val_4648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4650 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0041, (cst_val *)&val_4651},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0042, (cst_val *)&val_0542},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0043, (cst_val *)&val_4652},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0044, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4653 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0046, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4654 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0048, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4658 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0053, (cst_val *)&val_4659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4661 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0056, (cst_val *)&val_4662},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0057, (cst_val *)&val_0026},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0058, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4663 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0060, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4666 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0064, (cst_val *)&val_4667},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4668 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0066, (cst_val *)&val_0073},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0067, (cst_val *)&val_0261},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0068, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4671 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0072, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4672 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ah_13_NO_0074, (cst_val *)&val_1770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4674 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ah_13_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_ah_13_cart = {
  cmu_us_awb_single_mcep_ah_13_cart_nodes,
  cmu_us_awb_single_mcep_ah_13_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_v_184_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0000, (cst_val *)&val_0849},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0002, (cst_val *)&val_0679},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0003, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4677 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0007, (cst_val *)&val_0009},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0008, (cst_val *)&val_0154},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0009, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4679 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0012, (cst_val *)&val_4680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4682 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0015, (cst_val *)&val_0525},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0016, (cst_val *)&val_0101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4684 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0019, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0020, (cst_val *)&val_4685},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0021, (cst_val *)&val_1507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4687 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0024, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4689 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0027, (cst_val *)&val_0906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4691 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0030, (cst_val *)&val_0700},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0031, (cst_val *)&val_0049},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0032, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4694 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0036, (cst_val *)&val_4695},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_184_NO_0037, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4698 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_v_184_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_v_184_cart = {
  cmu_us_awb_single_mcep_v_184_cart_nodes,
  cmu_us_awb_single_mcep_v_184_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_v_185_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0001, (cst_val *)&val_0129},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0002, (cst_val *)&val_0679},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0003, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4702 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0008, (cst_val *)&val_0905},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0009, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0010, (cst_val *)&val_0700},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0011, (cst_val *)&val_4703},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4705 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0014, (cst_val *)&val_4706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4708 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0017, (cst_val *)&val_0264},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0018, (cst_val *)&val_0905},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0019, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0020, (cst_val *)&val_1284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4711 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0024, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4712 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0026, (cst_val *)&val_4713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4715 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0029, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4717 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0032, (cst_val *)&val_0992},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0033, (cst_val *)&val_0976},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0034, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4718 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0036, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4720 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0039, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4721 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0041, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0042, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4724 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0046, (cst_val *)&val_4725},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0047, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0048, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4728 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_185_NO_0052, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4730 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_v_185_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_v_185_cart = {
  cmu_us_awb_single_mcep_v_185_cart_nodes,
  cmu_us_awb_single_mcep_v_185_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_v_186_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0001, (cst_val *)&val_0116},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0002, (cst_val *)&val_0952},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0003, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4732 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0006, (cst_val *)&val_0030},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0007, (cst_val *)&val_1387},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0008, (cst_val *)&val_4733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4734 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0010, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4736 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0013, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4739 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0017, (cst_val *)&val_4740},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0018, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4742 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0021, (cst_val *)&val_0864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4744 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0024, (cst_val *)&val_1843},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0025, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0026, (cst_val *)&val_4745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4746 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0028, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4748 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0031, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0032, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4749 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0034, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4751 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0037, (cst_val *)&val_0073},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0038, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4754 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0042, (cst_val *)&val_4755},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0043, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0044, (cst_val *)&val_4756},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0045, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4757 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0047, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4759 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0050, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4761 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0053, (cst_val *)&val_0077},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0054, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4762 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0056, (cst_val *)&val_0526},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0057, (cst_val *)&val_2787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4764 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0060, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4765 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0062, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0063, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0064, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4768 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0068, (cst_val *)&val_4769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4770 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0070, (cst_val *)&val_4771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4774 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_v_186_NO_0074, (cst_val *)&val_3769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4776 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_v_186_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_v_186_cart = {
  cmu_us_awb_single_mcep_v_186_cart_nodes,
  cmu_us_awb_single_mcep_v_186_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_dh_51_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0000, (cst_val *)&val_4777},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0002, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4778 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0004, (cst_val *)&val_4779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4780 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0006, (cst_val *)&val_4781},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0007, (cst_val *)&val_3466},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0008, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4785 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0013, (cst_val *)&val_3133},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0014, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4786 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0016, (cst_val *)&val_2052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4787 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0018, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4788 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0020, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0021, (cst_val *)&val_4789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4791 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0024, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4794 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0028, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0029, (cst_val *)&val_0622},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0030, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4795 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0032, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4797 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0035, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4798 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0037, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4800 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0040, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4801 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0042, (cst_val *)&val_0065},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0043, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4802 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0045, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4804 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0048, (cst_val *)&val_1208},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0049, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4806 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0052, (cst_val *)&val_1424},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0053, (cst_val *)&val_0064},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0054, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0055, (cst_val *)&val_0578},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0056, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4807 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0058, (cst_val *)&val_0102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4809 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0061, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4811 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0064, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0065, (cst_val *)&val_4812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4815 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0069, (cst_val *)&val_0658},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0070, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4816 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0072, (cst_val *)&val_1336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4819 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0076, (cst_val *)&val_4820},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0077, (cst_val *)&val_0587},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0078, (cst_val *)&val_4821},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0079, (cst_val *)&val_1535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4824 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_51_NO_0083, (cst_val *)&val_4825},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4828 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_dh_51_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_dh_51_cart = {
  cmu_us_awb_single_mcep_dh_51_cart_nodes,
  cmu_us_awb_single_mcep_dh_51_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_dh_52_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0000, (cst_val *)&val_4829},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0001, (cst_val *)&val_0065},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0002, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0003, (cst_val *)&val_4830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4833 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0007, (cst_val *)&val_0402},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0008, (cst_val *)&val_0932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4834 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0010, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0011, (cst_val *)&val_4830},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0012, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4836 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0015, (cst_val *)&val_3706},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4839 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0020, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4840 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0022, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4841 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0024, (cst_val *)&val_4842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4844 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0027, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0028, (cst_val *)&val_4845},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0029, (cst_val *)&val_0592},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0030, (cst_val *)&val_0188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4848 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0034, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4850 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0037, (cst_val *)&val_4851},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0038, (cst_val *)&val_3706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4853 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0041, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4855 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0044, (cst_val *)&val_4856},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0045, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0046, (cst_val *)&val_4857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4859 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0049, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0050, (cst_val *)&val_1452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4861 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0053, (cst_val *)&val_4862},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0054, (cst_val *)&val_4863},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4866 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0058, (cst_val *)&val_0185},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0059, (cst_val *)&val_3175},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0060, (cst_val *)&val_2116},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0061, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4868 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0064, (cst_val *)&val_1770},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0065, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4870 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0068, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4872 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0071, (cst_val *)&val_4873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4875 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_52_NO_0074, (cst_val *)&val_4876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4878 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_dh_52_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_dh_52_cart = {
  cmu_us_awb_single_mcep_dh_52_cart_nodes,
  cmu_us_awb_single_mcep_dh_52_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_dh_53_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0000, (cst_val *)&val_0932},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0001, (cst_val *)&val_0049},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0002, (cst_val *)&val_0887},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0003, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4882 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0008, (cst_val *)&val_0016},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0009, (cst_val *)&val_4829},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0010, (cst_val *)&val_0009},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0011, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0012, (cst_val *)&val_4883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4884 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0014, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4887 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0018, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4888 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0020, (cst_val *)&val_0004},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0021, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0022, (cst_val *)&val_4889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4891 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0025, (cst_val *)&val_1403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4895 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0030, (cst_val *)&val_3862},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0031, (cst_val *)&val_4896},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0032, (cst_val *)&val_0017},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0033, (cst_val *)&val_0340},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4898 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0036, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4899 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0038, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4902 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0042, (cst_val *)&val_0232},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0043, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4904 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0046, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4905 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4906 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0050, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0051, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4908 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0054, (cst_val *)&val_0049},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0055, (cst_val *)&val_0315},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_dh_53_NO_0056, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4912 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_dh_53_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_dh_53_cart = {
  cmu_us_awb_single_mcep_dh_53_cart_nodes,
  cmu_us_awb_single_mcep_dh_53_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_d_46_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0001, (cst_val *)&val_1070},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0002, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4914 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0005, (cst_val *)&val_4915},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0006, (cst_val *)&val_4916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4919 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0010, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0011, (cst_val *)&val_1424},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0012, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0013, (cst_val *)&val_4920},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0014, (cst_val *)&val_0009},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0015, (cst_val *)&val_1387},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0016, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4921 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0018, (cst_val *)&val_3094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4923 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0021, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4926 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0025, (cst_val *)&val_4927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4929 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0028, (cst_val *)&val_0130},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0029, (cst_val *)&val_4930},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0030, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4931 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0032, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4932 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0034, (cst_val *)&val_1769},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0035, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4934 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0038, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4935 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0040, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4938 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0044, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4939 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0046, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4940 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0048, (cst_val *)&val_4941},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0049, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4943 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0052, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4944 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0054, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4946 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0057, (cst_val *)&val_0868},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0058, (cst_val *)&val_0147},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0059, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4948 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0062, (cst_val *)&val_4949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4950 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0064, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4952 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0067, (cst_val *)&val_4953},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0068, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4955 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0071, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4957 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0074, (cst_val *)&val_0065},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0075, (cst_val *)&val_0027},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0076, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0077, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4958 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0079, (cst_val *)&val_0373},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0080, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4960 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0083, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4962 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0086, (cst_val *)&val_3211},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0087, (cst_val *)&val_0077},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0088, (cst_val *)&val_4963},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0089, (cst_val *)&val_0016},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0090, (cst_val *)&val_1858},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0091, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4966 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0095, (cst_val *)&val_4967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4969 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0098, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4971 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0101, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4972 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0103, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4975 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0107, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4976 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0109, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4977 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0111, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4979 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0114, (cst_val *)&val_1532},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0115, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0116, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4981 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0119, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4983 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0122, (cst_val *)&val_1551},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0123, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4985 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0126, (cst_val *)&val_4986},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0127, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4987 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0129, (cst_val *)&val_0399},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_46_NO_0130, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4991 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_d_46_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_d_46_cart = {
  cmu_us_awb_single_mcep_d_46_cart_nodes,
  cmu_us_awb_single_mcep_d_46_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_d_47_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0000, (cst_val *)&val_0378},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0001, (cst_val *)&val_0373},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0002, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4992 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0005, (cst_val *)&val_0130},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0006, (cst_val *)&val_4993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4995 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0009, (cst_val *)&val_0906},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0010, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4998 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0014, (cst_val *)&val_1070},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0015, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4999 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0017, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0018, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0019, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5000 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0021, (cst_val *)&val_5001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5003 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0024, (cst_val *)&val_0065},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0025, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5006 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0029, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5007 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0031, (cst_val *)&val_3276},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0032, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5008 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0034, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5011 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0038, (cst_val *)&val_0021},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0039, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0040, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5013 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0043, (cst_val *)&val_5014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5016 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0046, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5018 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0049, (cst_val *)&val_0147},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0050, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5019 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0052, (cst_val *)&val_0009},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0053, (cst_val *)&val_0700},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0054, (cst_val *)&val_0279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5021 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0057, (cst_val *)&val_0049},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0058, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5022 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0060, (cst_val *)&val_0398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5025 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0064, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5026 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0066, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5027 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0068, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5029 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0071, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0072, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0073, (cst_val *)&val_5030},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0074, (cst_val *)&val_1955},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0075, (cst_val *)&val_3818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5032 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0078, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5035 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0082, (cst_val *)&val_1971},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0083, (cst_val *)&val_0399},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0084, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5037 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0087, (cst_val *)&val_5038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5040 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0090, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0091, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5043 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0095, (cst_val *)&val_5044},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0096, (cst_val *)&val_5045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5046 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0098, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5047 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0100, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5049 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0103, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5050 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0105, (cst_val *)&val_1115},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0106, (cst_val *)&val_0906},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0107, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5053 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0111, (cst_val *)&val_5054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5056 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0114, (cst_val *)&val_0721},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0115, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0116, (cst_val *)&val_0012},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0117, (cst_val *)&val_0003},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0118, (cst_val *)&val_4916},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0119, (cst_val *)&val_5057},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0120, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5058 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0122, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0123, (cst_val *)&val_5059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5061 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0126, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5064 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0130, (cst_val *)&val_5065},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0131, (cst_val *)&val_1413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5067 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0134, (cst_val *)&val_5068},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0135, (cst_val *)&val_5069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5072 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0139, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5073 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0141, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5075 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0144, (cst_val *)&val_0064},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0145, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5077 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0148, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5078 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0150, (cst_val *)&val_5079},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0151, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5081 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0154, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5083 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0157, (cst_val *)&val_0065},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0158, (cst_val *)&val_1177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5085 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0161, (cst_val *)&val_5086},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0162, (cst_val *)&val_5087},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0163, (cst_val *)&val_1084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5090 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0167, (cst_val *)&val_0003},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0168, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5091 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0170, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5094 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0174, (cst_val *)&val_0065},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0175, (cst_val *)&val_3550},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0176, (cst_val *)&val_1792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5096 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0179, (cst_val *)&val_5097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5099 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0182, (cst_val *)&val_5100},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0183, (cst_val *)&val_0005},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0184, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0185, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0186, (cst_val *)&val_0130},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0187, (cst_val *)&val_5101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5102 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0189, (cst_val *)&val_5103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5105 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0192, (cst_val *)&val_1853},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0193, (cst_val *)&val_5106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5108 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0196, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5110 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0199, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5113 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0203, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5114 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0205, (cst_val *)&val_5115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5116 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0207, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5117 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0209, (cst_val *)&val_5118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5120 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_47_NO_0212, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5122 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_d_47_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_single_mcep_d_47_cart = {
  cmu_us_awb_single_mcep_d_47_cart_nodes,
  cmu_us_awb_single_mcep_d_47_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_d_48_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0001, (cst_val *)&val_0130},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0002, (cst_val *)&val_0477},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0003, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5124 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0006, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5125 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0008, (cst_val *)&val_5126},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0009, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5128 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0012, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5130 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0015, (cst_val *)&val_5131},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0016, (cst_val *)&val_0478},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0017, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0018, (cst_val *)&val_0135},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0019, (cst_val *)&val_5132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5135 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0023, (cst_val *)&val_5136},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5138 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0026, (cst_val *)&val_0953},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0027, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5141 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0031, (cst_val *)&val_5142},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0032, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5143 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0034, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5144 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0036, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0037, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5145 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0039, (cst_val *)&val_5146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5148 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0042, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5149 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0044, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5151 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0047, (cst_val *)&val_5152},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5154 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0050, (cst_val *)&val_0980},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0051, (cst_val *)&val_5155},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0052, (cst_val *)&val_5156},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0053, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0054, (cst_val *)&val_0316},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0055, (cst_val *)&val_0147},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0056, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5158 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0059, (cst_val *)&val_0130},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0060, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5159 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0062, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5161 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0065, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5163 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0068, (cst_val *)&val_0102},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0069, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5164 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0071, (cst_val *)&val_3584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5166 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0074, (cst_val *)&val_5167},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0075, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5170 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0079, (cst_val *)&val_0041},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0080, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5171 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0082, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5174 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0086, (cst_val *)&val_5175},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0087, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5177 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0090, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5179 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0093, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5180 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0095, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0096, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5182 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0099, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5183 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0101, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5185 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0104, (cst_val *)&val_0064},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0105, (cst_val *)&val_0187},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0106, (cst_val *)&val_5186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5187 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0108, (cst_val *)&val_5188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5191 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0112, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0113, (cst_val *)&val_5192},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0114, (cst_val *)&val_0185},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0115, (cst_val *)&val_0085},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0116, (cst_val *)&val_0077},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0117, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5193 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0119, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5194 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0121, (cst_val *)&val_5195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5198 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0125, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5200 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0128, (cst_val *)&val_0009},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0129, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0130, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5203 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0134, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5204 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0136, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5207 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0140, (cst_val *)&val_0121},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0141, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0142, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5209 },
{ 30, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0145, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5211 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0148, (cst_val *)&val_0494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5212 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_d_48_NO_0150, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5214 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_d_48_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_d_48_cart = {
  cmu_us_awb_single_mcep_d_48_cart_nodes,
  cmu_us_awb_single_mcep_d_48_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_n_116_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0001, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0002, (cst_val *)&val_5215},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5217 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0005, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0006, (cst_val *)&val_5218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5220 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0009, (cst_val *)&val_0510},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0010, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5221 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0012, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5222 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0014, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0015, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5224 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0018, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5225 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0020, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5226 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0022, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5229 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0026, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0027, (cst_val *)&val_5230},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0028, (cst_val *)&val_5231},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0029, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0030, (cst_val *)&val_0159},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0031, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5232 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0033, (cst_val *)&val_2999},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0034, (cst_val *)&val_0477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5234 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0037, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5237 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0041, (cst_val *)&val_0009},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0042, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5239 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0045, (cst_val *)&val_3729},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0046, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5240 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0048, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5242 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0051, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5244 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0054, (cst_val *)&val_0009},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0055, (cst_val *)&val_1273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5245 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0057, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5246 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0059, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5247 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0061, (cst_val *)&val_3769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5249 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0064, (cst_val *)&val_2083},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0065, (cst_val *)&val_1792},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0066, (cst_val *)&val_5250},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5251 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0068, (cst_val *)&val_0131},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0069, (cst_val *)&val_5252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5256 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0074, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0075, (cst_val *)&val_2787},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0076, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5259 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0080, (cst_val *)&val_0007},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0081, (cst_val *)&val_5260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5262 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0084, (cst_val *)&val_0126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5263 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0086, (cst_val *)&val_0064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0087, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5264 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0089, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5266 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0092, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5268 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0095, (cst_val *)&val_1208},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0096, (cst_val *)&val_5269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5270 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0098, (cst_val *)&val_1282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5271 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0100, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5272 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0102, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5274 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0105, (cst_val *)&val_0007},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0106, (cst_val *)&val_3243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5275 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0108, (cst_val *)&val_0291},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0109, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5277 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0112, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5279 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0115, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0116, (cst_val *)&val_5280},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0117, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5281 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0119, (cst_val *)&val_0049},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0120, (cst_val *)&val_2083},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0121, (cst_val *)&val_0743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5283 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0124, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5284 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0126, (cst_val *)&val_5260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5286 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0129, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5287 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0131, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5289 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0134, (cst_val *)&val_0045},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0135, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5291 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0138, (cst_val *)&val_5292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5293 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0140, (cst_val *)&val_0734},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0141, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0142, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5296 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0146, (cst_val *)&val_0049},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0147, (cst_val *)&val_1987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5299 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0151, (cst_val *)&val_0613},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0152, (cst_val *)&val_2988},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0153, (cst_val *)&val_4896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5300 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0155, (cst_val *)&val_5301},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0156, (cst_val *)&val_5302},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0157, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5307 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0163, (cst_val *)&val_4651},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0164, (cst_val *)&val_0679},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0165, (cst_val *)&val_0003},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0166, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5308 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0168, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5311 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0172, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5312 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0174, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5314 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0177, (cst_val *)&val_0009},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0178, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5315 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0180, (cst_val *)&val_0073},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0181, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5318 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0185, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5320 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0188, (cst_val *)&val_0073},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0189, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5323 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0192, (cst_val *)&val_0673},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0193, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5324 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0195, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5326 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0198, (cst_val *)&val_0154},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0199, (cst_val *)&val_4830},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0200, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5329 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0204, (cst_val *)&val_0188},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0205, (cst_val *)&val_5330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5332 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_116_NO_0208, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5334 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_n_116_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_awb_single_mcep_n_116_cart = {
  cmu_us_awb_single_mcep_n_116_cart_nodes,
  cmu_us_awb_single_mcep_n_116_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_n_117_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0000, (cst_val *)&val_0578},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0002, (cst_val *)&val_5335},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0003, (cst_val *)&val_0232},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0004, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5336 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0006, (cst_val *)&val_5337},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0007, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5340 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0011, (cst_val *)&val_3211},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0012, (cst_val *)&val_1287},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0013, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5342 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0016, (cst_val *)&val_0009},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0017, (cst_val *)&val_0017},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0018, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5344 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0021, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5346 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0024, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5347 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0026, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5349 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0029, (cst_val *)&val_5350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5351 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0031, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5353 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0034, (cst_val *)&val_0550},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0035, (cst_val *)&val_1222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5355 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0038, (cst_val *)&val_0672},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0039, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5356 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0041, (cst_val *)&val_0135},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0042, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5358 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0045, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5359 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0047, (cst_val *)&val_5360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5362 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0050, (cst_val *)&val_1287},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0051, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5363 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0053, (cst_val *)&val_5364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5366 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0056, (cst_val *)&val_5367},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5369 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0059, (cst_val *)&val_5370},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0060, (cst_val *)&val_0173},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0061, (cst_val *)&val_0010},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0062, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0063, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5372 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0066, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5373 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0068, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5375 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0071, (cst_val *)&val_0232},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0072, (cst_val *)&val_5376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5378 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0075, (cst_val *)&val_5379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5380 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0077, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5382 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0080, (cst_val *)&val_2119},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0081, (cst_val *)&val_4896},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0082, (cst_val *)&val_5383},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0083, (cst_val *)&val_5384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5386 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0086, (cst_val *)&val_5387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5388 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0088, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5391 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0092, (cst_val *)&val_5392},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0093, (cst_val *)&val_0116},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0094, (cst_val *)&val_3842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5394 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0097, (cst_val *)&val_5395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5396 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0099, (cst_val *)&val_5397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5399 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0102, (cst_val *)&val_0003},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0103, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5400 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0105, (cst_val *)&val_5401},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0106, (cst_val *)&val_5402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5405 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0110, (cst_val *)&val_0993},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0111, (cst_val *)&val_0017},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0112, (cst_val *)&val_5406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5408 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0115, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5409 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0117, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5411 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0120, (cst_val *)&val_1074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5413 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0123, (cst_val *)&val_0261},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0124, (cst_val *)&val_0045},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0125, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5414 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0127, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5415 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0129, (cst_val *)&val_5416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5417 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0131, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5419 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0134, (cst_val *)&val_2958},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0135, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5422 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0139, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5423 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0141, (cst_val *)&val_0578},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0142, (cst_val *)&val_5376},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0143, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0144, (cst_val *)&val_5424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5425 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0146, (cst_val *)&val_5426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5430 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0151, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5432 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0154, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0155, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0156, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5435 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0160, (cst_val *)&val_2260},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0161, (cst_val *)&val_3002},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0162, (cst_val *)&val_0578},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0163, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5436 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0165, (cst_val *)&val_5437},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0166, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5439 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0169, (cst_val *)&val_5440},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0170, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5442 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0173, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0174, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5444 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0177, (cst_val *)&val_0244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5446 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0180, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5448 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0183, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0184, (cst_val *)&val_2366},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0185, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5449 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0187, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5450 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0189, (cst_val *)&val_5451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5453 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0192, (cst_val *)&val_5454},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0193, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5455 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0195, (cst_val *)&val_0296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5457 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0198, (cst_val *)&val_1609},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0199, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5458 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0201, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5459 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0203, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5462 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0207, (cst_val *)&val_5463},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0208, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5464 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0210, (cst_val *)&val_0147},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0211, (cst_val *)&val_0077},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0212, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5467 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0216, (cst_val *)&val_5468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5470 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0219, (cst_val *)&val_0147},
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0220, (cst_val *)&val_1971},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0221, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5472 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0224, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5474 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0227, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0228, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0229, (cst_val *)&val_1222},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0230, (cst_val *)&val_5475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5477 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0233, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5479 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0236, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5480 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0238, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5483 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0242, (cst_val *)&val_5392},
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0243, (cst_val *)&val_0672},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0244, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0245, (cst_val *)&val_5484},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0246, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5487 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0250, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5488 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0252, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5490 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0255, (cst_val *)&val_0041},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0256, (cst_val *)&val_0660},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0257, (cst_val *)&val_0070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5492 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0260, (cst_val *)&val_0009},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0261, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5493 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0263, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5494 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0265, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5496 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0268, (cst_val *)&val_5497},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5498 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0270, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5500 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0273, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5501 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0275, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5502 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0277, (cst_val *)&val_2116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5504 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0280, (cst_val *)&val_0952},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0281, (cst_val *)&val_0130},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0282, (cst_val *)&val_0017},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0283, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5505 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0285, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5507 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0288, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5508 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0290, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5510 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0293, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5511 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0295, (cst_val *)&val_0077},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0296, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5513 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0299, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5515 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0302, (cst_val *)&val_1271},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0303, (cst_val *)&val_5516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5518 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0306, (cst_val *)&val_0147},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0307, (cst_val *)&val_0003},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0308, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5519 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0310, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5520 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0312, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5522 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0315, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5523 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0317, (cst_val *)&val_5524},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0318, (cst_val *)&val_1003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0319, (cst_val *)&val_2988},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0320, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5526 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0323, (cst_val *)&val_1177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5528 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0326, (cst_val *)&val_5529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5531 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0329, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5533 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_117_NO_0332, (cst_val *)&val_5534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5536 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_n_117_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_awb_single_mcep_n_117_cart = {
  cmu_us_awb_single_mcep_n_117_cart_nodes,
  cmu_us_awb_single_mcep_n_117_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_n_118_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0001, (cst_val *)&val_0378},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0002, (cst_val *)&val_0479},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0003, (cst_val *)&val_2805},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0004, (cst_val *)&val_5537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5539 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0007, (cst_val *)&val_1769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5541 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0010, (cst_val *)&val_0953},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0011, (cst_val *)&val_0185},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0012, (cst_val *)&val_5542},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0013, (cst_val *)&val_4651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5544 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0016, (cst_val *)&val_1403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5546 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0019, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5547 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0021, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5548 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0023, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5549 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0025, (cst_val *)&val_5550},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0026, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5553 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0030, (cst_val *)&val_1099},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0031, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5555 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0034, (cst_val *)&val_5556},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0035, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0036, (cst_val *)&val_0004},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0037, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5557 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0039, (cst_val *)&val_5558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5560 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0042, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5563 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0046, (cst_val *)&val_0017},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0047, (cst_val *)&val_0041},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5565 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0051, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0052, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5566 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0054, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5569 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0058, (cst_val *)&val_5570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5572 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0061, (cst_val *)&val_0479},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0062, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0063, (cst_val *)&val_0398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5575 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0067, (cst_val *)&val_5576},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0068, (cst_val *)&val_0721},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0069, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5577 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0071, (cst_val *)&val_5578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5580 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0074, (cst_val *)&val_5581},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0075, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0076, (cst_val *)&val_1465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5582 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0078, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5584 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0081, (cst_val *)&val_0009},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0082, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5586 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0085, (cst_val *)&val_0049},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0086, (cst_val *)&val_5587},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5589 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0089, (cst_val *)&val_5590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5593 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0093, (cst_val *)&val_0953},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0094, (cst_val *)&val_2260},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0095, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5594 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0097, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5596 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0100, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5597 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0102, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5599 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0105, (cst_val *)&val_4779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5600 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0107, (cst_val *)&val_5601},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0108, (cst_val *)&val_5602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5605 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0112, (cst_val *)&val_5606},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0113, (cst_val *)&val_1088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0114, (cst_val *)&val_5607},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0115, (cst_val *)&val_1254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5610 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0119, (cst_val *)&val_1535},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0120, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0121, (cst_val *)&val_5611},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0122, (cst_val *)&val_0894},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0123, (cst_val *)&val_5612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5616 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0128, (cst_val *)&val_0580},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0129, (cst_val *)&val_5617},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0130, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5619 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0133, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5620 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0135, (cst_val *)&val_5621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5622 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0137, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5624 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0140, (cst_val *)&val_5625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5627 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0143, (cst_val *)&val_0721},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0144, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0145, (cst_val *)&val_5628},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0146, (cst_val *)&val_2968},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0147, (cst_val *)&val_1794},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5630 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0150, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0151, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5632 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0154, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0155, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5633 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0157, (cst_val *)&val_2119},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0158, (cst_val *)&val_5634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5635 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0160, (cst_val *)&val_3015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5638 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0164, (cst_val *)&val_0003},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0165, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5641 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0169, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5643 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0172, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5645 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0175, (cst_val *)&val_0045},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0176, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5646 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0178, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5648 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0181, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0182, (cst_val *)&val_5649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5651 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0185, (cst_val *)&val_0511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5653 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0188, (cst_val *)&val_0045},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0189, (cst_val *)&val_0525},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0190, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5654 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0192, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5655 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0194, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5657 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0197, (cst_val *)&val_0009},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0198, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5659 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0201, (cst_val *)&val_5660},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0202, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5661 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0204, (cst_val *)&val_0561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5662 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0206, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5664 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0209, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0210, (cst_val *)&val_5665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5668 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0214, (cst_val *)&val_0008},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0215, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0216, (cst_val *)&val_0980},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0217, (cst_val *)&val_3276},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0218, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5670 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0221, (cst_val *)&val_5671},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0222, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5674 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0226, (cst_val *)&val_5675},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0227, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5677 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0230, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0231, (cst_val *)&val_5678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5679 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0233, (cst_val *)&val_5680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5683 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0237, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5684 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0239, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0240, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5686 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0243, (cst_val *)&val_3467},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0244, (cst_val *)&val_3680},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5688 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0247, (cst_val *)&val_4896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5690 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0250, (cst_val *)&val_0185},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0251, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0252, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5692 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0255, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5694 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0258, (cst_val *)&val_0041},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0259, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5695 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0261, (cst_val *)&val_0933},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0262, (cst_val *)&val_5696},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0263, (cst_val *)&val_2515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5700 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0268, (cst_val *)&val_5701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5702 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_n_118_NO_0270, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5704 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_n_118_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_n_118_cart = {
  cmu_us_awb_single_mcep_n_118_cart_nodes,
  cmu_us_awb_single_mcep_n_118_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_jh_96_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0000, (cst_val *)&val_1403},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0001, (cst_val *)&val_0077},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0002, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5705 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0004, (cst_val *)&val_5706},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0005, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5707 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0007, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5709 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0010, (cst_val *)&val_5710},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5712 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0013, (cst_val *)&val_5713},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0014, (cst_val *)&val_5714},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0015, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5715 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0017, (cst_val *)&val_5716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5720 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0022, (cst_val *)&val_1379},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0023, (cst_val *)&val_5721},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0024, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5722 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0026, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5723 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0028, (cst_val *)&val_0003},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0029, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5726 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0033, (cst_val *)&val_0003},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0034, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5727 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0036, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0037, (cst_val *)&val_5728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5732 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0042, (cst_val *)&val_5733},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0043, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5734 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0045, (cst_val *)&val_5735},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5736 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_96_NO_0047, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5739 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_jh_96_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_awb_single_mcep_jh_96_cart = {
  cmu_us_awb_single_mcep_jh_96_cart_nodes,
  cmu_us_awb_single_mcep_jh_96_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_jh_97_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0000, (cst_val *)&val_0399},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0001, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0002, (cst_val *)&val_0525},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0003, (cst_val *)&val_5740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5743 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0007, (cst_val *)&val_0130},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0008, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5745 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0011, (cst_val *)&val_5746},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0012, (cst_val *)&val_2208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5749 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0016, (cst_val *)&val_5750},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0017, (cst_val *)&val_5751},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0018, (cst_val *)&val_0380},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0019, (cst_val *)&val_0147},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0020, (cst_val *)&val_5752},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5756 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0025, (cst_val *)&val_4133},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0026, (cst_val *)&val_5757},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0027, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5760 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0031, (cst_val *)&val_5761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5762 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0033, (cst_val *)&val_0525},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0034, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5765 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0038, (cst_val *)&val_5766},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0039, (cst_val *)&val_1379},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0040, (cst_val *)&val_3175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5768 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0043, (cst_val *)&val_3175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5769 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0045, (cst_val *)&val_3948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5771 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_97_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5773 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_jh_97_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_jh_97_cart = {
  cmu_us_awb_single_mcep_jh_97_cart_nodes,
  cmu_us_awb_single_mcep_jh_97_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_jh_98_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0000, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0001, (cst_val *)&val_1872},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0002, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5774 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0004, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5776 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0007, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5777 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0009, (cst_val *)&val_1345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5779 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0012, (cst_val *)&val_0399},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0013, (cst_val *)&val_0016},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0014, (cst_val *)&val_0187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5781 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0017, (cst_val *)&val_0187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5782 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0019, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5784 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0022, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0023, (cst_val *)&val_0068},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0024, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5787 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0028, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5788 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_jh_98_NO_0030, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5790 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_jh_98_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_single_mcep_jh_98_cart = {
  cmu_us_awb_single_mcep_jh_98_cart_nodes,
  cmu_us_awb_single_mcep_jh_98_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_r_146_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0001, (cst_val *)&val_5791},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0002, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0003, (cst_val *)&val_2003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0004, (cst_val *)&val_2609},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0005, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5793 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0008, (cst_val *)&val_0853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5795 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0011, (cst_val *)&val_2272},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5797 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0014, (cst_val *)&val_0041},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0015, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5799 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0019, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0020, (cst_val *)&val_5800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5801 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0022, (cst_val *)&val_0399},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0023, (cst_val *)&val_0868},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0024, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5803 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0027, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5807 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0032, (cst_val *)&val_5808},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0033, (cst_val *)&val_0952},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0034, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5810 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0037, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5812 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0040, (cst_val *)&val_5813},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0041, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5814 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0043, (cst_val *)&val_1543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5816 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0046, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5817 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0048, (cst_val *)&val_1084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5819 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0051, (cst_val *)&val_0121},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0052, (cst_val *)&val_5820},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0053, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5823 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0057, (cst_val *)&val_5824},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0058, (cst_val *)&val_0147},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0059, (cst_val *)&val_0055},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0060, (cst_val *)&val_0278},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0061, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5825 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0063, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5827 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0066, (cst_val *)&val_5828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5830 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0069, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5832 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0072, (cst_val *)&val_2448},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0073, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5833 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0075, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5834 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0077, (cst_val *)&val_0179},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0078, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5835 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0080, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5837 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0083, (cst_val *)&val_5587},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0084, (cst_val *)&val_1115},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0085, (cst_val *)&val_1413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5838 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0087, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5841 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0091, (cst_val *)&val_5842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5844 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0094, (cst_val *)&val_5845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5846 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0096, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5849 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0100, (cst_val *)&val_0007},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0101, (cst_val *)&val_0017},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0102, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5851 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0105, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5852 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0107, (cst_val *)&val_5800},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0108, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5854 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0111, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5855 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0113, (cst_val *)&val_5856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5858 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0116, (cst_val *)&val_0011},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0117, (cst_val *)&val_0725},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0118, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5859 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0120, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5861 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0123, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5863 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0126, (cst_val *)&val_0003},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0127, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5864 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0129, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5865 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0131, (cst_val *)&val_0043},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0132, (cst_val *)&val_5866},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5869 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0136, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0137, (cst_val *)&val_0077},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0138, (cst_val *)&val_5870},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5872 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0141, (cst_val *)&val_0812},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0142, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5873 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0144, (cst_val *)&val_5874},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5877 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0148, (cst_val *)&val_5878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5879 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0150, (cst_val *)&val_5880},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0151, (cst_val *)&val_3203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5882 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0154, (cst_val *)&val_5883},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_146_NO_0155, (cst_val *)&val_3932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5886 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_r_146_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_r_146_cart = {
  cmu_us_awb_single_mcep_r_146_cart_nodes,
  cmu_us_awb_single_mcep_r_146_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_r_147_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0001, (cst_val *)&val_0952},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0002, (cst_val *)&val_0130},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0003, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5888 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0006, (cst_val *)&val_2448},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0007, (cst_val *)&val_5889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5891 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0010, (cst_val *)&val_1365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5893 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0013, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0014, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5894 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0016, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5896 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0019, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0020, (cst_val *)&val_0672},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0021, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5898 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0024, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5900 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0027, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5902 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0030, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0031, (cst_val *)&val_0027},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0032, (cst_val *)&val_0121},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0033, (cst_val *)&val_5903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5905 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0036, (cst_val *)&val_0065},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0037, (cst_val *)&val_5906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5908 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0040, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5909 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0042, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0043, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5911 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0046, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5912 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0048, (cst_val *)&val_5913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5915 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0051, (cst_val *)&val_0131},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0052, (cst_val *)&val_1955},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0053, (cst_val *)&val_5916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5919 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0057, (cst_val *)&val_5920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5922 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0060, (cst_val *)&val_1792},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0061, (cst_val *)&val_0232},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0062, (cst_val *)&val_1284},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0063, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0064, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5924 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0067, (cst_val *)&val_0578},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0068, (cst_val *)&val_5925},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5927 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0071, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5929 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0074, (cst_val *)&val_0045},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0075, (cst_val *)&val_5930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5932 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0078, (cst_val *)&val_5933},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0079, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5934 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0081, (cst_val *)&val_5935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5937 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0084, (cst_val *)&val_5938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5940 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0087, (cst_val *)&val_0009},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0088, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5941 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0090, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5942 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0092, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0093, (cst_val *)&val_0360},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0094, (cst_val *)&val_0905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5945 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0098, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5946 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0100, (cst_val *)&val_0952},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0101, (cst_val *)&val_0993},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0102, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5949 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0106, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5951 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0109, (cst_val *)&val_5952},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0110, (cst_val *)&val_5953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5955 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0113, (cst_val *)&val_0147},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0114, (cst_val *)&val_0016},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0115, (cst_val *)&val_5956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5958 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0118, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5959 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0120, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5961 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0123, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0124, (cst_val *)&val_0797},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0125, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5962 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0127, (cst_val *)&val_5963},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0128, (cst_val *)&val_5964},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5967 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0132, (cst_val *)&val_5883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5969 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0135, (cst_val *)&val_2260},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0136, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5972 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0140, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0141, (cst_val *)&val_0330},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0142, (cst_val *)&val_0003},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0143, (cst_val *)&val_5973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5977 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0148, (cst_val *)&val_0003},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0149, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5979 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0152, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5980 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0154, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5981 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_147_NO_0156, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5983 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_r_147_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_r_147_cart = {
  cmu_us_awb_single_mcep_r_147_cart_nodes,
  cmu_us_awb_single_mcep_r_147_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_r_148_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0001, (cst_val *)&val_5984},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0002, (cst_val *)&val_0129},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0003, (cst_val *)&val_0130},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0004, (cst_val *)&val_0064},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0005, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5986 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0008, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5987 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0010, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5988 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0012, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0013, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5990 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0016, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5992 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0019, (cst_val *)&val_0526},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0020, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5994 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0023, (cst_val *)&val_0009},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0024, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5996 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0027, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5997 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0029, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5998 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0031, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6000 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0034, (cst_val *)&val_0232},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0035, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0036, (cst_val *)&val_0398},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0037, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6001 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0039, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6005 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0044, (cst_val *)&val_1183},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0045, (cst_val *)&val_6006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6007 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0047, (cst_val *)&val_6008},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0048, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0049, (cst_val *)&val_2912},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0050, (cst_val *)&val_0154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6011 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0054, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6012 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0056, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6014 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0059, (cst_val *)&val_6015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6016 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0061, (cst_val *)&val_1506},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0062, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0063, (cst_val *)&val_2912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6020 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0068, (cst_val *)&val_0027},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0069, (cst_val *)&val_3181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6021 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0071, (cst_val *)&val_6022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6025 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0075, (cst_val *)&val_1423},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0076, (cst_val *)&val_0980},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0077, (cst_val *)&val_2133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6027 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0080, (cst_val *)&val_6028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6030 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0083, (cst_val *)&val_0232},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0084, (cst_val *)&val_0031},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0085, (cst_val *)&val_0834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6031 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0087, (cst_val *)&val_2451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6033 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0090, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6035 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0093, (cst_val *)&val_0016},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0094, (cst_val *)&val_0002},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0095, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6036 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0097, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6038 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0100, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6040 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0103, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6041 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0105, (cst_val *)&val_0003},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0106, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6042 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0108, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6044 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0111, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0112, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6046 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0115, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0116, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6049 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0120, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0121, (cst_val *)&val_1090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6050 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0123, (cst_val *)&val_0065},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0124, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0125, (cst_val *)&val_6051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6054 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0129, (cst_val *)&val_1402},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0130, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6055 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0132, (cst_val *)&val_6056},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0133, (cst_val *)&val_6057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6059 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0136, (cst_val *)&val_0017},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0137, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6061 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0140, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6064 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0144, (cst_val *)&val_0232},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0145, (cst_val *)&val_0402},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0146, (cst_val *)&val_6065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6067 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0149, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6068 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0151, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6070 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0154, (cst_val *)&val_0007},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0155, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6071 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0157, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0158, (cst_val *)&val_6072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6074 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0161, (cst_val *)&val_5920},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0162, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6076 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0165, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6078 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0168, (cst_val *)&val_5751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6079 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_r_148_NO_0170, (cst_val *)&val_2451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6081 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_r_148_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_awb_single_mcep_r_148_cart = {
  cmu_us_awb_single_mcep_r_148_cart_nodes,
  cmu_us_awb_single_mcep_r_148_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ey_66_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0000, (cst_val *)&val_0130},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0001, (cst_val *)&val_0121},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0002, (cst_val *)&val_1551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6083 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0005, (cst_val *)&val_0147},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0006, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6085 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0009, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6086 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0011, (cst_val *)&val_2598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6087 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0013, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6089 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0016, (cst_val *)&val_1287},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0017, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0018, (cst_val *)&val_0073},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0019, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6092 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0023, (cst_val *)&val_0007},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0024, (cst_val *)&val_1276},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0025, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6094 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0028, (cst_val *)&val_6095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6097 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0031, (cst_val *)&val_6098},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0032, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0033, (cst_val *)&val_6099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6102 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0037, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6103 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0039, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6104 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0041, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6106 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0044, (cst_val *)&val_0003},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0045, (cst_val *)&val_0131},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0046, (cst_val *)&val_1387},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0047, (cst_val *)&val_6107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6110 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0051, (cst_val *)&val_6111},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0052, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6114 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0056, (cst_val *)&val_0399},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0057, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0058, (cst_val *)&val_6115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6117 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0061, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6118 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0063, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6119 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0065, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6121 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0068, (cst_val *)&val_0121},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0069, (cst_val *)&val_0154},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0070, (cst_val *)&val_1276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6123 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0073, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6125 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0076, (cst_val *)&val_6126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6127 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0078, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0079, (cst_val *)&val_1420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6129 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0082, (cst_val *)&val_6130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6131 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_66_NO_0084, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6133 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ey_66_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_awb_single_mcep_ey_66_cart = {
  cmu_us_awb_single_mcep_ey_66_cart_nodes,
  cmu_us_awb_single_mcep_ey_66_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ey_67_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0000, (cst_val *)&val_6134},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0001, (cst_val *)&val_6135},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0002, (cst_val *)&val_6136},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0003, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0004, (cst_val *)&val_6137},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0005, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0006, (cst_val *)&val_6138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6140 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0009, (cst_val *)&val_6141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6144 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0013, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6146 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0016, (cst_val *)&val_6147},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0017, (cst_val *)&val_0008},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0018, (cst_val *)&val_1987},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0019, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6148 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0021, (cst_val *)&val_6149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6152 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0025, (cst_val *)&val_6153},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0026, (cst_val *)&val_0049},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0027, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6155 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0030, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6157 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0033, (cst_val *)&val_0660},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0034, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0035, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6159 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0038, (cst_val *)&val_6160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6162 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0041, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0042, (cst_val *)&val_0055},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0043, (cst_val *)&val_6163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6166 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0047, (cst_val *)&val_6167},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0048, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6168 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0050, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6169 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0052, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0053, (cst_val *)&val_6170},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6171 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0055, (cst_val *)&val_0276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6173 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0058, (cst_val *)&val_0435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6174 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0060, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6176 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0063, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6177 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0065, (cst_val *)&val_0045},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0066, (cst_val *)&val_1073},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0067, (cst_val *)&val_6178},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0068, (cst_val *)&val_6179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6182 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0072, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0073, (cst_val *)&val_6183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6185 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0076, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6187 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0079, (cst_val *)&val_6188},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0080, (cst_val *)&val_1045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0081, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6191 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0085, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6192 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0087, (cst_val *)&val_2398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6194 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0090, (cst_val *)&val_6195},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0091, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6196 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0093, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6199 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0097, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0098, (cst_val *)&val_6200},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0099, (cst_val *)&val_6201},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0100, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6203 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0103, (cst_val *)&val_0211},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0104, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6206 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0108, (cst_val *)&val_1052},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0109, (cst_val *)&val_6207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6209 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0112, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6210 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0114, (cst_val *)&val_0073},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0115, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6213 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0119, (cst_val *)&val_4051},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0120, (cst_val *)&val_0049},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0121, (cst_val *)&val_6214},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0122, (cst_val *)&val_6215},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0123, (cst_val *)&val_6216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6218 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0126, (cst_val *)&val_0658},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6220 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0129, (cst_val *)&val_0007},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0130, (cst_val *)&val_6221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6223 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0133, (cst_val *)&val_0045},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0134, (cst_val *)&val_6224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6227 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0138, (cst_val *)&val_6228},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0139, (cst_val *)&val_1971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6229 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0141, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6231 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0144, (cst_val *)&val_6232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6233 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0146, (cst_val *)&val_6234},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0147, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6236 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0150, (cst_val *)&val_6237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6238 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0152, (cst_val *)&val_4695},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0153, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6241 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0157, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6242 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0159, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6243 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0161, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6245 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0164, (cst_val *)&val_0008},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0165, (cst_val *)&val_0017},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0166, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0167, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6248 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0171, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6249 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0173, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6250 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0175, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6252 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0178, (cst_val *)&val_0003},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0179, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6254 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0182, (cst_val *)&val_6255},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0183, (cst_val *)&val_1770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6256 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_67_NO_0185, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6259 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ey_67_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_awb_single_mcep_ey_67_cart = {
  cmu_us_awb_single_mcep_ey_67_cart_nodes,
  cmu_us_awb_single_mcep_ey_67_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ey_68_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0000, (cst_val *)&val_1131},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0001, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0002, (cst_val *)&val_0578},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0003, (cst_val *)&val_0232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0004, (cst_val *)&val_6260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6262 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0007, (cst_val *)&val_0017},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0008, (cst_val *)&val_0673},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0009, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6264 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0012, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6265 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0014, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6267 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0017, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6268 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0019, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0020, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6271 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0024, (cst_val *)&val_6272},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0025, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0026, (cst_val *)&val_0916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6275 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0030, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6277 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0033, (cst_val *)&val_0520},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0034, (cst_val *)&val_6278},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0035, (cst_val *)&val_6279},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0036, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6283 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0041, (cst_val *)&val_0017},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0042, (cst_val *)&val_6284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6286 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0045, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6287 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0047, (cst_val *)&val_2088},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0048, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0049, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6289 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0052, (cst_val *)&val_0494},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0053, (cst_val *)&val_6290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6292 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0056, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6294 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0059, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6295 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0061, (cst_val *)&val_6296},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6298 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0064, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0065, (cst_val *)&val_0025},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0066, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0067, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0068, (cst_val *)&val_6299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6300 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0070, (cst_val *)&val_1987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6302 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0073, (cst_val *)&val_0864},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0074, (cst_val *)&val_4328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6305 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0078, (cst_val *)&val_6306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6307 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0080, (cst_val *)&val_6308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6310 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0083, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6311 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0085, (cst_val *)&val_6312},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0086, (cst_val *)&val_6313},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0087, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6314 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0089, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6316 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0092, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6318 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0095, (cst_val *)&val_0278},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0096, (cst_val *)&val_6319},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6320 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0098, (cst_val *)&val_6321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6323 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0101, (cst_val *)&val_6324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6326 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0104, (cst_val *)&val_0514},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0105, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0106, (cst_val *)&val_0065},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0107, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6327 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0109, (cst_val *)&val_1183},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0110, (cst_val *)&val_2550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6329 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0113, (cst_val *)&val_3754},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6331 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0116, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6332 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0118, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6333 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0120, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6335 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0123, (cst_val *)&val_0049},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0124, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6336 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0126, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6337 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0128, (cst_val *)&val_0935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6338 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0130, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6339 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0132, (cst_val *)&val_3818},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6341 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0135, (cst_val *)&val_0300},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0136, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6343 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0139, (cst_val *)&val_0016},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0140, (cst_val *)&val_1955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6345 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ey_68_NO_0143, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6348 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ey_68_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_awb_single_mcep_ey_68_cart = {
  cmu_us_awb_single_mcep_ey_68_cart_nodes,
  cmu_us_awb_single_mcep_ey_68_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_pau_141_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0000, (cst_val *)&val_0003},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0001, (cst_val *)&val_0581},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0002, (cst_val *)&val_0130},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0003, (cst_val *)&val_1774},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0004, (cst_val *)&val_0519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6350 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0007, (cst_val *)&val_3138},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0008, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0009, (cst_val *)&val_3707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6351 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0011, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6352 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0013, (cst_val *)&val_6353},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0014, (cst_val *)&val_6354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6358 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0019, (cst_val *)&val_2687},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6359 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0021, (cst_val *)&val_0086},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0022, (cst_val *)&val_3947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6360 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0024, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6363 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0028, (cst_val *)&val_6364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6365 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0030, (cst_val *)&val_0887},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0031, (cst_val *)&val_0135},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0032, (cst_val *)&val_0525},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0033, (cst_val *)&val_6366},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0034, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0035, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6367 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0037, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6369 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0040, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6371 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0043, (cst_val *)&val_2999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6373 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0046, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0047, (cst_val *)&val_6374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6375 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0049, (cst_val *)&val_3592},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0050, (cst_val *)&val_6376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6380 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0055, (cst_val *)&val_0525},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0056, (cst_val *)&val_6381},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0057, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6382 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0059, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6384 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0062, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6386 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0065, (cst_val *)&val_6366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6388 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0068, (cst_val *)&val_0004},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0069, (cst_val *)&val_0147},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0070, (cst_val *)&val_0498},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0071, (cst_val *)&val_6389},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6391 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0074, (cst_val *)&val_6392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6394 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0077, (cst_val *)&val_6395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6396 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0079, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6397 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0081, (cst_val *)&val_6398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6400 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0084, (cst_val *)&val_0045},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0085, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6402 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0088, (cst_val *)&val_0330},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0089, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6403 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0091, (cst_val *)&val_0867},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6406 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0095, (cst_val *)&val_5883},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0096, (cst_val *)&val_0237},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0097, (cst_val *)&val_6407},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0098, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6411 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0103, (cst_val *)&val_0130},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0104, (cst_val *)&val_1045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6413 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0107, (cst_val *)&val_1318},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0108, (cst_val *)&val_0905},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0109, (cst_val *)&val_3541},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6415 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0112, (cst_val *)&val_0244},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0113, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6416 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0115, (cst_val *)&val_3924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6418 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0118, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6421 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0122, (cst_val *)&val_0533},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0123, (cst_val *)&val_0581},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0124, (cst_val *)&val_2737},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0125, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6422 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0127, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6423 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0129, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6424 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0131, (cst_val *)&val_0045},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0132, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6426 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0135, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6428 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0138, (cst_val *)&val_1003},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0139, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6429 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0141, (cst_val *)&val_6430},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0142, (cst_val *)&val_1187},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0143, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6432 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0146, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0147, (cst_val *)&val_0615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6434 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0150, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6437 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0154, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6439 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0157, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0158, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6441 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0161, (cst_val *)&val_0147},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0162, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6443 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0165, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6444 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0167, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6446 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0170, (cst_val *)&val_0017},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0171, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0172, (cst_val *)&val_0592},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0173, (cst_val *)&val_0592},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0174, (cst_val *)&val_3842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6447 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0176, (cst_val *)&val_6448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6450 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0179, (cst_val *)&val_1515},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0180, (cst_val *)&val_0016},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0181, (cst_val *)&val_6451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6453 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0184, (cst_val *)&val_0122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6455 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0187, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6457 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0190, (cst_val *)&val_6458},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0191, (cst_val *)&val_6459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6460 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0193, (cst_val *)&val_6461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6462 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0195, (cst_val *)&val_0612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6463 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0197, (cst_val *)&val_6464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6466 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0200, (cst_val *)&val_6467},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0201, (cst_val *)&val_0916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6470 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0205, (cst_val *)&val_0276},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0206, (cst_val *)&val_0853},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0207, (cst_val *)&val_1955},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0208, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6471 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0210, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6474 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0214, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0215, (cst_val *)&val_4920},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0216, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6475 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0218, (cst_val *)&val_6476},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6478 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0221, (cst_val *)&val_2846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6482 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0226, (cst_val *)&val_0073},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0227, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0228, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6483 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0230, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6485 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0233, (cst_val *)&val_0673},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0234, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6487 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0237, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6489 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0240, (cst_val *)&val_6490},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0241, (cst_val *)&val_3133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6491 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0243, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6493 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0246, (cst_val *)&val_0147},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0247, (cst_val *)&val_0121},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0248, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6495 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0251, (cst_val *)&val_0725},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0252, (cst_val *)&val_0003},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0253, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6496 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0255, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6498 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0258, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6499 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0260, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6501 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0263, (cst_val *)&val_0065},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0264, (cst_val *)&val_0417},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0265, (cst_val *)&val_1073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6503 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0268, (cst_val *)&val_2436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6506 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0272, (cst_val *)&val_6507},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0273, (cst_val *)&val_1284},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0274, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0275, (cst_val *)&val_3006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6508 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0277, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6510 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0280, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6511 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0282, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6512 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0284, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6514 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0287, (cst_val *)&val_0011},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0288, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6515 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_141_NO_0290, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6519 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_pau_141_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_pau_141_cart = {
  cmu_us_awb_single_mcep_pau_141_cart_nodes,
  cmu_us_awb_single_mcep_pau_141_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_pau_143_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0000, (cst_val *)&val_6520},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0001, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0002, (cst_val *)&val_6521},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0003, (cst_val *)&val_0856},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0004, (cst_val *)&val_3467},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0005, (cst_val *)&val_3466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6523 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0008, (cst_val *)&val_1099},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0009, (cst_val *)&val_3574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6525 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0012, (cst_val *)&val_6526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6527 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0014, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0015, (cst_val *)&val_4102},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0016, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6529 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0019, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6531 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0022, (cst_val *)&val_4411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6532 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0024, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0025, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6534 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0028, (cst_val *)&val_6535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6536 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0030, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6537 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0032, (cst_val *)&val_6538},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0033, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6541 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0037, (cst_val *)&val_2003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0038, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6543 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0041, (cst_val *)&val_3572},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6545 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0044, (cst_val *)&val_6546},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0045, (cst_val *)&val_6547},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0046, (cst_val *)&val_6548},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0047, (cst_val *)&val_0130},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0048, (cst_val *)&val_4346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6550 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0051, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6552 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0054, (cst_val *)&val_0042},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0055, (cst_val *)&val_0147},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0056, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6553 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0058, (cst_val *)&val_0031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6555 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0061, (cst_val *)&val_0933},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0062, (cst_val *)&val_6556},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6558 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0065, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6559 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0067, (cst_val *)&val_6560},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0068, (cst_val *)&val_0067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6562 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0071, (cst_val *)&val_3704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6564 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0074, (cst_val *)&val_3797},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0075, (cst_val *)&val_6565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6567 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0078, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6569 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0081, (cst_val *)&val_1987},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0082, (cst_val *)&val_0068},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0083, (cst_val *)&val_0003},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0084, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6570 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0086, (cst_val *)&val_0953},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0087, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6572 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0090, (cst_val *)&val_6573},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6575 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0093, (cst_val *)&val_6576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6578 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0096, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6579 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0098, (cst_val *)&val_4695},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6580 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0100, (cst_val *)&val_0485},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0101, (cst_val *)&val_6581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6584 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0105, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0106, (cst_val *)&val_2569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6586 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0109, (cst_val *)&val_1387},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0110, (cst_val *)&val_2546},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0111, (cst_val *)&val_3729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6589 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0115, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6590 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0117, (cst_val *)&val_0007},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0118, (cst_val *)&val_3561},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0119, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6593 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0123, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6594 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0125, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6595 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0127, (cst_val *)&val_6596},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0128, (cst_val *)&val_6597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6599 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0131, (cst_val *)&val_1504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6601 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0134, (cst_val *)&val_6602},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0135, (cst_val *)&val_6603},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0136, (cst_val *)&val_0834},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6604 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0138, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6605 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0140, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0141, (cst_val *)&val_2821},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0142, (cst_val *)&val_6606},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0143, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6608 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0146, (cst_val *)&val_3711},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0147, (cst_val *)&val_6609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6611 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0150, (cst_val *)&val_6612},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0151, (cst_val *)&val_2793},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6613 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0153, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6615 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0156, (cst_val *)&val_4411},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6616 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0158, (cst_val *)&val_6617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6620 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0162, (cst_val *)&val_3371},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0163, (cst_val *)&val_3574},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6622 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0166, (cst_val *)&val_1052},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0167, (cst_val *)&val_6354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6624 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0170, (cst_val *)&val_3842},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0171, (cst_val *)&val_1236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6625 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0173, (cst_val *)&val_3467},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0174, (cst_val *)&val_3711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6626 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0176, (cst_val *)&val_3466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6628 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0179, (cst_val *)&val_0739},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0180, (cst_val *)&val_0052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6629 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0182, (cst_val *)&val_3711},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6631 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0185, (cst_val *)&val_1878},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0186, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6633 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0189, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6635 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0192, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6637 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0195, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0196, (cst_val *)&val_0739},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0197, (cst_val *)&val_6638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6641 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0201, (cst_val *)&val_1208},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0202, (cst_val *)&val_6642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6643 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0204, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6645 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0207, (cst_val *)&val_0007},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0208, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6647 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0211, (cst_val *)&val_6648},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0212, (cst_val *)&val_6649},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0213, (cst_val *)&val_6650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6651 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0215, (cst_val *)&val_6652},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0216, (cst_val *)&val_6653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6655 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0219, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6657 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0222, (cst_val *)&val_3604},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0223, (cst_val *)&val_3957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6658 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0225, (cst_val *)&val_6642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6659 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0227, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6663 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0232, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0233, (cst_val *)&val_3729},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0234, (cst_val *)&val_4022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6666 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0238, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6667 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0240, (cst_val *)&val_3559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6668 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0242, (cst_val *)&val_0691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6670 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0245, (cst_val *)&val_3443},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0246, (cst_val *)&val_6671},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0247, (cst_val *)&val_0147},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0248, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6672 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0250, (cst_val *)&val_6673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6674 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0252, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6676 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0255, (cst_val *)&val_0147},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0256, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6678 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0259, (cst_val *)&val_0330},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0260, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6681 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0264, (cst_val *)&val_0065},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0265, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6683 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0268, (cst_val *)&val_6684},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0269, (cst_val *)&val_0017},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0270, (cst_val *)&val_6685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6687 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0273, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6688 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0275, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0276, (cst_val *)&val_0145},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0277, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6689 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0279, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6691 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0282, (cst_val *)&val_1465},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0283, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6694 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0287, (cst_val *)&val_6695},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0288, (cst_val *)&val_4194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6696 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0290, (cst_val *)&val_4651},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0291, (cst_val *)&val_1115},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0292, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6698 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0295, (cst_val *)&val_6699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6701 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0298, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6703 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0301, (cst_val *)&val_1987},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0302, (cst_val *)&val_4194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6704 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0304, (cst_val *)&val_0232},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0305, (cst_val *)&val_6705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6707 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0308, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6710 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0312, (cst_val *)&val_4652},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0313, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6711 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0315, (cst_val *)&val_0716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6714 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0319, (cst_val *)&val_6715},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0320, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6716 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0322, (cst_val *)&val_1271},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0323, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6718 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0326, (cst_val *)&val_0065},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0327, (cst_val *)&val_6719},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6720 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0329, (cst_val *)&val_6721},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0330, (cst_val *)&val_6722},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6724 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0333, (cst_val *)&val_6725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6726 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0335, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6728 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0338, (cst_val *)&val_0121},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0339, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0340, (cst_val *)&val_6729},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6731 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0343, (cst_val *)&val_5824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6733 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0346, (cst_val *)&val_0003},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0347, (cst_val *)&val_4346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6735 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0350, (cst_val *)&val_6736},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0351, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0352, (cst_val *)&val_6737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6738 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0354, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6740 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0357, (cst_val *)&val_0003},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0358, (cst_val *)&val_2550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6742 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0361, (cst_val *)&val_6743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6745 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0364, (cst_val *)&val_6746},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0365, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6748 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0368, (cst_val *)&val_6749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6750 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0370, (cst_val *)&val_6751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6752 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0372, (cst_val *)&val_6753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6755 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0375, (cst_val *)&val_6756},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0376, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6757 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0378, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6758 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0380, (cst_val *)&val_0045},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0381, (cst_val *)&val_3619},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6761 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0385, (cst_val *)&val_6762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6764 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0388, (cst_val *)&val_0045},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0389, (cst_val *)&val_6765},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0390, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6766 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0392, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6767 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0394, (cst_val *)&val_6768},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6769 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0396, (cst_val *)&val_3707},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0397, (cst_val *)&val_6770},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0398, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6772 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0401, (cst_val *)&val_6773},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6776 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0405, (cst_val *)&val_0065},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0406, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6778 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0409, (cst_val *)&val_6768},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6779 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0411, (cst_val *)&val_0024},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0412, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6781 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0415, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6782 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0417, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6783 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0419, (cst_val *)&val_6784},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0420, (cst_val *)&val_1090},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0421, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6786 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0424, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6789 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0428, (cst_val *)&val_6684},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0429, (cst_val *)&val_0797},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0430, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0431, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6790 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0433, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6792 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0436, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6793 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0438, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6794 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0440, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6796 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0443, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0444, (cst_val *)&val_1236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6798 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0447, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6799 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0449, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6801 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0452, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0453, (cst_val *)&val_0525},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0454, (cst_val *)&val_0261},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0455, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6803 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0458, (cst_val *)&val_6804},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0459, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6806 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0462, (cst_val *)&val_6807},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6809 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0465, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6810 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0467, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6811 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0469, (cst_val *)&val_0116},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0470, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6814 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0474, (cst_val *)&val_0312},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0475, (cst_val *)&val_6207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6815 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0477, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6816 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0479, (cst_val *)&val_0953},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0480, (cst_val *)&val_6597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6819 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0484, (cst_val *)&val_6820},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0485, (cst_val *)&val_0080},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0486, (cst_val *)&val_0856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6822 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0489, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6823 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0491, (cst_val *)&val_0261},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0492, (cst_val *)&val_1099},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0493, (cst_val *)&val_6824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6827 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0497, (cst_val *)&val_6828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6830 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0500, (cst_val *)&val_1099},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0501, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6832 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0504, (cst_val *)&val_6833},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_143_NO_0505, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6836 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_pau_143_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_pau_143_cart = {
  cmu_us_awb_single_mcep_pau_143_cart_nodes,
  cmu_us_awb_single_mcep_pau_143_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_f_71_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0000, (cst_val *)&val_0003},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0002, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6837 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0004, (cst_val *)&val_3550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6838 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0006, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6840 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0009, (cst_val *)&val_1302},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0010, (cst_val *)&val_0147},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0011, (cst_val *)&val_1222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6842 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0014, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6844 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0017, (cst_val *)&val_0147},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0018, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6846 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0021, (cst_val *)&val_0041},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0022, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6849 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0026, (cst_val *)&val_0129},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0027, (cst_val *)&val_5321},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0028, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6851 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0031, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6852 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0033, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0034, (cst_val *)&val_0247},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0035, (cst_val *)&val_0906},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0036, (cst_val *)&val_6853},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0037, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6858 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0043, (cst_val *)&val_0147},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0044, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6860 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0047, (cst_val *)&val_6861},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0048, (cst_val *)&val_6862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6865 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0052, (cst_val *)&val_3134},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0053, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6866 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0055, (cst_val *)&val_0812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6868 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0058, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6869 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0060, (cst_val *)&val_6870},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0061, (cst_val *)&val_1493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6872 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0064, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6873 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0066, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6874 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0068, (cst_val *)&val_4522},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0069, (cst_val *)&val_6875},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6877 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0072, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6878 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_71_NO_0074, (cst_val *)&val_6879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6881 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_f_71_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_f_71_cart = {
  cmu_us_awb_single_mcep_f_71_cart_nodes,
  cmu_us_awb_single_mcep_f_71_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_f_72_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0000, (cst_val *)&val_0849},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0002, (cst_val *)&val_0147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0003, (cst_val *)&val_6882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6885 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0007, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0008, (cst_val *)&val_0673},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0009, (cst_val *)&val_0378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6887 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0012, (cst_val *)&val_2529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6888 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0014, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6890 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0017, (cst_val *)&val_1222},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0018, (cst_val *)&val_3862},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0019, (cst_val *)&val_3550},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0020, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6891 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0022, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6893 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0025, (cst_val *)&val_6894},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0026, (cst_val *)&val_6895},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0027, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6897 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0030, (cst_val *)&val_6898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6900 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0033, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6902 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0036, (cst_val *)&val_0673},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0037, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6904 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0040, (cst_val *)&val_6905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6906 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0042, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6908 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0045, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0046, (cst_val *)&val_1465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6910 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0049, (cst_val *)&val_1379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6912 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0052, (cst_val *)&val_0801},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0053, (cst_val *)&val_0378},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0054, (cst_val *)&val_0009},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0055, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6914 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0058, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6915 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0060, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6916 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0062, (cst_val *)&val_3175},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0063, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6917 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0065, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6918 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0067, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6919 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0069, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6920 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0071, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6922 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0074, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6924 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0077, (cst_val *)&val_0009},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0078, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6925 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0080, (cst_val *)&val_0398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6927 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0083, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6928 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0085, (cst_val *)&val_6929},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0086, (cst_val *)&val_6930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6932 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0089, (cst_val *)&val_0009},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0090, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6935 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0094, (cst_val *)&val_0273},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0095, (cst_val *)&val_0540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6936 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0097, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6938 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0100, (cst_val *)&val_0232},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0101, (cst_val *)&val_2641},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6939 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0103, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6940 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0105, (cst_val *)&val_0032},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0106, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6941 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0108, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6944 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0112, (cst_val *)&val_0041},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0113, (cst_val *)&val_0049},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0114, (cst_val *)&val_6945},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0115, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6946 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0117, (cst_val *)&val_0878},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0118, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6947 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0120, (cst_val *)&val_6948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6950 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0123, (cst_val *)&val_5842},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0124, (cst_val *)&val_0003},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0125, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6952 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0128, (cst_val *)&val_5842},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0129, (cst_val *)&val_6953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6954 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0131, (cst_val *)&val_0232},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0132, (cst_val *)&val_2366},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0133, (cst_val *)&val_1385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6956 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0136, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6958 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0139, (cst_val *)&val_6959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6960 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0141, (cst_val *)&val_0028},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0142, (cst_val *)&val_1853},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0143, (cst_val *)&val_4194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6962 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0146, (cst_val *)&val_0116},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0147, (cst_val *)&val_6963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6965 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0150, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6967 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0153, (cst_val *)&val_6968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6972 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0158, (cst_val *)&val_6973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6975 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0161, (cst_val *)&val_2912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6976 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0163, (cst_val *)&val_6977},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6978 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0165, (cst_val *)&val_6979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6981 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0168, (cst_val *)&val_6982},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0169, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0170, (cst_val *)&val_0055},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0171, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6985 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0175, (cst_val *)&val_6986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6988 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0178, (cst_val *)&val_0029},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_72_NO_0179, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6991 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_f_72_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_f_72_cart = {
  cmu_us_awb_single_mcep_f_72_cart_nodes,
  cmu_us_awb_single_mcep_f_72_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_f_73_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0000, (cst_val *)&val_6992},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0001, (cst_val *)&val_0031},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0002, (cst_val *)&val_0005},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0003, (cst_val *)&val_6993},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0004, (cst_val *)&val_6994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6995 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0006, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6996 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0008, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6998 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0011, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0012, (cst_val *)&val_3133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7000 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0015, (cst_val *)&val_0116},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0016, (cst_val *)&val_7001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7003 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0019, (cst_val *)&val_4740},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0020, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0021, (cst_val *)&val_0131},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0022, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7004 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0024, (cst_val *)&val_7005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7007 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0027, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7008 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0029, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7012 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0034, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0035, (cst_val *)&val_7013},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0036, (cst_val *)&val_0704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7015 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0039, (cst_val *)&val_7016},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0040, (cst_val *)&val_7017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7020 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0044, (cst_val *)&val_0380},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0045, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7021 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0047, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0048, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7022 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0050, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7023 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0052, (cst_val *)&val_7024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7027 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0056, (cst_val *)&val_0232},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0057, (cst_val *)&val_0953},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0058, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7029 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0061, (cst_val *)&val_7030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7032 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0064, (cst_val *)&val_0049},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0065, (cst_val *)&val_0003},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0066, (cst_val *)&val_7033},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0067, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7035 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0070, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7036 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0072, (cst_val *)&val_3232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7038 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0075, (cst_val *)&val_3443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7039 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0077, (cst_val *)&val_5649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7041 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0080, (cst_val *)&val_1971},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0081, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7043 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0084, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7045 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0087, (cst_val *)&val_0003},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0088, (cst_val *)&val_7046},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0089, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7047 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0091, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7051 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0096, (cst_val *)&val_0525},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0097, (cst_val *)&val_0232},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0098, (cst_val *)&val_0077},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0099, (cst_val *)&val_7052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7055 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0103, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0104, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7057 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0107, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0108, (cst_val *)&val_7058},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0109, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7060 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0112, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7063 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0116, (cst_val *)&val_0147},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0117, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7065 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0120, (cst_val *)&val_0232},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0121, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7066 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0123, (cst_val *)&val_4479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7068 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0126, (cst_val *)&val_0009},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0127, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7070 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0130, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7071 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_f_73_NO_0132, (cst_val *)&val_7072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7074 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_f_73_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_f_73_cart = {
  cmu_us_awb_single_mcep_f_73_cart_nodes,
  cmu_us_awb_single_mcep_f_73_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ih_86_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0000, (cst_val *)&val_0533},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0001, (cst_val *)&val_3232},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0002, (cst_val *)&val_7075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7077 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0005, (cst_val *)&val_7078},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0006, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7080 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0009, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7081 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0011, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7083 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0014, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0015, (cst_val *)&val_2338},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0016, (cst_val *)&val_0064},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7084 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0019, (cst_val *)&val_1222},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0020, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7085 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0022, (cst_val *)&val_1950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7087 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0025, (cst_val *)&val_1950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7089 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0028, (cst_val *)&val_7090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7091 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0030, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7093 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0033, (cst_val *)&val_1222},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0034, (cst_val *)&val_0041},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0035, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7095 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0038, (cst_val *)&val_7096},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0039, (cst_val *)&val_2208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7098 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0042, (cst_val *)&val_0969},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0043, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7102 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0048, (cst_val *)&val_1276},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0049, (cst_val *)&val_1131},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0050, (cst_val *)&val_7103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7104 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0052, (cst_val *)&val_7105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7107 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0055, (cst_val *)&val_0672},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0056, (cst_val *)&val_7108},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0057, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7109 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0059, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7111 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0062, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7113 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0065, (cst_val *)&val_7114},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0066, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7115 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0068, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7117 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0071, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7119 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0074, (cst_val *)&val_0214},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0075, (cst_val *)&val_2272},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0076, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7120 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0078, (cst_val *)&val_7121},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0079, (cst_val *)&val_0682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7123 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0082, (cst_val *)&val_3276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7125 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0085, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7127 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0088, (cst_val *)&val_7128},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0089, (cst_val *)&val_0147},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0090, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7129 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0092, (cst_val *)&val_2618},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0093, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7132 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0097, (cst_val *)&val_3443},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0098, (cst_val *)&val_2598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7133 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0100, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0101, (cst_val *)&val_0438},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0102, (cst_val *)&val_7134},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0103, (cst_val *)&val_0049},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0104, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7136 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0107, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7140 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0112, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7141 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0114, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7142 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0116, (cst_val *)&val_1518},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7143 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0118, (cst_val *)&val_7144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7147 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0122, (cst_val *)&val_0232},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0123, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7149 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0126, (cst_val *)&val_0041},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0127, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7150 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0129, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7152 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0132, (cst_val *)&val_0247},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0133, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7154 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0136, (cst_val *)&val_0131},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0137, (cst_val *)&val_1518},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0138, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7156 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0141, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7158 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0144, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7159 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0146, (cst_val *)&val_0073},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0147, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7161 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0150, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_86_NO_0151, (cst_val *)&val_7162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7165 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ih_86_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_single_mcep_ih_86_cart = {
  cmu_us_awb_single_mcep_ih_86_cart_nodes,
  cmu_us_awb_single_mcep_ih_86_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ih_87_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0000, (cst_val *)&val_0725},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0002, (cst_val *)&val_0008},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0003, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0004, (cst_val *)&val_0028},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0005, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7167 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0008, (cst_val *)&val_0064},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0009, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7168 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0011, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7171 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0015, (cst_val *)&val_5883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7172 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0017, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7174 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0020, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7175 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0022, (cst_val *)&val_0028},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0023, (cst_val *)&val_0029},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0024, (cst_val *)&val_0909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7178 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0028, (cst_val *)&val_7179},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0029, (cst_val *)&val_7180},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0030, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7182 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0033, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7183 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0035, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7186 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0039, (cst_val *)&val_1208},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0040, (cst_val *)&val_0801},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7187 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0042, (cst_val *)&val_7188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7190 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0045, (cst_val *)&val_7191},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0046, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0047, (cst_val *)&val_0398},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0048, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7194 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0052, (cst_val *)&val_0130},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0053, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7195 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0055, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7196 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0057, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7197 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0059, (cst_val *)&val_1271},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0060, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7198 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0062, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7200 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0065, (cst_val *)&val_3276},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0066, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7202 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0069, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7204 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0072, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7205 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0074, (cst_val *)&val_1287},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0075, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7206 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0077, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7208 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0080, (cst_val *)&val_0147},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0081, (cst_val *)&val_0049},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0082, (cst_val *)&val_0065},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0083, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7209 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7211 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0087, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7212 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0089, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0090, (cst_val *)&val_0187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7215 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0094, (cst_val *)&val_0014},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0095, (cst_val *)&val_0244},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0096, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7217 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0099, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7219 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0102, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7221 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0105, (cst_val *)&val_0065},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0106, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7222 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0108, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7223 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0110, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7224 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0112, (cst_val *)&val_1213},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0113, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7225 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0115, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7227 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0118, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7228 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0120, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0121, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7231 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0125, (cst_val *)&val_0592},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0126, (cst_val *)&val_0147},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0127, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7232 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0129, (cst_val *)&val_0004},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0130, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7235 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0134, (cst_val *)&val_0049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0135, (cst_val *)&val_3443},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0136, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7238 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0140, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7240 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0143, (cst_val *)&val_0073},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0144, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7241 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0146, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7243 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0149, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7245 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0152, (cst_val *)&val_0130},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0153, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7246 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0155, (cst_val *)&val_0017},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0156, (cst_val *)&val_0064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0157, (cst_val *)&val_0906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7248 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0160, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7250 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0163, (cst_val *)&val_0147},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0164, (cst_val *)&val_1621},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0165, (cst_val *)&val_7251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7254 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0169, (cst_val *)&val_7255},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0170, (cst_val *)&val_1871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7257 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0173, (cst_val *)&val_7258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7260 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0176, (cst_val *)&val_0121},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0177, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0178, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7262 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0181, (cst_val *)&val_7263},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0182, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0183, (cst_val *)&val_7264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7266 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0186, (cst_val *)&val_7267},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0187, (cst_val *)&val_7268},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7269 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0189, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7271 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0192, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7272 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0194, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7273 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0196, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7275 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0199, (cst_val *)&val_3650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7276 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0201, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7278 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0204, (cst_val *)&val_0003},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0205, (cst_val *)&val_2121},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0206, (cst_val *)&val_0030},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0207, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7281 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0211, (cst_val *)&val_0673},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0212, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7282 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0214, (cst_val *)&val_1792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7284 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0217, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7285 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0219, (cst_val *)&val_0003},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0220, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7287 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0223, (cst_val *)&val_1379},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0224, (cst_val *)&val_7288},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7289 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0226, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7292 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0230, (cst_val *)&val_0003},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0231, (cst_val *)&val_1459},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0232, (cst_val *)&val_3525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7293 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0234, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7296 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0238, (cst_val *)&val_0130},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0239, (cst_val *)&val_0526},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0240, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7298 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0243, (cst_val *)&val_7299},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0244, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7301 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0247, (cst_val *)&val_1356},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0248, (cst_val *)&val_7302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7305 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0252, (cst_val *)&val_7306},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0253, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0254, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7308 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0257, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7309 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0259, (cst_val *)&val_7310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7311 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0261, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7313 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0264, (cst_val *)&val_0121},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0265, (cst_val *)&val_0916},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0266, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7316 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0270, (cst_val *)&val_0130},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0271, (cst_val *)&val_0073},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0272, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7318 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0275, (cst_val *)&val_2742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7320 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0278, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0279, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0280, (cst_val *)&val_6820},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0281, (cst_val *)&val_7321},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0282, (cst_val *)&val_6548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7325 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0287, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7326 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0289, (cst_val *)&val_0003},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0290, (cst_val *)&val_7327},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0291, (cst_val *)&val_7328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7331 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0295, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7332 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0297, (cst_val *)&val_0015},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0298, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7333 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0300, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7336 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0304, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7337 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0306, (cst_val *)&val_0027},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0307, (cst_val *)&val_0045},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0308, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7338 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0310, (cst_val *)&val_7339},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7341 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0313, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7343 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0316, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7344 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0318, (cst_val *)&val_0003},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0319, (cst_val *)&val_7345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7347 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_87_NO_0322, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7349 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ih_87_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_single_mcep_ih_87_cart = {
  cmu_us_awb_single_mcep_ih_87_cart_nodes,
  cmu_us_awb_single_mcep_ih_87_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ih_88_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0001, (cst_val *)&val_2532},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0002, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0003, (cst_val *)&val_7350},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0004, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7351 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0006, (cst_val *)&val_7352},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0007, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7355 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0011, (cst_val *)&val_7356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7358 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0014, (cst_val *)&val_0247},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0015, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7359 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0017, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0018, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7362 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0022, (cst_val *)&val_0073},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0023, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7364 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0026, (cst_val *)&val_7365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7366 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0028, (cst_val *)&val_6548},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0029, (cst_val *)&val_1177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7369 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0033, (cst_val *)&val_0073},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0034, (cst_val *)&val_0479},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0035, (cst_val *)&val_1963},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0036, (cst_val *)&val_7370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7371 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0038, (cst_val *)&val_7372},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7375 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0042, (cst_val *)&val_7376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7377 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0044, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7379 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0047, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0048, (cst_val *)&val_1263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7381 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0051, (cst_val *)&val_0077},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0052, (cst_val *)&val_1912},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0053, (cst_val *)&val_1292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7383 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0056, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7384 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0058, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7385 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0060, (cst_val *)&val_0016},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0061, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7389 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0066, (cst_val *)&val_3467},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0067, (cst_val *)&val_0952},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0068, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7392 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0072, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0073, (cst_val *)&val_7393},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0074, (cst_val *)&val_1187},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0075, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7394 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0077, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7396 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0080, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7398 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0083, (cst_val *)&val_0185},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0084, (cst_val *)&val_7399},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0085, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7400 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0087, (cst_val *)&val_0014},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0088, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7402 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0091, (cst_val *)&val_0049},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0092, (cst_val *)&val_7403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7405 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0095, (cst_val *)&val_7406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7409 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0099, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7410 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0101, (cst_val *)&val_4380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7412 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0104, (cst_val *)&val_0494},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0105, (cst_val *)&val_5870},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0106, (cst_val *)&val_0049},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0107, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7414 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0110, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7416 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0113, (cst_val *)&val_7417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7418 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0115, (cst_val *)&val_7419},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7421 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0118, (cst_val *)&val_0065},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0119, (cst_val *)&val_4380},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0120, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0121, (cst_val *)&val_5952},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0122, (cst_val *)&val_2912},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0123, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7424 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0127, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7425 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0129, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0130, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7428 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0134, (cst_val *)&val_0658},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0135, (cst_val *)&val_7429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7431 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0138, (cst_val *)&val_7432},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0139, (cst_val *)&val_7433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7435 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0142, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7437 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0145, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7438 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0147, (cst_val *)&val_1806},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0148, (cst_val *)&val_0801},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0149, (cst_val *)&val_0041},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0150, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7441 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0154, (cst_val *)&val_7442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7444 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0157, (cst_val *)&val_2116},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0158, (cst_val *)&val_1520},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0159, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7445 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0161, (cst_val *)&val_7446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7448 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0164, (cst_val *)&val_7449},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0165, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7450 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0167, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7452 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0170, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0171, (cst_val *)&val_0868},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0172, (cst_val *)&val_3842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7454 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0175, (cst_val *)&val_6022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7458 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0180, (cst_val *)&val_0801},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0181, (cst_val *)&val_1088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0182, (cst_val *)&val_1092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7459 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0184, (cst_val *)&val_7460},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0185, (cst_val *)&val_1621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7462 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0188, (cst_val *)&val_0247},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0189, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7464 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0192, (cst_val *)&val_7465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7467 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0195, (cst_val *)&val_0017},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0196, (cst_val *)&val_7468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7469 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0198, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7471 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0201, (cst_val *)&val_0542},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0202, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7473 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0205, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7475 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0208, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0209, (cst_val *)&val_7476},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0210, (cst_val *)&val_7477},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0211, (cst_val *)&val_7478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7479 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0213, (cst_val *)&val_6126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7481 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0216, (cst_val *)&val_3801},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0217, (cst_val *)&val_0173},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0218, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7482 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0220, (cst_val *)&val_7483},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0221, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7485 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0224, (cst_val *)&val_7486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7490 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0229, (cst_val *)&val_7491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7492 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0231, (cst_val *)&val_1088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0232, (cst_val *)&val_7493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7496 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ih_88_NO_0236, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7498 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ih_88_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_ih_88_cart = {
  cmu_us_awb_single_mcep_ih_88_cart_nodes,
  cmu_us_awb_single_mcep_ih_88_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ax_27_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0000, (cst_val *)&val_0027},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0001, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0002, (cst_val *)&val_1287},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0003, (cst_val *)&val_0007},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0004, (cst_val *)&val_0045},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0005, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7500 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0008, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7502 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0011, (cst_val *)&val_0526},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0012, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0013, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7503 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0015, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7506 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0019, (cst_val *)&val_0077},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0020, (cst_val *)&val_7507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7509 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0023, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0024, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7510 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0026, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7512 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0029, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7514 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0032, (cst_val *)&val_4296},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0033, (cst_val *)&val_0273},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0034, (cst_val *)&val_0906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7516 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0037, (cst_val *)&val_0350},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0038, (cst_val *)&val_1074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7517 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0040, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7519 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0043, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7522 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0047, (cst_val *)&val_7523},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0048, (cst_val *)&val_7524},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0049, (cst_val *)&val_7525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7527 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0052, (cst_val *)&val_0147},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0053, (cst_val *)&val_7528},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0054, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7529 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0056, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7531 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0059, (cst_val *)&val_0478},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0060, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7532 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0062, (cst_val *)&val_0135},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0063, (cst_val *)&val_7533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7537 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0068, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0069, (cst_val *)&val_0007},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0070, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7539 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0073, (cst_val *)&val_7540},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0074, (cst_val *)&val_0478},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0075, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7543 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0079, (cst_val *)&val_7544},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7545 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0081, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7547 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0084, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7548 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0086, (cst_val *)&val_0121},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0087, (cst_val *)&val_7549},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7551 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0090, (cst_val *)&val_0007},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0091, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7552 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0093, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7554 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0096, (cst_val *)&val_0041},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0097, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7555 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0099, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7557 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0102, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7559 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0105, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0106, (cst_val *)&val_0008},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0107, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0108, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7562 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0112, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7563 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0114, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7565 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0117, (cst_val *)&val_7566},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0118, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0119, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7567 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0121, (cst_val *)&val_7568},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7570 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0124, (cst_val *)&val_0658},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0125, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7571 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0127, (cst_val *)&val_7572},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0128, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7573 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0130, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7576 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0134, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7578 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0137, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7580 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0140, (cst_val *)&val_0045},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0141, (cst_val *)&val_0025},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0142, (cst_val *)&val_7581},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0143, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7582 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0145, (cst_val *)&val_1465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7583 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0147, (cst_val *)&val_7584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7587 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0151, (cst_val *)&val_3443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7589 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0154, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7590 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0156, (cst_val *)&val_7591},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0157, (cst_val *)&val_0380},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0158, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7594 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0162, (cst_val *)&val_0147},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0163, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0164, (cst_val *)&val_0017},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0165, (cst_val *)&val_7595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7596 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0167, (cst_val *)&val_7597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7599 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0170, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7601 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0173, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7602 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0175, (cst_val *)&val_2398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7604 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0178, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7605 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0180, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7606 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0182, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7607 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0184, (cst_val *)&val_0976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7608 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0186, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7609 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0188, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0189, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7611 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_27_NO_0192, (cst_val *)&val_4920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7613 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ax_27_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_awb_single_mcep_ax_27_cart = {
  cmu_us_awb_single_mcep_ax_27_cart_nodes,
  cmu_us_awb_single_mcep_ax_27_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ax_28_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0001, (cst_val *)&val_0378},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0002, (cst_val *)&val_0479},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0003, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7614 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0005, (cst_val *)&val_0077},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0006, (cst_val *)&val_0016},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0007, (cst_val *)&val_7615},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0008, (cst_val *)&val_7616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7620 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0013, (cst_val *)&val_7621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7623 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0016, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7624 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0018, (cst_val *)&val_1070},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0019, (cst_val *)&val_4411},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0020, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7625 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0022, (cst_val *)&val_7626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7628 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0025, (cst_val *)&val_4667},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0026, (cst_val *)&val_7629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7631 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0029, (cst_val *)&val_0526},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0030, (cst_val *)&val_0017},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0031, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7634 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0035, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7635 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0037, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7637 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0040, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7638 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0042, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7639 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0044, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7641 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0047, (cst_val *)&val_0064},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0048, (cst_val *)&val_7642},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0049, (cst_val *)&val_0065},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0050, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7644 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0053, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7645 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0055, (cst_val *)&val_7646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7648 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0058, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7650 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0061, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7651 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0063, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0064, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7653 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0067, (cst_val *)&val_7654},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0068, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0069, (cst_val *)&val_2195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7656 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0072, (cst_val *)&val_1120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7659 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0076, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0077, (cst_val *)&val_0399},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0078, (cst_val *)&val_0491},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0079, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7661 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0082, (cst_val *)&val_1872},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0083, (cst_val *)&val_0530},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0084, (cst_val *)&val_0673},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0085, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7664 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0089, (cst_val *)&val_7665},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7668 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0093, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7669 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0095, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0096, (cst_val *)&val_7670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7672 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0099, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7674 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0102, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0103, (cst_val *)&val_7675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7676 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0105, (cst_val *)&val_0147},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0106, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0107, (cst_val *)&val_7677},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7680 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0111, (cst_val *)&val_1403},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0112, (cst_val *)&val_1702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7682 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0115, (cst_val *)&val_0969},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0116, (cst_val *)&val_7683},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0117, (cst_val *)&val_7684},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7688 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0122, (cst_val *)&val_7689},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0123, (cst_val *)&val_0520},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0124, (cst_val *)&val_0853},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0125, (cst_val *)&val_7524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7690 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0127, (cst_val *)&val_0976},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0128, (cst_val *)&val_7691},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0129, (cst_val *)&val_0027},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0130, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7693 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0133, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7697 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0138, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0139, (cst_val *)&val_7698},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0140, (cst_val *)&val_2398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7701 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0144, (cst_val *)&val_1081},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0145, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0146, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7705 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0151, (cst_val *)&val_1090},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0152, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7706 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0154, (cst_val *)&val_0812},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0155, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7709 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0159, (cst_val *)&val_0494},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0160, (cst_val *)&val_0147},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0161, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0162, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7712 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0166, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7713 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0168, (cst_val *)&val_0498},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0169, (cst_val *)&val_7714},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7716 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0172, (cst_val *)&val_6153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7718 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0175, (cst_val *)&val_0116},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0176, (cst_val *)&val_6153},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0177, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7721 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0181, (cst_val *)&val_4522},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0182, (cst_val *)&val_0049},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0183, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7723 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0186, (cst_val *)&val_0823},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0187, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7725 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0190, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7726 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0192, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7728 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0195, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7729 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0197, (cst_val *)&val_1806},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0198, (cst_val *)&val_0085},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0199, (cst_val *)&val_7730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7733 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0203, (cst_val *)&val_0032},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0204, (cst_val *)&val_0853},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0205, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7734 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0207, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7738 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0212, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7739 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_28_NO_0214, (cst_val *)&val_7740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7742 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ax_28_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_awb_single_mcep_ax_28_cart = {
  cmu_us_awb_single_mcep_ax_28_cart_nodes,
  cmu_us_awb_single_mcep_ax_28_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_p_136_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0001, (cst_val *)&val_0872},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0002, (cst_val *)&val_2366},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0003, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7745 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0007, (cst_val *)&val_0173},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0008, (cst_val *)&val_1403},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0009, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7747 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0012, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7749 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0015, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7750 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0017, (cst_val *)&val_7751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7753 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0020, (cst_val *)&val_0261},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0021, (cst_val *)&val_0065},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0022, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7755 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0025, (cst_val *)&val_0147},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0026, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7756 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0028, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7758 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0031, (cst_val *)&val_0261},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0032, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7760 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0035, (cst_val *)&val_7761},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0036, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7762 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0038, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7764 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0041, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7765 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0043, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7767 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0046, (cst_val *)&val_7768},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0047, (cst_val *)&val_7769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7770 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0049, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7771 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0051, (cst_val *)&val_7772},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0052, (cst_val *)&val_3243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7773 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0054, (cst_val *)&val_0660},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0055, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0056, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7776 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0060, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7777 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0062, (cst_val *)&val_1452},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0063, (cst_val *)&val_1074},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0064, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7782 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0070, (cst_val *)&val_0064},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0071, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7783 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0073, (cst_val *)&val_7784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7786 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0076, (cst_val *)&val_7787},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0077, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7788 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0079, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7789 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0081, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7791 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_136_NO_0084, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7793 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_p_136_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_p_136_cart = {
  cmu_us_awb_single_mcep_p_136_cart_nodes,
  cmu_us_awb_single_mcep_p_136_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_p_137_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0000, (cst_val *)&val_0849},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0001, (cst_val *)&val_0673},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0002, (cst_val *)&val_1359},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0003, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7794 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0005, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7795 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0007, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7796 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0009, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7798 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0012, (cst_val *)&val_0402},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0013, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7799 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0015, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7802 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0019, (cst_val *)&val_1345},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0020, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7803 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0022, (cst_val *)&val_0147},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0023, (cst_val *)&val_7804},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0024, (cst_val *)&val_7805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7807 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0027, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7809 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0030, (cst_val *)&val_0041},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0031, (cst_val *)&val_0624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7812 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0035, (cst_val *)&val_0135},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0036, (cst_val *)&val_3584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7813 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0038, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7815 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0041, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7816 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0043, (cst_val *)&val_5820},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7818 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0046, (cst_val *)&val_7819},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0047, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0048, (cst_val *)&val_0045},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0049, (cst_val *)&val_6546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7820 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0051, (cst_val *)&val_6126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7822 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0054, (cst_val *)&val_2297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7823 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0056, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7825 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0059, (cst_val *)&val_0700},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0060, (cst_val *)&val_7826},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0061, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0062, (cst_val *)&val_7827},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7828 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0064, (cst_val *)&val_3744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7829 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0066, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7830 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0068, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7832 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0071, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7834 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0074, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7836 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0077, (cst_val *)&val_0660},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0078, (cst_val *)&val_7837},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0079, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7839 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0082, (cst_val *)&val_2121},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0083, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7842 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0087, (cst_val *)&val_0360},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0088, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7843 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0090, (cst_val *)&val_0041},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0091, (cst_val *)&val_7844},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7846 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0094, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7847 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0096, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7849 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0099, (cst_val *)&val_0003},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0100, (cst_val *)&val_0147},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0101, (cst_val *)&val_1345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7851 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0104, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7852 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0106, (cst_val *)&val_0144},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0107, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7855 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0111, (cst_val *)&val_1318},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0112, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0113, (cst_val *)&val_2529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7857 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0116, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7858 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0118, (cst_val *)&val_7859},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7860 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0120, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7862 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0123, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7864 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0126, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0127, (cst_val *)&val_0674},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0128, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7867 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0132, (cst_val *)&val_0144},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0133, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7868 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0135, (cst_val *)&val_7869},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_137_NO_0136, (cst_val *)&val_1792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7873 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_p_137_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_p_137_cart = {
  cmu_us_awb_single_mcep_p_137_cart_nodes,
  cmu_us_awb_single_mcep_p_137_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_p_138_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0000, (cst_val *)&val_0261},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0001, (cst_val *)&val_0992},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0002, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7874 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0004, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0005, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7876 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0008, (cst_val *)&val_0130},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0009, (cst_val *)&val_4789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7879 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0013, (cst_val *)&val_0130},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0014, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7880 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0016, (cst_val *)&val_0121},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0017, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7882 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0020, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0021, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7885 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0025, (cst_val *)&val_0064},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0026, (cst_val *)&val_0823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7887 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0029, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7888 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0031, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7890 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0034, (cst_val *)&val_0823},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0035, (cst_val *)&val_7891},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0036, (cst_val *)&val_1264},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0037, (cst_val *)&val_7892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7894 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0040, (cst_val *)&val_7895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7897 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0043, (cst_val *)&val_7898},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0044, (cst_val *)&val_6126},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7900 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0047, (cst_val *)&val_0852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7902 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0050, (cst_val *)&val_0725},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0051, (cst_val *)&val_0009},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0052, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7904 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0055, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7905 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0057, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7906 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0059, (cst_val *)&val_7907},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0060, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7909 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0063, (cst_val *)&val_0399},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0064, (cst_val *)&val_7910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7913 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0068, (cst_val *)&val_0064},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0069, (cst_val *)&val_7914},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7915 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0071, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7917 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0074, (cst_val *)&val_0757},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0075, (cst_val *)&val_0330},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0076, (cst_val *)&val_7918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7919 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0078, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7921 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0081, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7923 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0084, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7924 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0086, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7925 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_p_138_NO_0088, (cst_val *)&val_4920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7927 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_p_138_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_awb_single_mcep_p_138_cart = {
  cmu_us_awb_single_mcep_p_138_cart_nodes,
  cmu_us_awb_single_mcep_p_138_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_iy_91_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0001, (cst_val *)&val_1543},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0002, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7929 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0005, (cst_val *)&val_1302},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0006, (cst_val *)&val_0214},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0007, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0008, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7931 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0011, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7933 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0014, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7934 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0016, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7935 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0018, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0019, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7937 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0022, (cst_val *)&val_7938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7940 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0025, (cst_val *)&val_1292},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0026, (cst_val *)&val_7941},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7942 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0028, (cst_val *)&val_0147},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0029, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7944 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0032, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7946 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0035, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7947 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0037, (cst_val *)&val_2146},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0038, (cst_val *)&val_1452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7950 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0042, (cst_val *)&val_0232},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0043, (cst_val *)&val_0003},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0044, (cst_val *)&val_1532},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0045, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7952 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0048, (cst_val *)&val_1500},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0049, (cst_val *)&val_0734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7955 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0053, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7956 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0055, (cst_val *)&val_7957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7959 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0058, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0059, (cst_val *)&val_0853},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0060, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7960 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0062, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7962 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0065, (cst_val *)&val_4517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7964 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0068, (cst_val *)&val_1532},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0069, (cst_val *)&val_2338},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0070, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7965 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0072, (cst_val *)&val_1843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7966 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0074, (cst_val *)&val_7967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7969 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0077, (cst_val *)&val_7970},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0078, (cst_val *)&val_7971},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0079, (cst_val *)&val_7972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7974 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0082, (cst_val *)&val_7975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7977 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0085, (cst_val *)&val_7978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7979 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0087, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7981 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0090, (cst_val *)&val_0007},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0091, (cst_val *)&val_0077},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0092, (cst_val *)&val_0906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7983 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0095, (cst_val *)&val_7984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7986 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0098, (cst_val *)&val_0121},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0099, (cst_val *)&val_0673},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0100, (cst_val *)&val_0674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7987 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0102, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7989 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0105, (cst_val *)&val_0798},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0106, (cst_val *)&val_0580},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0107, (cst_val *)&val_3550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7992 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0111, (cst_val *)&val_5750},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0112, (cst_val *)&val_3232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7993 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0114, (cst_val *)&val_1074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7996 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0118, (cst_val *)&val_0016},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0119, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7998 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0122, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7999 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0124, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8000 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_91_NO_0126, (cst_val *)&val_8001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8003 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_iy_91_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_iy_91_cart = {
  cmu_us_awb_single_mcep_iy_91_cart_nodes,
  cmu_us_awb_single_mcep_iy_91_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_iy_92_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0000, (cst_val *)&val_0008},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0001, (cst_val *)&val_0147},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0002, (cst_val *)&val_8004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0003, (cst_val *)&val_0550},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0004, (cst_val *)&val_8005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8007 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0007, (cst_val *)&val_0264},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0008, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8008 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0010, (cst_val *)&val_0004},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0011, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8009 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0013, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8011 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0016, (cst_val *)&val_4830},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8013 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0019, (cst_val *)&val_0853},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0020, (cst_val *)&val_0380},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0021, (cst_val *)&val_4640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8015 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0024, (cst_val *)&val_8016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8019 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0028, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0029, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0030, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8022 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0034, (cst_val *)&val_0399},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0035, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8023 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0037, (cst_val *)&val_5842},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0038, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8026 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0042, (cst_val *)&val_8027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8029 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0045, (cst_val *)&val_8030},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0046, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0047, (cst_val *)&val_4896},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0048, (cst_val *)&val_8031},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8033 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0051, (cst_val *)&val_8034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8035 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0053, (cst_val *)&val_8036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8038 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0056, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0057, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8039 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0059, (cst_val *)&val_1741},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8040 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0061, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8042 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0064, (cst_val *)&val_0121},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0065, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8044 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0068, (cst_val *)&val_2957},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0069, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8047 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0073, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0074, (cst_val *)&val_0049},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0075, (cst_val *)&val_8048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8050 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0078, (cst_val *)&val_0316},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0079, (cst_val *)&val_8051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8054 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0083, (cst_val *)&val_0065},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0084, (cst_val *)&val_8055},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0085, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8057 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0088, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0089, (cst_val *)&val_3276},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8060 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0093, (cst_val *)&val_0121},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0094, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8062 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0097, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8063 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0099, (cst_val *)&val_0672},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0100, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8065 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0103, (cst_val *)&val_0399},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0104, (cst_val *)&val_0064},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0105, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8069 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0110, (cst_val *)&val_5587},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0111, (cst_val *)&val_0147},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0112, (cst_val *)&val_0130},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0113, (cst_val *)&val_1621},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0114, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8071 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0117, (cst_val *)&val_8072},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0118, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8075 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0122, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8077 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0125, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8078 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0127, (cst_val *)&val_0041},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0128, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8079 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0130, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8080 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0132, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8081 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0134, (cst_val *)&val_0660},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0135, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8084 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0139, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8085 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0141, (cst_val *)&val_8086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8088 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0144, (cst_val *)&val_0065},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0145, (cst_val *)&val_8089},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0146, (cst_val *)&val_8090},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0147, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8092 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0150, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8094 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0153, (cst_val *)&val_8095},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0154, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8096 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0156, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8099 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0160, (cst_val *)&val_6395},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0161, (cst_val *)&val_0007},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0162, (cst_val *)&val_8100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8101 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0164, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8102 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0166, (cst_val *)&val_0916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8104 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0169, (cst_val *)&val_8105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0170, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0171, (cst_val *)&val_1955},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0172, (cst_val *)&val_0003},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0173, (cst_val *)&val_2912},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0174, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8106 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0176, (cst_val *)&val_8107},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0177, (cst_val *)&val_8108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8110 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0180, (cst_val *)&val_8111},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0181, (cst_val *)&val_8112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8116 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0186, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8117 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0188, (cst_val *)&val_2325},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8119 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0191, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8120 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0193, (cst_val *)&val_6804},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0194, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8121 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0196, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8122 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0198, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0199, (cst_val *)&val_1188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8124 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0202, (cst_val *)&val_1507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8126 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0205, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8128 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0208, (cst_val *)&val_0003},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0209, (cst_val *)&val_1115},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0210, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8129 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0212, (cst_val *)&val_3908},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0213, (cst_val *)&val_8130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8133 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0217, (cst_val *)&val_8134},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0218, (cst_val *)&val_1254},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8137 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0222, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0223, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8138 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0225, (cst_val *)&val_1459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8140 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0228, (cst_val *)&val_0624},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0229, (cst_val *)&val_0003},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0230, (cst_val *)&val_0003},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0231, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8143 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0235, (cst_val *)&val_0315},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0236, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8145 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0239, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8146 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0241, (cst_val *)&val_8147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8149 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0244, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8151 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0247, (cst_val *)&val_8152},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0248, (cst_val *)&val_0485},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0249, (cst_val *)&val_0049},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0250, (cst_val *)&val_0003},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0251, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8153 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0253, (cst_val *)&val_8154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8155 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0255, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8156 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0257, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8158 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0260, (cst_val *)&val_0007},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0261, (cst_val *)&val_0659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8160 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0264, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8161 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0266, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8162 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0268, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8163 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0270, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8165 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0273, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0274, (cst_val *)&val_0147},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0275, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8167 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0278, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8169 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0281, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8170 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0283, (cst_val *)&val_0003},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0284, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8172 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0287, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8174 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0290, (cst_val *)&val_0660},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0291, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8176 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0294, (cst_val *)&val_0003},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0295, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8179 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0299, (cst_val *)&val_0045},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0300, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0301, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8182 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0305, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8183 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0307, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0308, (cst_val *)&val_8184},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8186 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0311, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8187 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0313, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8189 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_92_NO_0316, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8191 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_iy_92_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_iy_92_cart = {
  cmu_us_awb_single_mcep_iy_92_cart_nodes,
  cmu_us_awb_single_mcep_iy_92_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_iy_93_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0001, (cst_val *)&val_0247},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0002, (cst_val *)&val_1099},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0003, (cst_val *)&val_8192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8194 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0006, (cst_val *)&val_0232},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0007, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0008, (cst_val *)&val_8195},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0009, (cst_val *)&val_0852},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8197 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0012, (cst_val *)&val_8198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8199 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0014, (cst_val *)&val_2221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8201 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0017, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8203 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0020, (cst_val *)&val_0578},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0021, (cst_val *)&val_0073},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0022, (cst_val *)&val_0673},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0023, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8205 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0026, (cst_val *)&val_8206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8208 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0029, (cst_val *)&val_4667},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8209 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0031, (cst_val *)&val_0953},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0032, (cst_val *)&val_8210},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8212 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0035, (cst_val *)&val_0673},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0036, (cst_val *)&val_2049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8214 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0039, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8216 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0042, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8217 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0044, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8218 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0046, (cst_val *)&val_2297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8220 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0049, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0050, (cst_val *)&val_5713},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0051, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0052, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8221 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0054, (cst_val *)&val_8222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8224 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0057, (cst_val *)&val_8225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8227 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0060, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8228 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0062, (cst_val *)&val_0270},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0063, (cst_val *)&val_2840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8230 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0066, (cst_val *)&val_3845},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0067, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0068, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8232 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0071, (cst_val *)&val_8233},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8236 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0075, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8237 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0077, (cst_val *)&val_8238},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0078, (cst_val *)&val_0131},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0079, (cst_val *)&val_1955},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8240 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0082, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8242 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0085, (cst_val *)&val_0003},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0086, (cst_val *)&val_8243},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0087, (cst_val *)&val_0935},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8245 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0090, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8247 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0093, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8248 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0095, (cst_val *)&val_2957},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8250 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0098, (cst_val *)&val_8251},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0099, (cst_val *)&val_1792},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0100, (cst_val *)&val_0121},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0101, (cst_val *)&val_8252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8254 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0104, (cst_val *)&val_0003},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0105, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8256 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0108, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8257 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0110, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8258 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0112, (cst_val *)&val_0147},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0113, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8260 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0116, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8262 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0119, (cst_val *)&val_8263},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0120, (cst_val *)&val_2325},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0121, (cst_val *)&val_8264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8266 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0124, (cst_val *)&val_2221},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0125, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8268 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0128, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8269 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0130, (cst_val *)&val_0147},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0131, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8272 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0135, (cst_val *)&val_0003},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0136, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8274 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0139, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8275 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0141, (cst_val *)&val_8276},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0142, (cst_val *)&val_8277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8280 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0146, (cst_val *)&val_0700},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0147, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0148, (cst_val *)&val_1359},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0149, (cst_val *)&val_8281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8283 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0152, (cst_val *)&val_0360},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0153, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8285 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0156, (cst_val *)&val_7761},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0157, (cst_val *)&val_0188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8288 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0161, (cst_val *)&val_1088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0162, (cst_val *)&val_1763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8290 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0165, (cst_val *)&val_1090},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0166, (cst_val *)&val_0980},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0167, (cst_val *)&val_0767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8292 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0170, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8294 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0173, (cst_val *)&val_0520},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0174, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8296 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0177, (cst_val *)&val_0494},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0178, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8298 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0181, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8299 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0183, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8300 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0185, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8301 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0187, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8303 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0190, (cst_val *)&val_0065},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0191, (cst_val *)&val_8304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8306 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0194, (cst_val *)&val_0045},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0195, (cst_val *)&val_0048},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0196, (cst_val *)&val_8307},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0197, (cst_val *)&val_5766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8308 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0199, (cst_val *)&val_0175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8309 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0201, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8313 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0206, (cst_val *)&val_0027},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0207, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8314 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0209, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8315 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0211, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8317 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0214, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8318 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_iy_93_NO_0216, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8320 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_iy_93_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_iy_93_cart = {
  cmu_us_awb_single_mcep_iy_93_cart_nodes,
  cmu_us_awb_single_mcep_iy_93_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_l_106_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0001, (cst_val *)&val_0232},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0002, (cst_val *)&val_0147},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0003, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8321 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0005, (cst_val *)&val_0378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8323 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0008, (cst_val *)&val_0044},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0009, (cst_val *)&val_0009},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0010, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8325 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0013, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8328 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0017, (cst_val *)&val_1403},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0018, (cst_val *)&val_1070},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0019, (cst_val *)&val_0147},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0020, (cst_val *)&val_0041},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0021, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8331 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0025, (cst_val *)&val_0525},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0026, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0027, (cst_val *)&val_0009},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0028, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8333 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0031, (cst_val *)&val_8334},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0032, (cst_val *)&val_7629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8337 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0036, (cst_val *)&val_8338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8339 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0038, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8341 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0041, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0042, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8343 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0045, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8344 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0047, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8346 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0050, (cst_val *)&val_0003},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0051, (cst_val *)&val_0009},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0052, (cst_val *)&val_8347},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0053, (cst_val *)&val_8348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8351 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0057, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8352 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0059, (cst_val *)&val_8353},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0060, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8354 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0062, (cst_val *)&val_1336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8357 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0066, (cst_val *)&val_3203},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0067, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8359 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0070, (cst_val *)&val_0232},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0071, (cst_val *)&val_1222},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8361 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0074, (cst_val *)&val_0102},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0075, (cst_val *)&val_8362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8364 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0078, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8365 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0080, (cst_val *)&val_8366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8368 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0083, (cst_val *)&val_0003},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0084, (cst_val *)&val_0007},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0085, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0086, (cst_val *)&val_7683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8371 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0090, (cst_val *)&val_0359},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0091, (cst_val *)&val_8372},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0092, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8373 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0094, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8375 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0097, (cst_val *)&val_3806},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0098, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8376 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0100, (cst_val *)&val_0009},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0101, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8378 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0104, (cst_val *)&val_2088},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0105, (cst_val *)&val_1955},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0106, (cst_val *)&val_3344},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8383 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0112, (cst_val *)&val_0159},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0113, (cst_val *)&val_8384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8387 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0117, (cst_val *)&val_0015},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0118, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8388 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0120, (cst_val *)&val_3203},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0121, (cst_val *)&val_8389},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0122, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8391 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0125, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8393 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0128, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0129, (cst_val *)&val_8394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8396 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0132, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8397 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0134, (cst_val *)&val_8398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8400 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0137, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0138, (cst_val *)&val_0003},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0139, (cst_val *)&val_8401},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8403 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0142, (cst_val *)&val_0279},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0143, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8406 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0147, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8407 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0149, (cst_val *)&val_8408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8409 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0151, (cst_val *)&val_3203},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8411 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0154, (cst_val *)&val_0704},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0155, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8412 },
{ 30, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0157, (cst_val *)&val_0402},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0158, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0159, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8413 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0161, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8415 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0164, (cst_val *)&val_8416},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0165, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8419 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0169, (cst_val *)&val_0007},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0170, (cst_val *)&val_8420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8422 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0173, (cst_val *)&val_0350},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0174, (cst_val *)&val_4789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8425 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0178, (cst_val *)&val_0045},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0179, (cst_val *)&val_0064},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0180, (cst_val *)&val_8426},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0181, (cst_val *)&val_0204},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0182, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8428 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0185, (cst_val *)&val_0380},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0186, (cst_val *)&val_1070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8431 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0190, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8433 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0193, (cst_val *)&val_5808},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8434 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0195, (cst_val *)&val_0003},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0196, (cst_val *)&val_8435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8438 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0200, (cst_val *)&val_0041},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0201, (cst_val *)&val_0952},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0202, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8440 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0205, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8441 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0207, (cst_val *)&val_8442},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0208, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8443 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0210, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8446 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0214, (cst_val *)&val_1543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8447 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_106_NO_0216, (cst_val *)&val_5766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8449 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_l_106_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_awb_single_mcep_l_106_cart = {
  cmu_us_awb_single_mcep_l_106_cart_nodes,
  cmu_us_awb_single_mcep_l_106_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_l_107_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0000, (cst_val *)&val_0000},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0001, (cst_val *)&val_0077},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0002, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0003, (cst_val *)&val_0009},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0004, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8450 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0006, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0007, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8451 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0009, (cst_val *)&val_8452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8454 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0012, (cst_val *)&val_1963},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0013, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8457 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0017, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0018, (cst_val *)&val_2742},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0019, (cst_val *)&val_8458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8461 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0023, (cst_val *)&val_0010},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0024, (cst_val *)&val_0872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8463 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0027, (cst_val *)&val_0116},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0028, (cst_val *)&val_0017},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0029, (cst_val *)&val_8464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8466 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0032, (cst_val *)&val_8467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8468 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0034, (cst_val *)&val_8469},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0035, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8472 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0039, (cst_val *)&val_8473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8474 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0041, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8476 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0044, (cst_val *)&val_8477},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0045, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0046, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8479 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0049, (cst_val *)&val_1808},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0050, (cst_val *)&val_1971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8481 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0053, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8482 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0055, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8483 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0057, (cst_val *)&val_8484},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8485 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0059, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8487 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0062, (cst_val *)&val_0045},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0063, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8489 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0066, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8491 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0069, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0070, (cst_val *)&val_1207},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0071, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8492 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0073, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8493 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0075, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8496 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0079, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0080, (cst_val *)&val_0068},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0081, (cst_val *)&val_8497},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8498 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0083, (cst_val *)&val_4640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8500 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0086, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8501 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0088, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8503 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0091, (cst_val *)&val_0232},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0092, (cst_val *)&val_1990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8505 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0095, (cst_val *)&val_8467},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0096, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8506 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0098, (cst_val *)&val_0041},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0099, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8507 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0101, (cst_val *)&val_0887},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0102, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8509 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0105, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8510 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0107, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8513 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0111, (cst_val *)&val_0045},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0112, (cst_val *)&val_0232},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0113, (cst_val *)&val_8514},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0114, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8517 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0118, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8518 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0120, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8519 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0122, (cst_val *)&val_0003},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0123, (cst_val *)&val_8520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8522 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0126, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8524 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0129, (cst_val *)&val_0036},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0130, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8527 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0134, (cst_val *)&val_0041},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0135, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0136, (cst_val *)&val_8528},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0137, (cst_val *)&val_0009},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0138, (cst_val *)&val_8529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8531 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0141, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0142, (cst_val *)&val_8532},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0143, (cst_val *)&val_0700},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0144, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8534 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0147, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8535 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0149, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8537 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0152, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8540 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0156, (cst_val *)&val_7837},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0157, (cst_val *)&val_0147},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0158, (cst_val *)&val_5713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8544 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0163, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0164, (cst_val *)&val_0017},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0165, (cst_val *)&val_0615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8545 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0167, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8546 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0169, (cst_val *)&val_2121},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0170, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8548 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0173, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8549 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0175, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8551 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0178, (cst_val *)&val_8552},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0179, (cst_val *)&val_0003},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0180, (cst_val *)&val_8553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8555 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0183, (cst_val *)&val_2458},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0184, (cst_val *)&val_2195},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0185, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8556 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0187, (cst_val *)&val_0131},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0188, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8559 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0192, (cst_val *)&val_8560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8561 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0194, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8564 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0198, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0199, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8566 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0202, (cst_val *)&val_0009},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0203, (cst_val *)&val_8567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8569 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0206, (cst_val *)&val_1385},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0207, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8572 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0211, (cst_val *)&val_0073},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0212, (cst_val *)&val_0009},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0213, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8574 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0216, (cst_val *)&val_8575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8577 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0219, (cst_val *)&val_8353},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0220, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8578 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0222, (cst_val *)&val_8579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8582 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0226, (cst_val *)&val_0232},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0227, (cst_val *)&val_5920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8583 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0229, (cst_val *)&val_8584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8585 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0231, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8587 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0234, (cst_val *)&val_8588},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0235, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8589 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0237, (cst_val *)&val_8590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8591 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0239, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8593 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0242, (cst_val *)&val_8594},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_107_NO_0243, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8597 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_l_107_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_awb_single_mcep_l_107_cart = {
  cmu_us_awb_single_mcep_l_107_cart_nodes,
  cmu_us_awb_single_mcep_l_107_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_l_108_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0001, (cst_val *)&val_0232},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0002, (cst_val *)&val_1208},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0003, (cst_val *)&val_3181},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8598 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0005, (cst_val *)&val_0561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8599 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0007, (cst_val *)&val_4740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8601 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0010, (cst_val *)&val_0037},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0011, (cst_val *)&val_1862},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0012, (cst_val *)&val_8602},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8604 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0015, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8605 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0017, (cst_val *)&val_6746},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0018, (cst_val *)&val_0027},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0019, (cst_val *)&val_0003},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0020, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8606 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0022, (cst_val *)&val_0868},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8609 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0026, (cst_val *)&val_0175},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0027, (cst_val *)&val_8610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8615 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0033, (cst_val *)&val_0009},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0034, (cst_val *)&val_0360},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0035, (cst_val *)&val_0009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0036, (cst_val *)&val_0360},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0037, (cst_val *)&val_8616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8618 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0040, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8619 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0042, (cst_val *)&val_8620},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8623 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0046, (cst_val *)&val_8624},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0047, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8625 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0049, (cst_val *)&val_8626},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0050, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8629 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0054, (cst_val *)&val_0009},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0055, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8630 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0057, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8633 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0061, (cst_val *)&val_0232},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0062, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8634 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0064, (cst_val *)&val_1317},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0065, (cst_val *)&val_0767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8635 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0067, (cst_val *)&val_4479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8637 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0070, (cst_val *)&val_0370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8639 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0073, (cst_val *)&val_1794},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0074, (cst_val *)&val_3181},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0075, (cst_val *)&val_0887},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0076, (cst_val *)&val_0187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8641 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0079, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8643 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0082, (cst_val *)&val_0003},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0083, (cst_val *)&val_0932},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0084, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8645 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0087, (cst_val *)&val_8646},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0088, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8647 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0090, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8649 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0093, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8651 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0096, (cst_val *)&val_0872},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0097, (cst_val *)&val_8004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8652 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0099, (cst_val *)&val_8653},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0100, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8655 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0103, (cst_val *)&val_8656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8658 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0106, (cst_val *)&val_0064},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0107, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8660 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0110, (cst_val *)&val_0003},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0111, (cst_val *)&val_8661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8663 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0114, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8664 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0116, (cst_val *)&val_0340},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8666 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0119, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8668 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0122, (cst_val *)&val_8669},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0123, (cst_val *)&val_0232},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0124, (cst_val *)&val_8497},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0125, (cst_val *)&val_8670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8671 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0127, (cst_val *)&val_0045},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0128, (cst_val *)&val_2049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8673 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0131, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8675 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0134, (cst_val *)&val_8676},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0135, (cst_val *)&val_3752},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0136, (cst_val *)&val_1764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8678 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0139, (cst_val *)&val_8679},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0140, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8682 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0144, (cst_val *)&val_3752},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0145, (cst_val *)&val_0853},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0146, (cst_val *)&val_1208},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0147, (cst_val *)&val_8683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8685 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0150, (cst_val *)&val_8686},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8687 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0152, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8690 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0156, (cst_val *)&val_8691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8693 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0159, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0160, (cst_val *)&val_7433},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0161, (cst_val *)&val_0045},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0162, (cst_val *)&val_8694},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0163, (cst_val *)&val_8695},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0164, (cst_val *)&val_0278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8699 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0169, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8700 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0171, (cst_val *)&val_8701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8703 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0174, (cst_val *)&val_1648},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0175, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8706 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0179, (cst_val *)&val_8707},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0180, (cst_val *)&val_0073},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0181, (cst_val *)&val_8708},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0182, (cst_val *)&val_3541},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8710 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0185, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8712 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0188, (cst_val *)&val_0049},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0189, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8713 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0191, (cst_val *)&val_4437},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8715 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0194, (cst_val *)&val_2260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8717 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0197, (cst_val *)&val_0045},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0198, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8718 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0200, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8719 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0202, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8721 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0205, (cst_val *)&val_0041},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0206, (cst_val *)&val_0953},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0207, (cst_val *)&val_8722},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8725 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0211, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8727 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0214, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0215, (cst_val *)&val_6768},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8728 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0217, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0218, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8730 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0221, (cst_val *)&val_1088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0222, (cst_val *)&val_6022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8732 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0225, (cst_val *)&val_0017},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0226, (cst_val *)&val_0530},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0227, (cst_val *)&val_0578},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0228, (cst_val *)&val_8733},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0229, (cst_val *)&val_1535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8738 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0235, (cst_val *)&val_0542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8739 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0237, (cst_val *)&val_0049},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0238, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8742 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0242, (cst_val *)&val_0953},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0243, (cst_val *)&val_0009},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0244, (cst_val *)&val_2821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8743 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0246, (cst_val *)&val_2968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8745 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0249, (cst_val *)&val_0028},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0250, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8746 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0252, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8749 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0256, (cst_val *)&val_0041},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0257, (cst_val *)&val_8497},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8750 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0259, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8752 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0262, (cst_val *)&val_0952},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0263, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8753 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0265, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8755 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_l_108_NO_0268, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8757 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_l_108_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_l_108_cart = {
  cmu_us_awb_single_mcep_l_108_cart_nodes,
  cmu_us_awb_single_mcep_l_108_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_z_199_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0000, (cst_val *)&val_1365},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0001, (cst_val *)&val_0003},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0002, (cst_val *)&val_0232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0003, (cst_val *)&val_1769},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0004, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8758 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0006, (cst_val *)&val_0673},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0007, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8760 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0010, (cst_val *)&val_8761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8763 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0013, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0014, (cst_val *)&val_0027},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0015, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8767 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0020, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0021, (cst_val *)&val_0673},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0022, (cst_val *)&val_0894},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0023, (cst_val *)&val_2052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8770 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0027, (cst_val *)&val_8771},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0028, (cst_val *)&val_4651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8774 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0032, (cst_val *)&val_0680},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0033, (cst_val *)&val_8775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8777 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0036, (cst_val *)&val_0673},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0037, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8779 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0040, (cst_val *)&val_0017},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0041, (cst_val *)&val_8780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8783 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0045, (cst_val *)&val_1963},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0046, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8784 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0048, (cst_val *)&val_0976},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0049, (cst_val *)&val_8785},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0050, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8790 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0056, (cst_val *)&val_0015},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0057, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8791 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0059, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0060, (cst_val *)&val_1694},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0061, (cst_val *)&val_0187},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0062, (cst_val *)&val_8792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8794 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0065, (cst_val *)&val_8795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8798 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0069, (cst_val *)&val_0033},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0070, (cst_val *)&val_5828},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0071, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8801 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0075, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8802 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0077, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8803 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0079, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8805 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0082, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8806 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0084, (cst_val *)&val_2451},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_199_NO_0085, (cst_val *)&val_6770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8809 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_z_199_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_z_199_cart = {
  cmu_us_awb_single_mcep_z_199_cart_nodes,
  cmu_us_awb_single_mcep_z_199_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_z_200_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0001, (cst_val *)&val_8810},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0002, (cst_val *)&val_0672},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0003, (cst_val *)&val_8811},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0004, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8814 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0008, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8815 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0010, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8817 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0013, (cst_val *)&val_0121},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0014, (cst_val *)&val_7017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0015, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8820 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0019, (cst_val *)&val_1872},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0020, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0021, (cst_val *)&val_0402},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0022, (cst_val *)&val_8821},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0023, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8823 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0026, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8825 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0029, (cst_val *)&val_0017},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0030, (cst_val *)&val_1843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8826 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0032, (cst_val *)&val_0320},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8828 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0035, (cst_val *)&val_1696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8830 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0038, (cst_val *)&val_0980},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0039, (cst_val *)&val_1821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8832 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0042, (cst_val *)&val_1207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8834 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0045, (cst_val *)&val_0085},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0046, (cst_val *)&val_0009},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0047, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8836 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0050, (cst_val *)&val_5750},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8839 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0054, (cst_val *)&val_1424},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0055, (cst_val *)&val_8810},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0056, (cst_val *)&val_2787},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0057, (cst_val *)&val_0011},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0058, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8842 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0062, (cst_val *)&val_1131},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0063, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8845 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0067, (cst_val *)&val_0147},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0068, (cst_val *)&val_1003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0069, (cst_val *)&val_2305},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0070, (cst_val *)&val_8846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8848 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0073, (cst_val *)&val_8849},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0074, (cst_val *)&val_5883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8851 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0077, (cst_val *)&val_8852},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0078, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8853 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0080, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8855 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0083, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8856 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0085, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0086, (cst_val *)&val_8857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8858 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0088, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8862 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0093, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8863 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0095, (cst_val *)&val_0121},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0096, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8865 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0099, (cst_val *)&val_0017},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0100, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8866 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0102, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8868 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0105, (cst_val *)&val_8869},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8871 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0108, (cst_val *)&val_0003},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0109, (cst_val *)&val_8872},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0110, (cst_val *)&val_8873},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0111, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8874 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0113, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8877 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0117, (cst_val *)&val_8878},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0118, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8881 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0122, (cst_val *)&val_0007},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0123, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8883 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0126, (cst_val *)&val_0232},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0127, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8885 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_200_NO_0130, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8887 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_z_200_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_awb_single_mcep_z_200_cart = {
  cmu_us_awb_single_mcep_z_200_cart_nodes,
  cmu_us_awb_single_mcep_z_200_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_z_201_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0001, (cst_val *)&val_1872},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0002, (cst_val *)&val_1287},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0003, (cst_val *)&val_3006},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0004, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8888 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0006, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8890 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0009, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0010, (cst_val *)&val_3948},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0011, (cst_val *)&val_3068},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0012, (cst_val *)&val_2805},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0013, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8893 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0017, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8895 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0020, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0021, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8897 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0024, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8898 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0026, (cst_val *)&val_8899},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8900 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0028, (cst_val *)&val_2737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8902 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0031, (cst_val *)&val_4411},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0032, (cst_val *)&val_8903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8905 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0035, (cst_val *)&val_0073},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0036, (cst_val *)&val_0049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0037, (cst_val *)&val_1715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8909 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0042, (cst_val *)&val_0121},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0043, (cst_val *)&val_4051},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0044, (cst_val *)&val_0953},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0045, (cst_val *)&val_0887},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0046, (cst_val *)&val_8910},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0047, (cst_val *)&val_8911},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0048, (cst_val *)&val_3559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8915 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0053, (cst_val *)&val_8916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8919 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0057, (cst_val *)&val_3797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8921 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0060, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0061, (cst_val *)&val_8922},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0062, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0063, (cst_val *)&val_3479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8924 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0066, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8925 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0068, (cst_val *)&val_8926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8928 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0071, (cst_val *)&val_0887},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0072, (cst_val *)&val_0398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8929 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0074, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8930 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0076, (cst_val *)&val_0529},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0077, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8933 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0081, (cst_val *)&val_0878},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0082, (cst_val *)&val_8934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8936 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0085, (cst_val *)&val_8937},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0086, (cst_val *)&val_8938},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8939 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0088, (cst_val *)&val_1045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8941 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0091, (cst_val *)&val_0725},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0092, (cst_val *)&val_7837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8944 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0096, (cst_val *)&val_0003},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0097, (cst_val *)&val_8810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8945 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0099, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0100, (cst_val *)&val_8946},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0101, (cst_val *)&val_8947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8948 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0103, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8950 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0106, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8952 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0109, (cst_val *)&val_8953},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0110, (cst_val *)&val_3175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8955 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0113, (cst_val *)&val_3057},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0114, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8958 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0118, (cst_val *)&val_8959},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0119, (cst_val *)&val_0144},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0120, (cst_val *)&val_0077},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0121, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8961 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0124, (cst_val *)&val_8962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8964 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0127, (cst_val *)&val_4411},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0128, (cst_val *)&val_8965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8967 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0131, (cst_val *)&val_8968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8970 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0134, (cst_val *)&val_8971},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0135, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0136, (cst_val *)&val_8972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8976 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0141, (cst_val *)&val_4296},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0142, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8979 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0146, (cst_val *)&val_1222},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0147, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0148, (cst_val *)&val_0244},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0149, (cst_val *)&val_0350},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8980 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0151, (cst_val *)&val_0017},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0152, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8982 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0155, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8983 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0157, (cst_val *)&val_8984},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0158, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8987 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0162, (cst_val *)&val_1092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8989 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0165, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8990 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0167, (cst_val *)&val_0520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8991 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0169, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8992 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0171, (cst_val *)&val_0852},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0172, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8994 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0175, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8996 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0178, (cst_val *)&val_0864},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0179, (cst_val *)&val_0009},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0180, (cst_val *)&val_0121},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0181, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8998 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0184, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8999 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0186, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9002 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0190, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0191, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9003 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0193, (cst_val *)&val_9004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9006 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0196, (cst_val *)&val_9007},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0197, (cst_val *)&val_0969},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0198, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9009 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_z_201_NO_0201, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9012 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_z_201_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_z_201_cart = {
  cmu_us_awb_single_mcep_z_201_cart_nodes,
  cmu_us_awb_single_mcep_z_201_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_pau_161_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0000, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0001, (cst_val *)&val_0378},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0002, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0003, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0004, (cst_val *)&val_1808},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9013 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0006, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9014 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0008, (cst_val *)&val_0491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9016 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0011, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9017 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0013, (cst_val *)&val_1912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9019 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0016, (cst_val *)&val_1741},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0017, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9020 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0019, (cst_val *)&val_5625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9022 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0022, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9024 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0025, (cst_val *)&val_9025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0026, (cst_val *)&val_0300},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0027, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9027 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0030, (cst_val *)&val_6560},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0031, (cst_val *)&val_0007},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0032, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9029 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0035, (cst_val *)&val_0014},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0036, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9030 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0038, (cst_val *)&val_7468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9033 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0042, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9035 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0045, (cst_val *)&val_0045},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0046, (cst_val *)&val_9036},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0047, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9037 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0049, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9039 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0052, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9041 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0055, (cst_val *)&val_3344},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0056, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9044 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0060, (cst_val *)&val_0525},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0061, (cst_val *)&val_0485},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0062, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0063, (cst_val *)&val_0015},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0064, (cst_val *)&val_0116},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0065, (cst_val *)&val_9045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9047 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0068, (cst_val *)&val_0068},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0069, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9048 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0071, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9051 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0075, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9052 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0077, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9054 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0080, (cst_val *)&val_0129},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0081, (cst_val *)&val_0045},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0082, (cst_val *)&val_0065},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0083, (cst_val *)&val_0135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9056 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0086, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9057 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0088, (cst_val *)&val_2609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9060 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0092, (cst_val *)&val_0007},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0093, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9061 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0095, (cst_val *)&val_0017},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0096, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9062 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0098, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9064 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0101, (cst_val *)&val_7698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9066 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0104, (cst_val *)&val_0478},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0105, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9067 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0107, (cst_val *)&val_9068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9070 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0110, (cst_val *)&val_7024},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0111, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9072 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0114, (cst_val *)&val_1052},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0115, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9074 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0118, (cst_val *)&val_0073},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0119, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9077 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0123, (cst_val *)&val_9078},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0124, (cst_val *)&val_9079},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0125, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0126, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9080 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0128, (cst_val *)&val_9081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9083 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0131, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9084 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0133, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9085 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0135, (cst_val *)&val_3664},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9087 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0138, (cst_val *)&val_6602},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0139, (cst_val *)&val_3053},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0140, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9088 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0142, (cst_val *)&val_0435},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0143, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9091 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0147, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9092 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0149, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9095 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0153, (cst_val *)&val_9096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9098 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0156, (cst_val *)&val_0065},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0157, (cst_val *)&val_0130},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0158, (cst_val *)&val_1806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9100 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0161, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9102 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0164, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0165, (cst_val *)&val_0700},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0166, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9105 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0170, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0171, (cst_val *)&val_3467},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0172, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9107 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0175, (cst_val *)&val_0010},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0176, (cst_val *)&val_1090},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9110 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_pau_161_NO_0180, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9112 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_pau_161_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_awb_single_mcep_pau_161_cart = {
  cmu_us_awb_single_mcep_pau_161_cart_nodes,
  cmu_us_awb_single_mcep_pau_161_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_s_151_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0000, (cst_val *)&val_1403},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0001, (cst_val *)&val_0121},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0002, (cst_val *)&val_0077},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0003, (cst_val *)&val_0130},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0004, (cst_val *)&val_9113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9115 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0007, (cst_val *)&val_9116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9118 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0010, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9119 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0012, (cst_val *)&val_9120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9122 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0015, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0016, (cst_val *)&val_0402},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0017, (cst_val *)&val_0007},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0018, (cst_val *)&val_0009},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0019, (cst_val *)&val_3243},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0020, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9126 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0025, (cst_val *)&val_7675},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0026, (cst_val *)&val_9127},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0027, (cst_val *)&val_0019},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0028, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9129 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0031, (cst_val *)&val_0009},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0032, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9130 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0034, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9133 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0038, (cst_val *)&val_9134},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0039, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9137 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0043, (cst_val *)&val_0049},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0044, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9139 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0047, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9140 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0049, (cst_val *)&val_9141},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0050, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9144 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0054, (cst_val *)&val_3243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9145 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0056, (cst_val *)&val_1208},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0057, (cst_val *)&val_9146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9148 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0060, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9149 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0062, (cst_val *)&val_0077},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0063, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9151 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0066, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9152 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0068, (cst_val *)&val_0601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9154 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0071, (cst_val *)&val_0073},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0072, (cst_val *)&val_0064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0073, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9155 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0075, (cst_val *)&val_9156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9158 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0078, (cst_val *)&val_9159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9161 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0081, (cst_val *)&val_3459},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0082, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9162 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0084, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9164 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0087, (cst_val *)&val_0017},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0088, (cst_val *)&val_0003},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0089, (cst_val *)&val_1271},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0090, (cst_val *)&val_8946},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9166 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0093, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9167 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0095, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9169 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0098, (cst_val *)&val_0016},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0099, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9171 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0102, (cst_val *)&val_5880},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9173 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0105, (cst_val *)&val_0077},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0106, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9174 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0108, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9175 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0110, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0111, (cst_val *)&val_9176},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9179 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0115, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9181 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0118, (cst_val *)&val_0003},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0119, (cst_val *)&val_0003},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0120, (cst_val *)&val_9182},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0121, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9183 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0123, (cst_val *)&val_0036},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0124, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9184 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0126, (cst_val *)&val_8112},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9187 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0130, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9189 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0133, (cst_val *)&val_1115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9191 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0136, (cst_val *)&val_0261},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0137, (cst_val *)&val_3232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0138, (cst_val *)&val_0121},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0139, (cst_val *)&val_0637},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0140, (cst_val *)&val_0032},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0141, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9194 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0145, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9195 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0147, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9197 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0150, (cst_val *)&val_8420},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0151, (cst_val *)&val_9198},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0152, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9199 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0154, (cst_val *)&val_9200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9203 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0158, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9204 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0160, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9205 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0162, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9206 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0164, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9208 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0167, (cst_val *)&val_0147},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0168, (cst_val *)&val_9209},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0169, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9210 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0171, (cst_val *)&val_0121},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0172, (cst_val *)&val_3479},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0173, (cst_val *)&val_9211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9213 },
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0176, (cst_val *)&val_9214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9217 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0180, (cst_val *)&val_0700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9218 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0182, (cst_val *)&val_0121},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0183, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9221 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0187, (cst_val *)&val_3243},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9222 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0189, (cst_val *)&val_0147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0190, (cst_val *)&val_9223},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0191, (cst_val *)&val_9224},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0192, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9225 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0194, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9229 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0199, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9230 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0201, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9232 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0204, (cst_val *)&val_1365},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0205, (cst_val *)&val_0049},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0206, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9234 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0209, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9235 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0211, (cst_val *)&val_9236},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9238 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0214, (cst_val *)&val_0121},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0215, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9240 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0218, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9241 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_151_NO_0220, (cst_val *)&val_9036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9243 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_s_151_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_single_mcep_s_151_cart = {
  cmu_us_awb_single_mcep_s_151_cart_nodes,
  cmu_us_awb_single_mcep_s_151_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_s_152_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0000, (cst_val *)&val_0525},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0001, (cst_val *)&val_0011},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0002, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0003, (cst_val *)&val_0725},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0004, (cst_val *)&val_1115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9244 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0006, (cst_val *)&val_9245},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0007, (cst_val *)&val_0003},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0008, (cst_val *)&val_0932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9248 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0012, (cst_val *)&val_0526},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0013, (cst_val *)&val_9249},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9251 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0016, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0017, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9253 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0020, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9255 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0023, (cst_val *)&val_9256},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0024, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9257 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0026, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9258 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0028, (cst_val *)&val_1872},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0029, (cst_val *)&val_0049},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0030, (cst_val *)&val_0003},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0031, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9259 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0033, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9261 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0036, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9265 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0041, (cst_val *)&val_9266},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0042, (cst_val *)&val_2121},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0043, (cst_val *)&val_9267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9271 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0048, (cst_val *)&val_9272},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0049, (cst_val *)&val_0003},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0050, (cst_val *)&val_0887},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0051, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9275 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0055, (cst_val *)&val_1271},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0056, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9277 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0059, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9278 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0061, (cst_val *)&val_0065},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0062, (cst_val *)&val_0725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9279 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0064, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9281 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0067, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9282 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0069, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9283 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0071, (cst_val *)&val_9284},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0072, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9285 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0074, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9288 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0078, (cst_val *)&val_1271},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0079, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9290 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0082, (cst_val *)&val_0992},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0083, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9291 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0085, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9293 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0088, (cst_val *)&val_9294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9296 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0091, (cst_val *)&val_0315},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0092, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0093, (cst_val *)&val_9256},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0094, (cst_val *)&val_9297},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0095, (cst_val *)&val_0887},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0096, (cst_val *)&val_9298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9300 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0099, (cst_val *)&val_0856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9302 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0102, (cst_val *)&val_0173},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0103, (cst_val *)&val_9303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9305 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0106, (cst_val *)&val_9306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9307 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0108, (cst_val *)&val_0340},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0109, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9309 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0112, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9311 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0115, (cst_val *)&val_0011},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0116, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9312 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0118, (cst_val *)&val_9313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9315 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0121, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9316 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0123, (cst_val *)&val_0887},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0124, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9319 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0128, (cst_val *)&val_9320},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0129, (cst_val *)&val_0049},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0130, (cst_val *)&val_0009},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0131, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0132, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9323 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0136, (cst_val *)&val_0232},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0137, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9325 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0140, (cst_val *)&val_0887},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0141, (cst_val *)&val_0045},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0142, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9327 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0145, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9329 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0148, (cst_val *)&val_0003},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0149, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9332 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0153, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9333 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0155, (cst_val *)&val_0932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9334 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0157, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0158, (cst_val *)&val_0887},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0159, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9336 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0162, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9338 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0165, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9339 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0167, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9340 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0169, (cst_val *)&val_9341},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0170, (cst_val *)&val_2968},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9343 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0173, (cst_val *)&val_9344},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0174, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9347 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0178, (cst_val *)&val_0049},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0179, (cst_val *)&val_0038},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0180, (cst_val *)&val_0041},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0181, (cst_val *)&val_9348},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9350 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0184, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9351 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0186, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9353 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0189, (cst_val *)&val_9354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9356 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0192, (cst_val *)&val_0147},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0193, (cst_val *)&val_0003},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0194, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0195, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9358 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0198, (cst_val *)&val_0030},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0199, (cst_val *)&val_9359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9362 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0203, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0204, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9364 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0207, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9366 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0210, (cst_val *)&val_9367},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0211, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0212, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9369 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0215, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9370 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0217, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9372 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0220, (cst_val *)&val_9373},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0221, (cst_val *)&val_9374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9375 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0223, (cst_val *)&val_9376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9377 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0225, (cst_val *)&val_0173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9380 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0229, (cst_val *)&val_0232},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0230, (cst_val *)&val_6804},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0231, (cst_val *)&val_0041},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0232, (cst_val *)&val_1298},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0233, (cst_val *)&val_4589},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9381 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0235, (cst_val *)&val_9382},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9385 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0239, (cst_val *)&val_9386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9387 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0241, (cst_val *)&val_0045},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0242, (cst_val *)&val_0017},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0243, (cst_val *)&val_9388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9390 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0246, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9392 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0249, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9394 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0252, (cst_val *)&val_9395},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0253, (cst_val *)&val_9396},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0254, (cst_val *)&val_9397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9399 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0257, (cst_val *)&val_0003},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0258, (cst_val *)&val_9400},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9402 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0261, (cst_val *)&val_9403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9404 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0263, (cst_val *)&val_9405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9407 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0266, (cst_val *)&val_0065},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0267, (cst_val *)&val_1987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9409 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0270, (cst_val *)&val_9410},
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0271, (cst_val *)&val_0041},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0272, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9411 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0274, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0275, (cst_val *)&val_1808},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0276, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9412 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0278, (cst_val *)&val_9413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9414 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0280, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9416 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0283, (cst_val *)&val_9417},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0284, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9421 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0289, (cst_val *)&val_6722},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9422 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0291, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9424 },
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0294, (cst_val *)&val_1208},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0295, (cst_val *)&val_9425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9427 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0298, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0299, (cst_val *)&val_0882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9429 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0302, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9430 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0304, (cst_val *)&val_9431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9433 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0307, (cst_val *)&val_0147},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0308, (cst_val *)&val_0009},
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0309, (cst_val *)&val_0045},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0310, (cst_val *)&val_9434},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0311, (cst_val *)&val_0049},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0312, (cst_val *)&val_9435},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9437 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0315, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9439 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0318, (cst_val *)&val_9440},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0319, (cst_val *)&val_0003},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0320, (cst_val *)&val_9441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9442 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0322, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9444 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0325, (cst_val *)&val_9386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9445 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0327, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9446 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0329, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9447 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0331, (cst_val *)&val_9448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9450 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0334, (cst_val *)&val_3726},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0335, (cst_val *)&val_9451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9454 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0339, (cst_val *)&val_0526},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0340, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9455 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0342, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9457 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0345, (cst_val *)&val_9458},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0346, (cst_val *)&val_8695},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0347, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9459 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0349, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9461 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0352, (cst_val *)&val_0064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0353, (cst_val *)&val_0017},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0354, (cst_val *)&val_0009},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0355, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9462 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0357, (cst_val *)&val_9374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9464 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0360, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9466 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0363, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9467 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0365, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9468 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0367, (cst_val *)&val_2569},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9470 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0370, (cst_val *)&val_1302},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0371, (cst_val *)&val_0003},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0372, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9473 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0376, (cst_val *)&val_0049},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0377, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9476 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0381, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9477 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0383, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9478 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0385, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9480 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0388, (cst_val *)&val_1177},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0389, (cst_val *)&val_0533},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0390, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9481 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0392, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9483 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0395, (cst_val *)&val_1208},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0396, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9484 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0398, (cst_val *)&val_3954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9486 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0401, (cst_val *)&val_0003},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0402, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9487 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0404, (cst_val *)&val_0003},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0405, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9489 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0408, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9491 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0411, (cst_val *)&val_9492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9493 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0413, (cst_val *)&val_6746},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0414, (cst_val *)&val_9494},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9495 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0416, (cst_val *)&val_9496},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9499 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0420, (cst_val *)&val_9500},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0421, (cst_val *)&val_1420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9502 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0424, (cst_val *)&val_9503},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9504 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0426, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9506 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0429, (cst_val *)&val_9507},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0430, (cst_val *)&val_0045},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0431, (cst_val *)&val_0232},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0432, (cst_val *)&val_0147},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0433, (cst_val *)&val_9508},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9509 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0435, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9512 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0439, (cst_val *)&val_0045},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0440, (cst_val *)&val_6560},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9514 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0443, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9515 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0445, (cst_val *)&val_0533},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0446, (cst_val *)&val_9516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9519 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0450, (cst_val *)&val_9520},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0451, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9521 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0453, (cst_val *)&val_7689},
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0454, (cst_val *)&val_0041},
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0455, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9523 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0458, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9524 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0460, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9525 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0462, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9526 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0464, (cst_val *)&val_9527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9528 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0466, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9530 },
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0469, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9532 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0472, (cst_val *)&val_2435},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0473, (cst_val *)&val_0173},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0474, (cst_val *)&val_0064},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0475, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9533 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0477, (cst_val *)&val_0034},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0478, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9534 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0480, (cst_val *)&val_0003},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0481, (cst_val *)&val_9535},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9539 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0486, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9540 },
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0488, (cst_val *)&val_0045},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0489, (cst_val *)&val_0009},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0490, (cst_val *)&val_0211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9542 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0493, (cst_val *)&val_0003},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0494, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9545 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0498, (cst_val *)&val_0485},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0499, (cst_val *)&val_1146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9548 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0503, (cst_val *)&val_9549},
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0504, (cst_val *)&val_0045},
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0505, (cst_val *)&val_0017},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0506, (cst_val *)&val_9550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9553 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0510, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9554 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0512, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9556 },
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0515, (cst_val *)&val_0041},
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0516, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9558 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0519, (cst_val *)&val_0003},
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0520, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9560 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0523, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9562 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0526, (cst_val *)&val_9563},
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0527, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9564 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0529, (cst_val *)&val_2787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9567 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0533, (cst_val *)&val_9568},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0534, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9569 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0536, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9570 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0538, (cst_val *)&val_9571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9573 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0541, (cst_val *)&val_0017},
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0542, (cst_val *)&val_9574},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0543, (cst_val *)&val_9575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9576 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0545, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9578 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0548, (cst_val *)&val_1770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9580 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0551, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9581 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0553, (cst_val *)&val_9582},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9584 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0556, (cst_val *)&val_9585},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0557, (cst_val *)&val_0147},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0558, (cst_val *)&val_9586},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0559, (cst_val *)&val_9587},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0560, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9588 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0562, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9590 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0565, (cst_val *)&val_9591},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0566, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9594 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0570, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9595 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0572, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9597 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0575, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9598 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0577, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9599 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0579, (cst_val *)&val_0003},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0580, (cst_val *)&val_9600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9602 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0583, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9603 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0585, (cst_val *)&val_1284},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0586, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9604 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0588, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9607 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0592, (cst_val *)&val_0064},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0593, (cst_val *)&val_0116},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0594, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9608 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0596, (cst_val *)&val_0894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9610 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0599, (cst_val *)&val_1924},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0600, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9612 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0603, (cst_val *)&val_9613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9615 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0606, (cst_val *)&val_0009},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0607, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9617 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0610, (cst_val *)&val_0017},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0611, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9619 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0614, (cst_val *)&val_9620},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0615, (cst_val *)&val_9621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9622 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0617, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9624 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0620, (cst_val *)&val_0478},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0621, (cst_val *)&val_0009},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0622, (cst_val *)&val_4789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9626 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0625, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0626, (cst_val *)&val_1924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9628 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_152_NO_0629, (cst_val *)&val_9629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9632 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_s_152_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_s_152_cart = {
  cmu_us_awb_single_mcep_s_152_cart_nodes,
  cmu_us_awb_single_mcep_s_152_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_s_153_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0001, (cst_val *)&val_0002},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0002, (cst_val *)&val_0009},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0003, (cst_val *)&val_0261},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0004, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9635 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0008, (cst_val *)&val_0478},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0009, (cst_val *)&val_0135},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0010, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9638 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0014, (cst_val *)&val_7105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9639 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0016, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0017, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9641 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0020, (cst_val *)&val_6548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9643 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0023, (cst_val *)&val_0130},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0024, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9644 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0026, (cst_val *)&val_2269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9645 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0028, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9646 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0030, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9648 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0033, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9649 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0035, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9651 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0038, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0039, (cst_val *)&val_0077},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0040, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0041, (cst_val *)&val_1963},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0042, (cst_val *)&val_0130},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0043, (cst_val *)&val_9652},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0044, (cst_val *)&val_9653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9654 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0046, (cst_val *)&val_9655},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9658 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0050, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0051, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9661 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0055, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9663 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0058, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9665 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0061, (cst_val *)&val_3133},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0062, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0063, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9667 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0066, (cst_val *)&val_0801},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0067, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9669 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0070, (cst_val *)&val_0043},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0071, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9670 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0073, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9672 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0076, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9674 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0079, (cst_val *)&val_2233},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0080, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9676 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0083, (cst_val *)&val_9677},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9679 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0086, (cst_val *)&val_0797},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0087, (cst_val *)&val_0121},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0088, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0089, (cst_val *)&val_5146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9681 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0092, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9682 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0094, (cst_val *)&val_6548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9684 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0097, (cst_val *)&val_0065},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0098, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9686 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0101, (cst_val *)&val_0953},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0102, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0103, (cst_val *)&val_9687},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9688 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0105, (cst_val *)&val_7370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9690 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0108, (cst_val *)&val_6746},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9692 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0111, (cst_val *)&val_0798},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0112, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9694 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0115, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9695 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0117, (cst_val *)&val_0478},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0118, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9697 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0121, (cst_val *)&val_3211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9699 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0124, (cst_val *)&val_0953},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0125, (cst_val *)&val_9440},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0126, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9702 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0130, (cst_val *)&val_2121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9703 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0132, (cst_val *)&val_5820},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0133, (cst_val *)&val_1090},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0134, (cst_val *)&val_3706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9706 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0138, (cst_val *)&val_0743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9707 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_s_153_NO_0140, (cst_val *)&val_9708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9710 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_s_153_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_awb_single_mcep_s_153_cart = {
  cmu_us_awb_single_mcep_s_153_cart_nodes,
  cmu_us_awb_single_mcep_s_153_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_eh_56_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0000, (cst_val *)&val_0121},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0001, (cst_val *)&val_0232},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0002, (cst_val *)&val_1971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9711 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0004, (cst_val *)&val_0159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9713 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0007, (cst_val *)&val_1551},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0008, (cst_val *)&val_9714},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0009, (cst_val *)&val_3908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9715 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0011, (cst_val *)&val_9716},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9718 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0014, (cst_val *)&val_0525},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0015, (cst_val *)&val_9719},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9722 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0019, (cst_val *)&val_8610},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0020, (cst_val *)&val_9723},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0021, (cst_val *)&val_4896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9724 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0023, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9727 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0027, (cst_val *)&val_1284},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0028, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9729 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0031, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9731 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0034, (cst_val *)&val_0130},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0035, (cst_val *)&val_0147},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0036, (cst_val *)&val_0363},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0037, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9733 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0040, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9734 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0042, (cst_val *)&val_2609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9736 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0045, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9737 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0047, (cst_val *)&val_0073},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0048, (cst_val *)&val_0131},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0049, (cst_val *)&val_9738},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9741 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0053, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9742 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0055, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9744 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0058, (cst_val *)&val_0041},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0059, (cst_val *)&val_9745},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0060, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9747 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0063, (cst_val *)&val_2011},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0064, (cst_val *)&val_9748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9750 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0067, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9752 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0070, (cst_val *)&val_9753},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0071, (cst_val *)&val_1532},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0072, (cst_val *)&val_9754},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0073, (cst_val *)&val_9755},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9756 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0075, (cst_val *)&val_9757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9759 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0078, (cst_val *)&val_2208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9761 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0081, (cst_val *)&val_9762},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0082, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0083, (cst_val *)&val_9763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9764 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0085, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9765 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0087, (cst_val *)&val_0121},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0088, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9767 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0091, (cst_val *)&val_2598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9769 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0094, (cst_val *)&val_0064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0095, (cst_val *)&val_0244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9770 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0097, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9773 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0101, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0102, (cst_val *)&val_9774},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0103, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9777 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0107, (cst_val *)&val_0045},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0108, (cst_val *)&val_9778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9779 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0110, (cst_val *)&val_9780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9782 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0113, (cst_val *)&val_9783},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0114, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9786 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0118, (cst_val *)&val_9787},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0119, (cst_val *)&val_0007},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0120, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9789 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0123, (cst_val *)&val_0363},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0124, (cst_val *)&val_9787},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0125, (cst_val *)&val_6749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9792 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0129, (cst_val *)&val_9793},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0130, (cst_val *)&val_9794},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0131, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9797 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0135, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9798 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0137, (cst_val *)&val_1891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9800 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0140, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0141, (cst_val *)&val_0017},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_56_NO_0142, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9804 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_eh_56_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_awb_single_mcep_eh_56_cart = {
  cmu_us_awb_single_mcep_eh_56_cart_nodes,
  cmu_us_awb_single_mcep_eh_56_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_eh_57_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0001, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0002, (cst_val *)&val_1183},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0003, (cst_val *)&val_0007},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0004, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9806 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0007, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9808 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0010, (cst_val *)&val_0049},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0011, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9810 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0014, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9811 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0016, (cst_val *)&val_5713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9812 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0018, (cst_val *)&val_9813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9816 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0022, (cst_val *)&val_9817},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0023, (cst_val *)&val_1131},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0024, (cst_val *)&val_0872},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0025, (cst_val *)&val_0147},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0026, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9819 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0029, (cst_val *)&val_5842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9820 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0031, (cst_val *)&val_4740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9822 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0034, (cst_val *)&val_1208},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0035, (cst_val *)&val_9823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9825 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0038, (cst_val *)&val_0525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9826 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0040, (cst_val *)&val_1271},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9827 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0042, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9828 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0044, (cst_val *)&val_0061},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0045, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9829 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0047, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9831 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0050, (cst_val *)&val_0017},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0051, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9833 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0054, (cst_val *)&val_0147},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0055, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9835 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0058, (cst_val *)&val_9836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9838 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0061, (cst_val *)&val_6153},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0062, (cst_val *)&val_3806},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0063, (cst_val *)&val_9839},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0064, (cst_val *)&val_0018},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0065, (cst_val *)&val_1081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9841 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0068, (cst_val *)&val_9842},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9844 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0071, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9846 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0074, (cst_val *)&val_9847},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9849 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0077, (cst_val *)&val_0007},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0078, (cst_val *)&val_1424},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0079, (cst_val *)&val_0049},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0080, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9850 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0082, (cst_val *)&val_2442},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0083, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9853 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0087, (cst_val *)&val_9854},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0088, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9856 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0091, (cst_val *)&val_0017},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0092, (cst_val *)&val_1713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9859 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0096, (cst_val *)&val_9860},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0097, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9863 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0101, (cst_val *)&val_6214},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0102, (cst_val *)&val_0121},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0103, (cst_val *)&val_0435},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0104, (cst_val *)&val_3094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9864 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0106, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9866 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0109, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9867 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0111, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9869 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0114, (cst_val *)&val_0045},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0115, (cst_val *)&val_0041},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0116, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9871 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0119, (cst_val *)&val_2451},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0120, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9872 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0122, (cst_val *)&val_2366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9874 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0125, (cst_val *)&val_2361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9875 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0127, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9877 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0130, (cst_val *)&val_0680},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0131, (cst_val *)&val_0615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9879 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0134, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9880 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0136, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9882 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0139, (cst_val *)&val_1207},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0140, (cst_val *)&val_0121},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0141, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0142, (cst_val *)&val_9883},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0143, (cst_val *)&val_9884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9886 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0146, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9888 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0149, (cst_val *)&val_9889},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0150, (cst_val *)&val_9890},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9893 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0154, (cst_val *)&val_0065},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0155, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9895 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0158, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9896 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0160, (cst_val *)&val_0003},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0161, (cst_val *)&val_8051},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0162, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9897 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0164, (cst_val *)&val_9898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9900 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0167, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9901 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0169, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9905 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0174, (cst_val *)&val_0045},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0175, (cst_val *)&val_0007},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0176, (cst_val *)&val_9906},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9908 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0179, (cst_val *)&val_0121},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0180, (cst_val *)&val_0003},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0181, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9910 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0184, (cst_val *)&val_6312},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0185, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9913 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0189, (cst_val *)&val_4296},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0190, (cst_val *)&val_0360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9915 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0193, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9917 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_57_NO_0196, (cst_val *)&val_0757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9919 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_eh_57_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_eh_57_cart = {
  cmu_us_awb_single_mcep_eh_57_cart_nodes,
  cmu_us_awb_single_mcep_eh_57_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_eh_58_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0000, (cst_val *)&val_9920},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0001, (cst_val *)&val_0823},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0002, (cst_val *)&val_0015},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0003, (cst_val *)&val_9921},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9922 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0005, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9924 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0008, (cst_val *)&val_0007},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0009, (cst_val *)&val_4328},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9926 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0012, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9927 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0014, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9928 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0016, (cst_val *)&val_9929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9930 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0018, (cst_val *)&val_6324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9932 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0021, (cst_val *)&val_0065},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0022, (cst_val *)&val_9933},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0023, (cst_val *)&val_0030},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0024, (cst_val *)&val_0878},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0025, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9935 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0028, (cst_val *)&val_9936},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0029, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0030, (cst_val *)&val_0045},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0031, (cst_val *)&val_0049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0032, (cst_val *)&val_1668},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0033, (cst_val *)&val_9937},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9942 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0039, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9943 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0041, (cst_val *)&val_0049},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0042, (cst_val *)&val_9944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9945 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0044, (cst_val *)&val_1049},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0045, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9947 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0048, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9950 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0052, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9952 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0055, (cst_val *)&val_0520},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0056, (cst_val *)&val_0525},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0057, (cst_val *)&val_9953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9955 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0060, (cst_val *)&val_9956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9957 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0062, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9958 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0064, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9959 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0066, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9962 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0070, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9964 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0073, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0074, (cst_val *)&val_0121},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0075, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9966 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0078, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9968 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0081, (cst_val *)&val_1271},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0082, (cst_val *)&val_0680},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0083, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9970 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0086, (cst_val *)&val_9971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9973 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0089, (cst_val *)&val_9974},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0090, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9975 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0092, (cst_val *)&val_9976},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0093, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9977 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0095, (cst_val *)&val_9978},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0096, (cst_val *)&val_9979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9980 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0098, (cst_val *)&val_9981},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0099, (cst_val *)&val_0448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9984 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0103, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9985 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0105, (cst_val *)&val_9986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9988 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0108, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9989 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0110, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0111, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9991 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0114, (cst_val *)&val_1507},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0115, (cst_val *)&val_1049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0116, (cst_val *)&val_9992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9996 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0121, (cst_val *)&val_0045},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0122, (cst_val *)&val_9997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9998 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0124, (cst_val *)&val_0153},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0125, (cst_val *)&val_0179},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10001 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0129, (cst_val *)&val_10002},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0130, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10004 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0133, (cst_val *)&val_10005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10007 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0136, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0137, (cst_val *)&val_0017},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0138, (cst_val *)&val_0952},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0139, (cst_val *)&val_7468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10008 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0141, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10010 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0144, (cst_val *)&val_1763},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0145, (cst_val *)&val_7468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10011 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0147, (cst_val *)&val_10012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10015 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0151, (cst_val *)&val_0520},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0152, (cst_val *)&val_0525},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0153, (cst_val *)&val_6603},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0154, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10016 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0156, (cst_val *)&val_0952},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0157, (cst_val *)&val_10017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10019 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0160, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10020 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0162, (cst_val *)&val_0485},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0163, (cst_val *)&val_10021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10025 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0168, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10026 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0170, (cst_val *)&val_2133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10028 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0173, (cst_val *)&val_0494},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0174, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10029 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0176, (cst_val *)&val_9007},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0177, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10031 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0180, (cst_val *)&val_3862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10033 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0183, (cst_val *)&val_0129},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0184, (cst_val *)&val_0823},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0185, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10034 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0187, (cst_val *)&val_10035},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0188, (cst_val *)&val_10036},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0189, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10040 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0194, (cst_val *)&val_0065},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0195, (cst_val *)&val_0672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10042 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0198, (cst_val *)&val_1298},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0199, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10045 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0203, (cst_val *)&val_0064},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0204, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10048 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0208, (cst_val *)&val_10049},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0209, (cst_val *)&val_10050},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0210, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10052 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0213, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10054 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0216, (cst_val *)&val_0073},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0217, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10056 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_eh_58_NO_0220, (cst_val *)&val_0300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10058 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_eh_58_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_awb_single_mcep_eh_58_cart = {
  cmu_us_awb_single_mcep_eh_58_cart_nodes,
  cmu_us_awb_single_mcep_eh_58_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_t_164_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0001, (cst_val *)&val_0533},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0002, (cst_val *)&val_0743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10059 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0004, (cst_val *)&val_0967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10060 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0006, (cst_val *)&val_0672},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0007, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10062 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0010, (cst_val *)&val_2325},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0011, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10065 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0015, (cst_val *)&val_0017},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0016, (cst_val *)&val_0049},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0017, (cst_val *)&val_10066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10069 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0021, (cst_val *)&val_7465},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0022, (cst_val *)&val_10070},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0023, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10071 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0025, (cst_val *)&val_1424},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0026, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10072 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0028, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10074 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0031, (cst_val *)&val_0041},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0032, (cst_val *)&val_10075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10078 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0036, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10080 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0039, (cst_val *)&val_0658},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0040, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10081 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0042, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10083 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0045, (cst_val *)&val_4393},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0046, (cst_val *)&val_0498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10086 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0050, (cst_val *)&val_0373},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0051, (cst_val *)&val_0065},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0052, (cst_val *)&val_1131},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0053, (cst_val *)&val_2448},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0054, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10088 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0057, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10091 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0061, (cst_val *)&val_0003},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0062, (cst_val *)&val_0045},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0063, (cst_val *)&val_0232},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0064, (cst_val *)&val_0085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10093 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0067, (cst_val *)&val_4517},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0068, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10095 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0071, (cst_val *)&val_10096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10097 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0073, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10099 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0076, (cst_val *)&val_0085},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0077, (cst_val *)&val_0130},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0078, (cst_val *)&val_2083},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10100 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0080, (cst_val *)&val_0009},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0081, (cst_val *)&val_10101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10103 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0084, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10105 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0087, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10106 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0089, (cst_val *)&val_0077},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0090, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10109 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0094, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10110 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0096, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10111 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0098, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10112 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0100, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10114 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0103, (cst_val *)&val_0121},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0104, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10116 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0107, (cst_val *)&val_2958},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10118 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0110, (cst_val *)&val_1769},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0111, (cst_val *)&val_10119},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0112, (cst_val *)&val_10120},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0113, (cst_val *)&val_0065},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0114, (cst_val *)&val_10121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10123 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0117, (cst_val *)&val_0015},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0118, (cst_val *)&val_0049},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0119, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10126 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0123, (cst_val *)&val_1387},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0124, (cst_val *)&val_0045},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0125, (cst_val *)&val_10127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10129 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0128, (cst_val *)&val_2052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10132 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0132, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0133, (cst_val *)&val_3002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10134 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0136, (cst_val *)&val_2060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10135 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0138, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10136 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0140, (cst_val *)&val_0045},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0141, (cst_val *)&val_10137},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0142, (cst_val *)&val_1356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10140 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0146, (cst_val *)&val_7105},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0147, (cst_val *)&val_0147},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0148, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10143 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0152, (cst_val *)&val_10144},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0153, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10147 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0157, (cst_val *)&val_0065},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0158, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10149 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0161, (cst_val *)&val_10150},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0162, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10152 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0165, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10153 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0167, (cst_val *)&val_0003},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0168, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10156 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0172, (cst_val *)&val_0045},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0173, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10157 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0175, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0176, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10159 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0179, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10161 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0182, (cst_val *)&val_2083},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0183, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10163 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0186, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10164 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0188, (cst_val *)&val_10165},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0189, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10167 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0192, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10168 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0194, (cst_val *)&val_1208},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0195, (cst_val *)&val_10169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10171 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0198, (cst_val *)&val_10172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10173 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_164_NO_0200, (cst_val *)&val_5156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10175 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_t_164_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_awb_single_mcep_t_164_cart = {
  cmu_us_awb_single_mcep_t_164_cart_nodes,
  cmu_us_awb_single_mcep_t_164_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_t_165_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0000, (cst_val *)&val_0525},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0001, (cst_val *)&val_2366},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0002, (cst_val *)&val_0017},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0003, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10176 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0005, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10177 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0007, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0008, (cst_val *)&val_0068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10179 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0011, (cst_val *)&val_10180},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10182 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0014, (cst_val *)&val_0073},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0015, (cst_val *)&val_0049},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0016, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10183 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0018, (cst_val *)&val_0887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10184 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0020, (cst_val *)&val_10185},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0021, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10188 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0025, (cst_val *)&val_0003},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0026, (cst_val *)&val_0121},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0027, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10190 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0030, (cst_val *)&val_7103},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0031, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10193 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0035, (cst_val *)&val_10194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10196 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0038, (cst_val *)&val_10127},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0039, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10197 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0041, (cst_val *)&val_10198},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0042, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0043, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10202 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0048, (cst_val *)&val_8810},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0049, (cst_val *)&val_0887},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0050, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10204 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0053, (cst_val *)&val_10205},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0054, (cst_val *)&val_10206},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10209 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0058, (cst_val *)&val_10210},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0059, (cst_val *)&val_0303},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0060, (cst_val *)&val_0116},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0061, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10211 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0063, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10212 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0065, (cst_val *)&val_10213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10215 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0068, (cst_val *)&val_10216},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0069, (cst_val *)&val_10217},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0070, (cst_val *)&val_0147},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0071, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10218 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0073, (cst_val *)&val_10219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10222 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0077, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10223 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0079, (cst_val *)&val_7826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10226 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0083, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10228 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0086, (cst_val *)&val_0085},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0087, (cst_val *)&val_10229},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0088, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10230 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0090, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10232 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0093, (cst_val *)&val_0543},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0094, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0095, (cst_val *)&val_2119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10233 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0097, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10235 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0100, (cst_val *)&val_2101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10237 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0103, (cst_val *)&val_10238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10239 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0105, (cst_val *)&val_10240},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10241 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0107, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10243 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0110, (cst_val *)&val_0003},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0111, (cst_val *)&val_10244},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0112, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10245 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0114, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10246 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0116, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10247 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0118, (cst_val *)&val_0474},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10248 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0120, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10251 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0124, (cst_val *)&val_10252},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0125, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10253 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0127, (cst_val *)&val_0009},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0128, (cst_val *)&val_1741},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0129, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10255 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0132, (cst_val *)&val_0330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10257 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0135, (cst_val *)&val_1402},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0136, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10258 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0138, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10261 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0142, (cst_val *)&val_6476},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10262 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0144, (cst_val *)&val_10263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10265 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0147, (cst_val *)&val_10266},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0148, (cst_val *)&val_0526},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0149, (cst_val *)&val_10267},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0150, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10269 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0153, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0154, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10272 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0158, (cst_val *)&val_3032},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0159, (cst_val *)&val_10273},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0160, (cst_val *)&val_1336},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0161, (cst_val *)&val_10274},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0162, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10277 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0166, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10278 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0168, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10279 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0170, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0171, (cst_val *)&val_10280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10282 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0174, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10284 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0177, (cst_val *)&val_10285},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0178, (cst_val *)&val_10286},
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0179, (cst_val *)&val_0402},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10288 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0182, (cst_val *)&val_0003},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0183, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10289 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0185, (cst_val *)&val_6228},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0186, (cst_val *)&val_10290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10295 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0192, (cst_val *)&val_0041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0193, (cst_val *)&val_0725},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0194, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10296 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0196, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10297 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0198, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10298 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0200, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10300 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0203, (cst_val *)&val_0028},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0204, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10302 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0207, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10303 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0209, (cst_val *)&val_10304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10305 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0211, (cst_val *)&val_10306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10307 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0213, (cst_val *)&val_1263},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10309 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0216, (cst_val *)&val_0131},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0217, (cst_val *)&val_10310},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0218, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10314 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0223, (cst_val *)&val_0045},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0224, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10315 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0226, (cst_val *)&val_10316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10318 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0229, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10319 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0231, (cst_val *)&val_0316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10320 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0233, (cst_val *)&val_0612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10322 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0236, (cst_val *)&val_1365},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0237, (cst_val *)&val_10323},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0238, (cst_val *)&val_7072},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0239, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10324 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0241, (cst_val *)&val_0261},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0242, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10326 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0245, (cst_val *)&val_0129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10327 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0247, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10329 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0250, (cst_val *)&val_10330},
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0251, (cst_val *)&val_0064},
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0252, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10331 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0254, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10333 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0257, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10334 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0259, (cst_val *)&val_10335},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0260, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10336 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0262, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10339 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0266, (cst_val *)&val_0131},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0267, (cst_val *)&val_3706},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0268, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10342 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0272, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0273, (cst_val *)&val_2999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10345 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0277, (cst_val *)&val_0049},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0278, (cst_val *)&val_0316},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0279, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10347 },
{ 38, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0282, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10348 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0284, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10349 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0286, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10350 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0288, (cst_val *)&val_10351},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10353 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0291, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10354 },
{ 39, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0293, (cst_val *)&val_0003},
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0294, (cst_val *)&val_0402},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0295, (cst_val *)&val_10355},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0296, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10359 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0301, (cst_val *)&val_10360},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10362 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0304, (cst_val *)&val_0073},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0305, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10364 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0308, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10365 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0310, (cst_val *)&val_0147},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0311, (cst_val *)&val_7264},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0312, (cst_val *)&val_0041},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0313, (cst_val *)&val_10366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10370 },
{ 37, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0318, (cst_val *)&val_0017},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0319, (cst_val *)&val_10371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10373 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0322, (cst_val *)&val_10374},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0323, (cst_val *)&val_10375},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0324, (cst_val *)&val_2988},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10378 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0328, (cst_val *)&val_10379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10380 },
{ 40, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_165_NO_0330, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10382 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_t_165_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_awb_single_mcep_t_165_cart = {
  cmu_us_awb_single_mcep_t_165_cart_nodes,
  cmu_us_awb_single_mcep_t_165_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_t_166_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0000, (cst_val *)&val_10383},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0001, (cst_val *)&val_10384},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0002, (cst_val *)&val_9249},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0003, (cst_val *)&val_0864},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0004, (cst_val *)&val_1955},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0005, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0006, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10385 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0008, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10387 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0011, (cst_val *)&val_2269},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0012, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10389 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0015, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0016, (cst_val *)&val_0909},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0017, (cst_val *)&val_3706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10390 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0019, (cst_val *)&val_0637},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0020, (cst_val *)&val_0261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10394 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0025, (cst_val *)&val_1506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10396 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0028, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10397 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0030, (cst_val *)&val_2442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10398 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0032, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10400 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0035, (cst_val *)&val_0045},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0036, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10402 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0039, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0040, (cst_val *)&val_0009},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0041, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10404 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0044, (cst_val *)&val_4920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10405 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0046, (cst_val *)&val_1336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10407 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0049, (cst_val *)&val_0953},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0050, (cst_val *)&val_0175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10410 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0054, (cst_val *)&val_0064},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0055, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10411 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0057, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10413 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0060, (cst_val *)&val_1208},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0061, (cst_val *)&val_1702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10415 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0064, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10416 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0066, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10417 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0068, (cst_val *)&val_2020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10418 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0070, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10419 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0072, (cst_val *)&val_0980},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0073, (cst_val *)&val_10420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10421 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0075, (cst_val *)&val_10422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10423 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0077, (cst_val *)&val_10424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10426 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0080, (cst_val *)&val_0622},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10427 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0082, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0083, (cst_val *)&val_10428},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10431 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0087, (cst_val *)&val_0823},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0088, (cst_val *)&val_10432},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0089, (cst_val *)&val_2787},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0090, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10434 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10435 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0094, (cst_val *)&val_0980},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0095, (cst_val *)&val_10436},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0096, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10437 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0098, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10439 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0101, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10441 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0104, (cst_val *)&val_10442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10443 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0106, (cst_val *)&val_10444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10446 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0109, (cst_val *)&val_1153},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0110, (cst_val *)&val_0077},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0111, (cst_val *)&val_10447},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0112, (cst_val *)&val_0041},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0113, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10448 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0115, (cst_val *)&val_0147},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0116, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10450 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0119, (cst_val *)&val_0033},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0120, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10454 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0125, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10456 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0128, (cst_val *)&val_0175},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0129, (cst_val *)&val_0045},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0130, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10458 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0133, (cst_val *)&val_0399},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0134, (cst_val *)&val_0073},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0135, (cst_val *)&val_0856},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10459 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0137, (cst_val *)&val_10460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10462 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0140, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0141, (cst_val *)&val_1208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10464 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0144, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0145, (cst_val *)&val_0185},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0146, (cst_val *)&val_0009},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0147, (cst_val *)&val_2451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10468 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0152, (cst_val *)&val_0904},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0153, (cst_val *)&val_10469},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10470 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0155, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0156, (cst_val *)&val_0622},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0157, (cst_val *)&val_2269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10475 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0163, (cst_val *)&val_10476},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0164, (cst_val *)&val_6464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10478 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0167, (cst_val *)&val_0478},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0168, (cst_val *)&val_10479},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0169, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10480 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0171, (cst_val *)&val_0673},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0172, (cst_val *)&val_0049},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0173, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10484 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0178, (cst_val *)&val_1345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10485 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0180, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10488 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0184, (cst_val *)&val_0402},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0185, (cst_val *)&val_0147},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0186, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10489 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0188, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10492 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0192, (cst_val *)&val_10493},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10495 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0195, (cst_val *)&val_0045},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0196, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10496 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0198, (cst_val *)&val_0933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10498 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0201, (cst_val *)&val_0009},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0202, (cst_val *)&val_0009},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0203, (cst_val *)&val_1642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10499 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0205, (cst_val *)&val_0909},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0206, (cst_val *)&val_10500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10502 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0209, (cst_val *)&val_1292},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0210, (cst_val *)&val_0739},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10505 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0214, (cst_val *)&val_0009},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0215, (cst_val *)&val_10506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10507 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0217, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10510 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0221, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0222, (cst_val *)&val_10511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10513 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0225, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0226, (cst_val *)&val_10514},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10515 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0228, (cst_val *)&val_10516},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0229, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10519 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0233, (cst_val *)&val_1459},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0234, (cst_val *)&val_10520},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0235, (cst_val *)&val_0147},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0236, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10522 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0239, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0240, (cst_val *)&val_2896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10524 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0243, (cst_val *)&val_0065},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0244, (cst_val *)&val_10525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10527 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0247, (cst_val *)&val_10528},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0248, (cst_val *)&val_0049},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0249, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10532 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0254, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10533 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0256, (cst_val *)&val_7591},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0257, (cst_val *)&val_10534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10536 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0260, (cst_val *)&val_2097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10537 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0262, (cst_val *)&val_10538},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0263, (cst_val *)&val_1963},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0264, (cst_val *)&val_4920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10540 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0267, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10541 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0269, (cst_val *)&val_0041},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0270, (cst_val *)&val_2297},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10544 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0274, (cst_val *)&val_7162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10546 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0277, (cst_val *)&val_6671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10548 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0280, (cst_val *)&val_0147},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0281, (cst_val *)&val_7072},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0282, (cst_val *)&val_0073},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0283, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10549 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0285, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10551 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0288, (cst_val *)&val_0797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10552 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0290, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10554 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0293, (cst_val *)&val_2458},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0294, (cst_val *)&val_0953},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10556 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0297, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10557 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0299, (cst_val *)&val_0953},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0300, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10558 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0302, (cst_val *)&val_0278},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0303, (cst_val *)&val_2116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10562 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0308, (cst_val *)&val_0525},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0309, (cst_val *)&val_0147},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0310, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10563 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0312, (cst_val *)&val_10564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10565 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0314, (cst_val *)&val_3015},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0315, (cst_val *)&val_10566},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0316, (cst_val *)&val_0009},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0317, (cst_val *)&val_10567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10569 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0320, (cst_val *)&val_2208},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0321, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10572 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0325, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10575 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0329, (cst_val *)&val_0064},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0330, (cst_val *)&val_6548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10577 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0333, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10579 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0336, (cst_val *)&val_0130},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0337, (cst_val *)&val_0085},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0338, (cst_val *)&val_10580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10583 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0342, (cst_val *)&val_0045},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0343, (cst_val *)&val_5383},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0344, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10584 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0346, (cst_val *)&val_10585},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10587 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0349, (cst_val *)&val_2269},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0350, (cst_val *)&val_10588},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0351, (cst_val *)&val_7591},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0352, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10592 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0357, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0358, (cst_val *)&val_2020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10593 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0360, (cst_val *)&val_1423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10594 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0362, (cst_val *)&val_0402},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0363, (cst_val *)&val_10595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10598 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0367, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10599 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0369, (cst_val *)&val_10600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10601 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0371, (cst_val *)&val_0116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10603 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0374, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10604 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0376, (cst_val *)&val_0823},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_t_166_NO_0377, (cst_val *)&val_0980},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10607 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_t_166_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_awb_single_mcep_t_166_cart = {
  cmu_us_awb_single_mcep_t_166_cart_nodes,
  cmu_us_awb_single_mcep_t_166_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_er_61_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0000, (cst_val *)&val_10608},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0001, (cst_val *)&val_0147},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0002, (cst_val *)&val_10609},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0003, (cst_val *)&val_0672},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0004, (cst_val *)&val_10610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10612 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0007, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0008, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10615 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0012, (cst_val *)&val_0691},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10616 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0014, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10617 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0016, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10618 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0018, (cst_val *)&val_0840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10620 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0021, (cst_val *)&val_1276},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0022, (cst_val *)&val_0049},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0023, (cst_val *)&val_10621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10624 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0027, (cst_val *)&val_10625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10626 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0029, (cst_val *)&val_0232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0030, (cst_val *)&val_10627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10629 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0033, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10630 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0035, (cst_val *)&val_9159},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0036, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10632 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0039, (cst_val *)&val_1518},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10633 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0041, (cst_val *)&val_0011},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0042, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10635 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0045, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10637 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0048, (cst_val *)&val_0027},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0049, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0050, (cst_val *)&val_2451},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0051, (cst_val *)&val_0077},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0052, (cst_val *)&val_7629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10639 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0055, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10641 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0058, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10642 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0060, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10643 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0062, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10645 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0065, (cst_val *)&val_1276},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0066, (cst_val *)&val_10646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10648 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0069, (cst_val *)&val_10649},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0070, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0071, (cst_val *)&val_0003},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0072, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10650 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0074, (cst_val *)&val_0147},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0075, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10651 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0077, (cst_val *)&val_0340},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10653 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0080, (cst_val *)&val_2609},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0081, (cst_val *)&val_10654},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10656 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0084, (cst_val *)&val_0077},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0085, (cst_val *)&val_0726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10660 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0090, (cst_val *)&val_10661},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0091, (cst_val *)&val_10662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10664 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0094, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10665 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0096, (cst_val *)&val_10666},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10667 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0098, (cst_val *)&val_10668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10671 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0102, (cst_val *)&val_0350},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0103, (cst_val *)&val_1459},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0104, (cst_val *)&val_9440},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0105, (cst_val *)&val_1387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10673 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0108, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10674 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0110, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0111, (cst_val *)&val_0017},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0112, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10675 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0114, (cst_val *)&val_10676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10679 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0118, (cst_val *)&val_1052},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10680 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0120, (cst_val *)&val_9159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10682 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0123, (cst_val *)&val_6306},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0124, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10683 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0126, (cst_val *)&val_0637},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0127, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10685 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0130, (cst_val *)&val_10686},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10688 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0133, (cst_val *)&val_0003},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0134, (cst_val *)&val_10689},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10692 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0138, (cst_val *)&val_0049},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0139, (cst_val *)&val_10693},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0140, (cst_val *)&val_0003},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0141, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10695 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0144, (cst_val *)&val_10696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10699 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0148, (cst_val *)&val_0065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10700 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0150, (cst_val *)&val_8926},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0151, (cst_val *)&val_1459},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0152, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10701 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_61_NO_0154, (cst_val *)&val_2116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10705 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_er_61_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_awb_single_mcep_er_61_cart = {
  cmu_us_awb_single_mcep_er_61_cart_nodes,
  cmu_us_awb_single_mcep_er_61_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_er_62_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0000, (cst_val *)&val_0380},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0001, (cst_val *)&val_0232},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0002, (cst_val *)&val_0003},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0003, (cst_val *)&val_0578},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0004, (cst_val *)&val_4651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10707 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0007, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10709 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0010, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10710 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0012, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10712 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0015, (cst_val *)&val_0578},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0016, (cst_val *)&val_0065},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0017, (cst_val *)&val_10713},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0018, (cst_val *)&val_2049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10716 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0022, (cst_val *)&val_10717},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0023, (cst_val *)&val_0045},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0024, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10718 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0026, (cst_val *)&val_0673},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10720 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0029, (cst_val *)&val_1987},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0030, (cst_val *)&val_1131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10721 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0032, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10722 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0034, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10724 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0037, (cst_val *)&val_0012},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0038, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10726 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0041, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10727 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0043, (cst_val *)&val_10728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10730 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0046, (cst_val *)&val_0147},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0047, (cst_val *)&val_0967},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0048, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10732 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0051, (cst_val *)&val_10733},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0052, (cst_val *)&val_10734},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10736 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0055, (cst_val *)&val_0077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10738 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0058, (cst_val *)&val_0017},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0059, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10740 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0062, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10741 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0064, (cst_val *)&val_10742},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0065, (cst_val *)&val_5883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10745 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0069, (cst_val *)&val_10746},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0070, (cst_val *)&val_10747},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0071, (cst_val *)&val_4133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10749 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0074, (cst_val *)&val_0003},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0075, (cst_val *)&val_0045},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0076, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10751 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0079, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10754 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0083, (cst_val *)&val_0045},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0084, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10756 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0087, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0088, (cst_val *)&val_10757},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10760 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0092, (cst_val *)&val_0232},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0093, (cst_val *)&val_0045},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0094, (cst_val *)&val_0048},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0095, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0096, (cst_val *)&val_10761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10764 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0100, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10766 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0103, (cst_val *)&val_10767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10768 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0105, (cst_val *)&val_5587},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0106, (cst_val *)&val_0526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10769 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0108, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10770 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0110, (cst_val *)&val_10771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10773 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0113, (cst_val *)&val_10774},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0114, (cst_val *)&val_1783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10776 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0117, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10777 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0119, (cst_val *)&val_0030},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0120, (cst_val *)&val_10778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10781 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0124, (cst_val *)&val_0003},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0125, (cst_val *)&val_0147},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0126, (cst_val *)&val_1808},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0127, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0128, (cst_val *)&val_10782},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10784 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0131, (cst_val *)&val_3392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10786 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0134, (cst_val *)&val_0878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10787 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0136, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10788 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0138, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10790 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0141, (cst_val *)&val_0211},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0142, (cst_val *)&val_10791},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0143, (cst_val *)&val_10792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10794 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0146, (cst_val *)&val_0660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10796 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0149, (cst_val *)&val_0009},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0150, (cst_val *)&val_10797},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0151, (cst_val *)&val_7306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10799 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0154, (cst_val *)&val_10800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10801 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0156, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10804 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0160, (cst_val *)&val_10805},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0161, (cst_val *)&val_10806},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0162, (cst_val *)&val_4777},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0163, (cst_val *)&val_0147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10808 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0166, (cst_val *)&val_10809},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10811 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0169, (cst_val *)&val_0154},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0170, (cst_val *)&val_10812},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0171, (cst_val *)&val_2977},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10813 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0173, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10815 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0176, (cst_val *)&val_10816},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0177, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10818 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0180, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10820 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0183, (cst_val *)&val_10821},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0184, (cst_val *)&val_0064},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0185, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10823 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0188, (cst_val *)&val_0658},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0189, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10826 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0193, (cst_val *)&val_0017},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0194, (cst_val *)&val_0073},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0195, (cst_val *)&val_10827},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10830 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0199, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10831 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0201, (cst_val *)&val_10832},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0202, (cst_val *)&val_10767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10833 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0204, (cst_val *)&val_0025},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0205, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10836 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0209, (cst_val *)&val_10837},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0210, (cst_val *)&val_0064},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0211, (cst_val *)&val_0131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10841 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0216, (cst_val *)&val_0003},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0217, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10842 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0219, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10843 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0221, (cst_val *)&val_10844},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10846 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0224, (cst_val *)&val_0045},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0225, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10848 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_62_NO_0228, (cst_val *)&val_10849},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10851 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_er_62_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
NULL };

const cst_cart cmu_us_awb_single_mcep_er_62_cart = {
  cmu_us_awb_single_mcep_er_62_cart_nodes,
  cmu_us_awb_single_mcep_er_62_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_er_63_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0001, (cst_val *)&val_10852},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0002, (cst_val *)&val_0235},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0003, (cst_val *)&val_10853},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10854 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0005, (cst_val *)&val_0041},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0006, (cst_val *)&val_0953},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0007, (cst_val *)&val_8946},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0008, (cst_val *)&val_4051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10857 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0012, (cst_val *)&val_10858},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10860 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0015, (cst_val *)&val_6548},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0016, (cst_val *)&val_7761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10863 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0020, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10865 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0023, (cst_val *)&val_10866},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0024, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0025, (cst_val *)&val_7306},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10867 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0027, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10868 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0029, (cst_val *)&val_0613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10869 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0031, (cst_val *)&val_6215},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10870 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0033, (cst_val *)&val_10871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10873 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0036, (cst_val *)&val_10874},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0037, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10876 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0040, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10877 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0042, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10878 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0044, (cst_val *)&val_10879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10881 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0047, (cst_val *)&val_6221},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0048, (cst_val *)&val_10816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10883 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0051, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10885 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0054, (cst_val *)&val_0065},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0055, (cst_val *)&val_1971},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0056, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0057, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10887 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0060, (cst_val *)&val_0798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10888 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0062, (cst_val *)&val_10889},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10891 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0065, (cst_val *)&val_10892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10893 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0067, (cst_val *)&val_0992},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10895 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0070, (cst_val *)&val_1090},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0071, (cst_val *)&val_1424},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0072, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10898 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0076, (cst_val *)&val_0003},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0077, (cst_val *)&val_1088},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0078, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10900 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0081, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10901 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0083, (cst_val *)&val_0021},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0084, (cst_val *)&val_0530},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0085, (cst_val *)&val_0144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10903 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0088, (cst_val *)&val_0247},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10906 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0092, (cst_val *)&val_4920},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0093, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0094, (cst_val *)&val_10907},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0095, (cst_val *)&val_4963},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0096, (cst_val *)&val_0130},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10911 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0101, (cst_val *)&val_0017},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0102, (cst_val *)&val_0725},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0103, (cst_val *)&val_10907},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10914 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0107, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0108, (cst_val *)&val_0725},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0109, (cst_val *)&val_0185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10917 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0113, (cst_val *)&val_2133},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0114, (cst_val *)&val_10918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10919 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0116, (cst_val *)&val_10920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10922 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0119, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10924 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0122, (cst_val *)&val_0017},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0123, (cst_val *)&val_10925},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0124, (cst_val *)&val_10926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10928 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0127, (cst_val *)&val_10929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10931 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0130, (cst_val *)&val_0373},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0131, (cst_val *)&val_0003},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0132, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10934 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0136, (cst_val *)&val_0045},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0137, (cst_val *)&val_7892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10935 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0139, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10936 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0141, (cst_val *)&val_10937},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0142, (cst_val *)&val_3806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10940 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_er_63_NO_0146, (cst_val *)&val_0375},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10942 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_er_63_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_er_63_cart = {
  cmu_us_awb_single_mcep_er_63_cart_nodes,
  cmu_us_awb_single_mcep_er_63_feat_table
};

static const cst_cart_node cmu_us_awb_single_mcep_ax_26_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0000, (cst_val *)&val_0147},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0001, (cst_val *)&val_0261},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0003, (cst_val *)&val_10943},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0004, (cst_val *)&val_7591},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0005, (cst_val *)&val_10944},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0006, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10947 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0010, (cst_val *)&val_0000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10948 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0012, (cst_val *)&val_4517},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0013, (cst_val *)&val_10949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10952 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0017, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10954 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0020, (cst_val *)&val_7938},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0021, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10956 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0024, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10957 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0026, (cst_val *)&val_3232},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0027, (cst_val *)&val_1561},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10959 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0030, (cst_val *)&val_0533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10961 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0033, (cst_val *)&val_0064},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0034, (cst_val *)&val_1292},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0035, (cst_val *)&val_7591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10963 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0038, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10964 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0040, (cst_val *)&val_7591},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0041, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10966 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0044, (cst_val *)&val_10967},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0045, (cst_val *)&val_7433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10970 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0049, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10971 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0051, (cst_val *)&val_6364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10972 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0053, (cst_val *)&val_0909},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10974 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0056, (cst_val *)&val_0525},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0057, (cst_val *)&val_0045},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0058, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10976 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0061, (cst_val *)&val_0849},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0062, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10977 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0064, (cst_val *)&val_0650},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0065, (cst_val *)&val_0045},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0066, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10978 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0068, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10980 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0071, (cst_val *)&val_10981},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0072, (cst_val *)&val_3006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10983 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0075, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10985 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0078, (cst_val *)&val_10986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10987 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0080, (cst_val *)&val_10988},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10990 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0083, (cst_val *)&val_10991},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0084, (cst_val *)&val_6115},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0085, (cst_val *)&val_0041},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0086, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10993 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0089, (cst_val *)&val_10994},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0090, (cst_val *)&val_2787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10996 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0093, (cst_val *)&val_1518},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0094, (cst_val *)&val_10997},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10999 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0097, (cst_val *)&val_1131},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0098, (cst_val *)&val_11000},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11003 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0102, (cst_val *)&val_0204},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0103, (cst_val *)&val_11004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11006 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0106, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11009 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0110, (cst_val *)&val_11010},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0111, (cst_val *)&val_0360},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0112, (cst_val *)&val_0147},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0113, (cst_val *)&val_11011},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0114, (cst_val *)&val_0073},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0115, (cst_val *)&val_5260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11013 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0118, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11015 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0121, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11017 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0124, (cst_val *)&val_11018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0125, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11019 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0127, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11020 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0129, (cst_val *)&val_0073},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0130, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11021 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0132, (cst_val *)&val_11022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11024 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0135, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11025 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0137, (cst_val *)&val_0003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11027 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0140, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11028 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0142, (cst_val *)&val_1292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11030 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0145, (cst_val *)&val_11031},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0146, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11033 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0149, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11034 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0151, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11036 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0154, (cst_val *)&val_11037},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0155, (cst_val *)&val_0045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11038 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0157, (cst_val *)&val_1518},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0158, (cst_val *)&val_11039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11041 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0161, (cst_val *)&val_0130},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_awb_single_mcep_ax_26_NO_0162, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11045 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_awb_single_mcep_ax_26_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_awb_single_mcep_ax_26_cart = {
  cmu_us_awb_single_mcep_ax_26_cart_nodes,
  cmu_us_awb_single_mcep_ax_26_feat_table
};


const cst_cart * const cmu_us_awb_single_mcep_carts[] = {
 &cmu_us_awb_single_mcep_zh_204_cart,
 &cmu_us_awb_single_mcep_zh_205_cart,
 &cmu_us_awb_single_mcep_zh_206_cart,
 &cmu_us_awb_single_mcep_oy_131_cart,
 &cmu_us_awb_single_mcep_oy_132_cart,
 &cmu_us_awb_single_mcep_oy_133_cart,
 &cmu_us_awb_single_mcep_ch_41_cart,
 &cmu_us_awb_single_mcep_ch_42_cart,
 &cmu_us_awb_single_mcep_ch_43_cart,
 &cmu_us_awb_single_mcep_aw_21_cart,
 &cmu_us_awb_single_mcep_aw_22_cart,
 &cmu_us_awb_single_mcep_aw_23_cart,
 &cmu_us_awb_single_mcep_ow_126_cart,
 &cmu_us_awb_single_mcep_ow_127_cart,
 &cmu_us_awb_single_mcep_ow_128_cart,
 &cmu_us_awb_single_mcep_b_36_cart,
 &cmu_us_awb_single_mcep_b_37_cart,
 &cmu_us_awb_single_mcep_b_38_cart,
 &cmu_us_awb_single_mcep_g_76_cart,
 &cmu_us_awb_single_mcep_g_77_cart,
 &cmu_us_awb_single_mcep_g_78_cart,
 &cmu_us_awb_single_mcep_ng_121_cart,
 &cmu_us_awb_single_mcep_ng_122_cart,
 &cmu_us_awb_single_mcep_ng_123_cart,
 &cmu_us_awb_single_mcep_uw_179_cart,
 &cmu_us_awb_single_mcep_uw_180_cart,
 &cmu_us_awb_single_mcep_uw_181_cart,
 &cmu_us_awb_single_mcep_sh_156_cart,
 &cmu_us_awb_single_mcep_sh_157_cart,
 &cmu_us_awb_single_mcep_sh_158_cart,
 &cmu_us_awb_single_mcep_uh_174_cart,
 &cmu_us_awb_single_mcep_uh_175_cart,
 &cmu_us_awb_single_mcep_uh_176_cart,
 &cmu_us_awb_single_mcep_hh_81_cart,
 &cmu_us_awb_single_mcep_hh_82_cart,
 &cmu_us_awb_single_mcep_hh_83_cart,
 &cmu_us_awb_single_mcep_ae_6_cart,
 &cmu_us_awb_single_mcep_ae_7_cart,
 &cmu_us_awb_single_mcep_ae_8_cart,
 &cmu_us_awb_single_mcep_y_194_cart,
 &cmu_us_awb_single_mcep_y_195_cart,
 &cmu_us_awb_single_mcep_y_196_cart,
 &cmu_us_awb_single_mcep_k_101_cart,
 &cmu_us_awb_single_mcep_k_102_cart,
 &cmu_us_awb_single_mcep_k_103_cart,
 &cmu_us_awb_single_mcep_aa_1_cart,
 &cmu_us_awb_single_mcep_aa_2_cart,
 &cmu_us_awb_single_mcep_aa_3_cart,
 &cmu_us_awb_single_mcep_ay_31_cart,
 &cmu_us_awb_single_mcep_ay_32_cart,
 &cmu_us_awb_single_mcep_ay_33_cart,
 &cmu_us_awb_single_mcep_w_189_cart,
 &cmu_us_awb_single_mcep_w_190_cart,
 &cmu_us_awb_single_mcep_w_191_cart,
 &cmu_us_awb_single_mcep_m_111_cart,
 &cmu_us_awb_single_mcep_m_112_cart,
 &cmu_us_awb_single_mcep_m_113_cart,
 &cmu_us_awb_single_mcep_pau_142_cart,
 &cmu_us_awb_single_mcep_ao_16_cart,
 &cmu_us_awb_single_mcep_ao_17_cart,
 &cmu_us_awb_single_mcep_ao_18_cart,
 &cmu_us_awb_single_mcep_th_169_cart,
 &cmu_us_awb_single_mcep_th_170_cart,
 &cmu_us_awb_single_mcep_th_171_cart,
 &cmu_us_awb_single_mcep_ah_11_cart,
 &cmu_us_awb_single_mcep_ah_12_cart,
 &cmu_us_awb_single_mcep_ah_13_cart,
 &cmu_us_awb_single_mcep_v_184_cart,
 &cmu_us_awb_single_mcep_v_185_cart,
 &cmu_us_awb_single_mcep_v_186_cart,
 &cmu_us_awb_single_mcep_dh_51_cart,
 &cmu_us_awb_single_mcep_dh_52_cart,
 &cmu_us_awb_single_mcep_dh_53_cart,
 &cmu_us_awb_single_mcep_d_46_cart,
 &cmu_us_awb_single_mcep_d_47_cart,
 &cmu_us_awb_single_mcep_d_48_cart,
 &cmu_us_awb_single_mcep_n_116_cart,
 &cmu_us_awb_single_mcep_n_117_cart,
 &cmu_us_awb_single_mcep_n_118_cart,
 &cmu_us_awb_single_mcep_jh_96_cart,
 &cmu_us_awb_single_mcep_jh_97_cart,
 &cmu_us_awb_single_mcep_jh_98_cart,
 &cmu_us_awb_single_mcep_r_146_cart,
 &cmu_us_awb_single_mcep_r_147_cart,
 &cmu_us_awb_single_mcep_r_148_cart,
 &cmu_us_awb_single_mcep_ey_66_cart,
 &cmu_us_awb_single_mcep_ey_67_cart,
 &cmu_us_awb_single_mcep_ey_68_cart,
 &cmu_us_awb_single_mcep_pau_141_cart,
 &cmu_us_awb_single_mcep_pau_143_cart,
 &cmu_us_awb_single_mcep_f_71_cart,
 &cmu_us_awb_single_mcep_f_72_cart,
 &cmu_us_awb_single_mcep_f_73_cart,
 &cmu_us_awb_single_mcep_ih_86_cart,
 &cmu_us_awb_single_mcep_ih_87_cart,
 &cmu_us_awb_single_mcep_ih_88_cart,
 &cmu_us_awb_single_mcep_ax_27_cart,
 &cmu_us_awb_single_mcep_ax_28_cart,
 &cmu_us_awb_single_mcep_p_136_cart,
 &cmu_us_awb_single_mcep_p_137_cart,
 &cmu_us_awb_single_mcep_p_138_cart,
 &cmu_us_awb_single_mcep_iy_91_cart,
 &cmu_us_awb_single_mcep_iy_92_cart,
 &cmu_us_awb_single_mcep_iy_93_cart,
 &cmu_us_awb_single_mcep_l_106_cart,
 &cmu_us_awb_single_mcep_l_107_cart,
 &cmu_us_awb_single_mcep_l_108_cart,
 &cmu_us_awb_single_mcep_z_199_cart,
 &cmu_us_awb_single_mcep_z_200_cart,
 &cmu_us_awb_single_mcep_z_201_cart,
 &cmu_us_awb_single_mcep_pau_161_cart,
 &cmu_us_awb_single_mcep_s_151_cart,
 &cmu_us_awb_single_mcep_s_152_cart,
 &cmu_us_awb_single_mcep_s_153_cart,
 &cmu_us_awb_single_mcep_eh_56_cart,
 &cmu_us_awb_single_mcep_eh_57_cart,
 &cmu_us_awb_single_mcep_eh_58_cart,
 &cmu_us_awb_single_mcep_t_164_cart,
 &cmu_us_awb_single_mcep_t_165_cart,
 &cmu_us_awb_single_mcep_t_166_cart,
 &cmu_us_awb_single_mcep_er_61_cart,
 &cmu_us_awb_single_mcep_er_62_cart,
 &cmu_us_awb_single_mcep_er_63_cart,
 &cmu_us_awb_single_mcep_ax_26_cart,
 0 };
