/*****************************************************/
/**  Autogenerated cmu_us_slt single_mcep carts    */
/*****************************************************/

#include "cst_string.h"
#include "cst_cart.h"
#include "cmu_us_slt_cg_single_mcep_trees.h"

static const cst_cart_node cmu_us_slt_single_mcep_zh_204_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0000, (cst_val *)&val_0000},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0001, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0003 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0004, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0005, (cst_val *)&val_0005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0006 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0007, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0007 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0009, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0009 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_zh_204_NO_0011, (cst_val *)&val_0010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0013 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_zh_204_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_zh_204_cart = {
  cmu_us_slt_single_mcep_zh_204_cart_nodes,
  cmu_us_slt_single_mcep_zh_204_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_zh_205_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_zh_205_NO_0000, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0016 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_zh_205_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_slt_single_mcep_zh_205_cart = {
  cmu_us_slt_single_mcep_zh_205_cart_nodes,
  cmu_us_slt_single_mcep_zh_205_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_zh_206_cart_nodes[] = {
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0017 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_zh_206_feat_table[] = {
NULL };

const cst_cart cmu_us_slt_single_mcep_zh_206_cart = {
  cmu_us_slt_single_mcep_zh_206_cart_nodes,
  cmu_us_slt_single_mcep_zh_206_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_oy_131_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0001, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0021 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0004, (cst_val *)&val_0022},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0005, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0024 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0007, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0027 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0010, (cst_val *)&val_0023},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0011, (cst_val *)&val_0028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0030 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0014, (cst_val *)&val_0031},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0015, (cst_val *)&val_0032},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0016, (cst_val *)&val_0033},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0035 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0019, (cst_val *)&val_0036},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0020, (cst_val *)&val_0037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0040 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0024, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0041 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_131_NO_0026, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0044 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_oy_131_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
NULL };

const cst_cart cmu_us_slt_single_mcep_oy_131_cart = {
  cmu_us_slt_single_mcep_oy_131_cart_nodes,
  cmu_us_slt_single_mcep_oy_131_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_oy_132_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0000, (cst_val *)&val_0045},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0001, (cst_val *)&val_0046},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0002, (cst_val *)&val_0047},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0003, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0050 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0006, (cst_val *)&val_0051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0053 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0009, (cst_val *)&val_0054},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0010, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0056 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0013, (cst_val *)&val_0057},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0014, (cst_val *)&val_0058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0060 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0017, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0063 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0020, (cst_val *)&val_0064},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0021, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0065 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0023, (cst_val *)&val_0066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0068 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_132_NO_0026, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0070 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_oy_132_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_slt_single_mcep_oy_132_cart = {
  cmu_us_slt_single_mcep_oy_132_cart_nodes,
  cmu_us_slt_single_mcep_oy_132_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_oy_133_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0000, (cst_val *)&val_0071},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0001, (cst_val *)&val_0072},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0002, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0003, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0075 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0005, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0077 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0007, (cst_val *)&val_0078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0080 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0010, (cst_val *)&val_0081},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0011, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0083 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0013, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0087 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0017, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0018, (cst_val *)&val_0089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0092 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0022, (cst_val *)&val_0001},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0023, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0094 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_oy_133_NO_0025, (cst_val *)&val_0095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0098 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_oy_133_feat_table[] = {
"lisp_cg_phone_index",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_oy_133_cart = {
  cmu_us_slt_single_mcep_oy_133_cart_nodes,
  cmu_us_slt_single_mcep_oy_133_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ch_41_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0000, (cst_val *)&val_0099},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0002, (cst_val *)&val_0100},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0003, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0101 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0005, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0103 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0008, (cst_val *)&val_0104},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0009, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0107 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0012, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0110 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0015, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0112 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0018, (cst_val *)&val_0113},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0019, (cst_val *)&val_0114},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0020, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0117 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0023, (cst_val *)&val_0118},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0024, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0120 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0026, (cst_val *)&val_0121},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0122 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0028, (cst_val *)&val_0123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0124 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0030, (cst_val *)&val_0125},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0031, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0127 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0034, (cst_val *)&val_0128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0131 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0038, (cst_val *)&val_0132},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_41_NO_0039, (cst_val *)&val_0133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0136 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ch_41_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ch_41_cart = {
  cmu_us_slt_single_mcep_ch_41_cart_nodes,
  cmu_us_slt_single_mcep_ch_41_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ch_42_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0001, (cst_val *)&val_0138},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0002, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0139 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0004, (cst_val *)&val_0140},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0005, (cst_val *)&val_0141},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0006, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0143 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0008, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0145 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0011, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0146 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0013, (cst_val *)&val_0043},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0014, (cst_val *)&val_0016},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0015, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0150 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0020, (cst_val *)&val_0016},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0021, (cst_val *)&val_0151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0152 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0023, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0155 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0026, (cst_val *)&val_0076},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0027, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0158 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0031, (cst_val *)&val_0159},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0032, (cst_val *)&val_0160},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0033, (cst_val *)&val_0161},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0164 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0037, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0165 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0039, (cst_val *)&val_0166},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0040, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0168 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0043, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0170 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0045, (cst_val *)&val_0171},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0046, (cst_val *)&val_0172},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0047, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0175 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0176 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0052, (cst_val *)&val_0169},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0053, (cst_val *)&val_0177},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0054, (cst_val *)&val_0178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0181 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0058, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0182 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_42_NO_0060, (cst_val *)&val_0183},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0185 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ch_42_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_ch_42_cart = {
  cmu_us_slt_single_mcep_ch_42_cart_nodes,
  cmu_us_slt_single_mcep_ch_42_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ch_43_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0002, (cst_val *)&val_0186},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0003, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0188 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0006, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0007, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0191 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0010, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0193 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0013, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0196 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0016, (cst_val *)&val_0141},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0017, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0018, (cst_val *)&val_0197},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0199 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0021, (cst_val *)&val_0004},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0022, (cst_val *)&val_0200},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0023, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0203 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0027, (cst_val *)&val_0204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0206 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0030, (cst_val *)&val_0207},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0031, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0209 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0034, (cst_val *)&val_0001},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0035, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0211 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0038, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0039, (cst_val *)&val_0151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0213 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ch_43_NO_0042, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0215 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ch_43_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_ch_43_cart = {
  cmu_us_slt_single_mcep_ch_43_cart_nodes,
  cmu_us_slt_single_mcep_ch_43_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aw_21_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0001, (cst_val *)&val_0216},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0002, (cst_val *)&val_0217},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0003, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0221 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0007, (cst_val *)&val_0222},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0008, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0226 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0012, (cst_val *)&val_0227},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0013, (cst_val *)&val_0228},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0014, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0229 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0016, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0231 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0019, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0233 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0021, (cst_val *)&val_0023},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0022, (cst_val *)&val_0234},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0236 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0025, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0238 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0027, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0241 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0030, (cst_val *)&val_0242},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0031, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0032, (cst_val *)&val_0243},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0033, (cst_val *)&val_0108},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0034, (cst_val *)&val_0244},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0035, (cst_val *)&val_0245},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0249 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0040, (cst_val *)&val_0228},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0041, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0251 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0044, (cst_val *)&val_0252},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0045, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0254 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0048, (cst_val *)&val_0255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0257 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0051, (cst_val *)&val_0258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0260 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0054, (cst_val *)&val_0261},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0055, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0263 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0058, (cst_val *)&val_0264},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0059, (cst_val *)&val_0265},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0060, (cst_val *)&val_0266},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0269 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0064, (cst_val *)&val_0270},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0065, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0272 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0068, (cst_val *)&val_0228},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0069, (cst_val *)&val_0273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0275 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_21_NO_0072, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0277 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aw_21_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_aw_21_cart = {
  cmu_us_slt_single_mcep_aw_21_cart_nodes,
  cmu_us_slt_single_mcep_aw_21_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aw_22_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0001, (cst_val *)&val_0278},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0002, (cst_val *)&val_0279},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0003, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0281 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0005, (cst_val *)&val_0282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0283 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0007, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0286 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0010, (cst_val *)&val_0228},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0011, (cst_val *)&val_0287},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0012, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0289 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0015, (cst_val *)&val_0290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0293 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0019, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0020, (cst_val *)&val_0294},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0021, (cst_val *)&val_0295},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0022, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0298 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0026, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0300 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0028, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0302 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0030, (cst_val *)&val_0303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0305 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0033, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0307 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0036, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0037, (cst_val *)&val_0308},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0038, (cst_val *)&val_0088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0039, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0311 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0042, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0312 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0044, (cst_val *)&val_0313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0314 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0046, (cst_val *)&val_0315},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0317 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0049, (cst_val *)&val_0318},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0050, (cst_val *)&val_0200},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0051, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0319 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0053, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0320 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0055, (cst_val *)&val_0321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0323 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0058, (cst_val *)&val_0324},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0326 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0061, (cst_val *)&val_0327},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0062, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0328 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0064, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0331 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0067, (cst_val *)&val_0284},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0068, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0334 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0072, (cst_val *)&val_0072},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0073, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0074, (cst_val *)&val_0335},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0336 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0076, (cst_val *)&val_0337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0340 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0080, (cst_val *)&val_0341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0342 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_22_NO_0082, (cst_val *)&val_0343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0345 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aw_22_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_aw_22_cart = {
  cmu_us_slt_single_mcep_aw_22_cart_nodes,
  cmu_us_slt_single_mcep_aw_22_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aw_23_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0000, (cst_val *)&val_0014},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0001, (cst_val *)&val_0346},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0002, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0347 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0004, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0349 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0007, (cst_val *)&val_0072},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0008, (cst_val *)&val_0350},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0009, (cst_val *)&val_0351},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0353 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0012, (cst_val *)&val_0354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0356 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0015, (cst_val *)&val_0357},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0016, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0360 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0019, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0362 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0022, (cst_val *)&val_0363},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0023, (cst_val *)&val_0364},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0024, (cst_val *)&val_0365},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0025, (cst_val *)&val_0366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0368 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0028, (cst_val *)&val_0063},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0370 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0031, (cst_val *)&val_0371},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0032, (cst_val *)&val_0372},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0033, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0375 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0036, (cst_val *)&val_0376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0378 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0039, (cst_val *)&val_0379},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0040, (cst_val *)&val_0380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0383 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0044, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0045, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0386 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0048, (cst_val *)&val_0364},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0049, (cst_val *)&val_0142},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0050, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0389 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0053, (cst_val *)&val_0390},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0054, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0394 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0058, (cst_val *)&val_0395},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0059, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0397 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0062, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0398 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0064, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0400 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0066, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0401 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aw_23_NO_0068, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0403 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aw_23_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_aw_23_cart = {
  cmu_us_slt_single_mcep_aw_23_cart_nodes,
  cmu_us_slt_single_mcep_aw_23_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ow_126_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0001, (cst_val *)&val_0093},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0002, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0405 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0005, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0406 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0007, (cst_val *)&val_0407},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0008, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0409 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0010, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0412 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0014, (cst_val *)&val_0413},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0015, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0016, (cst_val *)&val_0264},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0017, (cst_val *)&val_0414},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0018, (cst_val *)&val_0415},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0417 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0021, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0419 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0024, (cst_val *)&val_0023},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0025, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0422 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0028, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0424 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0030, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0426 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0033, (cst_val *)&val_0137},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0034, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0428 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0037, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0430 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0040, (cst_val *)&val_0264},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0041, (cst_val *)&val_0431},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0042, (cst_val *)&val_0432},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0043, (cst_val *)&val_0433},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0044, (cst_val *)&val_0434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0436 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0047, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0438 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0050, (cst_val *)&val_0439},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0051, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0443 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0055, (cst_val *)&val_0444},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0056, (cst_val *)&val_0445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0447 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0059, (cst_val *)&val_0448},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0060, (cst_val *)&val_0449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0450 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0062, (cst_val *)&val_0451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0452 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0064, (cst_val *)&val_0453},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0456 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0068, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0457 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0070, (cst_val *)&val_0458},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0071, (cst_val *)&val_0459},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0072, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0460 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0074, (cst_val *)&val_0461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0462 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0076, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0464 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0079, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0466 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0081, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0468 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0083, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0469 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0085, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0470 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0087, (cst_val *)&val_0471},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0088, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0474 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0092, (cst_val *)&val_0228},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0093, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0476 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0096, (cst_val *)&val_0477},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0097, (cst_val *)&val_0478},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0098, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0480 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0100, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0483 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0104, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0484 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0106, (cst_val *)&val_0485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0486 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_126_NO_0108, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0488 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ow_126_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ow_126_cart = {
  cmu_us_slt_single_mcep_ow_126_cart_nodes,
  cmu_us_slt_single_mcep_ow_126_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ow_127_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0001, (cst_val *)&val_0489},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0002, (cst_val *)&val_0228},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0003, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0491 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0006, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0494 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0009, (cst_val *)&val_0453},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0010, (cst_val *)&val_0495},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0498 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0014, (cst_val *)&val_0004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0015, (cst_val *)&val_0499},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0016, (cst_val *)&val_0287},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0017, (cst_val *)&val_0500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0501 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0019, (cst_val *)&val_0023},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0020, (cst_val *)&val_0502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0505 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0024, (cst_val *)&val_0506},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0025, (cst_val *)&val_0507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0509 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0028, (cst_val *)&val_0510},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0029, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0512 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0032, (cst_val *)&val_0513},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0033, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0515 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0036, (cst_val *)&val_0516},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0037, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0520 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0042, (cst_val *)&val_0228},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0043, (cst_val *)&val_0521},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0044, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0522 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0046, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0523 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0048, (cst_val *)&val_0524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0526 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0051, (cst_val *)&val_0527},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0052, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0528 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0054, (cst_val *)&val_0529},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0055, (cst_val *)&val_0530},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0056, (cst_val *)&val_0531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0536 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0062, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0063, (cst_val *)&val_0138},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0064, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0537 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0066, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0540 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0069, (cst_val *)&val_0541},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0542 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0071, (cst_val *)&val_0543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0545 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0074, (cst_val *)&val_0140},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0075, (cst_val *)&val_0546},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0076, (cst_val *)&val_0547},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0077, (cst_val *)&val_0548},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0078, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0549 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0080, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0552 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0083, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0553 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0085, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0555 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0088, (cst_val *)&val_0012},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0089, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0557 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0092, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0093, (cst_val *)&val_0558},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0094, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0561 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0098, (cst_val *)&val_0023},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0099, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0563 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0102, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0565 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0105, (cst_val *)&val_0566},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0568 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0108, (cst_val *)&val_0072},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0109, (cst_val *)&val_0228},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0110, (cst_val *)&val_0569},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0111, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0572 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0115, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0573 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0117, (cst_val *)&val_0574},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0118, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0577 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0121, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0580 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0124, (cst_val *)&val_0228},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0125, (cst_val *)&val_0581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0583 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0128, (cst_val *)&val_0584},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0585 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_127_NO_0130, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0587 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ow_127_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ow_127_cart = {
  cmu_us_slt_single_mcep_ow_127_cart_nodes,
  cmu_us_slt_single_mcep_ow_127_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ow_128_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0000, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0001, (cst_val *)&val_0365},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0002, (cst_val *)&val_0588},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0003, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0589 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0005, (cst_val *)&val_0590},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0006, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0591 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0008, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0594 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0011, (cst_val *)&val_0595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0596 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0013, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0599 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0016, (cst_val *)&val_0600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0602 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0019, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0604 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0022, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0023, (cst_val *)&val_0605},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0024, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0607 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0027, (cst_val *)&val_0608},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0028, (cst_val *)&val_0609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0611 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0031, (cst_val *)&val_0140},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0032, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0613 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0035, (cst_val *)&val_0614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0616 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0038, (cst_val *)&val_0617},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0039, (cst_val *)&val_0618},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0040, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0620 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0043, (cst_val *)&val_0621},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0044, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0624 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0048, (cst_val *)&val_0093},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0049, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0627 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0052, (cst_val *)&val_0363},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0053, (cst_val *)&val_0061},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0054, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0629 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0057, (cst_val *)&val_0105},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0058, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0631 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0061, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0062, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0632 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0064, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0634 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0067, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0636 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0070, (cst_val *)&val_0637},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ow_128_NO_0071, (cst_val *)&val_0638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0641 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ow_128_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_slt_single_mcep_ow_128_cart = {
  cmu_us_slt_single_mcep_ow_128_cart_nodes,
  cmu_us_slt_single_mcep_ow_128_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_b_36_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0001, (cst_val *)&val_0642},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0002, (cst_val *)&val_0643},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0003, (cst_val *)&val_0644},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0004, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0646 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0007, (cst_val *)&val_0084},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0008, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0648 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0011, (cst_val *)&val_0649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0651 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0014, (cst_val *)&val_0137},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0015, (cst_val *)&val_0652},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0016, (cst_val *)&val_0653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0655 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0019, (cst_val *)&val_0530},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0020, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0021, (cst_val *)&val_0656},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0022, (cst_val *)&val_0657},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0660 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0026, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0661 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0028, (cst_val *)&val_0662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0667 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0034, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0035, (cst_val *)&val_0668},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0036, (cst_val *)&val_0004},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0037, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0038, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0670 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0040, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0672 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0043, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0674 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0046, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0677 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0049, (cst_val *)&val_0678},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0050, (cst_val *)&val_0679},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0051, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0680 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0053, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0682 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0055, (cst_val *)&val_0683},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0056, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0684 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0058, (cst_val *)&val_0685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0688 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0062, (cst_val *)&val_0023},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0063, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0689 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0065, (cst_val *)&val_0690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0692 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0068, (cst_val *)&val_0693},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0069, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0695 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0072, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0696 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0074, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0698 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0077, (cst_val *)&val_0699},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0078, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0701 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0081, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0703 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0084, (cst_val *)&val_0299},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0085, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0704 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0087, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0706 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0089, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0708 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_36_NO_0092, (cst_val *)&val_0709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0711 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_b_36_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_slt_single_mcep_b_36_cart = {
  cmu_us_slt_single_mcep_b_36_cart_nodes,
  cmu_us_slt_single_mcep_b_36_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_b_37_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0000, (cst_val *)&val_0668},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0001, (cst_val *)&val_0217},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0002, (cst_val *)&val_0712},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0003, (cst_val *)&val_0713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0716 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0007, (cst_val *)&val_0218},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0008, (cst_val *)&val_0284},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0009, (cst_val *)&val_0717},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0010, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0718 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0012, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0721 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0016, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0723 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0019, (cst_val *)&val_0724},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0020, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0726 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0023, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0729 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0026, (cst_val *)&val_0730},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0027, (cst_val *)&val_0018},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0028, (cst_val *)&val_0140},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0029, (cst_val *)&val_0218},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0030, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0732 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0033, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0734 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0035, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0735 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0037, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0736 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0039, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0739 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0043, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0741 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0045, (cst_val *)&val_0668},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0046, (cst_val *)&val_0742},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0745 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0050, (cst_val *)&val_0669},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0051, (cst_val *)&val_0004},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_37_NO_0052, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0749 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_b_37_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_b_37_cart = {
  cmu_us_slt_single_mcep_b_37_cart_nodes,
  cmu_us_slt_single_mcep_b_37_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_b_38_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0000, (cst_val *)&val_0073},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0001, (cst_val *)&val_0237},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0003, (cst_val *)&val_0750},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0004, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0753 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0008, (cst_val *)&val_0008},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0009, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0754 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0011, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0756 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0014, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0757 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0016, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0759 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0019, (cst_val *)&val_0760},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0020, (cst_val *)&val_0675},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0021, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0022, (cst_val *)&val_0761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0763 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0025, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0765 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0028, (cst_val *)&val_0766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0768 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0031, (cst_val *)&val_0001},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0032, (cst_val *)&val_0769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0771 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0035, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0036, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0774 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_b_38_NO_0040, (cst_val *)&val_0775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0777 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_b_38_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_slt_single_mcep_b_38_cart = {
  cmu_us_slt_single_mcep_b_38_cart_nodes,
  cmu_us_slt_single_mcep_b_38_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_g_76_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0000, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0778 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0002, (cst_val *)&val_0779},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0003, (cst_val *)&val_0780},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0004, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0781 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0006, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0782 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0008, (cst_val *)&val_0783},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0009, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0786 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0013, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0788 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0016, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0017, (cst_val *)&val_0414},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0018, (cst_val *)&val_0414},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0019, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0791 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_76_NO_0023, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0794 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_g_76_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_g_76_cart = {
  cmu_us_slt_single_mcep_g_76_cart_nodes,
  cmu_us_slt_single_mcep_g_76_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_g_77_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0000, (cst_val *)&val_0795},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0001, (cst_val *)&val_0779},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0002, (cst_val *)&val_0795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0796 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0004, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0798 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0007, (cst_val *)&val_0799},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0800 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0009, (cst_val *)&val_0194},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0010, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0802 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0013, (cst_val *)&val_0803},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0805 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0016, (cst_val *)&val_0806},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0017, (cst_val *)&val_0014},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0018, (cst_val *)&val_0151},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0019, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0808 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0022, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0809 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0024, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0811 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0027, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0812 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0029, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0813 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0031, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0814 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0033, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0816 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0036, (cst_val *)&val_0817},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0037, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0818 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0039, (cst_val *)&val_0819},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0040, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0822 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0044, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0823 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_77_NO_0046, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0826 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_g_77_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_g_77_cart = {
  cmu_us_slt_single_mcep_g_77_cart_nodes,
  cmu_us_slt_single_mcep_g_77_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_g_78_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0000, (cst_val *)&val_0827},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0001, (cst_val *)&val_0828},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0002, (cst_val *)&val_0621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0829 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0004, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0830 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0006, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0832 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0009, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0010, (cst_val *)&val_0833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0835 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0013, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0837 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0015, (cst_val *)&val_0838},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0840 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0018, (cst_val *)&val_0001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0019, (cst_val *)&val_0218},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0020, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0842 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0023, (cst_val *)&val_0547},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0024, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0843 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0026, (cst_val *)&val_0844},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0846 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0029, (cst_val *)&val_0847},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0849 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0032, (cst_val *)&val_0850},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0033, (cst_val *)&val_0014},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0034, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0852 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0037, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0853 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0039, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0040, (cst_val *)&val_0137},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0041, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0855 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0044, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0858 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0048, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0859 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0050, (cst_val *)&val_0200},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0051, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0860 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0053, (cst_val *)&val_0828},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0054, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0861 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0056, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0863 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0059, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0864 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0061, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0867 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0064, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0868 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_g_78_NO_0066, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0870 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_g_78_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_g_78_cart = {
  cmu_us_slt_single_mcep_g_78_cart_nodes,
  cmu_us_slt_single_mcep_g_78_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ng_121_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0000, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0001, (cst_val *)&val_0550},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0002, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0003, (cst_val *)&val_0284},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0004, (cst_val *)&val_0871},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0872 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0006, (cst_val *)&val_0873},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0007, (cst_val *)&val_0874},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0876 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0010, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0878 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0013, (cst_val *)&val_0879},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0014, (cst_val *)&val_0880},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0882 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0017, (cst_val *)&val_0883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0884 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0019, (cst_val *)&val_0885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0887 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0022, (cst_val *)&val_0888},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0023, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0889 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0025, (cst_val *)&val_0890},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0026, (cst_val *)&val_0891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0894 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0030, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0895 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0032, (cst_val *)&val_0547},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0033, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0899 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0037, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0038, (cst_val *)&val_0900},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0039, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0903 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0043, (cst_val *)&val_0239},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0044, (cst_val *)&val_0904},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0045, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0907 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0049, (cst_val *)&val_0908},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0050, (cst_val *)&val_0909},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0051, (cst_val *)&val_0558},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0052, (cst_val *)&val_0910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0911 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0054, (cst_val *)&val_0912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0915 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0058, (cst_val *)&val_0916},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0918 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0061, (cst_val *)&val_0919},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0062, (cst_val *)&val_0920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0922 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0065, (cst_val *)&val_0923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0925 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0068, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0926 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0070, (cst_val *)&val_0927},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_121_NO_0071, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0930 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ng_121_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
NULL };

const cst_cart cmu_us_slt_single_mcep_ng_121_cart = {
  cmu_us_slt_single_mcep_ng_121_cart_nodes,
  cmu_us_slt_single_mcep_ng_121_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ng_122_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0001, (cst_val *)&val_0621},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0002, (cst_val *)&val_0931},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0003, (cst_val *)&val_0020},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0004, (cst_val *)&val_0004},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0005, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0933 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0008, (cst_val *)&val_0934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0935 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0010, (cst_val *)&val_0936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0939 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0014, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0941 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0017, (cst_val *)&val_0942},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0018, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0019, (cst_val *)&val_0795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0945 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0023, (cst_val *)&val_0237},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0024, (cst_val *)&val_0946},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0948 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0027, (cst_val *)&val_0949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0950 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0029, (cst_val *)&val_0951},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0030, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0031, (cst_val *)&val_0952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0953 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0033, (cst_val *)&val_0954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0957 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0037, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0959 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0040, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0041, (cst_val *)&val_0960},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0042, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0961 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0044, (cst_val *)&val_0023},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0045, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0963 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0048, (cst_val *)&val_0681},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0049, (cst_val *)&val_0964},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0050, (cst_val *)&val_0965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0968 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0054, (cst_val *)&val_0969},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0055, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0970 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0057, (cst_val *)&val_0299},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0058, (cst_val *)&val_0971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0972 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0060, (cst_val *)&val_0973},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0975 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0063, (cst_val *)&val_0976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0979 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0067, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0980 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0069, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0981 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0071, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0984 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0074, (cst_val *)&val_0218},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0075, (cst_val *)&val_0985},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0076, (cst_val *)&val_0986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0988 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0079, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0991 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0082, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0992 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0084, (cst_val *)&val_0993},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0085, (cst_val *)&val_0994},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_122_NO_0086, (cst_val *)&val_0995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_0999 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ng_122_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_ng_122_cart = {
  cmu_us_slt_single_mcep_ng_122_cart_nodes,
  cmu_us_slt_single_mcep_ng_122_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ng_123_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0001, (cst_val *)&val_1000},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0002, (cst_val *)&val_1001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0003, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1003 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0006, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1005 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0009, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1008 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0012, (cst_val *)&val_1009},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0013, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0014, (cst_val *)&val_0047},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0015, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1011 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0018, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1013 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0021, (cst_val *)&val_0617},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0022, (cst_val *)&val_1014},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0023, (cst_val *)&val_1009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1016 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0026, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1018 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0029, (cst_val *)&val_0365},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0030, (cst_val *)&val_1019},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0031, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1021 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0034, (cst_val *)&val_0414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1023 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0037, (cst_val *)&val_1024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1026 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0040, (cst_val *)&val_1027},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0041, (cst_val *)&val_0617},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0042, (cst_val *)&val_1028},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0043, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1031 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0047, (cst_val *)&val_1032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1034 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0050, (cst_val *)&val_1035},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0051, (cst_val *)&val_1036},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0052, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1039 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0056, (cst_val *)&val_0617},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0057, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1040 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0059, (cst_val *)&val_0015},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0060, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1043 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0064, (cst_val *)&val_0931},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ng_123_NO_0065, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1047 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ng_123_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_ng_123_cart = {
  cmu_us_slt_single_mcep_ng_123_cart_nodes,
  cmu_us_slt_single_mcep_ng_123_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uw_179_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0001, (cst_val *)&val_1048},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0002, (cst_val *)&val_1049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1050 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0004, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1052 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0007, (cst_val *)&val_0942},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0008, (cst_val *)&val_1053},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1055 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0011, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1056 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0013, (cst_val *)&val_1057},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0014, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1059 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0017, (cst_val *)&val_1060},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0018, (cst_val *)&val_1061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1064 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0022, (cst_val *)&val_0675},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0023, (cst_val *)&val_0465},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0024, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1065 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0026, (cst_val *)&val_0986},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0027, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1068 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0031, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1070 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0034, (cst_val *)&val_0264},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0035, (cst_val *)&val_0099},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0036, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1073 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0039, (cst_val *)&val_1074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1075 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0041, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1077 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0044, (cst_val *)&val_1078},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0045, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0046, (cst_val *)&val_0099},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0047, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1079 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0049, (cst_val *)&val_1080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1082 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0052, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1083 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0054, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1084 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0056, (cst_val *)&val_1085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1087 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0059, (cst_val *)&val_1088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1090 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0062, (cst_val *)&val_1019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1091 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0064, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1092 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0066, (cst_val *)&val_1093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1094 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0068, (cst_val *)&val_0084},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_179_NO_0069, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1097 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uw_179_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_uw_179_cart = {
  cmu_us_slt_single_mcep_uw_179_cart_nodes,
  cmu_us_slt_single_mcep_uw_179_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uw_180_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0000, (cst_val *)&val_1049},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0001, (cst_val *)&val_0088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0002, (cst_val *)&val_0169},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0003, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1098 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0005, (cst_val *)&val_0023},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0006, (cst_val *)&val_1099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1102 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0010, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1103 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0012, (cst_val *)&val_1104},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0013, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1107 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0017, (cst_val *)&val_0023},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0018, (cst_val *)&val_0363},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0019, (cst_val *)&val_0151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1108 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0021, (cst_val *)&val_0775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1111 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0025, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1112 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0027, (cst_val *)&val_1113},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0028, (cst_val *)&val_1114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1115 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0030, (cst_val *)&val_1116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1118 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0033, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0034, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1122 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0038, (cst_val *)&val_0011},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0039, (cst_val *)&val_0301},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0040, (cst_val *)&val_1123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1124 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0042, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1125 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0044, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1127 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0047, (cst_val *)&val_1128},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1130 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0050, (cst_val *)&val_1131},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0051, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1132 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0053, (cst_val *)&val_0004},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0054, (cst_val *)&val_1133},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1134 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0056, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1136 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0059, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1139 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0062, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1140 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0064, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1141 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0066, (cst_val *)&val_1142},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_180_NO_0067, (cst_val *)&val_1143},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1146 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uw_180_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_uw_180_cart = {
  cmu_us_slt_single_mcep_uw_180_cart_nodes,
  cmu_us_slt_single_mcep_uw_180_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uw_181_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0000, (cst_val *)&val_1147},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0001, (cst_val *)&val_0064},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0002, (cst_val *)&val_0151},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0003, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1148 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0005, (cst_val *)&val_1149},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0006, (cst_val *)&val_0617},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0007, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1153 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0012, (cst_val *)&val_1154},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0013, (cst_val *)&val_1155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1157 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0016, (cst_val *)&val_1158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1160 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0019, (cst_val *)&val_1161},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0020, (cst_val *)&val_0014},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0021, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1162 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1163 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0024, (cst_val *)&val_0465},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0025, (cst_val *)&val_1164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1166 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0028, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1168 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0030, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1170 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0033, (cst_val *)&val_0023},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0034, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0035, (cst_val *)&val_1119},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0036, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1174 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0041, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1175 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0043, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1177 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0046, (cst_val *)&val_0064},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0047, (cst_val *)&val_0395},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0048, (cst_val *)&val_0194},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0049, (cst_val *)&val_1178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1181 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0053, (cst_val *)&val_1048},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0054, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1183 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0057, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1185 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0060, (cst_val *)&val_0064},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0061, (cst_val *)&val_0018},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0062, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1187 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0065, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1188 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0067, (cst_val *)&val_1189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1191 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0070, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1192 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0072, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0073, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1195 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0076, (cst_val *)&val_1196},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uw_181_NO_0077, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1199 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uw_181_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_uw_181_cart = {
  cmu_us_slt_single_mcep_uw_181_cart_nodes,
  cmu_us_slt_single_mcep_uw_181_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_sh_156_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0000, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0001, (cst_val *)&val_0006},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0003, (cst_val *)&val_0575},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0004, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1202 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0008, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1204 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0011, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0012, (cst_val *)&val_1205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1207 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0015, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0016, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0017, (cst_val *)&val_1009},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0018, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1209 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0021, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1211 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1212 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0025, (cst_val *)&val_0105},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0026, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1215 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0030, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0031, (cst_val *)&val_1216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1217 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0033, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1220 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0036, (cst_val *)&val_0433},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0037, (cst_val *)&val_1221},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0038, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1224 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0042, (cst_val *)&val_0140},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0043, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1226 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_156_NO_0046, (cst_val *)&val_1227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1229 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_sh_156_feat_table[] = {
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_sh_156_cart = {
  cmu_us_slt_single_mcep_sh_156_cart_nodes,
  cmu_us_slt_single_mcep_sh_156_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_sh_157_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0000, (cst_val *)&val_1230},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0001, (cst_val *)&val_0007},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0003, (cst_val *)&val_0151},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0004, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1231 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0006, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1233 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0008, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1235 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0011, (cst_val *)&val_0137},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0012, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1236 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0014, (cst_val *)&val_1237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1240 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0018, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1241 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0020, (cst_val *)&val_0023},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0021, (cst_val *)&val_1242},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1244 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0024, (cst_val *)&val_1245},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1247 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0027, (cst_val *)&val_0007},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0028, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1248 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0030, (cst_val *)&val_1249},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0031, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1250 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0033, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1251 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0035, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1254 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0039, (cst_val *)&val_0105},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0040, (cst_val *)&val_0727},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0041, (cst_val *)&val_0140},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0042, (cst_val *)&val_1255},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1256 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0044, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1257 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0046, (cst_val *)&val_1258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1260 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0049, (cst_val *)&val_0108},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0050, (cst_val *)&val_1261},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1263 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0053, (cst_val *)&val_1264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1266 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0056, (cst_val *)&val_1267},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0057, (cst_val *)&val_1164},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0058, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1269 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0061, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1270 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0063, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1273 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0067, (cst_val *)&val_0295},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0068, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0069, (cst_val *)&val_0061},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0070, (cst_val *)&val_1274},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1277 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0074, (cst_val *)&val_0014},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0075, (cst_val *)&val_0547},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0076, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1280 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0080, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1282 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0083, (cst_val *)&val_0018},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0084, (cst_val *)&val_1283},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0085, (cst_val *)&val_1284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1286 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0088, (cst_val *)&val_0239},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0089, (cst_val *)&val_1287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1290 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0093, (cst_val *)&val_0023},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0094, (cst_val *)&val_0395},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0095, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1291 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0097, (cst_val *)&val_1292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1294 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0100, (cst_val *)&val_0105},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0101, (cst_val *)&val_1295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1297 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0104, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0105, (cst_val *)&val_1298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1301 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0109, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0110, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1302 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0112, (cst_val *)&val_1303},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0113, (cst_val *)&val_1304},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1306 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0116, (cst_val *)&val_0108},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0117, (cst_val *)&val_1307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1309 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0120, (cst_val *)&val_1310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1312 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0123, (cst_val *)&val_1313},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0124, (cst_val *)&val_1314},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1315 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0126, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1317 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0129, (cst_val *)&val_1318},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0130, (cst_val *)&val_0001},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0131, (cst_val *)&val_0001},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0132, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1321 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0136, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1322 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0138, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1324 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0141, (cst_val *)&val_1325},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0142, (cst_val *)&val_1326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1329 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0146, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1330 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0148, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1331 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0150, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1332 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_157_NO_0152, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1334 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_sh_157_feat_table[] = {
"lisp_cg_phone_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_slt_single_mcep_sh_157_cart = {
  cmu_us_slt_single_mcep_sh_157_cart_nodes,
  cmu_us_slt_single_mcep_sh_157_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_sh_158_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0000, (cst_val *)&val_0795},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0001, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1335 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0003, (cst_val *)&val_1336},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0004, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1337 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0006, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1340 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0009, (cst_val *)&val_1341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1342 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0011, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0012, (cst_val *)&val_1343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1346 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0016, (cst_val *)&val_1347},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0017, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1348 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0019, (cst_val *)&val_1349},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1351 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0022, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1352 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_sh_158_NO_0024, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1354 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_sh_158_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_sh_158_cart = {
  cmu_us_slt_single_mcep_sh_158_cart_nodes,
  cmu_us_slt_single_mcep_sh_158_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uh_174_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0001, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1357 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0004, (cst_val *)&val_1358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1359 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0006, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0007, (cst_val *)&val_0105},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0008, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1362 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_174_NO_0012, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1364 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uh_174_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_uh_174_cart = {
  cmu_us_slt_single_mcep_uh_174_cart_nodes,
  cmu_us_slt_single_mcep_uh_174_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uh_175_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0000, (cst_val *)&val_1365},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0001, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1366 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0003, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1368 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0006, (cst_val *)&val_1369},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0007, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1370 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0009, (cst_val *)&val_1371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1373 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_175_NO_0012, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1375 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uh_175_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_uh_175_cart = {
  cmu_us_slt_single_mcep_uh_175_cart_nodes,
  cmu_us_slt_single_mcep_uh_175_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_uh_176_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0000, (cst_val *)&val_1347},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0001, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1376 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0003, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1378 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0005, (cst_val *)&val_0287},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0006, (cst_val *)&val_1379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1381 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0009, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1383 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0012, (cst_val *)&val_1384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1385 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_uh_176_NO_0014, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1388 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_uh_176_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_uh_176_cart = {
  cmu_us_slt_single_mcep_uh_176_cart_nodes,
  cmu_us_slt_single_mcep_uh_176_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_hh_81_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0001, (cst_val *)&val_1389},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0002, (cst_val *)&val_0047},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0003, (cst_val *)&val_0021},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0004, (cst_val *)&val_0108},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0005, (cst_val *)&val_1390},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0006, (cst_val *)&val_0218},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0007, (cst_val *)&val_1391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1394 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0011, (cst_val *)&val_1395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1396 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0013, (cst_val *)&val_1397},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0014, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1399 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0017, (cst_val *)&val_1400},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1402 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0020, (cst_val *)&val_1403},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1405 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0023, (cst_val *)&val_1406},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0024, (cst_val *)&val_1407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1408 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0026, (cst_val *)&val_1409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1410 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0028, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1412 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0031, (cst_val *)&val_1413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1416 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0035, (cst_val *)&val_0137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0036, (cst_val *)&val_0013},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0037, (cst_val *)&val_1390},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0038, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1418 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0041, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1420 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0044, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1421 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0046, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1423 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0048, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0049, (cst_val *)&val_1424},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1425 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0051, (cst_val *)&val_1426},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1428 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0054, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0055, (cst_val *)&val_1429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1432 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0059, (cst_val *)&val_1433},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0060, (cst_val *)&val_0217},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0061, (cst_val *)&val_1434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1436 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0064, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1439 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0068, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0069, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1440 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0071, (cst_val *)&val_1441},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1443 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0074, (cst_val *)&val_0621},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0075, (cst_val *)&val_0467},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0076, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0077, (cst_val *)&val_1444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1447 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0081, (cst_val *)&val_0001},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1448 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0084, (cst_val *)&val_1449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1451 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0087, (cst_val *)&val_0681},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0088, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1453 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0091, (cst_val *)&val_0228},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0092, (cst_val *)&val_0001},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0093, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1456 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0097, (cst_val *)&val_0001},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0098, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1457 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0100, (cst_val *)&val_0232},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0101, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1460 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0105, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1462 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_81_NO_0108, (cst_val *)&val_1463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1465 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_hh_81_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_hh_81_cart = {
  cmu_us_slt_single_mcep_hh_81_cart_nodes,
  cmu_us_slt_single_mcep_hh_81_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_hh_82_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0000, (cst_val *)&val_1048},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0001, (cst_val *)&val_0088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0002, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1467 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0004, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1469 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0007, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0008, (cst_val *)&val_1470},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0009, (cst_val *)&val_1471},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0010, (cst_val *)&val_0313},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0011, (cst_val *)&val_0783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1474 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0015, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1476 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0018, (cst_val *)&val_1477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1479 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0021, (cst_val *)&val_0228},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0022, (cst_val *)&val_0001},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0023, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1482 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0027, (cst_val *)&val_0001},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0028, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1484 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0031, (cst_val *)&val_0001},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0032, (cst_val *)&val_1485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1487 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0035, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1488 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0037, (cst_val *)&val_1489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1491 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0040, (cst_val *)&val_0064},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0041, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0042, (cst_val *)&val_1492},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0043, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1494 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0046, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1496 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0049, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1498 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0052, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1499 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0054, (cst_val *)&val_0004},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0055, (cst_val *)&val_0824},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0056, (cst_val *)&val_1500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1503 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0060, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1504 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0062, (cst_val *)&val_0824},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_82_NO_0063, (cst_val *)&val_1505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1508 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_hh_82_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_slt_single_mcep_hh_82_cart = {
  cmu_us_slt_single_mcep_hh_82_cart_nodes,
  cmu_us_slt_single_mcep_hh_82_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_hh_83_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0000, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0001, (cst_val *)&val_1509},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0002, (cst_val *)&val_1341},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0003, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0004, (cst_val *)&val_1510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1513 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0008, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1514 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0010, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1516 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0013, (cst_val *)&val_1341},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0014, (cst_val *)&val_0004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0015, (cst_val *)&val_0072},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0016, (cst_val *)&val_1517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1520 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0020, (cst_val *)&val_0047},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0021, (cst_val *)&val_1521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1524 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0025, (cst_val *)&val_1525},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0026, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1527 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0029, (cst_val *)&val_0228},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0030, (cst_val *)&val_1528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1530 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0033, (cst_val *)&val_1531},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0034, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1533 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0037, (cst_val *)&val_0064},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0038, (cst_val *)&val_1534},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1536 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0041, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1537 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0043, (cst_val *)&val_1538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1540 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0046, (cst_val *)&val_0088},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0047, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1541 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0049, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1543 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0052, (cst_val *)&val_0001},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0053, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0054, (cst_val *)&val_1544},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1547 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0058, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0059, (cst_val *)&val_1548},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0060, (cst_val *)&val_0047},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0061, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1549 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1552 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0066, (cst_val *)&val_0108},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0067, (cst_val *)&val_0001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0068, (cst_val *)&val_1553},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0069, (cst_val *)&val_0014},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0070, (cst_val *)&val_0047},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0071, (cst_val *)&val_1554},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1557 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0075, (cst_val *)&val_1558},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0076, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1562 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0081, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1563 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0083, (cst_val *)&val_0064},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0084, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1566 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0088, (cst_val *)&val_1567},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0089, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0090, (cst_val *)&val_1395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1570 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0094, (cst_val *)&val_1571},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_hh_83_NO_0095, (cst_val *)&val_1572},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1575 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_hh_83_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_hh_83_cart = {
  cmu_us_slt_single_mcep_hh_83_cart_nodes,
  cmu_us_slt_single_mcep_hh_83_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ae_6_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0001, (cst_val *)&val_1413},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0002, (cst_val *)&val_0217},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0003, (cst_val *)&val_1576},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0004, (cst_val *)&val_1577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1578 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0006, (cst_val *)&val_1579},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0007, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1581 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0010, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1582 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0012, (cst_val *)&val_0995},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0013, (cst_val *)&val_1583},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1586 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0017, (cst_val *)&val_1587},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0018, (cst_val *)&val_1588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1590 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0021, (cst_val *)&val_1591},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0022, (cst_val *)&val_1592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1593 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0024, (cst_val *)&val_1594},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1596 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0027, (cst_val *)&val_0108},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0028, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1599 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0032, (cst_val *)&val_1600},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0033, (cst_val *)&val_0018},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0034, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1603 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0038, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0039, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1605 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0042, (cst_val *)&val_1606},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0043, (cst_val *)&val_0699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1609 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0047, (cst_val *)&val_0018},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0048, (cst_val *)&val_0015},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0049, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1611 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0052, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1613 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0055, (cst_val *)&val_1614},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0056, (cst_val *)&val_0365},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0057, (cst_val *)&val_0023},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0058, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1615 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0060, (cst_val *)&val_1616},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0061, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1618 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0063, (cst_val *)&val_1619},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1621 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0066, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1624 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0070, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1625 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0072, (cst_val *)&val_1626},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0073, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1627 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0075, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1630 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0079, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1632 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0082, (cst_val *)&val_0228},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0083, (cst_val *)&val_0237},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0084, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1634 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0087, (cst_val *)&val_1221},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0088, (cst_val *)&val_0004},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0089, (cst_val *)&val_0228},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0090, (cst_val *)&val_0055},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1636 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0093, (cst_val *)&val_0423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1637 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0095, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1639 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0098, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1640 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0100, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1642 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0103, (cst_val *)&val_1643},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0104, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1644 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0106, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1645 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0108, (cst_val *)&val_0108},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0109, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1647 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0112, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1650 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0115, (cst_val *)&val_0004},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0116, (cst_val *)&val_0061},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0117, (cst_val *)&val_0108},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0118, (cst_val *)&val_1651},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1653 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0121, (cst_val *)&val_0115},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0122, (cst_val *)&val_0502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1656 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0126, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1657 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0128, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1658 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1659 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0131, (cst_val *)&val_0395},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0132, (cst_val *)&val_1660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1662 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0135, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1663 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0137, (cst_val *)&val_1664},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1665 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0139, (cst_val *)&val_1666},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1668 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0142, (cst_val *)&val_0927},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0143, (cst_val *)&val_1422},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0144, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1670 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0146, (cst_val *)&val_0592},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0147, (cst_val *)&val_1671},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0148, (cst_val *)&val_1672},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1673 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1676 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0153, (cst_val *)&val_0004},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0154, (cst_val *)&val_0023},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0155, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1678 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0158, (cst_val *)&val_0137},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0159, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1680 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0162, (cst_val *)&val_1681},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0163, (cst_val *)&val_1682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1684 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0166, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1687 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0169, (cst_val *)&val_0048},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0170, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1689 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0173, (cst_val *)&val_0105},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0174, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1692 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0178, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0179, (cst_val *)&val_1693},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_6_NO_0180, (cst_val *)&val_1694},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1698 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ae_6_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ae_6_cart = {
  cmu_us_slt_single_mcep_ae_6_cart_nodes,
  cmu_us_slt_single_mcep_ae_6_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ae_7_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0000, (cst_val *)&val_0228},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0001, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0002, (cst_val *)&val_1699},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0003, (cst_val *)&val_1006},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0004, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0005, (cst_val *)&val_1700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1702 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0008, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1704 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0011, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1705 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0013, (cst_val *)&val_0550},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0014, (cst_val *)&val_1706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1707 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0016, (cst_val *)&val_1155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1709 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0019, (cst_val *)&val_1710},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0020, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1712 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0023, (cst_val *)&val_0239},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0024, (cst_val *)&val_1713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1714 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0026, (cst_val *)&val_1715},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1717 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0029, (cst_val *)&val_1718},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1720 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0032, (cst_val *)&val_0072},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0033, (cst_val *)&val_0621},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0034, (cst_val *)&val_1721},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1723 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0037, (cst_val *)&val_1724},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0038, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0039, (cst_val *)&val_1725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1728 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0043, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1730 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0046, (cst_val *)&val_0023},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0047, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1731 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0049, (cst_val *)&val_1732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1735 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0053, (cst_val *)&val_1736},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0054, (cst_val *)&val_1737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1738 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0056, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0057, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1740 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0060, (cst_val *)&val_1741},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1742 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0062, (cst_val *)&val_1470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1744 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0065, (cst_val *)&val_0363},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0066, (cst_val *)&val_1745},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0067, (cst_val *)&val_1746},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1747 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0069, (cst_val *)&val_0072},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0070, (cst_val *)&val_1748},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1751 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0074, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0075, (cst_val *)&val_1752},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0076, (cst_val *)&val_1753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1757 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0081, (cst_val *)&val_1758},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1760 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0084, (cst_val *)&val_0927},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0085, (cst_val *)&val_0399},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0086, (cst_val *)&val_0024},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0087, (cst_val *)&val_0964},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1762 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0090, (cst_val *)&val_1763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1765 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0093, (cst_val *)&val_0942},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0094, (cst_val *)&val_0105},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0095, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1766 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0097, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1768 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0100, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1770 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0103, (cst_val *)&val_1422},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0104, (cst_val *)&val_1771},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0105, (cst_val *)&val_1772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1775 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0109, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1776 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0111, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1777 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0113, (cst_val *)&val_0471},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0114, (cst_val *)&val_1778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1780 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0117, (cst_val *)&val_0040},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0118, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1783 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0122, (cst_val *)&val_1009},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0123, (cst_val *)&val_0217},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0124, (cst_val *)&val_1784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1786 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0127, (cst_val *)&val_1422},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0128, (cst_val *)&val_1787},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0129, (cst_val *)&val_1788},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1790 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0132, (cst_val *)&val_1791},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1793 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0135, (cst_val *)&val_0061},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0136, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1795 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0139, (cst_val *)&val_0108},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0140, (cst_val *)&val_0140},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0141, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1797 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0144, (cst_val *)&val_0004},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0145, (cst_val *)&val_1798},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0146, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1800 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0149, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1801 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0151, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1803 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0154, (cst_val *)&val_0048},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0155, (cst_val *)&val_1804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1806 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0158, (cst_val *)&val_1807},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0159, (cst_val *)&val_0140},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0160, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1811 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0165, (cst_val *)&val_1812},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0166, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1815 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0169, (cst_val *)&val_1816},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1818 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0172, (cst_val *)&val_0399},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0173, (cst_val *)&val_1819},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0174, (cst_val *)&val_0012},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0175, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0176, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1822 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0180, (cst_val *)&val_1823},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0181, (cst_val *)&val_1824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1826 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0184, (cst_val *)&val_1827},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1829 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0187, (cst_val *)&val_1830},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0188, (cst_val *)&val_1831},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0189, (cst_val *)&val_0516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1834 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0193, (cst_val *)&val_1835},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1837 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0196, (cst_val *)&val_0088},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0197, (cst_val *)&val_1838},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0198, (cst_val *)&val_0218},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0199, (cst_val *)&val_1839},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0200, (cst_val *)&val_1840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1843 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0204, (cst_val *)&val_1844},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0205, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1845 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0207, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1846 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0209, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1848 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0212, (cst_val *)&val_1849},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1851 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0215, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1852 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0217, (cst_val *)&val_0061},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0218, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1854 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0221, (cst_val *)&val_1855},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0222, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1856 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0224, (cst_val *)&val_1857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1860 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0228, (cst_val *)&val_0137},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0229, (cst_val *)&val_1861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1863 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0232, (cst_val *)&val_0061},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0233, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1864 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0235, (cst_val *)&val_1865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1867 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0238, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1868 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0240, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0241, (cst_val *)&val_1869},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0242, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1871 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0245, (cst_val *)&val_0471},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0246, (cst_val *)&val_1872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1874 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0249, (cst_val *)&val_0064},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0250, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1875 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0252, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1876 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0254, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1877 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0256, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1880 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0259, (cst_val *)&val_1881},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0260, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1882 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0262, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1885 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0266, (cst_val *)&val_1886},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0267, (cst_val *)&val_1887},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0268, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1890 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0272, (cst_val *)&val_1891},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0273, (cst_val *)&val_0017},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0274, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1893 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0277, (cst_val *)&val_0850},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0278, (cst_val *)&val_0119},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0279, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1896 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0283, (cst_val *)&val_0399},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0284, (cst_val *)&val_1897},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1899 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0287, (cst_val *)&val_1900},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0288, (cst_val *)&val_1901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1904 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_7_NO_0292, (cst_val *)&val_1905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1907 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ae_7_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_ae_7_cart = {
  cmu_us_slt_single_mcep_ae_7_cart_nodes,
  cmu_us_slt_single_mcep_ae_7_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ae_8_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0000, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0001, (cst_val *)&val_0363},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0002, (cst_val *)&val_0471},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0003, (cst_val *)&val_1908},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0004, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1911 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0008, (cst_val *)&val_1912},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0009, (cst_val *)&val_1310},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0010, (cst_val *)&val_1044},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0011, (cst_val *)&val_1913},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0012, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1917 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0017, (cst_val *)&val_1918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1919 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0019, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1921 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0022, (cst_val *)&val_0399},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0023, (cst_val *)&val_1922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1924 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0026, (cst_val *)&val_0023},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0027, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1927 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0031, (cst_val *)&val_1928},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0032, (cst_val *)&val_1929},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1931 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0035, (cst_val *)&val_1932},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0036, (cst_val *)&val_1933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1936 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0040, (cst_val *)&val_0588},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0041, (cst_val *)&val_0228},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0042, (cst_val *)&val_0137},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0043, (cst_val *)&val_1626},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0044, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1937 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0046, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1939 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0049, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1940 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0051, (cst_val *)&val_0679},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0052, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1941 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0054, (cst_val *)&val_1942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1944 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0057, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1946 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0060, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0061, (cst_val *)&val_0108},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0062, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1948 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0065, (cst_val *)&val_0313},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0066, (cst_val *)&val_1949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1951 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0069, (cst_val *)&val_1952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1953 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0071, (cst_val *)&val_1954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1955 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0073, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1957 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0076, (cst_val *)&val_0025},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0077, (cst_val *)&val_0478},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0078, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1961 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0083, (cst_val *)&val_1962},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0084, (cst_val *)&val_0004},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0085, (cst_val *)&val_0140},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0086, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1964 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0088, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1966 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0091, (cst_val *)&val_1967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1969 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0094, (cst_val *)&val_0652},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0095, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1971 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0097, (cst_val *)&val_1972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1974 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0100, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1976 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0103, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1977 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0105, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1979 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0107, (cst_val *)&val_0595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1980 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0109, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1981 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0111, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1983 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0114, (cst_val *)&val_1984},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0115, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1985 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0117, (cst_val *)&val_1986},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0118, (cst_val *)&val_1987},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0119, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1989 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0122, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1991 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0125, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1993 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0128, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1994 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0130, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1995 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ae_8_NO_0132, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1997 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ae_8_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_ae_8_cart = {
  cmu_us_slt_single_mcep_ae_8_cart_nodes,
  cmu_us_slt_single_mcep_ae_8_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_y_194_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0001, (cst_val *)&val_0217},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0002, (cst_val *)&val_0022},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0003, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_1998 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0005, (cst_val *)&val_1999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2001 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0008, (cst_val *)&val_2002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2004 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0011, (cst_val *)&val_0142},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0012, (cst_val *)&val_2005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2007 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0015, (cst_val *)&val_2005},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0016, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2009 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0019, (cst_val *)&val_1660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2010 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0021, (cst_val *)&val_2011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2013 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0024, (cst_val *)&val_0105},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0025, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2015 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0028, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2016 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0030, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2017 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0032, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2018 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_194_NO_0034, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2021 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_y_194_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_y_194_cart = {
  cmu_us_slt_single_mcep_y_194_cart_nodes,
  cmu_us_slt_single_mcep_y_194_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_y_195_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0001, (cst_val *)&val_0018},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0002, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2022 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0004, (cst_val *)&val_0072},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0005, (cst_val *)&val_2023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2026 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0009, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0010, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2028 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0013, (cst_val *)&val_0141},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0014, (cst_val *)&val_0371},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0015, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2032 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0020, (cst_val *)&val_0228},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0021, (cst_val *)&val_2033},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0022, (cst_val *)&val_1577},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0023, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2036 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0027, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2038 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0030, (cst_val *)&val_0011},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0031, (cst_val *)&val_2039},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0032, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2041 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0035, (cst_val *)&val_0414},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0036, (cst_val *)&val_2042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2044 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0039, (cst_val *)&val_2045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2047 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0042, (cst_val *)&val_2048},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0043, (cst_val *)&val_0021},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0044, (cst_val *)&val_2042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2051 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_195_NO_0048, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2053 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_y_195_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_slt_single_mcep_y_195_cart = {
  cmu_us_slt_single_mcep_y_195_cart_nodes,
  cmu_us_slt_single_mcep_y_195_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_y_196_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0000, (cst_val *)&val_2054},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0001, (cst_val *)&val_0064},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0002, (cst_val *)&val_2055},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0003, (cst_val *)&val_2056},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0004, (cst_val *)&val_2057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2061 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0009, (cst_val *)&val_2056},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0010, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2063 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0013, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2066 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0016, (cst_val *)&val_0014},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0017, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2067 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0019, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2069 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0022, (cst_val *)&val_0927},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0023, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2070 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0025, (cst_val *)&val_2071},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0026, (cst_val *)&val_2072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2073 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0028, (cst_val *)&val_2074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2076 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0031, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2078 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0034, (cst_val *)&val_2079},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0035, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2080 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0037, (cst_val *)&val_2081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2083 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0040, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2084 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_y_196_NO_0042, (cst_val *)&val_2085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2087 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_y_196_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_y_196_cart = {
  cmu_us_slt_single_mcep_y_196_cart_nodes,
  cmu_us_slt_single_mcep_y_196_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_k_101_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0000, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0002, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0003, (cst_val *)&val_0237},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0004, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2088 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0006, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2090 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0009, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2091 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0011, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2092 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0013, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2094 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0016, (cst_val *)&val_0001},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0017, (cst_val *)&val_2095},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0018, (cst_val *)&val_2096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2098 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0021, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2099 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0023, (cst_val *)&val_2100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2102 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0026, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2104 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0028, (cst_val *)&val_1053},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0029, (cst_val *)&val_2105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2106 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0031, (cst_val *)&val_2019},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0032, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2109 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0036, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2110 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0038, (cst_val *)&val_2039},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0039, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2113 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0043, (cst_val *)&val_0088},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0044, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2115 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0047, (cst_val *)&val_0228},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0048, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2117 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0051, (cst_val *)&val_1167},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0052, (cst_val *)&val_2118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2120 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0055, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2122 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0058, (cst_val *)&val_2118},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0059, (cst_val *)&val_0137},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0060, (cst_val *)&val_2123},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0061, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0062, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2125 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0065, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2127 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0068, (cst_val *)&val_0018},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0069, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0070, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2128 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0072, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2130 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0075, (cst_val *)&val_0014},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0076, (cst_val *)&val_2131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2134 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0080, (cst_val *)&val_0001},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0081, (cst_val *)&val_2135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2137 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2138 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0085, (cst_val *)&val_0239},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0086, (cst_val *)&val_2139},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2141 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0089, (cst_val *)&val_0994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2142 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0091, (cst_val *)&val_2143},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2145 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0094, (cst_val *)&val_0004},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0095, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2146 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_101_NO_0097, (cst_val *)&val_2147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2150 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_k_101_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_slt_single_mcep_k_101_cart = {
  cmu_us_slt_single_mcep_k_101_cart_nodes,
  cmu_us_slt_single_mcep_k_101_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_k_102_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0001, (cst_val *)&val_1395},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0002, (cst_val *)&val_0942},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0003, (cst_val *)&val_0088},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0004, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2151 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0006, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2153 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0009, (cst_val *)&val_1048},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0010, (cst_val *)&val_1395},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0011, (cst_val *)&val_2154},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0012, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0013, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2158 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0018, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2159 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0020, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2161 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0023, (cst_val *)&val_2162},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0024, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2164 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0027, (cst_val *)&val_0004},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0028, (cst_val *)&val_0073},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0029, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2168 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0034, (cst_val *)&val_0088},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0035, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2170 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0038, (cst_val *)&val_2171},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0039, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2172 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0041, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2173 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0043, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2174 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0045, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2175 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0047, (cst_val *)&val_2176},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0048, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2178 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0051, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2180 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0054, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2182 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0057, (cst_val *)&val_1258},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0058, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2184 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0061, (cst_val *)&val_1137},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0062, (cst_val *)&val_0414},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0063, (cst_val *)&val_2185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2186 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0065, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2187 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0067, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2188 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0069, (cst_val *)&val_0018},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0070, (cst_val *)&val_2189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2192 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0074, (cst_val *)&val_0105},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0075, (cst_val *)&val_2193},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0076, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2194 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0078, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2197 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0082, (cst_val *)&val_0014},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0083, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2199 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0085, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2201 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0088, (cst_val *)&val_2202},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0089, (cst_val *)&val_0021},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0090, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2203 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0092, (cst_val *)&val_2204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2207 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0096, (cst_val *)&val_2208},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0097, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2209 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0099, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2210 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0101, (cst_val *)&val_2211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2213 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0104, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2214 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0106, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2216 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0109, (cst_val *)&val_2217},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0110, (cst_val *)&val_2218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2220 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0113, (cst_val *)&val_1310},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0114, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2222 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0117, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2224 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0120, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0121, (cst_val *)&val_0009},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0122, (cst_val *)&val_2225},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0123, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2226 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0125, (cst_val *)&val_0064},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0126, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2228 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0129, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2230 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0132, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2232 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0135, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2233 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0137, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2234 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0139, (cst_val *)&val_0923},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0140, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2236 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0143, (cst_val *)&val_2237},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0144, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2240 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0148, (cst_val *)&val_0004},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0149, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0150, (cst_val *)&val_0218},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0151, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2241 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0153, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2245 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_102_NO_0158, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2247 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_k_102_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
NULL };

const cst_cart cmu_us_slt_single_mcep_k_102_cart = {
  cmu_us_slt_single_mcep_k_102_cart_nodes,
  cmu_us_slt_single_mcep_k_102_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_k_103_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0000, (cst_val *)&val_0365},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0001, (cst_val *)&val_0795},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0002, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0003, (cst_val *)&val_0683},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0004, (cst_val *)&val_0252},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0005, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2248 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0007, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2250 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0010, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2251 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0012, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2253 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0015, (cst_val *)&val_0003},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0016, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2254 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0018, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2255 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0020, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2256 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0022, (cst_val *)&val_1758},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2259 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0026, (cst_val *)&val_0001},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0027, (cst_val *)&val_1571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2261 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0030, (cst_val *)&val_0023},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0031, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2263 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0034, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0035, (cst_val *)&val_0982},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0036, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2265 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0039, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2266 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0041, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2269 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0045, (cst_val *)&val_0001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0046, (cst_val *)&val_2270},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0047, (cst_val *)&val_0105},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0048, (cst_val *)&val_0073},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0049, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2272 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0052, (cst_val *)&val_2273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2274 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0054, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2276 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0057, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2278 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0060, (cst_val *)&val_1341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2279 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0062, (cst_val *)&val_2280},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0063, (cst_val *)&val_2281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2282 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0065, (cst_val *)&val_2283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2285 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0068, (cst_val *)&val_2286},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0069, (cst_val *)&val_2287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2289 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0072, (cst_val *)&val_2290},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2292 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0075, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0076, (cst_val *)&val_1978},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0077, (cst_val *)&val_1395},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0078, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2294 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0081, (cst_val *)&val_2295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2296 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0083, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2297 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0085, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2299 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0088, (cst_val *)&val_2300},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0089, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2302 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0091, (cst_val *)&val_2303},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0092, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2306 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0096, (cst_val *)&val_2301},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0097, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2307 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0099, (cst_val *)&val_2308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2310 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0102, (cst_val *)&val_2311},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0103, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2313 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0106, (cst_val *)&val_2314},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2316 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0109, (cst_val *)&val_0395},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0110, (cst_val *)&val_0817},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0111, (cst_val *)&val_2317},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0112, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2320 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0116, (cst_val *)&val_1137},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0117, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2322 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0120, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2323 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0122, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2325 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0125, (cst_val *)&val_2326},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0126, (cst_val *)&val_0018},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0127, (cst_val *)&val_1338},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0128, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0129, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2328 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0132, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2330 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0135, (cst_val *)&val_2331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2332 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0137, (cst_val *)&val_0011},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0138, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2333 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0140, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2335 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0143, (cst_val *)&val_1616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2337 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0146, (cst_val *)&val_0001},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0147, (cst_val *)&val_0018},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0148, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2339 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0151, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2341 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0154, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2342 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0156, (cst_val *)&val_0046},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0157, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2344 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0160, (cst_val *)&val_2345},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0161, (cst_val *)&val_2346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2349 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0165, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2350 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0167, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2351 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2352 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0170, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0171, (cst_val *)&val_2353},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0172, (cst_val *)&val_0001},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0173, (cst_val *)&val_2354},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2355 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0175, (cst_val *)&val_2356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2358 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0178, (cst_val *)&val_2317},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2359 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0180, (cst_val *)&val_2360},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0181, (cst_val *)&val_1085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2363 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0185, (cst_val *)&val_0001},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0186, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2365 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0189, (cst_val *)&val_0115},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0190, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2367 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0193, (cst_val *)&val_2368},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2370 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0196, (cst_val *)&val_0004},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0197, (cst_val *)&val_0025},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0198, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2371 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0200, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2372 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0202, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2374 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0205, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2376 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0208, (cst_val *)&val_2377},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0209, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2378 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_k_103_NO_0211, (cst_val *)&val_2379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2382 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_k_103_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_k_103_cart = {
  cmu_us_slt_single_mcep_k_103_cart_nodes,
  cmu_us_slt_single_mcep_k_103_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aa_1_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0001, (cst_val *)&val_0217},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0002, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2384 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0005, (cst_val *)&val_0414},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0006, (cst_val *)&val_0642},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0007, (cst_val *)&val_2385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2387 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0010, (cst_val *)&val_2005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2389 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0013, (cst_val *)&val_0073},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0014, (cst_val *)&val_2390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2392 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0017, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2394 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0020, (cst_val *)&val_1355},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0021, (cst_val *)&val_2395},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0022, (cst_val *)&val_2396},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0023, (cst_val *)&val_0538},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0024, (cst_val *)&val_2397},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2401 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0029, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2403 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0032, (cst_val *)&val_0264},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0033, (cst_val *)&val_0100},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0034, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2405 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0037, (cst_val *)&val_0363},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0038, (cst_val *)&val_2406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2408 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0041, (cst_val *)&val_2409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2410 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0043, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2412 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0046, (cst_val *)&val_0001},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0047, (cst_val *)&val_1395},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0048, (cst_val *)&val_2413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2416 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0052, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0053, (cst_val *)&val_1470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2418 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0056, (cst_val *)&val_0218},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0057, (cst_val *)&val_0105},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0058, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2419 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0060, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2421 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0063, (cst_val *)&val_0795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2423 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0066, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2424 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_1_NO_0068, (cst_val *)&val_2425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2427 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aa_1_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_slt_single_mcep_aa_1_cart = {
  cmu_us_slt_single_mcep_aa_1_cart_nodes,
  cmu_us_slt_single_mcep_aa_1_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aa_2_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0000, (cst_val *)&val_1422},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0001, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2428 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0003, (cst_val *)&val_0114},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0004, (cst_val *)&val_2429},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0005, (cst_val *)&val_2377},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0006, (cst_val *)&val_0717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2432 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0010, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2434 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0013, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2436 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0016, (cst_val *)&val_2437},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0017, (cst_val *)&val_1406},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0018, (cst_val *)&val_0140},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0019, (cst_val *)&val_2438},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0020, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2439 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0022, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0023, (cst_val *)&val_2440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2444 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0028, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0029, (cst_val *)&val_0433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2445 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0031, (cst_val *)&val_0017},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0032, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2448 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0036, (cst_val *)&val_0061},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0037, (cst_val *)&val_2449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2450 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0039, (cst_val *)&val_0558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2452 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0042, (cst_val *)&val_0643},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0043, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2453 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0045, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2455 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0048, (cst_val *)&val_0064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0049, (cst_val *)&val_2456},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0050, (cst_val *)&val_2457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2460 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0054, (cst_val *)&val_0228},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0055, (cst_val *)&val_2461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2463 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0058, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2465 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0061, (cst_val *)&val_0228},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0062, (cst_val *)&val_2466},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0063, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0064, (cst_val *)&val_2467},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0065, (cst_val *)&val_2468},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0066, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2470 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0069, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2472 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0072, (cst_val *)&val_2473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2475 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0075, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2476 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0077, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2478 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0080, (cst_val *)&val_2479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2480 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0082, (cst_val *)&val_0239},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0083, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2482 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0086, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2483 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0088, (cst_val *)&val_2484},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2485 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0090, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2486 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0092, (cst_val *)&val_2487},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0093, (cst_val *)&val_2488},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2491 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0097, (cst_val *)&val_0228},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0098, (cst_val *)&val_2492},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0099, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2493 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0101, (cst_val *)&val_2494},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0102, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2495 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0104, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2498 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0108, (cst_val *)&val_1422},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0109, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2500 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0112, (cst_val *)&val_0105},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0113, (cst_val *)&val_2501},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0114, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2503 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0117, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0118, (cst_val *)&val_2504},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2508 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0123, (cst_val *)&val_0043},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0124, (cst_val *)&val_0088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0125, (cst_val *)&val_2509},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0126, (cst_val *)&val_2510},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0127, (cst_val *)&val_2511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2512 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0129, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2514 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0132, (cst_val *)&val_2515},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0133, (cst_val *)&val_2516},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0134, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2521 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0140, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0141, (cst_val *)&val_2522},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0142, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2523 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0144, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2524 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0146, (cst_val *)&val_2525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2526 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0148, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2527 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0150, (cst_val *)&val_0018},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0151, (cst_val *)&val_2528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2531 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0155, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2532 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0157, (cst_val *)&val_2533},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0158, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2536 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0162, (cst_val *)&val_0018},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0163, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2538 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0166, (cst_val *)&val_2539},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0167, (cst_val *)&val_0471},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0168, (cst_val *)&val_2540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2542 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0171, (cst_val *)&val_2543},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0172, (cst_val *)&val_2544},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0173, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2545 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0175, (cst_val *)&val_2546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2547 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0177, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2549 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0180, (cst_val *)&val_2550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2553 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0184, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2554 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0186, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2555 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2556 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0189, (cst_val *)&val_0018},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0190, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2558 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0193, (cst_val *)&val_2559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2561 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0196, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0197, (cst_val *)&val_2562},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0198, (cst_val *)&val_2563},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0199, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2565 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0202, (cst_val *)&val_2566},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2568 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0205, (cst_val *)&val_0228},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0206, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2571 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0210, (cst_val *)&val_2572},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0211, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2574 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_2_NO_0214, (cst_val *)&val_2575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2577 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aa_2_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_aa_2_cart = {
  cmu_us_slt_single_mcep_aa_2_cart_nodes,
  cmu_us_slt_single_mcep_aa_2_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_aa_3_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0000, (cst_val *)&val_0364},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0001, (cst_val *)&val_2578},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0002, (cst_val *)&val_2579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2580 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0004, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2582 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0007, (cst_val *)&val_0042},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0008, (cst_val *)&val_0228},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0009, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2585 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0013, (cst_val *)&val_2586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2587 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0015, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2589 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0018, (cst_val *)&val_0595},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0019, (cst_val *)&val_0186},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0020, (cst_val *)&val_0108},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0021, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2592 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0025, (cst_val *)&val_0605},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0026, (cst_val *)&val_2593},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0027, (cst_val *)&val_2594},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0028, (cst_val *)&val_0524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2596 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0031, (cst_val *)&val_0108},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0032, (cst_val *)&val_1492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2599 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0036, (cst_val *)&val_2600},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0037, (cst_val *)&val_2601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2604 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0041, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2606 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0044, (cst_val *)&val_0828},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0045, (cst_val *)&val_0140},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0046, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2607 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0048, (cst_val *)&val_0780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2609 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0051, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2610 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0053, (cst_val *)&val_2611},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0054, (cst_val *)&val_2612},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0055, (cst_val *)&val_2613},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2614 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0057, (cst_val *)&val_2615},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2617 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0060, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2619 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0063, (cst_val *)&val_0683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2621 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0066, (cst_val *)&val_0228},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0067, (cst_val *)&val_0217},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0068, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2623 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0071, (cst_val *)&val_0142},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0072, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2624 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0074, (cst_val *)&val_2625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2626 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0076, (cst_val *)&val_2627},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2629 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0079, (cst_val *)&val_2630},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2631 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0081, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0082, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2633 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0085, (cst_val *)&val_0590},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0086, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2635 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0089, (cst_val *)&val_0675},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0090, (cst_val *)&val_0783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2638 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0094, (cst_val *)&val_2639},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0095, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0096, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2640 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0098, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2642 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0101, (cst_val *)&val_2643},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0102, (cst_val *)&val_2644},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0103, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2647 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0107, (cst_val *)&val_1137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0108, (cst_val *)&val_2648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2651 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0112, (cst_val *)&val_0004},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0113, (cst_val *)&val_2643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2652 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0115, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2654 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0118, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2655 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_aa_3_NO_0120, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2657 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_aa_3_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_aa_3_cart = {
  cmu_us_slt_single_mcep_aa_3_cart_nodes,
  cmu_us_slt_single_mcep_aa_3_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ay_31_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0001, (cst_val *)&val_1579},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0002, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2658 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0004, (cst_val *)&val_2473},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2660 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0007, (cst_val *)&val_2661},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0008, (cst_val *)&val_0217},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0009, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2664 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0013, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2665 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0015, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2667 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0018, (cst_val *)&val_2668},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0019, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0020, (cst_val *)&val_1060},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0021, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2669 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0023, (cst_val *)&val_2670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2672 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0026, (cst_val *)&val_0006},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0027, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2673 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0029, (cst_val *)&val_2674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2676 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0032, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2677 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0034, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2678 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0036, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2680 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0039, (cst_val *)&val_0705},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0040, (cst_val *)&val_0004},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0041, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2682 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0044, (cst_val *)&val_0592},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0045, (cst_val *)&val_2683},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0046, (cst_val *)&val_2684},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2687 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0050, (cst_val *)&val_2688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2690 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0053, (cst_val *)&val_0850},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0054, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0055, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2691 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0057, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2693 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0060, (cst_val *)&val_0228},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0061, (cst_val *)&val_0237},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0062, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2696 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0066, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2698 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0069, (cst_val *)&val_0228},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0070, (cst_val *)&val_2699},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0071, (cst_val *)&val_1606},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0072, (cst_val *)&val_2700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2702 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0075, (cst_val *)&val_2703},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2706 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0079, (cst_val *)&val_0420},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0080, (cst_val *)&val_2707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2709 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0083, (cst_val *)&val_0018},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0084, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2711 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0087, (cst_val *)&val_2712},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2713 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0089, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2714 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0091, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2716 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0094, (cst_val *)&val_2717},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0095, (cst_val *)&val_2718},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0096, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2719 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0098, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2721 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0101, (cst_val *)&val_0228},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0102, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2723 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0105, (cst_val *)&val_0638},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0106, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2726 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0110, (cst_val *)&val_0073},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0111, (cst_val *)&val_2727},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0112, (cst_val *)&val_2728},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0113, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2730 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0116, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2732 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0119, (cst_val *)&val_1699},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0120, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2733 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0122, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2735 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0125, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2736 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0127, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2737 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2738 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0130, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0131, (cst_val *)&val_2739},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0132, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2740 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0134, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2742 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0137, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2743 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0139, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2745 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0142, (cst_val *)&val_0228},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0143, (cst_val *)&val_1019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0144, (cst_val *)&val_1713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2748 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0148, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2749 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0150, (cst_val *)&val_0023},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_31_NO_0151, (cst_val *)&val_2750},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2753 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ay_31_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ay_31_cart = {
  cmu_us_slt_single_mcep_ay_31_cart_nodes,
  cmu_us_slt_single_mcep_ay_31_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ay_32_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0001, (cst_val *)&val_1009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0002, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0003, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0004, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2755 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0007, (cst_val *)&val_2756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2758 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0010, (cst_val *)&val_2759},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0011, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2762 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0015, (cst_val *)&val_0035},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0016, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2763 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0018, (cst_val *)&val_2764},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0019, (cst_val *)&val_2765},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0020, (cst_val *)&val_0652},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0021, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2767 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0024, (cst_val *)&val_1164},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2768 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0026, (cst_val *)&val_0516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2770 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0029, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2772 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0032, (cst_val *)&val_0020},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0033, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2774 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0036, (cst_val *)&val_2775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2777 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0039, (cst_val *)&val_0200},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0040, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2780 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0044, (cst_val *)&val_1365},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0045, (cst_val *)&val_2781},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0046, (cst_val *)&val_0018},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0047, (cst_val *)&val_2563},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2783 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0050, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2784 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0052, (cst_val *)&val_2785},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0053, (cst_val *)&val_0989},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0054, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2786 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0056, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2787 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0058, (cst_val *)&val_2788},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2789 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2790 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0061, (cst_val *)&val_0140},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0062, (cst_val *)&val_2791},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0063, (cst_val *)&val_2792},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2794 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0066, (cst_val *)&val_2795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2797 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0069, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2800 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0073, (cst_val *)&val_1167},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0074, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2801 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0076, (cst_val *)&val_1577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2802 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0078, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2804 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0081, (cst_val *)&val_1365},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0082, (cst_val *)&val_0061},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0083, (cst_val *)&val_2805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2807 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0086, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2808 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0088, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2810 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0091, (cst_val *)&val_0018},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0092, (cst_val *)&val_0061},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0093, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2812 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0096, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0097, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2814 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0100, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2817 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0104, (cst_val *)&val_2818},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0105, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2819 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0107, (cst_val *)&val_0023},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0108, (cst_val *)&val_2494},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0109, (cst_val *)&val_2820},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2823 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0113, (cst_val *)&val_0833},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0114, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2824 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0116, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2827 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0120, (cst_val *)&val_0986},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0121, (cst_val *)&val_0088},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0122, (cst_val *)&val_2828},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0123, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0124, (cst_val *)&val_2829},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2831 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0127, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2833 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0130, (cst_val *)&val_2834},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0131, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2835 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0133, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2838 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0137, (cst_val *)&val_1009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0138, (cst_val *)&val_0054},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0139, (cst_val *)&val_0061},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0140, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2840 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0143, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2843 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0147, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2844 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0149, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0150, (cst_val *)&val_2845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2847 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0153, (cst_val *)&val_0061},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0154, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2849 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0157, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2850 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0159, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2851 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0161, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2852 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0163, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2853 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0165, (cst_val *)&val_2854},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0166, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2857 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0170, (cst_val *)&val_2858},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0171, (cst_val *)&val_0004},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0172, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2861 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0176, (cst_val *)&val_2862},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0177, (cst_val *)&val_0018},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0178, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2864 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0181, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2865 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0183, (cst_val *)&val_0018},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0184, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2867 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0187, (cst_val *)&val_2081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2869 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0190, (cst_val *)&val_0023},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0191, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2870 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0193, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2872 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_32_NO_0196, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2874 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ay_32_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_ay_32_cart = {
  cmu_us_slt_single_mcep_ay_32_cart_nodes,
  cmu_us_slt_single_mcep_ay_32_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ay_33_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0000, (cst_val *)&val_0072},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0002, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2875 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0004, (cst_val *)&val_1978},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0005, (cst_val *)&val_0140},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0006, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2878 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0010, (cst_val *)&val_0228},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0011, (cst_val *)&val_0169},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0012, (cst_val *)&val_2879},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0013, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2880 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2881 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0016, (cst_val *)&val_0239},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0017, (cst_val *)&val_2882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2885 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0021, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2886 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0023, (cst_val *)&val_2887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2889 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0026, (cst_val *)&val_0232},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0027, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2891 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0030, (cst_val *)&val_2892},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0031, (cst_val *)&val_2893},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0032, (cst_val *)&val_0088},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0033, (cst_val *)&val_2894},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0034, (cst_val *)&val_2895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2898 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0038, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2899 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0040, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2901 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0043, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2903 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0046, (cst_val *)&val_0088},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0047, (cst_val *)&val_2904},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0048, (cst_val *)&val_2905},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0049, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2909 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0054, (cst_val *)&val_2910},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0055, (cst_val *)&val_2479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2912 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0058, (cst_val *)&val_0923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2914 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0061, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0062, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2915 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0064, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2916 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0066, (cst_val *)&val_2917},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0067, (cst_val *)&val_2918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2921 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0071, (cst_val *)&val_2922},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0072, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0073, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2923 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0075, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2925 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0078, (cst_val *)&val_0088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0079, (cst_val *)&val_2926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2928 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0082, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2929 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0084, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2930 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0086, (cst_val *)&val_2931},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0087, (cst_val *)&val_2932},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0088, (cst_val *)&val_2933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2935 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0091, (cst_val *)&val_2936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2939 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0095, (cst_val *)&val_0088},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0096, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2940 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0098, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2942 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0101, (cst_val *)&val_1338},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0102, (cst_val *)&val_2943},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2945 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0105, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2946 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0107, (cst_val *)&val_1377},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0108, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2948 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0111, (cst_val *)&val_2949},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0112, (cst_val *)&val_0004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0113, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2950 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0115, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2951 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0117, (cst_val *)&val_2952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2954 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0120, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2955 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2957 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0124, (cst_val *)&val_0064},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0125, (cst_val *)&val_0088},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0126, (cst_val *)&val_0089},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0127, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2958 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0129, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2960 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0132, (cst_val *)&val_2961},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0133, (cst_val *)&val_2962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2965 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0137, (cst_val *)&val_0617},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0138, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2966 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0140, (cst_val *)&val_2967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2969 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0143, (cst_val *)&val_1377},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0144, (cst_val *)&val_2970},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0145, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2973 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0149, (cst_val *)&val_0365},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0150, (cst_val *)&val_2974},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0151, (cst_val *)&val_2975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2978 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0155, (cst_val *)&val_0140},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0156, (cst_val *)&val_0364},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0157, (cst_val *)&val_2979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2983 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0162, (cst_val *)&val_0004},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0163, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0164, (cst_val *)&val_0084},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0165, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2986 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0169, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2988 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0172, (cst_val *)&val_1978},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0173, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2990 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0176, (cst_val *)&val_0023},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0177, (cst_val *)&val_0007},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0178, (cst_val *)&val_0595},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0179, (cst_val *)&val_0724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2992 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0182, (cst_val *)&val_2643},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0183, (cst_val *)&val_2993},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0184, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2996 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0188, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_2998 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0191, (cst_val *)&val_0595},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0192, (cst_val *)&val_2999},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3001 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0195, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3002 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0197, (cst_val *)&val_3003},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3005 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0200, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3006 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0202, (cst_val *)&val_1193},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0203, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3008 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ay_33_NO_0206, (cst_val *)&val_2970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3010 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ay_33_feat_table[] = {
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_ay_33_cart = {
  cmu_us_slt_single_mcep_ay_33_cart_nodes,
  cmu_us_slt_single_mcep_ay_33_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_w_189_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0001, (cst_val *)&val_1466},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0002, (cst_val *)&val_0817},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0003, (cst_val *)&val_1406},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0004, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3013 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0008, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3014 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0010, (cst_val *)&val_1422},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0011, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3016 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0014, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3017 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0016, (cst_val *)&val_0461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3019 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0019, (cst_val *)&val_3020},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0020, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3022 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0023, (cst_val *)&val_3023},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0024, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3026 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0028, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0029, (cst_val *)&val_0638},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0030, (cst_val *)&val_0001},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0031, (cst_val *)&val_0414},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0032, (cst_val *)&val_3027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3029 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0035, (cst_val *)&val_3030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3031 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0037, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3033 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0040, (cst_val *)&val_3034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3035 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0042, (cst_val *)&val_3036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3037 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0044, (cst_val *)&val_2105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3038 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0046, (cst_val *)&val_3039},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0047, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3041 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0050, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3043 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0053, (cst_val *)&val_3044},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0054, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3047 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0058, (cst_val *)&val_0420},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0059, (cst_val *)&val_3048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3050 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0062, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0063, (cst_val *)&val_2270},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0064, (cst_val *)&val_0575},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0065, (cst_val *)&val_2683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3053 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0069, (cst_val *)&val_2699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3055 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0072, (cst_val *)&val_0467},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0073, (cst_val *)&val_1626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3056 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0075, (cst_val *)&val_0618},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0076, (cst_val *)&val_3057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3060 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_189_NO_0080, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3063 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_w_189_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
NULL };

const cst_cart cmu_us_slt_single_mcep_w_189_cart = {
  cmu_us_slt_single_mcep_w_189_cart_nodes,
  cmu_us_slt_single_mcep_w_189_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_w_190_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0001, (cst_val *)&val_0740},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0002, (cst_val *)&val_0015},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0003, (cst_val *)&val_1019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0004, (cst_val *)&val_3064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3065 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0006, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3067 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0009, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3070 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0013, (cst_val *)&val_0284},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0014, (cst_val *)&val_1009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0015, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3072 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0018, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3073 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0020, (cst_val *)&val_3074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3076 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0023, (cst_val *)&val_0001},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0024, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3078 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0027, (cst_val *)&val_1422},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0028, (cst_val *)&val_0013},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0029, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3080 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3081 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0033, (cst_val *)&val_0618},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0034, (cst_val *)&val_3082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3085 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0038, (cst_val *)&val_0108},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0039, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0040, (cst_val *)&val_0643},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0041, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3086 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0043, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3087 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0045, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3088 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0047, (cst_val *)&val_2845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3090 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0050, (cst_val *)&val_1466},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0051, (cst_val *)&val_0395},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0052, (cst_val *)&val_3091},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3093 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0055, (cst_val *)&val_1463},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0056, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3096 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0060, (cst_val *)&val_0013},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0061, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3097 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0063, (cst_val *)&val_0824},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0064, (cst_val *)&val_0492},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0065, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3101 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0070, (cst_val *)&val_3102},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0071, (cst_val *)&val_0018},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0072, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3104 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0075, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3105 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0077, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3106 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0079, (cst_val *)&val_1227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3109 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0083, (cst_val *)&val_0200},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0084, (cst_val *)&val_1044},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0085, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3110 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0087, (cst_val *)&val_3111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3114 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0091, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3115 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0093, (cst_val *)&val_0313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3117 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0096, (cst_val *)&val_0057},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0097, (cst_val *)&val_0232},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0098, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3119 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0101, (cst_val *)&val_0408},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0102, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3120 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0104, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3122 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0107, (cst_val *)&val_0018},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0108, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3125 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0112, (cst_val *)&val_3126},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0113, (cst_val *)&val_0232},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0114, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3128 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0117, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0118, (cst_val *)&val_3129},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0119, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3131 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0122, (cst_val *)&val_3132},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0123, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3134 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0126, (cst_val *)&val_3135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3137 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0129, (cst_val *)&val_3138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3140 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_190_NO_0132, (cst_val *)&val_3141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3143 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_w_190_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_w_190_cart = {
  cmu_us_slt_single_mcep_w_190_cart_nodes,
  cmu_us_slt_single_mcep_w_190_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_w_191_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0000, (cst_val *)&val_0108},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0002, (cst_val *)&val_1341},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0003, (cst_val *)&val_0414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3144 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0005, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3146 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0008, (cst_val *)&val_0019},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0009, (cst_val *)&val_0140},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0010, (cst_val *)&val_0295},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0011, (cst_val *)&val_3147},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0012, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3152 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0018, (cst_val *)&val_0140},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0019, (cst_val *)&val_0365},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0020, (cst_val *)&val_3153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3155 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0023, (cst_val *)&val_3156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3159 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0027, (cst_val *)&val_3160},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0028, (cst_val *)&val_0019},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0029, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3162 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0032, (cst_val *)&val_3163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3165 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0035, (cst_val *)&val_0013},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0036, (cst_val *)&val_1044},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0037, (cst_val *)&val_2211},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0038, (cst_val *)&val_0140},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0039, (cst_val *)&val_3166},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3167 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0041, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3170 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0045, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3171 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0047, (cst_val *)&val_3172},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3174 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0050, (cst_val *)&val_3175},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0051, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3176 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0053, (cst_val *)&val_1143},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0054, (cst_val *)&val_3177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3180 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0058, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3181 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0060, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3183 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0063, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3184 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0065, (cst_val *)&val_0004},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0066, (cst_val *)&val_3185},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3187 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0069, (cst_val *)&val_0453},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0070, (cst_val *)&val_3188},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3191 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0074, (cst_val *)&val_0064},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0075, (cst_val *)&val_0014},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0076, (cst_val *)&val_3192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3194 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0079, (cst_val *)&val_3195},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0080, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3197 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0083, (cst_val *)&val_0740},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0084, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3199 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0087, (cst_val *)&val_0668},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0088, (cst_val *)&val_3200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3203 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0092, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0093, (cst_val *)&val_0019},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0094, (cst_val *)&val_3204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3206 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0097, (cst_val *)&val_3207},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3209 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0100, (cst_val *)&val_0014},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0101, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3211 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0104, (cst_val *)&val_3129},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0105, (cst_val *)&val_3212},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3214 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0108, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3215 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_w_191_NO_0110, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3217 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_w_191_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_w_191_cart = {
  cmu_us_slt_single_mcep_w_191_cart_nodes,
  cmu_us_slt_single_mcep_w_191_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_m_111_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0001, (cst_val *)&val_1071},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0002, (cst_val *)&val_1406},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0003, (cst_val *)&val_2468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3220 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0007, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3221 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3222 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0010, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0011, (cst_val *)&val_3223},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0012, (cst_val *)&val_3224},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3226 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0015, (cst_val *)&val_3227},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0016, (cst_val *)&val_0605},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0017, (cst_val *)&val_0025},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0018, (cst_val *)&val_0001},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0019, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0020, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3228 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0022, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3230 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0025, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3232 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0028, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3233 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0030, (cst_val *)&val_0123},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0031, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3235 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0034, (cst_val *)&val_2105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3236 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0036, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3237 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0038, (cst_val *)&val_2162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3239 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0041, (cst_val *)&val_0123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3240 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0043, (cst_val *)&val_3241},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0044, (cst_val *)&val_2707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3244 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0048, (cst_val *)&val_3245},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0049, (cst_val *)&val_3246},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0050, (cst_val *)&val_3247},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0051, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3248 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0053, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3252 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0058, (cst_val *)&val_3253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3254 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0060, (cst_val *)&val_2300},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3256 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0063, (cst_val *)&val_0073},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0064, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3257 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3258 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0067, (cst_val *)&val_3259},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0068, (cst_val *)&val_3260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3263 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0072, (cst_val *)&val_0232},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0073, (cst_val *)&val_3264},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0074, (cst_val *)&val_3265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3267 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0077, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3268 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0079, (cst_val *)&val_0017},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0080, (cst_val *)&val_0018},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0081, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3272 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0086, (cst_val *)&val_3273},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0087, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3274 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0089, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3276 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0092, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0093, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3277 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_111_NO_0095, (cst_val *)&val_3278},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3281 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_m_111_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_m_111_cart = {
  cmu_us_slt_single_mcep_m_111_cart_nodes,
  cmu_us_slt_single_mcep_m_111_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_m_112_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0001, (cst_val *)&val_0365},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0002, (cst_val *)&val_2300},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0003, (cst_val *)&val_3282},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0004, (cst_val *)&val_0061},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0005, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3284 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0008, (cst_val *)&val_3285},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0009, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3287 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0012, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3289 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0015, (cst_val *)&val_0088},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0016, (cst_val *)&val_1167},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0017, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3291 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0020, (cst_val *)&val_3292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3293 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3294 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0023, (cst_val *)&val_3295},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0024, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3297 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0027, (cst_val *)&val_0061},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0028, (cst_val *)&val_3298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3300 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0031, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3302 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0034, (cst_val *)&val_0099},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0035, (cst_val *)&val_0006},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0036, (cst_val *)&val_0395},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0037, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3305 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0041, (cst_val *)&val_3306},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0042, (cst_val *)&val_0395},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0043, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3307 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0045, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3310 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0049, (cst_val *)&val_3311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3313 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0052, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3314 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0054, (cst_val *)&val_3315},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0055, (cst_val *)&val_3316},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3317 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0057, (cst_val *)&val_2468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3319 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0060, (cst_val *)&val_3320},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0061, (cst_val *)&val_3321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3324 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0065, (cst_val *)&val_1407},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0066, (cst_val *)&val_0137},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0067, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3325 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0069, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3327 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0072, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3329 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0075, (cst_val *)&val_3330},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0076, (cst_val *)&val_0105},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0077, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3334 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0082, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0083, (cst_val *)&val_3335},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0084, (cst_val *)&val_0237},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0085, (cst_val *)&val_0989},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0086, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3336 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0088, (cst_val *)&val_3337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3338 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0090, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3340 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0093, (cst_val *)&val_3341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3343 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0096, (cst_val *)&val_3344},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0097, (cst_val *)&val_0061},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0098, (cst_val *)&val_3345},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3347 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0101, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0102, (cst_val *)&val_0440},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0103, (cst_val *)&val_0014},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0104, (cst_val *)&val_0433},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3351 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0109, (cst_val *)&val_0105},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0110, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3353 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0113, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3355 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0116, (cst_val *)&val_3356},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0117, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3357 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0119, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3358 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0121, (cst_val *)&val_3359},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0122, (cst_val *)&val_3360},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0123, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3361 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3362 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0126, (cst_val *)&val_3363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3365 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0129, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3367 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0132, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0133, (cst_val *)&val_3368},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0134, (cst_val *)&val_3369},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0135, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3371 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0138, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3374 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0142, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3375 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0144, (cst_val *)&val_0004},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0145, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3378 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0149, (cst_val *)&val_0006},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0150, (cst_val *)&val_0105},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0151, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3380 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0154, (cst_val *)&val_0023},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0155, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3382 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0158, (cst_val *)&val_3383},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0159, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3386 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0163, (cst_val *)&val_3387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3388 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0165, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3390 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0168, (cst_val *)&val_0186},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0169, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3391 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0171, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3393 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0174, (cst_val *)&val_0740},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0175, (cst_val *)&val_0014},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0176, (cst_val *)&val_0985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3396 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0180, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0181, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3397 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0183, (cst_val *)&val_0061},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0184, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3400 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0188, (cst_val *)&val_0900},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0189, (cst_val *)&val_0100},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0190, (cst_val *)&val_3401},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0191, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3404 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0195, (cst_val *)&val_3405},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3406 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0197, (cst_val *)&val_0001},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0198, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3408 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0201, (cst_val *)&val_1292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3409 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0203, (cst_val *)&val_1048},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0204, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3412 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0208, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3413 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_112_NO_0210, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3415 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_m_112_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"lisp_cg_phone_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_m_112_cart = {
  cmu_us_slt_single_mcep_m_112_cart_nodes,
  cmu_us_slt_single_mcep_m_112_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_m_113_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0001, (cst_val *)&val_2395},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0002, (cst_val *)&val_0617},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0003, (cst_val *)&val_0151},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0004, (cst_val *)&val_3416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3417 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0006, (cst_val *)&val_3418},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3419 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0008, (cst_val *)&val_3420},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0009, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0010, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3422 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0013, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3425 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0017, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3426 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0019, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3428 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0022, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3429 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0024, (cst_val *)&val_0099},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0025, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3430 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0027, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3432 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0030, (cst_val *)&val_0444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3434 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0033, (cst_val *)&val_3435},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0034, (cst_val *)&val_0390},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0035, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0036, (cst_val *)&val_3436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3439 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0040, (cst_val *)&val_0550},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0041, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3441 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0044, (cst_val *)&val_3442},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0045, (cst_val *)&val_3443},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0046, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3445 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0049, (cst_val *)&val_3446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3449 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0053, (cst_val *)&val_0056},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0054, (cst_val *)&val_3450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3452 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0057, (cst_val *)&val_3453},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3455 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0060, (cst_val *)&val_3456},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0061, (cst_val *)&val_0795},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0062, (cst_val *)&val_0004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0063, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0064, (cst_val *)&val_1571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3457 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0066, (cst_val *)&val_0108},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0067, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3458 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0069, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3460 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0072, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3462 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0075, (cst_val *)&val_0023},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0076, (cst_val *)&val_0284},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0077, (cst_val *)&val_3463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3464 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3466 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0081, (cst_val *)&val_0237},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0082, (cst_val *)&val_3467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3469 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0085, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3470 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0087, (cst_val *)&val_3471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3472 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0089, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3474 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0092, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3475 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0094, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3477 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0097, (cst_val *)&val_0004},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0098, (cst_val *)&val_0105},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0099, (cst_val *)&val_3478},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0100, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3479 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0102, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3480 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0104, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3482 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0107, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3484 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0110, (cst_val *)&val_3485},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0111, (cst_val *)&val_3486},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0112, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3489 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0116, (cst_val *)&val_0061},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0117, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3491 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0120, (cst_val *)&val_0395},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0121, (cst_val *)&val_0177},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0122, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3494 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0126, (cst_val *)&val_0597},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0127, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3497 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0131, (cst_val *)&val_0088},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0132, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3499 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0135, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3501 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0137, (cst_val *)&val_0023},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_m_113_NO_0138, (cst_val *)&val_3502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3506 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_m_113_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_m_113_cart = {
  cmu_us_slt_single_mcep_m_113_cart_nodes,
  cmu_us_slt_single_mcep_m_113_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_pau_143_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0000, (cst_val *)&val_1395},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0001, (cst_val *)&val_0232},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0002, (cst_val *)&val_1044},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0003, (cst_val *)&val_3507},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0004, (cst_val *)&val_3508},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3511 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0008, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3513 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0011, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0012, (cst_val *)&val_0004},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0013, (cst_val *)&val_0186},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0014, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0015, (cst_val *)&val_1571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3516 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0019, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0020, (cst_val *)&val_1571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3517 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3519 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0024, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0025, (cst_val *)&val_1287},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0026, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3520 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0028, (cst_val *)&val_0228},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0029, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3522 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0032, (cst_val *)&val_3523},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3525 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0035, (cst_val *)&val_3526},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0036, (cst_val *)&val_3527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3528 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0038, (cst_val *)&val_3529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3531 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0041, (cst_val *)&val_3532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3534 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0044, (cst_val *)&val_3535},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0045, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0046, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3537 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0049, (cst_val *)&val_0284},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0050, (cst_val *)&val_0018},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0051, (cst_val *)&val_0617},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0052, (cst_val *)&val_0309},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0053, (cst_val *)&val_3538},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0054, (cst_val *)&val_3539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3541 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0057, (cst_val *)&val_3542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3544 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0060, (cst_val *)&val_3545},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3548 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0064, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3549 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0066, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3551 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0069, (cst_val *)&val_0088},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0070, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3553 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0072, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3555 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0075, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0076, (cst_val *)&val_0309},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0077, (cst_val *)&val_3538},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0078, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3556 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0080, (cst_val *)&val_3557},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3559 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0083, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3561 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0086, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3563 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0089, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3565 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0092, (cst_val *)&val_0070},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0093, (cst_val *)&val_3526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3566 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0095, (cst_val *)&val_0681},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0096, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3568 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0099, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3569 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0101, (cst_val *)&val_3570},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0102, (cst_val *)&val_3571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3574 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0106, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3576 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0109, (cst_val *)&val_3577},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0110, (cst_val *)&val_0064},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0111, (cst_val *)&val_3578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3579 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0113, (cst_val *)&val_3580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3583 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0117, (cst_val *)&val_0681},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0118, (cst_val *)&val_3584},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0119, (cst_val *)&val_3535},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0120, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0121, (cst_val *)&val_2707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3586 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0124, (cst_val *)&val_3587},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3589 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0127, (cst_val *)&val_3590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3593 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0131, (cst_val *)&val_0004},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0132, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0133, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0134, (cst_val *)&val_0063},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3594 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0136, (cst_val *)&val_3595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3597 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0139, (cst_val *)&val_0942},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0140, (cst_val *)&val_3598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3600 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0143, (cst_val *)&val_3601},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0144, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3603 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0147, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3606 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0151, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0152, (cst_val *)&val_2858},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0153, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3607 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0155, (cst_val *)&val_0016},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0156, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3609 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0159, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3611 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0162, (cst_val *)&val_2533},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0163, (cst_val *)&val_3612},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0164, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3613 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0166, (cst_val *)&val_0023},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0167, (cst_val *)&val_0049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3616 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0171, (cst_val *)&val_0062},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0172, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3619 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0176, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3621 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0179, (cst_val *)&val_3622},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0180, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0181, (cst_val *)&val_0309},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0182, (cst_val *)&val_3538},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0183, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0184, (cst_val *)&val_1984},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0185, (cst_val *)&val_0223},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0186, (cst_val *)&val_0995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3624 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0189, (cst_val *)&val_3625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3626 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0191, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3628 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0194, (cst_val *)&val_3629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3631 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0197, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3633 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0200, (cst_val *)&val_0040},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0201, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0202, (cst_val *)&val_3450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3635 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0204, (cst_val *)&val_1908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3639 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0209, (cst_val *)&val_3640},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0210, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3641 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0212, (cst_val *)&val_3642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3643 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0214, (cst_val *)&val_1713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3646 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0218, (cst_val *)&val_0105},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0219, (cst_val *)&val_0548},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0220, (cst_val *)&val_3647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3650 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0224, (cst_val *)&val_1085},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0225, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3652 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0228, (cst_val *)&val_3653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3655 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0231, (cst_val *)&val_0105},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0232, (cst_val *)&val_0059},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3656 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0234, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3658 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0237, (cst_val *)&val_3570},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0238, (cst_val *)&val_3659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3660 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0240, (cst_val *)&val_3661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3663 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0243, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3665 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0246, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0247, (cst_val *)&val_3666},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0248, (cst_val *)&val_0309},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0249, (cst_val *)&val_3538},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0250, (cst_val *)&val_0617},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0251, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0252, (cst_val *)&val_2509},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0253, (cst_val *)&val_0343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3669 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0257, (cst_val *)&val_3661},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0258, (cst_val *)&val_3670},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0259, (cst_val *)&val_0084},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0260, (cst_val *)&val_1400},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0261, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3673 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0265, (cst_val *)&val_2193},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0266, (cst_val *)&val_1178},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0267, (cst_val *)&val_3674},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0268, (cst_val *)&val_3542},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0269, (cst_val *)&val_3253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3675 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0271, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3678 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0274, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3680 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0277, (cst_val *)&val_1028},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0278, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3682 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0281, (cst_val *)&val_3683},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0282, (cst_val *)&val_3684},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3685 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0284, (cst_val *)&val_3686},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3689 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0288, (cst_val *)&val_3690},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3692 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0291, (cst_val *)&val_3693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3694 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3695 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0294, (cst_val *)&val_3696},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0295, (cst_val *)&val_3612},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0296, (cst_val *)&val_3697},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3699 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0299, (cst_val *)&val_3700},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0300, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3702 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0303, (cst_val *)&val_3703},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0304, (cst_val *)&val_3704},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0305, (cst_val *)&val_3705},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0306, (cst_val *)&val_3706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3709 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0310, (cst_val *)&val_3710},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3712 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0313, (cst_val *)&val_3713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3715 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0316, (cst_val *)&val_3716},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0317, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0318, (cst_val *)&val_3717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3718 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0320, (cst_val *)&val_3590},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0321, (cst_val *)&val_3719},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0322, (cst_val *)&val_3720},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0323, (cst_val *)&val_0038},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3722 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0326, (cst_val *)&val_3676},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3724 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0329, (cst_val *)&val_3725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3726 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0331, (cst_val *)&val_0806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3728 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0334, (cst_val *)&val_3729},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0335, (cst_val *)&val_3730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3734 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0340, (cst_val *)&val_3735},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0341, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3737 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0344, (cst_val *)&val_3738},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0345, (cst_val *)&val_3739},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0346, (cst_val *)&val_3740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3744 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0351, (cst_val *)&val_3745},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0352, (cst_val *)&val_0047},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0353, (cst_val *)&val_3746},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0354, (cst_val *)&val_3747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3748 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0356, (cst_val *)&val_3749},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3753 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0361, (cst_val *)&val_3539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3754 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0363, (cst_val *)&val_3755},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3757 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0366, (cst_val *)&val_1984},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0367, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3758 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0369, (cst_val *)&val_3601},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0370, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3759 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0372, (cst_val *)&val_3760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3761 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3762 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3763 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0376, (cst_val *)&val_0088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0377, (cst_val *)&val_3764},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0378, (cst_val *)&val_3765},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0379, (cst_val *)&val_3552},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0380, (cst_val *)&val_3766},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0381, (cst_val *)&val_3767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3768 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0383, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3770 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0386, (cst_val *)&val_3771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3772 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0388, (cst_val *)&val_3773},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3775 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0391, (cst_val *)&val_3612},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0392, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3778 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0396, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0397, (cst_val *)&val_3779},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0398, (cst_val *)&val_3780},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0399, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3782 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0402, (cst_val *)&val_3783},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0403, (cst_val *)&val_3784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3786 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0406, (cst_val *)&val_3787},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3789 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0409, (cst_val *)&val_3661},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0410, (cst_val *)&val_3790},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0411, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3792 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0414, (cst_val *)&val_3735},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0415, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3794 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0418, (cst_val *)&val_0044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3796 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0421, (cst_val *)&val_3797},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0422, (cst_val *)&val_3798},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0423, (cst_val *)&val_3799},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0424, (cst_val *)&val_3800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3804 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0429, (cst_val *)&val_3805},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0430, (cst_val *)&val_0050},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3809 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0435, (cst_val *)&val_0053},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0436, (cst_val *)&val_3810},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3811 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0438, (cst_val *)&val_3812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3814 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0441, (cst_val *)&val_3661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3816 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0444, (cst_val *)&val_3817},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0445, (cst_val *)&val_3704},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0446, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3819 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3820 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0450, (cst_val *)&val_0001},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0451, (cst_val *)&val_3821},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0452, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3822 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0454, (cst_val *)&val_3823},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0455, (cst_val *)&val_3824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3825 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0457, (cst_val *)&val_3826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3828 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0460, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3830 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0463, (cst_val *)&val_3805},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0464, (cst_val *)&val_3831},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0465, (cst_val *)&val_3832},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0466, (cst_val *)&val_3833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3834 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0468, (cst_val *)&val_3835},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0469, (cst_val *)&val_3836},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0470, (cst_val *)&val_3837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3839 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0473, (cst_val *)&val_3840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3842 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0476, (cst_val *)&val_3843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3846 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0480, (cst_val *)&val_3847},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3849 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0483, (cst_val *)&val_3850},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0484, (cst_val *)&val_3851},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0485, (cst_val *)&val_3852},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0486, (cst_val *)&val_1908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3856 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0491, (cst_val *)&val_3826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3858 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0494, (cst_val *)&val_0004},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0495, (cst_val *)&val_3859},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0496, (cst_val *)&val_3860},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0497, (cst_val *)&val_0105},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0498, (cst_val *)&val_1061},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0499, (cst_val *)&val_3861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3862 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0501, (cst_val *)&val_3812},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3864 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0504, (cst_val *)&val_3865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3867 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0507, (cst_val *)&val_3821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3869 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3870 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0511, (cst_val *)&val_3860},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0512, (cst_val *)&val_0105},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0513, (cst_val *)&val_3871},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0514, (cst_val *)&val_3872},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3874 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0517, (cst_val *)&val_2643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3875 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0519, (cst_val *)&val_3861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3877 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0522, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3878 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0524, (cst_val *)&val_3821},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3880 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0527, (cst_val *)&val_3881},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3883 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0530, (cst_val *)&val_3598},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0531, (cst_val *)&val_3884},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0532, (cst_val *)&val_3885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3888 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0536, (cst_val *)&val_1338},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0537, (cst_val *)&val_0049},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0538, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3891 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0542, (cst_val *)&val_1406},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0543, (cst_val *)&val_0105},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0544, (cst_val *)&val_3861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3892 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0546, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3893 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0548, (cst_val *)&val_3894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3895 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3896 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0551, (cst_val *)&val_3897},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3899 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0554, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0555, (cst_val *)&val_3900},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0556, (cst_val *)&val_3901},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3902 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0558, (cst_val *)&val_3903},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0559, (cst_val *)&val_3904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3907 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0563, (cst_val *)&val_3908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3910 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0566, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3912 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0569, (cst_val *)&val_2643},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0570, (cst_val *)&val_3894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3914 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0573, (cst_val *)&val_3507},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0574, (cst_val *)&val_3915},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3917 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0577, (cst_val *)&val_0105},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0578, (cst_val *)&val_3861},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0579, (cst_val *)&val_3918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3919 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0581, (cst_val *)&val_3920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3921 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0583, (cst_val *)&val_3922},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0584, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0585, (cst_val *)&val_3923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3926 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0589, (cst_val *)&val_3764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3928 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0592, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0593, (cst_val *)&val_3897},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3930 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0596, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3932 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0599, (cst_val *)&val_0064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0600, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0601, (cst_val *)&val_3933},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0602, (cst_val *)&val_3934},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0603, (cst_val *)&val_3935},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0604, (cst_val *)&val_0516},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0605, (cst_val *)&val_3936},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0606, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0607, (cst_val *)&val_1984},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0608, (cst_val *)&val_1648},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0609, (cst_val *)&val_3937},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0610, (cst_val *)&val_1619},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0611, (cst_val *)&val_0284},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0612, (cst_val *)&val_1576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3940 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0616, (cst_val *)&val_3941},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0617, (cst_val *)&val_0284},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0618, (cst_val *)&val_2688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3945 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0623, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3947 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0626, (cst_val *)&val_0384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3949 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0629, (cst_val *)&val_3950},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3952 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0632, (cst_val *)&val_3953},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0633, (cst_val *)&val_0637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3954 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0635, (cst_val *)&val_3955},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0636, (cst_val *)&val_2905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3960 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0642, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3962 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0645, (cst_val *)&val_3765},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0646, (cst_val *)&val_3766},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0647, (cst_val *)&val_3963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3965 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0650, (cst_val *)&val_3771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3967 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0653, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0654, (cst_val *)&val_3446},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0655, (cst_val *)&val_0034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3971 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0660, (cst_val *)&val_3659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3972 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0662, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0663, (cst_val *)&val_3590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3973 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0665, (cst_val *)&val_3974},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3977 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0669, (cst_val *)&val_3634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0670, (cst_val *)&val_3978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3979 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0672, (cst_val *)&val_0337},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3983 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0677, (cst_val *)&val_3984},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0678, (cst_val *)&val_3985},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0679, (cst_val *)&val_3986},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0680, (cst_val *)&val_3634},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0681, (cst_val *)&val_3436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3989 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0685, (cst_val *)&val_3634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3990 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0687, (cst_val *)&val_3991},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3994 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0691, (cst_val *)&val_0105},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0692, (cst_val *)&val_0769},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0693, (cst_val *)&val_3861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3995 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0695, (cst_val *)&val_3996},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0696, (cst_val *)&val_3634},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0697, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_3999 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0701, (cst_val *)&val_3894},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4001 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0704, (cst_val *)&val_1571},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0705, (cst_val *)&val_3812},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0706, (cst_val *)&val_4002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4004 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0709, (cst_val *)&val_4005},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0710, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4009 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0715, (cst_val *)&val_2492},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0716, (cst_val *)&val_4010},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0717, (cst_val *)&val_3590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4013 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0721, (cst_val *)&val_3812},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0722, (cst_val *)&val_3634},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0723, (cst_val *)&val_4010},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0724, (cst_val *)&val_3861},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0725, (cst_val *)&val_3590},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0726, (cst_val *)&val_3725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4014 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0728, (cst_val *)&val_4015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4020 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0734, (cst_val *)&val_3861},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0735, (cst_val *)&val_3590},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0736, (cst_val *)&val_0041},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4024 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0741, (cst_val *)&val_3884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4026 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0744, (cst_val *)&val_0301},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0745, (cst_val *)&val_3640},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0746, (cst_val *)&val_3642},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0747, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0748, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4028 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0751, (cst_val *)&val_3934},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0752, (cst_val *)&val_4029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4030 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0754, (cst_val *)&val_3936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4033 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0758, (cst_val *)&val_3442},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0759, (cst_val *)&val_1606},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0760, (cst_val *)&val_4034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4037 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0764, (cst_val *)&val_0617},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0765, (cst_val *)&val_4034},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0766, (cst_val *)&val_3612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4040 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0770, (cst_val *)&val_4041},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0771, (cst_val *)&val_3936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4043 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0774, (cst_val *)&val_4044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4046 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0777, (cst_val *)&val_2700},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0778, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4048 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0781, (cst_val *)&val_4049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4051 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0784, (cst_val *)&val_3507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4052 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0786, (cst_val *)&val_3783},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0787, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0788, (cst_val *)&val_3527},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0789, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4053 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0791, (cst_val *)&val_1614},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0792, (cst_val *)&val_1531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4056 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0796, (cst_val *)&val_1531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4058 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0799, (cst_val *)&val_3766},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0800, (cst_val *)&val_0769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4059 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0802, (cst_val *)&val_3640},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0803, (cst_val *)&val_3642},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0804, (cst_val *)&val_0343},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0805, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4060 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4061 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0808, (cst_val *)&val_3936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4063 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0811, (cst_val *)&val_4064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0812, (cst_val *)&val_0266},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0813, (cst_val *)&val_0617},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0814, (cst_val *)&val_4034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4067 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0818, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4068 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4070 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0822, (cst_val *)&val_2700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4072 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0825, (cst_val *)&val_4034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4074 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0828, (cst_val *)&val_3642},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0829, (cst_val *)&val_0064},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0830, (cst_val *)&val_4075},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4077 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0833, (cst_val *)&val_0105},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0834, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4079 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0837, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4080 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0839, (cst_val *)&val_4081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4083 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0842, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0843, (cst_val *)&val_4034},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0844, (cst_val *)&val_1891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4085 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0847, (cst_val *)&val_4086},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0848, (cst_val *)&val_4087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4088 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4090 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0852, (cst_val *)&val_4091},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0853, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4092 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0855, (cst_val *)&val_1932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4096 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0860, (cst_val *)&val_4097},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0861, (cst_val *)&val_0001},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0862, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4098 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0864, (cst_val *)&val_4099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4100 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0866, (cst_val *)&val_1463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4102 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0869, (cst_val *)&val_0018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0870, (cst_val *)&val_0617},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0871, (cst_val *)&val_0105},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0872, (cst_val *)&val_4103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4104 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0874, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4106 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0877, (cst_val *)&val_0228},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0878, (cst_val *)&val_0137},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0879, (cst_val *)&val_3674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4108 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0882, (cst_val *)&val_4109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4110 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0884, (cst_val *)&val_4111},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4113 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0887, (cst_val *)&val_3545},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0888, (cst_val *)&val_0061},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0889, (cst_val *)&val_4114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4115 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4118 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0894, (cst_val *)&val_4103},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0895, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4120 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0898, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4122 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0901, (cst_val *)&val_0064},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0902, (cst_val *)&val_0237},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0903, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4123 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0905, (cst_val *)&val_0217},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0906, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4126 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0910, (cst_val *)&val_0617},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0911, (cst_val *)&val_4127},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0912, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4128 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0914, (cst_val *)&val_1318},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0915, (cst_val *)&val_4129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4132 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0919, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4134 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0922, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4136 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0925, (cst_val *)&val_0018},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0926, (cst_val *)&val_4137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4140 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0930, (cst_val *)&val_2377},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0931, (cst_val *)&val_0018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0932, (cst_val *)&val_0617},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0933, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0934, (cst_val *)&val_4141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4143 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0937, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0938, (cst_val *)&val_4144},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0939, (cst_val *)&val_4145},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4147 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0942, (cst_val *)&val_4148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4150 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0945, (cst_val *)&val_3129},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0946, (cst_val *)&val_4151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4153 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0949, (cst_val *)&val_3937},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4154 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0951, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4156 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0954, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4158 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0957, (cst_val *)&val_0064},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0958, (cst_val *)&val_0004},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0959, (cst_val *)&val_0617},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0960, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4161 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0964, (cst_val *)&val_3507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4162 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0966, (cst_val *)&val_0217},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0967, (cst_val *)&val_4163},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0968, (cst_val *)&val_1577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4164 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0970, (cst_val *)&val_3674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4167 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0974, (cst_val *)&val_4168},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4170 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0977, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0978, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4171 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0980, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4174 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0984, (cst_val *)&val_4175},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0985, (cst_val *)&val_4176},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0986, (cst_val *)&val_0395},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0987, (cst_val *)&val_2515},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0988, (cst_val *)&val_4177},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0989, (cst_val *)&val_3598},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4181 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0994, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4182 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0996, (cst_val *)&val_4010},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_0997, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4184 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1000, (cst_val *)&val_0105},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1001, (cst_val *)&val_2858},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1002, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4187 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1006, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4188 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1008, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4189 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1010, (cst_val *)&val_0064},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1011, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4191 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1014, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4192 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1016, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4194 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1019, (cst_val *)&val_0014},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1020, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4196 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1023, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4197 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1025, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4198 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1027, (cst_val *)&val_4199},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1028, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1029, (cst_val *)&val_2533},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1030, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4201 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1033, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4203 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1036, (cst_val *)&val_4204},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1037, (cst_val *)&val_4204},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1038, (cst_val *)&val_3766},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1039, (cst_val *)&val_4205},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4209 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1044, (cst_val *)&val_2509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4211 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1047, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4213 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1050, (cst_val *)&val_1614},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1051, (cst_val *)&val_3532},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1052, (cst_val *)&val_0137},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1053, (cst_val *)&val_4214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4216 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1056, (cst_val *)&val_0018},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1057, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1058, (cst_val *)&val_4217},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1059, (cst_val *)&val_1577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4219 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1062, (cst_val *)&val_1407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4221 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1065, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1066, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4223 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1069, (cst_val *)&val_0169},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1070, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4224 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1072, (cst_val *)&val_3764},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4225 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1074, (cst_val *)&val_1178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4227 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1077, (cst_val *)&val_3670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4229 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1080, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4231 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1083, (cst_val *)&val_0023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1084, (cst_val *)&val_4232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4234 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1087, (cst_val *)&val_4214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4235 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1089, (cst_val *)&val_4236},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1090, (cst_val *)&val_4237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4240 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1094, (cst_val *)&val_2533},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1095, (cst_val *)&val_4241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4242 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1097, (cst_val *)&val_0055},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1098, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4243 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1100, (cst_val *)&val_4244},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4247 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1104, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4248 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1106, (cst_val *)&val_4249},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1107, (cst_val *)&val_4250},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_143_NO_1108, (cst_val *)&val_4251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4255 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_pau_143_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
NULL };

const cst_cart cmu_us_slt_single_mcep_pau_143_cart = {
  cmu_us_slt_single_mcep_pau_143_cart_nodes,
  cmu_us_slt_single_mcep_pau_143_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ao_16_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0001, (cst_val *)&val_0132},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0002, (cst_val *)&val_0217},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0003, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4257 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0006, (cst_val *)&val_0371},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4259 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0009, (cst_val *)&val_4260},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0010, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4261 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0012, (cst_val *)&val_4262},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4265 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0016, (cst_val *)&val_0004},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0017, (cst_val *)&val_0061},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0018, (cst_val *)&val_2699},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0019, (cst_val *)&val_1406},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0020, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4267 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0023, (cst_val *)&val_4268},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0024, (cst_val *)&val_1470},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0025, (cst_val *)&val_4269},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4271 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0028, (cst_val *)&val_4272},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0029, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4276 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0034, (cst_val *)&val_0034},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0035, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4278 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0038, (cst_val *)&val_4279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4281 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0041, (cst_val *)&val_0705},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0042, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4282 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0044, (cst_val *)&val_4283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4285 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0047, (cst_val *)&val_0073},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0048, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4286 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0050, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4287 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4289 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0054, (cst_val *)&val_0105},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0055, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4290 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0057, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4292 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0060, (cst_val *)&val_4293},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0061, (cst_val *)&val_4294},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0062, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0063, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4298 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0068, (cst_val *)&val_0232},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0069, (cst_val *)&val_0218},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0070, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4300 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0073, (cst_val *)&val_4301},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0074, (cst_val *)&val_4302},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0075, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4304 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0078, (cst_val *)&val_4305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4307 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_16_NO_0081, (cst_val *)&val_4308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4311 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ao_16_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_slt_single_mcep_ao_16_cart = {
  cmu_us_slt_single_mcep_ao_16_cart_nodes,
  cmu_us_slt_single_mcep_ao_16_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ao_17_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0001, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4312 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0003, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0004, (cst_val *)&val_4313},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0005, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4315 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0008, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4317 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0011, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4318 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0013, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0014, (cst_val *)&val_0061},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0015, (cst_val *)&val_4319},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0016, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4323 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0021, (cst_val *)&val_4324},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0022, (cst_val *)&val_0575},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0023, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4327 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0027, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4328 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0029, (cst_val *)&val_4329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4331 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0032, (cst_val *)&val_0140},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0033, (cst_val *)&val_0287},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0034, (cst_val *)&val_4332},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0035, (cst_val *)&val_4333},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0036, (cst_val *)&val_0217},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0037, (cst_val *)&val_4334},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4336 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0040, (cst_val *)&val_3442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4340 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0045, (cst_val *)&val_4341},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0046, (cst_val *)&val_4342},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0047, (cst_val *)&val_4343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4345 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0050, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4346 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0052, (cst_val *)&val_1295},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0053, (cst_val *)&val_0076},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0054, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4347 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0056, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4348 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0058, (cst_val *)&val_2932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4350 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0061, (cst_val *)&val_4351},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4352 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0063, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4355 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0067, (cst_val *)&val_4356},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0068, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4359 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0072, (cst_val *)&val_0365},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0073, (cst_val *)&val_4360},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0074, (cst_val *)&val_0108},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0075, (cst_val *)&val_0108},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0076, (cst_val *)&val_0239},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0077, (cst_val *)&val_4361},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0078, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4363 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0081, (cst_val *)&val_0023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0082, (cst_val *)&val_2775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4365 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0085, (cst_val *)&val_0516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4368 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0089, (cst_val *)&val_4369},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0090, (cst_val *)&val_3557},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4371 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0093, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4373 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0096, (cst_val *)&val_0020},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0097, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4375 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0100, (cst_val *)&val_1071},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0101, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0102, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4378 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0106, (cst_val *)&val_4379},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0107, (cst_val *)&val_3934},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0108, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4380 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0110, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4381 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0112, (cst_val *)&val_4382},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4383 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0114, (cst_val *)&val_4384},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0115, (cst_val *)&val_4385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4389 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0120, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4391 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0123, (cst_val *)&val_0061},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0124, (cst_val *)&val_4392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4394 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0127, (cst_val *)&val_4395},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0128, (cst_val *)&val_4396},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0129, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4399 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0133, (cst_val *)&val_0064},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0134, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4401 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0137, (cst_val *)&val_4402},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0138, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4405 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0142, (cst_val *)&val_0004},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0143, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4406 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0145, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4408 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0148, (cst_val *)&val_4409},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0149, (cst_val *)&val_0621},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0150, (cst_val *)&val_4410},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0151, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4414 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0156, (cst_val *)&val_0011},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_17_NO_0157, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4416 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4417 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ao_17_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
NULL };

const cst_cart cmu_us_slt_single_mcep_ao_17_cart = {
  cmu_us_slt_single_mcep_ao_17_cart_nodes,
  cmu_us_slt_single_mcep_ao_17_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ao_18_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0000, (cst_val *)&val_0828},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0001, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4418 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0003, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0004, (cst_val *)&val_4419},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4420 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0006, (cst_val *)&val_4421},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4422 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0008, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4423 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0010, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4424 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0012, (cst_val *)&val_0001},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0013, (cst_val *)&val_1489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4427 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0017, (cst_val *)&val_0012},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0018, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4429 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0021, (cst_val *)&val_4430},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0022, (cst_val *)&val_0169},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0023, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4433 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0027, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4434 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0029, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4436 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0032, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0033, (cst_val *)&val_4437},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0034, (cst_val *)&val_4438},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0035, (cst_val *)&val_4439},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0036, (cst_val *)&val_4440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4441 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0038, (cst_val *)&val_4442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4444 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0041, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4446 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0044, (cst_val *)&val_4447},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0045, (cst_val *)&val_0373},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0046, (cst_val *)&val_4448},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4450 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0049, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4451 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0051, (cst_val *)&val_4452},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4454 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0054, (cst_val *)&val_4439},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0055, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4455 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0057, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4457 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0060, (cst_val *)&val_4458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4459 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0062, (cst_val *)&val_4460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4462 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0065, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4463 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0067, (cst_val *)&val_4464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4466 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0070, (cst_val *)&val_1978},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0071, (cst_val *)&val_0061},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0072, (cst_val *)&val_4467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4469 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0075, (cst_val *)&val_1489},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0076, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4471 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0079, (cst_val *)&val_4472},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0080, (cst_val *)&val_0048},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0081, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4473 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0083, (cst_val *)&val_4474},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0084, (cst_val *)&val_4475},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4480 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0090, (cst_val *)&val_4481},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0091, (cst_val *)&val_4482},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4483 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0093, (cst_val *)&val_4232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4485 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0096, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0097, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4486 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0099, (cst_val *)&val_4487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4488 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0101, (cst_val *)&val_1970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4490 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0104, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4491 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0106, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4492 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0108, (cst_val *)&val_3984},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ao_18_NO_0109, (cst_val *)&val_0223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4495 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ao_18_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_ao_18_cart = {
  cmu_us_slt_single_mcep_ao_18_cart_nodes,
  cmu_us_slt_single_mcep_ao_18_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_th_169_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0001, (cst_val *)&val_0009},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0002, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4497 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0005, (cst_val *)&val_4498},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4500 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0008, (cst_val *)&val_0643},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0009, (cst_val *)&val_0064},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0010, (cst_val *)&val_2118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4502 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0013, (cst_val *)&val_0643},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0014, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4503 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0016, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4505 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0019, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4507 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0022, (cst_val *)&val_0239},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0023, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0024, (cst_val *)&val_4508},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4510 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0027, (cst_val *)&val_2468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4512 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0030, (cst_val *)&val_0652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4513 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_169_NO_0032, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4515 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_th_169_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
NULL };

const cst_cart cmu_us_slt_single_mcep_th_169_cart = {
  cmu_us_slt_single_mcep_th_169_cart_nodes,
  cmu_us_slt_single_mcep_th_169_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_th_170_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0001, (cst_val *)&val_1044},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0002, (cst_val *)&val_3200},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0003, (cst_val *)&val_0942},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0004, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0005, (cst_val *)&val_1221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4517 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0008, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4519 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0011, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0012, (cst_val *)&val_1928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4522 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0016, (cst_val *)&val_4313},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0017, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4523 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0019, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0020, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4526 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0024, (cst_val *)&val_4527},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0025, (cst_val *)&val_2661},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0026, (cst_val *)&val_0232},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0027, (cst_val *)&val_4528},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4530 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0030, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4532 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0033, (cst_val *)&val_4533},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4535 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0036, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4537 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0039, (cst_val *)&val_4538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4539 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0041, (cst_val *)&val_4540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4542 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0044, (cst_val *)&val_1347},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0045, (cst_val *)&val_4543},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4544 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0047, (cst_val *)&val_0621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4546 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_170_NO_0050, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4548 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_th_170_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
NULL };

const cst_cart cmu_us_slt_single_mcep_th_170_cart = {
  cmu_us_slt_single_mcep_th_170_cart_nodes,
  cmu_us_slt_single_mcep_th_170_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_th_171_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0000, (cst_val *)&val_0047},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0001, (cst_val *)&val_0795},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0002, (cst_val *)&val_4549},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4551 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0005, (cst_val *)&val_0140},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0006, (cst_val *)&val_0769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4552 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0008, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4554 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0011, (cst_val *)&val_0015},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0012, (cst_val *)&val_4555},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0013, (cst_val *)&val_3580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4559 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0018, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4560 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0020, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4561 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_th_171_NO_0022, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4563 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_th_171_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_slt_single_mcep_th_171_cart = {
  cmu_us_slt_single_mcep_th_171_cart_nodes,
  cmu_us_slt_single_mcep_th_171_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ah_11_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0001, (cst_val *)&val_0295},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0002, (cst_val *)&val_0217},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0003, (cst_val *)&val_1395},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0004, (cst_val *)&val_1671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4566 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0008, (cst_val *)&val_2064},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0009, (cst_val *)&val_0237},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0010, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4568 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0013, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4569 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0015, (cst_val *)&val_4570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4572 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0018, (cst_val *)&val_4573},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0019, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4576 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0023, (cst_val *)&val_2005},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0024, (cst_val *)&val_1036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4578 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0027, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4580 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0030, (cst_val *)&val_1355},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0031, (cst_val *)&val_0228},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0032, (cst_val *)&val_0709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4582 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0035, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4584 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0038, (cst_val *)&val_0232},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0039, (cst_val *)&val_0108},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0040, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4587 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0044, (cst_val *)&val_0264},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0045, (cst_val *)&val_0795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4588 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0047, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4590 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0050, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0051, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4592 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0054, (cst_val *)&val_0705},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0055, (cst_val *)&val_4593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4594 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4595 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0058, (cst_val *)&val_4596},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0059, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0060, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4598 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_11_NO_0063, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4599 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4601 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ah_11_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_ah_11_cart = {
  cmu_us_slt_single_mcep_ah_11_cart_nodes,
  cmu_us_slt_single_mcep_ah_11_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ah_12_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0000, (cst_val *)&val_4602},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0001, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0002, (cst_val *)&val_4603},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0003, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4605 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0006, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4607 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0009, (cst_val *)&val_0088},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0010, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4608 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0012, (cst_val *)&val_4609},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0013, (cst_val *)&val_4610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4611 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0015, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4614 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0019, (cst_val *)&val_0061},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0020, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4616 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0023, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0024, (cst_val *)&val_4617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4620 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0028, (cst_val *)&val_0140},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0029, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0030, (cst_val *)&val_2468},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0031, (cst_val *)&val_1395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4622 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0034, (cst_val *)&val_4623},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4625 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0037, (cst_val *)&val_0088},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0038, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4627 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0041, (cst_val *)&val_2775},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0042, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4628 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0044, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4629 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0046, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4631 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4632 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0050, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0051, (cst_val *)&val_4633},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0052, (cst_val *)&val_4634},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0053, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4635 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0055, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4638 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0059, (cst_val *)&val_4639},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0060, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4640 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0062, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4641 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0064, (cst_val *)&val_4642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4644 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0067, (cst_val *)&val_1804},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0068, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4645 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0070, (cst_val *)&val_4646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4648 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0073, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0074, (cst_val *)&val_0137},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0075, (cst_val *)&val_4649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4651 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0078, (cst_val *)&val_1395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4653 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0081, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4654 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0083, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4656 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0086, (cst_val *)&val_0088},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0087, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4657 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0089, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0090, (cst_val *)&val_4658},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0091, (cst_val *)&val_4659},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4661 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0094, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4663 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0097, (cst_val *)&val_0969},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0098, (cst_val *)&val_1006},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0099, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4666 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4667 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0104, (cst_val *)&val_0105},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0105, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4669 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0108, (cst_val *)&val_0590},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0109, (cst_val *)&val_0669},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0110, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4670 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4671 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0113, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4673 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0116, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4674 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0118, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4675 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0120, (cst_val *)&val_1693},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0121, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4677 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_12_NO_0124, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4679 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ah_12_feat_table[] = {
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
NULL };

const cst_cart cmu_us_slt_single_mcep_ah_12_cart = {
  cmu_us_slt_single_mcep_ah_12_cart_nodes,
  cmu_us_slt_single_mcep_ah_12_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ah_13_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0000, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0001, (cst_val *)&val_4680},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0002, (cst_val *)&val_4681},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0003, (cst_val *)&val_2280},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0004, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4685 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0009, (cst_val *)&val_0023},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0010, (cst_val *)&val_0001},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0011, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4689 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0016, (cst_val *)&val_1812},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0017, (cst_val *)&val_2064},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0018, (cst_val *)&val_0004},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0019, (cst_val *)&val_0373},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0020, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4690 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0022, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4692 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0025, (cst_val *)&val_0023},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0026, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4693 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0028, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4694 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0030, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4696 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0033, (cst_val *)&val_0088},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0034, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4697 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0036, (cst_val *)&val_1838},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4698 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4700 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0040, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4702 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0043, (cst_val *)&val_0399},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0044, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0045, (cst_val *)&val_0391},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0046, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4705 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0050, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4706 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0052, (cst_val *)&val_4707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4709 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0055, (cst_val *)&val_0477},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4710 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0057, (cst_val *)&val_0228},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0058, (cst_val *)&val_4711},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0059, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4712 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0061, (cst_val *)&val_2728},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4714 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0064, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4715 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0066, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4717 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0069, (cst_val *)&val_0105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0070, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4719 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0073, (cst_val *)&val_0046},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0074, (cst_val *)&val_0082},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0075, (cst_val *)&val_0095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4722 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0079, (cst_val *)&val_1019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4724 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ah_13_NO_0082, (cst_val *)&val_4725},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4727 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ah_13_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_ah_13_cart = {
  cmu_us_slt_single_mcep_ah_13_cart_nodes,
  cmu_us_slt_single_mcep_ah_13_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_v_184_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0002, (cst_val *)&val_2103},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0003, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4729 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0006, (cst_val *)&val_0018},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0007, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0008, (cst_val *)&val_4730},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0009, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4732 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0012, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4734 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0015, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0016, (cst_val *)&val_4735},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4737 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0019, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4739 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0022, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4740 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0024, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4742 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0027, (cst_val *)&val_0008},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0028, (cst_val *)&val_0365},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0029, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4743 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0031, (cst_val *)&val_1928},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0032, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4747 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0037, (cst_val *)&val_4748},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0038, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4749 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4750 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0041, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4751 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0043, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4753 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_184_NO_0046, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4755 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_v_184_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_v_184_cart = {
  cmu_us_slt_single_mcep_v_184_cart_nodes,
  cmu_us_slt_single_mcep_v_184_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_v_185_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0000, (cst_val *)&val_0675},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0001, (cst_val *)&val_0433},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0003, (cst_val *)&val_4756},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0004, (cst_val *)&val_4757},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0005, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4761 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0010, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0011, (cst_val *)&val_0004},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0012, (cst_val *)&val_4762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4764 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0015, (cst_val *)&val_0287},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0016, (cst_val *)&val_4765},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4769 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0021, (cst_val *)&val_1009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4771 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0024, (cst_val *)&val_0218},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0025, (cst_val *)&val_0232},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0026, (cst_val *)&val_4772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4774 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0029, (cst_val *)&val_0679},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0030, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4775 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0032, (cst_val *)&val_4776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4777 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0034, (cst_val *)&val_4778},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4780 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0037, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4781 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0039, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4782 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0041, (cst_val *)&val_4783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4785 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0044, (cst_val *)&val_0018},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0045, (cst_val *)&val_0232},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0046, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4787 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0049, (cst_val *)&val_1221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4789 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0052, (cst_val *)&val_0140},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0053, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4790 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0055, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4792 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_185_NO_0058, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4794 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_v_185_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_v_185_cart = {
  cmu_us_slt_single_mcep_v_185_cart_nodes,
  cmu_us_slt_single_mcep_v_185_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_v_186_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0001, (cst_val *)&val_1071},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0002, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0003, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4796 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0006, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4797 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0008, (cst_val *)&val_4798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4800 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0011, (cst_val *)&val_4801},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0012, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4802 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0014, (cst_val *)&val_0652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4803 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0016, (cst_val *)&val_4804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4805 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4806 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0019, (cst_val *)&val_0433},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0020, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4808 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0023, (cst_val *)&val_4809},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4810 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0025, (cst_val *)&val_0445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4812 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0028, (cst_val *)&val_0942},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0029, (cst_val *)&val_0942},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0030, (cst_val *)&val_0004},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0031, (cst_val *)&val_0023},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0032, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4814 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0035, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0036, (cst_val *)&val_4815},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4818 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0040, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4819 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0042, (cst_val *)&val_1753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4821 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0045, (cst_val *)&val_0064},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0046, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4822 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0048, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4823 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0050, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0051, (cst_val *)&val_4824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4825 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4826 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0054, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4828 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0057, (cst_val *)&val_0780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4830 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0060, (cst_val *)&val_4831},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0061, (cst_val *)&val_0004},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0062, (cst_val *)&val_0004},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0063, (cst_val *)&val_4832},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0064, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4836 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0069, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4837 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0071, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4839 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0074, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4840 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0076, (cst_val *)&val_4841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4842 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0078, (cst_val *)&val_4843},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0079, (cst_val *)&val_0717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4845 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_v_186_NO_0082, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4846 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4847 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_v_186_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_v_186_cart = {
  cmu_us_slt_single_mcep_v_186_cart_nodes,
  cmu_us_slt_single_mcep_v_186_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_dh_51_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0001, (cst_val *)&val_0057},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0002, (cst_val *)&val_0008},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0003, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4848 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0005, (cst_val *)&val_1406},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0006, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4850 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0009, (cst_val *)&val_1579},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0010, (cst_val *)&val_2586},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4853 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0014, (cst_val *)&val_1406},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0015, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4854 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0017, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4856 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0020, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4858 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0023, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4859 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0025, (cst_val *)&val_0391},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0026, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0027, (cst_val *)&val_1579},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4862 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0031, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0032, (cst_val *)&val_0027},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0033, (cst_val *)&val_1221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4863 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0035, (cst_val *)&val_4864},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0036, (cst_val *)&val_1887},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0037, (cst_val *)&val_4865},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0038, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4869 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0043, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4872 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0047, (cst_val *)&val_4873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4874 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0049, (cst_val *)&val_0153},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4875 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0051, (cst_val *)&val_4876},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4878 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0054, (cst_val *)&val_4879},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0055, (cst_val *)&val_0888},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0056, (cst_val *)&val_0137},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0057, (cst_val *)&val_4880},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4883 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0061, (cst_val *)&val_0151},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0062, (cst_val *)&val_0200},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0063, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4886 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0067, (cst_val *)&val_4887},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0068, (cst_val *)&val_4888},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0069, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4890 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0072, (cst_val *)&val_4891},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4894 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0076, (cst_val *)&val_0088},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0077, (cst_val *)&val_1441},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0078, (cst_val *)&val_0675},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0079, (cst_val *)&val_4895},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4898 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0083, (cst_val *)&val_0727},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0084, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4901 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0088, (cst_val *)&val_0228},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0089, (cst_val *)&val_2699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4902 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0091, (cst_val *)&val_0414},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0092, (cst_val *)&val_0642},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0093, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4906 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0098, (cst_val *)&val_4907},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0099, (cst_val *)&val_2593},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0100, (cst_val *)&val_0004},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0101, (cst_val *)&val_4908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4910 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0104, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4913 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0108, (cst_val *)&val_0018},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0109, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4915 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0112, (cst_val *)&val_1218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4916 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_51_NO_0114, (cst_val *)&val_4917},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4919 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_dh_51_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_dh_51_cart = {
  cmu_us_slt_single_mcep_dh_51_cart_nodes,
  cmu_us_slt_single_mcep_dh_51_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_dh_52_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0001, (cst_val *)&val_0194},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0002, (cst_val *)&val_4920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4921 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0004, (cst_val *)&val_0492},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0005, (cst_val *)&val_4922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4923 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0007, (cst_val *)&val_4924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4926 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0010, (cst_val *)&val_4927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4929 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0013, (cst_val *)&val_0668},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0014, (cst_val *)&val_4930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4931 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0016, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4933 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0019, (cst_val *)&val_4934},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0020, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4936 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0023, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4938 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0026, (cst_val *)&val_0018},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0027, (cst_val *)&val_0088},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0028, (cst_val *)&val_0471},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0029, (cst_val *)&val_4939},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4942 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0033, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0034, (cst_val *)&val_4943},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4944 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0036, (cst_val *)&val_0783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4946 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0039, (cst_val *)&val_0189},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0040, (cst_val *)&val_4947},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0041, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4949 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0044, (cst_val *)&val_4950},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0045, (cst_val *)&val_0100},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0046, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4951 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4954 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0051, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4955 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0053, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4957 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0056, (cst_val *)&val_4313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4958 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_52_NO_0058, (cst_val *)&val_4959},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4961 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_dh_52_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_dh_52_cart = {
  cmu_us_slt_single_mcep_dh_52_cart_nodes,
  cmu_us_slt_single_mcep_dh_52_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_dh_53_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0001, (cst_val *)&val_1699},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0002, (cst_val *)&val_0228},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0003, (cst_val *)&val_4962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4964 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0006, (cst_val *)&val_0064},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0007, (cst_val *)&val_0492},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0008, (cst_val *)&val_4962},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0009, (cst_val *)&val_4965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4968 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0013, (cst_val *)&val_4969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4971 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0016, (cst_val *)&val_2280},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0017, (cst_val *)&val_4972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4973 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0019, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4975 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0022, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4976 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0024, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4978 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0027, (cst_val *)&val_4762},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0028, (cst_val *)&val_0228},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0029, (cst_val *)&val_4034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4980 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0032, (cst_val *)&val_4981},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0033, (cst_val *)&val_4982},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0034, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4984 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0037, (cst_val *)&val_4985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4986 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0039, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4988 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0042, (cst_val *)&val_4989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4991 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0045, (cst_val *)&val_0621},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0046, (cst_val *)&val_0390},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0047, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0048, (cst_val *)&val_0287},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0049, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4993 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0052, (cst_val *)&val_4994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4996 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0055, (cst_val *)&val_4333},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0056, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4998 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0059, (cst_val *)&val_1044},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0060, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_4999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5000 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0063, (cst_val *)&val_0014},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0064, (cst_val *)&val_5001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5004 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0068, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5005 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0070, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5007 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0073, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0074, (cst_val *)&val_1155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5009 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0077, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5011 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0080, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5012 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_dh_53_NO_0082, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5014 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_dh_53_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_dh_53_cart = {
  cmu_us_slt_single_mcep_dh_53_cart_nodes,
  cmu_us_slt_single_mcep_dh_53_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_d_46_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0001, (cst_val *)&val_4609},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0002, (cst_val *)&val_0833},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0003, (cst_val *)&val_0186},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0004, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5016 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0007, (cst_val *)&val_3044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5017 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0009, (cst_val *)&val_4610},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0010, (cst_val *)&val_0982},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0011, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5018 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0013, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5020 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0016, (cst_val *)&val_0018},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0017, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5023 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0021, (cst_val *)&val_3034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5024 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0023, (cst_val *)&val_0004},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0024, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5026 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0027, (cst_val *)&val_5027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5028 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0029, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5030 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0032, (cst_val *)&val_0004},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0033, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5031 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0035, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5033 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0038, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5035 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0041, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0042, (cst_val *)&val_0138},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0043, (cst_val *)&val_5036},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0044, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5037 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0046, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5039 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0049, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5041 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0052, (cst_val *)&val_0920},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0053, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0054, (cst_val *)&val_4649},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5042 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5045 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0059, (cst_val *)&val_5046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5047 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0061, (cst_val *)&val_0637},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0062, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5050 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0066, (cst_val *)&val_0228},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0067, (cst_val *)&val_0942},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0068, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0069, (cst_val *)&val_5051},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0070, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5052 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0072, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5053 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0074, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5056 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0078, (cst_val *)&val_1406},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0079, (cst_val *)&val_0699},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0080, (cst_val *)&val_1626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5057 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5059 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0085, (cst_val *)&val_5060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5062 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0088, (cst_val *)&val_5063},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0089, (cst_val *)&val_5064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0090, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5068 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0095, (cst_val *)&val_0064},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0096, (cst_val *)&val_0151},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0097, (cst_val *)&val_0018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0098, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0099, (cst_val *)&val_5069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5071 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0102, (cst_val *)&val_5072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5074 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0105, (cst_val *)&val_2468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5077 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0109, (cst_val *)&val_5078},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5079 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0111, (cst_val *)&val_5080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5082 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0114, (cst_val *)&val_0705},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0115, (cst_val *)&val_0072},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0116, (cst_val *)&val_0054},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0117, (cst_val *)&val_0100},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0118, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5084 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0121, (cst_val *)&val_5085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5088 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0125, (cst_val *)&val_2970},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0126, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5091 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0130, (cst_val *)&val_0420},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0131, (cst_val *)&val_0072},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0132, (cst_val *)&val_5092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5095 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0136, (cst_val *)&val_0100},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0137, (cst_val *)&val_0217},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0138, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5097 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0141, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5098 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0143, (cst_val *)&val_3446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5100 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0146, (cst_val *)&val_5101},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0147, (cst_val *)&val_0018},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_46_NO_0148, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5105 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_d_46_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_place",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_d_46_cart = {
  cmu_us_slt_single_mcep_d_46_cart_nodes,
  cmu_us_slt_single_mcep_d_46_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_d_47_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0001, (cst_val *)&val_0047},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0002, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0003, (cst_val *)&val_2882},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0004, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0005, (cst_val *)&val_2225},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0006, (cst_val *)&val_5106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5109 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0010, (cst_val *)&val_5110},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0011, (cst_val *)&val_0900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5113 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0015, (cst_val *)&val_0018},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0016, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5115 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0019, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5116 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0021, (cst_val *)&val_5117},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5119 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0024, (cst_val *)&val_0061},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0025, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0026, (cst_val *)&val_5120},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5121 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5123 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0030, (cst_val *)&val_0153},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0031, (cst_val *)&val_1167},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0032, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5124 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0034, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5126 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0037, (cst_val *)&val_0018},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0038, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0039, (cst_val *)&val_0986},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0040, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5127 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5129 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0044, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5131 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0047, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0048, (cst_val *)&val_0675},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0049, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5133 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0052, (cst_val *)&val_5134},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0053, (cst_val *)&val_5135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5137 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0056, (cst_val *)&val_1137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0057, (cst_val *)&val_5138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5140 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5141 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0061, (cst_val *)&val_5142},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0062, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5144 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0065, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5145 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0067, (cst_val *)&val_0621},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0068, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0069, (cst_val *)&val_5146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5150 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0074, (cst_val *)&val_0011},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0075, (cst_val *)&val_5151},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5154 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0079, (cst_val *)&val_5155},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0080, (cst_val *)&val_0018},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0081, (cst_val *)&val_0013},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0082, (cst_val *)&val_5156},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5159 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0086, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5160 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0088, (cst_val *)&val_0668},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0089, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5162 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0092, (cst_val *)&val_5163},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5165 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0095, (cst_val *)&val_0879},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0096, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5166 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0098, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5168 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0101, (cst_val *)&val_0018},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0102, (cst_val *)&val_3074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5170 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0105, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0106, (cst_val *)&val_5171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5173 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0109, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5175 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0112, (cst_val *)&val_0217},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0113, (cst_val *)&val_0025},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0114, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5178 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0118, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0119, (cst_val *)&val_0668},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0120, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0121, (cst_val *)&val_5179},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0122, (cst_val *)&val_0072},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0123, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5180 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5182 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5183 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0128, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5185 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0131, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5187 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0134, (cst_val *)&val_5188},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0135, (cst_val *)&val_1626},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0136, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5189 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0138, (cst_val *)&val_0964},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5191 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0141, (cst_val *)&val_0011},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0142, (cst_val *)&val_0004},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0143, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5192 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0145, (cst_val *)&val_0237},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0146, (cst_val *)&val_3851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5193 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5196 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0151, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5197 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5198 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0154, (cst_val *)&val_1006},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0155, (cst_val *)&val_0099},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0156, (cst_val *)&val_5199},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5202 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_47_NO_0160, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5204 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_d_47_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_d_47_cart = {
  cmu_us_slt_single_mcep_d_47_cart_nodes,
  cmu_us_slt_single_mcep_d_47_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_d_48_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0002, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0003, (cst_val *)&val_0679},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0004, (cst_val *)&val_0137},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0005, (cst_val *)&val_0954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5206 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0008, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5208 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0011, (cst_val *)&val_1044},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0012, (cst_val *)&val_5209},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5211 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0015, (cst_val *)&val_1928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5212 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0017, (cst_val *)&val_5213},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5215 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0020, (cst_val *)&val_0019},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0021, (cst_val *)&val_0301},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0022, (cst_val *)&val_3023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5218 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0026, (cst_val *)&val_0985},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0027, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5221 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0031, (cst_val *)&val_0395},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0032, (cst_val *)&val_1962},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0033, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5222 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0035, (cst_val *)&val_0590},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0036, (cst_val *)&val_5223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5225 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0039, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5227 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0042, (cst_val *)&val_2756},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5229 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0045, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5230 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0047, (cst_val *)&val_5101},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0048, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5231 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0050, (cst_val *)&val_0108},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0051, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0052, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5235 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0057, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5237 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0060, (cst_val *)&val_4873},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0061, (cst_val *)&val_0004},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0062, (cst_val *)&val_0023},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0063, (cst_val *)&val_0237},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0064, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5239 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0067, (cst_val *)&val_1338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5241 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0070, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5242 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0072, (cst_val *)&val_0189},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0073, (cst_val *)&val_0001},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0074, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5243 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0076, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5245 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0079, (cst_val *)&val_0140},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0080, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5247 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0083, (cst_val *)&val_0964},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5249 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0086, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5250 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0088, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5252 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0091, (cst_val *)&val_0228},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0092, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5254 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0095, (cst_val *)&val_0061},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0096, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5256 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0099, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5257 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0101, (cst_val *)&val_2211},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0102, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5258 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0104, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5259 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5261 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0108, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0109, (cst_val *)&val_0989},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0110, (cst_val *)&val_1963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5263 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5264 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0114, (cst_val *)&val_1249},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0115, (cst_val *)&val_1009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0116, (cst_val *)&val_2385},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0117, (cst_val *)&val_5265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5267 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0120, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5268 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0122, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5270 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0125, (cst_val *)&val_2949},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0126, (cst_val *)&val_0547},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0127, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5272 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0130, (cst_val *)&val_0012},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0131, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0132, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5277 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0138, (cst_val *)&val_0414},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0139, (cst_val *)&val_0237},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0140, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5278 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5279 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0143, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5281 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0146, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0147, (cst_val *)&val_0550},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0148, (cst_val *)&val_5282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5285 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_d_48_NO_0152, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5287 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_d_48_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_rindex",
"lisp_cg_phone_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_slt_single_mcep_d_48_cart = {
  cmu_us_slt_single_mcep_d_48_cart_nodes,
  cmu_us_slt_single_mcep_d_48_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_n_116_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0001, (cst_val *)&val_0638},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0003, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0004, (cst_val *)&val_0105},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0005, (cst_val *)&val_0414},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0006, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5290 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0010, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5292 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0013, (cst_val *)&val_0023},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0014, (cst_val *)&val_0237},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0015, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5293 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0017, (cst_val *)&val_0936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5295 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0020, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5297 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0023, (cst_val *)&val_0395},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0024, (cst_val *)&val_0414},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0025, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5299 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0028, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5301 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0031, (cst_val *)&val_0727},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0032, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5302 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0034, (cst_val *)&val_5303},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0035, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5305 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5306 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0039, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5307 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0041, (cst_val *)&val_5308},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5309 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0043, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5311 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0046, (cst_val *)&val_0681},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0047, (cst_val *)&val_5312},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0048, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5314 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0051, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0052, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5317 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0056, (cst_val *)&val_0642},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0057, (cst_val *)&val_0105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0058, (cst_val *)&val_0004},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0059, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5318 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5319 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0062, (cst_val *)&val_0025},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0063, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5320 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0065, (cst_val *)&val_5321},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5322 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0067, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5323 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0069, (cst_val *)&val_2949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5326 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0073, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5327 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0075, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5328 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0077, (cst_val *)&val_2019},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0078, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5329 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0080, (cst_val *)&val_5330},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5332 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0083, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5334 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0086, (cst_val *)&val_0001},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0087, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5335 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0089, (cst_val *)&val_0004},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0090, (cst_val *)&val_4934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5337 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0093, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0094, (cst_val *)&val_0683},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0095, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5338 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0097, (cst_val *)&val_0621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5342 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0102, (cst_val *)&val_0140},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0103, (cst_val *)&val_5343},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0104, (cst_val *)&val_0414},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0105, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5345 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0108, (cst_val *)&val_5346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5349 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0112, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5351 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0115, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0116, (cst_val *)&val_0954},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0117, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5352 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0119, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5354 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0122, (cst_val *)&val_5355},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0123, (cst_val *)&val_5356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5357 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0125, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5360 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0129, (cst_val *)&val_0200},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0130, (cst_val *)&val_0669},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0131, (cst_val *)&val_5361},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0132, (cst_val *)&val_5362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5365 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0136, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5367 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0139, (cst_val *)&val_0014},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0140, (cst_val *)&val_0014},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0141, (cst_val *)&val_1264},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0142, (cst_val *)&val_0597},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0143, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5372 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0149, (cst_val *)&val_3859},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0150, (cst_val *)&val_0001},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0151, (cst_val *)&val_5373},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0152, (cst_val *)&val_5374},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5376 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5377 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0156, (cst_val *)&val_5378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5381 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0160, (cst_val *)&val_0467},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0161, (cst_val *)&val_0218},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0162, (cst_val *)&val_0592},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0163, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5384 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0167, (cst_val *)&val_0064},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0168, (cst_val *)&val_5385},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5388 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0172, (cst_val *)&val_0301},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0173, (cst_val *)&val_0004},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0174, (cst_val *)&val_0088},
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0175, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5390 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0178, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5391 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0180, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5393 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0183, (cst_val *)&val_3666},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0184, (cst_val *)&val_5394},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5395 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0186, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5398 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0190, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5399 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_116_NO_0192, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5401 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_n_116_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
NULL };

const cst_cart cmu_us_slt_single_mcep_n_116_cart = {
  cmu_us_slt_single_mcep_n_116_cart_nodes,
  cmu_us_slt_single_mcep_n_116_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_n_117_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0001, (cst_val *)&val_0064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0002, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0003, (cst_val *)&val_0105},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0004, (cst_val *)&val_1489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5402 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0006, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5404 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0009, (cst_val *)&val_4137},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0010, (cst_val *)&val_5405},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0011, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5409 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0016, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0017, (cst_val *)&val_2356},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0018, (cst_val *)&val_5410},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0019, (cst_val *)&val_5411},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0020, (cst_val *)&val_3436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5413 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0023, (cst_val *)&val_5414},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0024, (cst_val *)&val_0108},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0025, (cst_val *)&val_3298},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5416 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0028, (cst_val *)&val_5417},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5418 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5419 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5420 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0032, (cst_val *)&val_0001},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0033, (cst_val *)&val_5421},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5423 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0036, (cst_val *)&val_5424},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0037, (cst_val *)&val_5346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5427 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0041, (cst_val *)&val_5428},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0042, (cst_val *)&val_0733},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5429 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0044, (cst_val *)&val_5430},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5432 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0047, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5433 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0049, (cst_val *)&val_5434},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5436 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0052, (cst_val *)&val_0888},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0053, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5437 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0055, (cst_val *)&val_1395},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0056, (cst_val *)&val_5438},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5440 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0059, (cst_val *)&val_0023},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0060, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5441 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0062, (cst_val *)&val_0329},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5443 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0065, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5445 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0068, (cst_val *)&val_1061},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0069, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0070, (cst_val *)&val_5446},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0071, (cst_val *)&val_0023},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0072, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5448 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0075, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5450 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0078, (cst_val *)&val_0018},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0079, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5452 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0082, (cst_val *)&val_5453},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5455 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0085, (cst_val *)&val_0471},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0086, (cst_val *)&val_5456},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0087, (cst_val *)&val_0295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5459 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0091, (cst_val *)&val_5460},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0092, (cst_val *)&val_0016},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0093, (cst_val *)&val_5461},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5464 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0097, (cst_val *)&val_5465},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0098, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5466 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0100, (cst_val *)&val_2905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5467 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5468 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0103, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5470 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5471 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0107, (cst_val *)&val_5472},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0108, (cst_val *)&val_0004},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0109, (cst_val *)&val_0004},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0110, (cst_val *)&val_0775},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0111, (cst_val *)&val_0105},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0112, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5473 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0114, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5475 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0117, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5476 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0119, (cst_val *)&val_0252},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0120, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5479 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0124, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5480 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5481 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0127, (cst_val *)&val_0125},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0128, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5482 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0130, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5483 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0132, (cst_val *)&val_5484},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0133, (cst_val *)&val_0025},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0134, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5485 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0136, (cst_val *)&val_5486},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0137, (cst_val *)&val_5487},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5489 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0140, (cst_val *)&val_5490},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0141, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5493 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0145, (cst_val *)&val_5494},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0146, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5495 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5496 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0149, (cst_val *)&val_3147},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0150, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5499 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0154, (cst_val *)&val_0108},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0155, (cst_val *)&val_5500},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0156, (cst_val *)&val_1386},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0157, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5504 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0162, (cst_val *)&val_5505},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5507 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0165, (cst_val *)&val_0023},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0166, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5508 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0168, (cst_val *)&val_5509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5510 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0170, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5513 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0173, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5515 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0176, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5516 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0178, (cst_val *)&val_5517},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0179, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5518 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5519 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0182, (cst_val *)&val_5520},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0183, (cst_val *)&val_0019},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0184, (cst_val *)&val_5521},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5523 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0187, (cst_val *)&val_5524},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0188, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5528 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0193, (cst_val *)&val_5424},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0194, (cst_val *)&val_0004},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0195, (cst_val *)&val_0414},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0196, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5529 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5530 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0199, (cst_val *)&val_0018},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0200, (cst_val *)&val_0105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0201, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5532 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0204, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5534 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0207, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5536 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0210, (cst_val *)&val_0942},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0211, (cst_val *)&val_1626},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0212, (cst_val *)&val_5537},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5539 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0215, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5540 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0217, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5542 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0220, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0221, (cst_val *)&val_0125},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0222, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5544 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5545 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0226, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5546 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0228, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5548 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0231, (cst_val *)&val_0001},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0232, (cst_val *)&val_5549},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0233, (cst_val *)&val_0025},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0234, (cst_val *)&val_5550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5551 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0236, (cst_val *)&val_5552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5554 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0239, (cst_val *)&val_0105},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0240, (cst_val *)&val_5555},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5557 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0243, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5559 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0246, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0247, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5561 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0250, (cst_val *)&val_0023},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0251, (cst_val *)&val_0018},
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0252, (cst_val *)&val_1693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5564 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5565 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0257, (cst_val *)&val_0108},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0258, (cst_val *)&val_0018},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0259, (cst_val *)&val_5566},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5568 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0262, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5570 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0265, (cst_val *)&val_5571},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0266, (cst_val *)&val_5572},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0267, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5574 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0270, (cst_val *)&val_5575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5577 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0273, (cst_val *)&val_5578},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0274, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5581 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0278, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0279, (cst_val *)&val_0621},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0280, (cst_val *)&val_0151},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0281, (cst_val *)&val_0018},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0282, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5583 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0285, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5584 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0287, (cst_val *)&val_0237},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0288, (cst_val *)&val_5585},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5588 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0292, (cst_val *)&val_0023},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0293, (cst_val *)&val_0936},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5590 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0296, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5592 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0299, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0300, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5594 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0303, (cst_val *)&val_0951},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0304, (cst_val *)&val_0237},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0305, (cst_val *)&val_0597},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0306, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5596 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0309, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0310, (cst_val *)&val_5597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5599 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0313, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5600 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0315, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5602 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0318, (cst_val *)&val_5603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5605 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5606 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0322, (cst_val *)&val_0590},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0323, (cst_val *)&val_0004},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0324, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5607 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0326, (cst_val *)&val_5608},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0327, (cst_val *)&val_5609},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0328, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5610 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0330, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5612 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0333, (cst_val *)&val_0105},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0334, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5613 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0336, (cst_val *)&val_0025},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0337, (cst_val *)&val_0140},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0338, (cst_val *)&val_5614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5618 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0343, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5619 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0345, (cst_val *)&val_0824},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0346, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5622 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0350, (cst_val *)&val_0105},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0351, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5624 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0354, (cst_val *)&val_0064},
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0355, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5627 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0359, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5628 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0361, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5630 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0364, (cst_val *)&val_0004},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0365, (cst_val *)&val_0681},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0366, (cst_val *)&val_5631},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5633 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0369, (cst_val *)&val_0061},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0370, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5635 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0373, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5636 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0375, (cst_val *)&val_5637},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5639 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0378, (cst_val *)&val_5640},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0379, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5641 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0381, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5643 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0384, (cst_val *)&val_0108},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0385, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5644 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0387, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5646 },
{ 32, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_117_NO_0390, (cst_val *)&val_4137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5648 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_n_117_feat_table[] = {
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_n_117_cart = {
  cmu_us_slt_single_mcep_n_117_cart_nodes,
  cmu_us_slt_single_mcep_n_117_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_n_118_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0001, (cst_val *)&val_5649},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0002, (cst_val *)&val_0617},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0003, (cst_val *)&val_5650},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0004, (cst_val *)&val_0625},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0005, (cst_val *)&val_5651},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0006, (cst_val *)&val_5652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5653 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0008, (cst_val *)&val_2211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5655 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0011, (cst_val *)&val_1984},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0012, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0013, (cst_val *)&val_2661},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5658 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0017, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5659 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0019, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5660 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0021, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5662 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0024, (cst_val *)&val_5663},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5664 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0026, (cst_val *)&val_5665},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0027, (cst_val *)&val_2131},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0028, (cst_val *)&val_1746},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0029, (cst_val *)&val_5666},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5670 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0034, (cst_val *)&val_5671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5673 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0037, (cst_val *)&val_0896},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0038, (cst_val *)&val_5674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5675 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0040, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5676 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0042, (cst_val *)&val_2515},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5677 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5679 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0046, (cst_val *)&val_0140},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0047, (cst_val *)&val_0015},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0048, (cst_val *)&val_0364},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0049, (cst_val *)&val_5680},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0050, (cst_val *)&val_0717},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0051, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5684 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0056, (cst_val *)&val_5685},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0057, (cst_val *)&val_5686},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0058, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5690 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0063, (cst_val *)&val_4907},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5692 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0066, (cst_val *)&val_5693},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0067, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5694 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0069, (cst_val *)&val_0088},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0070, (cst_val *)&val_3612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5697 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0074, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5698 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0076, (cst_val *)&val_5699},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0077, (cst_val *)&val_5700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5701 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5702 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0080, (cst_val *)&val_5703},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5704 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5706 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0085, (cst_val *)&val_0617},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0086, (cst_val *)&val_5707},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0087, (cst_val *)&val_0200},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0088, (cst_val *)&val_5699},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0089, (cst_val *)&val_5708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5711 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0093, (cst_val *)&val_2926},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0094, (cst_val *)&val_5712},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0095, (cst_val *)&val_5713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5715 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0098, (cst_val *)&val_0014},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0099, (cst_val *)&val_0194},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0100, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5718 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0104, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5720 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0107, (cst_val *)&val_5721},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5722 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5723 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0110, (cst_val *)&val_5724},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5725 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5726 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0113, (cst_val *)&val_3552},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0114, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5728 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0117, (cst_val *)&val_0140},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0118, (cst_val *)&val_0364},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0119, (cst_val *)&val_5729},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0120, (cst_val *)&val_5730},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0121, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5734 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0126, (cst_val *)&val_0365},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0127, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5736 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0130, (cst_val *)&val_5737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5739 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0133, (cst_val *)&val_0365},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0134, (cst_val *)&val_0237},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0135, (cst_val *)&val_0023},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0136, (cst_val *)&val_0638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5741 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5742 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0140, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5743 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5744 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0143, (cst_val *)&val_5745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5746 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0145, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5747 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0147, (cst_val *)&val_2379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5749 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0150, (cst_val *)&val_0004},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0151, (cst_val *)&val_0237},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0152, (cst_val *)&val_2331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5750 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0154, (cst_val *)&val_2280},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0155, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5751 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0157, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5753 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0160, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5754 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0162, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5755 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0164, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5757 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0167, (cst_val *)&val_0637},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0168, (cst_val *)&val_1577},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0169, (cst_val *)&val_0064},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0170, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5760 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0174, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5761 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0176, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5762 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0178, (cst_val *)&val_0942},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0179, (cst_val *)&val_5763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5765 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0182, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5768 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0186, (cst_val *)&val_5769},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0187, (cst_val *)&val_0140},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0188, (cst_val *)&val_2468},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0189, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0190, (cst_val *)&val_0989},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0191, (cst_val *)&val_2379},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5770 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5772 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0195, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5775 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0199, (cst_val *)&val_0105},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0200, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5777 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0203, (cst_val *)&val_4010},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0204, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5778 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0206, (cst_val *)&val_5779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5781 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0209, (cst_val *)&val_3507},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0210, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5783 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0213, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0214, (cst_val *)&val_5784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5785 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0216, (cst_val *)&val_5786},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5788 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0219, (cst_val *)&val_0232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0220, (cst_val *)&val_5789},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5791 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0223, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5793 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0226, (cst_val *)&val_5794},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5795 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0228, (cst_val *)&val_0595},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0229, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5797 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0232, (cst_val *)&val_0023},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0233, (cst_val *)&val_2643},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0234, (cst_val *)&val_1626},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0235, (cst_val *)&val_0709},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0236, (cst_val *)&val_0717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5799 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0239, (cst_val *)&val_1819},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0240, (cst_val *)&val_5800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5803 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0244, (cst_val *)&val_0137},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0245, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5804 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5805 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0248, (cst_val *)&val_0014},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0249, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5807 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0252, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5809 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0255, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5811 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0258, (cst_val *)&val_4010},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0259, (cst_val *)&val_0018},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0260, (cst_val *)&val_1772},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5813 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0263, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5815 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0266, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5816 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0268, (cst_val *)&val_3507},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5817 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_n_118_NO_0270, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5819 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_n_118_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_n_118_cart = {
  cmu_us_slt_single_mcep_n_118_cart_nodes,
  cmu_us_slt_single_mcep_n_118_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_jh_96_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0000, (cst_val *)&val_0795},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0001, (cst_val *)&val_5820},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0002, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5821 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0004, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5823 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0007, (cst_val *)&val_1413},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5825 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0010, (cst_val *)&val_1347},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0011, (cst_val *)&val_5826},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0012, (cst_val *)&val_4549},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0013, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5828 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0016, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5831 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0020, (cst_val *)&val_0643},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0021, (cst_val *)&val_0847},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0022, (cst_val *)&val_5832},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5834 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0025, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5836 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0028, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5837 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0030, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5838 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0032, (cst_val *)&val_5839},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5840 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_96_NO_0034, (cst_val *)&val_5841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5843 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_jh_96_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_place",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_jh_96_cart = {
  cmu_us_slt_single_mcep_jh_96_cart_nodes,
  cmu_us_slt_single_mcep_jh_96_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_jh_97_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0000, (cst_val *)&val_5844},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0001, (cst_val *)&val_1048},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0002, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5846 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0005, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0006, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5847 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0008, (cst_val *)&val_5848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5849 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0010, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5851 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0013, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5853 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0016, (cst_val *)&val_0072},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0017, (cst_val *)&val_5854},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5856 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_97_NO_0020, (cst_val *)&val_5857},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5859 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_jh_97_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"lisp_cg_phone_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_jh_97_cart = {
  cmu_us_slt_single_mcep_jh_97_cart_nodes,
  cmu_us_slt_single_mcep_jh_97_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_jh_98_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0001, (cst_val *)&val_1986},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0002, (cst_val *)&val_5860},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0003, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5861 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0005, (cst_val *)&val_5862},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0006, (cst_val *)&val_5863},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5864 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0008, (cst_val *)&val_3442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5865 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0010, (cst_val *)&val_5866},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5869 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0014, (cst_val *)&val_5870},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0015, (cst_val *)&val_0927},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0016, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5871 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0018, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5873 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0021, (cst_val *)&val_0014},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0022, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5876 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5877 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0027, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0028, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5879 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0031, (cst_val *)&val_5880},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0032, (cst_val *)&val_5881},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0033, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5882 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0035, (cst_val *)&val_5883},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5884 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5885 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0038, (cst_val *)&val_5886},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0039, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5890 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0044, (cst_val *)&val_0177},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0045, (cst_val *)&val_0850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5891 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0047, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5892 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0049, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5893 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0051, (cst_val *)&val_1972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5895 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0054, (cst_val *)&val_1036},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0055, (cst_val *)&val_0617},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0056, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5897 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0059, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5898 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5899 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0062, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5900 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0064, (cst_val *)&val_0617},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0065, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5902 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_jh_98_NO_0068, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5904 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_jh_98_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_jh_98_cart = {
  cmu_us_slt_single_mcep_jh_98_cart_nodes,
  cmu_us_slt_single_mcep_jh_98_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_r_146_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0001, (cst_val *)&val_0105},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0002, (cst_val *)&val_5905},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0003, (cst_val *)&val_4879},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0004, (cst_val *)&val_0099},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0005, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5907 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0008, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5909 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0011, (cst_val *)&val_5910},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0012, (cst_val *)&val_1682},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0013, (cst_val *)&val_5911},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0014, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5912 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5913 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0017, (cst_val *)&val_5914},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0018, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5916 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0021, (cst_val *)&val_0042},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0022, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5919 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0026, (cst_val *)&val_5920},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0027, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5924 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0032, (cst_val *)&val_0059},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0033, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5925 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0035, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5927 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0038, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5929 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0041, (cst_val *)&val_0395},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0042, (cst_val *)&val_1626},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0043, (cst_val *)&val_5930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5932 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0046, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0047, (cst_val *)&val_4332},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0048, (cst_val *)&val_0108},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0049, (cst_val *)&val_0105},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0050, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5934 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0053, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5935 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0055, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5936 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0057, (cst_val *)&val_1713},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0058, (cst_val *)&val_5863},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5941 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0064, (cst_val *)&val_0125},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0065, (cst_val *)&val_5942},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0066, (cst_val *)&val_5943},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0067, (cst_val *)&val_0108},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0068, (cst_val *)&val_5944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5947 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0072, (cst_val *)&val_3135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5949 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0075, (cst_val *)&val_5950},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0076, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0077, (cst_val *)&val_5951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5953 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0080, (cst_val *)&val_0061},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0081, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5955 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0084, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5956 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0086, (cst_val *)&val_0365},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0087, (cst_val *)&val_0683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5960 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0092, (cst_val *)&val_0018},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0093, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5961 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5962 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0096, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0097, (cst_val *)&val_5963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5965 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0100, (cst_val *)&val_5942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5967 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0103, (cst_val *)&val_5968},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0104, (cst_val *)&val_0001},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0105, (cst_val *)&val_5969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5972 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0109, (cst_val *)&val_0105},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0110, (cst_val *)&val_5973},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0111, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5975 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0114, (cst_val *)&val_1071},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0115, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5977 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0118, (cst_val *)&val_5978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5979 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0120, (cst_val *)&val_4458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5981 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0123, (cst_val *)&val_4081},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0124, (cst_val *)&val_0395},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0125, (cst_val *)&val_0313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5985 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0130, (cst_val *)&val_0550},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0131, (cst_val *)&val_0004},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0132, (cst_val *)&val_0105},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0133, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5986 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0135, (cst_val *)&val_0467},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0136, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5988 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0139, (cst_val *)&val_2211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5990 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0142, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5991 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0144, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5992 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0146, (cst_val *)&val_4762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5993 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5994 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0149, (cst_val *)&val_0237},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0150, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0151, (cst_val *)&val_1485},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0152, (cst_val *)&val_5995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5996 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0154, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_5999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6000 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0159, (cst_val *)&val_6001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6002 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0161, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6003 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0163, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6005 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0166, (cst_val *)&val_0183},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0167, (cst_val *)&val_6006},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0168, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6008 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0171, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6009 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0173, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6011 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0176, (cst_val *)&val_0105},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0177, (cst_val *)&val_1061},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0178, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6012 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0180, (cst_val *)&val_1358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6014 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6015 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0184, (cst_val *)&val_0088},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0185, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6017 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0188, (cst_val *)&val_4593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6018 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_146_NO_0190, (cst_val *)&val_6019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6021 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_r_146_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_r_146_cart = {
  cmu_us_slt_single_mcep_r_146_cart_nodes,
  cmu_us_slt_single_mcep_r_146_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_r_147_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0001, (cst_val *)&val_1221},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0003, (cst_val *)&val_0105},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0004, (cst_val *)&val_0023},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0005, (cst_val *)&val_0140},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0006, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6024 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0010, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6026 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0013, (cst_val *)&val_0232},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0014, (cst_val *)&val_1258},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0015, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6027 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6029 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0019, (cst_val *)&val_0228},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0020, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6031 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0023, (cst_val *)&val_0140},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0024, (cst_val *)&val_2882},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6033 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0027, (cst_val *)&val_6034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6036 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0030, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0031, (cst_val *)&val_0025},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0032, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0033, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6037 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6039 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0037, (cst_val *)&val_6040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6042 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0040, (cst_val *)&val_4649},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0041, (cst_val *)&val_0471},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0042, (cst_val *)&val_6043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6045 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0045, (cst_val *)&val_0023},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0046, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6046 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0048, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6048 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0051, (cst_val *)&val_6049},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0052, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6050 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0054, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6051 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0056, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0057, (cst_val *)&val_0064},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0058, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6053 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0061, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6057 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0066, (cst_val *)&val_6058},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6060 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0069, (cst_val *)&val_0001},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0070, (cst_val *)&val_6061},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0071, (cst_val *)&val_0931},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0072, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6063 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0075, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6065 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0078, (cst_val *)&val_6066},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6067 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0080, (cst_val *)&val_0018},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0081, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6068 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0083, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6071 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0087, (cst_val *)&val_6072},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0088, (cst_val *)&val_6073},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0089, (cst_val *)&val_0018},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0090, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6074 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0092, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6076 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0095, (cst_val *)&val_0492},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0096, (cst_val *)&val_6077},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6079 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0099, (cst_val *)&val_6080},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0100, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6082 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0103, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0104, (cst_val *)&val_6083},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0105, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6087 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0110, (cst_val *)&val_6088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0111, (cst_val *)&val_6089},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0112, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6091 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0115, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6093 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0118, (cst_val *)&val_0018},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0119, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6094 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0121, (cst_val *)&val_6095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6097 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0124, (cst_val *)&val_6098},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0125, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6101 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0129, (cst_val *)&val_0004},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0130, (cst_val *)&val_6088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0131, (cst_val *)&val_6102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6103 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0133, (cst_val *)&val_6104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6106 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0136, (cst_val *)&val_6080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6107 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0138, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6109 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0141, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6110 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0143, (cst_val *)&val_0004},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0144, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6112 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0147, (cst_val *)&val_6113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6114 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0149, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6115 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0151, (cst_val *)&val_6116},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0152, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6119 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0156, (cst_val *)&val_0679},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0157, (cst_val *)&val_0004},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0158, (cst_val *)&val_0018},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0159, (cst_val *)&val_0061},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0160, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6121 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0163, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6122 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0165, (cst_val *)&val_1258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6124 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0168, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6125 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0170, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6127 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0173, (cst_val *)&val_0237},
{ 33, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0174, (cst_val *)&val_2468},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0175, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6128 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0177, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6129 },
{ 33, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0179, (cst_val *)&val_0942},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0180, (cst_val *)&val_0025},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0181, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6130 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0183, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6131 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0185, (cst_val *)&val_6132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6137 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0191, (cst_val *)&val_0004},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0192, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6138 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0194, (cst_val *)&val_0506},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0195, (cst_val *)&val_2135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6140 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0198, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6141 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0200, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6143 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0203, (cst_val *)&val_0001},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0204, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6144 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6145 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0207, (cst_val *)&val_0025},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0208, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6146 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0210, (cst_val *)&val_3224},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0211, (cst_val *)&val_0014},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0212, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6151 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0218, (cst_val *)&val_0025},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0219, (cst_val *)&val_0001},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0220, (cst_val *)&val_0105},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0221, (cst_val *)&val_6152},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0222, (cst_val *)&val_0061},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0223, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6153 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0225, (cst_val *)&val_6154},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6158 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0230, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6159 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0232, (cst_val *)&val_6160},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6161 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0234, (cst_val *)&val_6162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6164 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0237, (cst_val *)&val_0018},
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0238, (cst_val *)&val_0395},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0239, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6166 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0242, (cst_val *)&val_0266},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0243, (cst_val *)&val_0105},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0244, (cst_val *)&val_3259},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0245, (cst_val *)&val_5910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6171 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0251, (cst_val *)&val_0301},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0252, (cst_val *)&val_0001},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0253, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6172 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0255, (cst_val *)&val_6173},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6174 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0257, (cst_val *)&val_6175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6177 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0260, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0261, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6179 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0264, (cst_val *)&val_6180},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6182 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0267, (cst_val *)&val_0004},
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0268, (cst_val *)&val_0001},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0269, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6184 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0272, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6186 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0275, (cst_val *)&val_0681},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0276, (cst_val *)&val_6187},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6188 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6189 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0279, (cst_val *)&val_6190},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6192 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_147_NO_0282, (cst_val *)&val_6193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6195 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_r_147_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_slt_single_mcep_r_147_cart = {
  cmu_us_slt_single_mcep_r_147_cart_nodes,
  cmu_us_slt_single_mcep_r_147_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_r_148_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0001, (cst_val *)&val_6196},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0002, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0003, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0004, (cst_val *)&val_6197},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6199 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0007, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6201 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0010, (cst_val *)&val_2775},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0011, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0012, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6202 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6203 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0015, (cst_val *)&val_0617},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0016, (cst_val *)&val_1258},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6205 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0019, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6207 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0022, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6208 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6209 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0025, (cst_val *)&val_0617},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0026, (cst_val *)&val_0592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6210 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0028, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6211 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0030, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6213 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0033, (cst_val *)&val_0088},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0034, (cst_val *)&val_0082},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0035, (cst_val *)&val_6214},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6216 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0038, (cst_val *)&val_6217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6218 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6219 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0041, (cst_val *)&val_0942},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0042, (cst_val *)&val_0364},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0043, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6221 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0046, (cst_val *)&val_6088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6223 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0049, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6224 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6225 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0052, (cst_val *)&val_1341},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0053, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0054, (cst_val *)&val_6226},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0055, (cst_val *)&val_6227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6228 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0057, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6229 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6230 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0060, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6231 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0062, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6232 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6233 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0065, (cst_val *)&val_0019},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0066, (cst_val *)&val_0727},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0067, (cst_val *)&val_0833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6236 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0071, (cst_val *)&val_5101},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6237 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6238 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0074, (cst_val *)&val_0004},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0075, (cst_val *)&val_0025},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0076, (cst_val *)&val_0395},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0077, (cst_val *)&val_0284},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0078, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6240 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0081, (cst_val *)&val_1571},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0082, (cst_val *)&val_0408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6242 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0085, (cst_val *)&val_1205},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0086, (cst_val *)&val_0072},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0087, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6243 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0089, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6245 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0092, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6248 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0096, (cst_val *)&val_3166},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0097, (cst_val *)&val_0709},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0098, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0099, (cst_val *)&val_3653},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6249 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0101, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6251 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0104, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0105, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6252 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0107, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6254 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0110, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6256 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0113, (cst_val *)&val_6257},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0114, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6259 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0117, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6260 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0119, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6261 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0121, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6263 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0124, (cst_val *)&val_2331},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0125, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6265 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0128, (cst_val *)&val_0140},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0129, (cst_val *)&val_6266},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6268 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0132, (cst_val *)&val_0681},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0133, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6269 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6270 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0136, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6271 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0138, (cst_val *)&val_6272},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0139, (cst_val *)&val_6273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6274 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6276 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0143, (cst_val *)&val_6277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6278 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0145, (cst_val *)&val_6279},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0146, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6281 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0149, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6282 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0151, (cst_val *)&val_1600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6284 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0154, (cst_val *)&val_6285},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0155, (cst_val *)&val_0105},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0156, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6287 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0159, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6288 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0161, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6289 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0163, (cst_val *)&val_4440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6290 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6291 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0166, (cst_val *)&val_6292},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0167, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6293 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0169, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6294 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0171, (cst_val *)&val_6295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6296 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6297 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0174, (cst_val *)&val_0595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6298 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_r_148_NO_0176, (cst_val *)&val_1196},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6300 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_r_148_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
NULL };

const cst_cart cmu_us_slt_single_mcep_r_148_cart = {
  cmu_us_slt_single_mcep_r_148_cart_nodes,
  cmu_us_slt_single_mcep_r_148_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ey_66_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0000, (cst_val *)&val_1006},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0001, (cst_val *)&val_0004},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0002, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0003, (cst_val *)&val_0232},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0004, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6301 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0006, (cst_val *)&val_6302},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6304 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0009, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0010, (cst_val *)&val_6305},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6306 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6307 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0013, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6308 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0015, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6309 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0017, (cst_val *)&val_0284},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0018, (cst_val *)&val_1681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6312 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0022, (cst_val *)&val_0232},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0023, (cst_val *)&val_1355},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0024, (cst_val *)&val_6313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6315 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0027, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6317 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0030, (cst_val *)&val_2699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6318 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0032, (cst_val *)&val_1681},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0033, (cst_val *)&val_6319},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6320 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6321 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0036, (cst_val *)&val_0023},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0037, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6323 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6324 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0041, (cst_val *)&val_0088},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0042, (cst_val *)&val_6325},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0043, (cst_val *)&val_6326},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6328 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0046, (cst_val *)&val_4301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6330 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0049, (cst_val *)&val_2005},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0050, (cst_val *)&val_0287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6331 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6332 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0053, (cst_val *)&val_2511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6333 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0055, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6334 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0057, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6336 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0060, (cst_val *)&val_0021},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0061, (cst_val *)&val_0027},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0062, (cst_val *)&val_0061},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0063, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6337 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0065, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6338 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6339 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0068, (cst_val *)&val_0004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0069, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6340 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0071, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6341 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6342 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0074, (cst_val *)&val_6343},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0075, (cst_val *)&val_0232},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0076, (cst_val *)&val_5671},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6345 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0079, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6347 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6348 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0084, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6350 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0087, (cst_val *)&val_0088},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0088, (cst_val *)&val_6351},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0089, (cst_val *)&val_0995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6353 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0092, (cst_val *)&val_6354},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0093, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6357 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0097, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0098, (cst_val *)&val_6358},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0099, (cst_val *)&val_0420},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0100, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6360 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0103, (cst_val *)&val_6361},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0104, (cst_val *)&val_2081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6362 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0106, (cst_val *)&val_4831},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6364 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0109, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6365 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0111, (cst_val *)&val_6366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6369 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0115, (cst_val *)&val_6370},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6371 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0117, (cst_val *)&val_3102},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6373 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0120, (cst_val *)&val_0395},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0121, (cst_val *)&val_0108},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0122, (cst_val *)&val_3923},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6375 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0125, (cst_val *)&val_0105},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0126, (cst_val *)&val_6376},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6379 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0130, (cst_val *)&val_1355},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0131, (cst_val *)&val_4137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6381 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0134, (cst_val *)&val_0018},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0135, (cst_val *)&val_1753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6383 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0138, (cst_val *)&val_0105},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0139, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6385 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0142, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6386 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_66_NO_0144, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6387 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6388 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ey_66_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ey_66_cart = {
  cmu_us_slt_single_mcep_ey_66_cart_nodes,
  cmu_us_slt_single_mcep_ey_66_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ey_67_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0001, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0002, (cst_val *)&val_3129},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0003, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6391 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0007, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0008, (cst_val *)&val_6392},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6393 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0010, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6396 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0014, (cst_val *)&val_0228},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0015, (cst_val *)&val_6397},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0016, (cst_val *)&val_0105},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0017, (cst_val *)&val_0022},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0018, (cst_val *)&val_1804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6399 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0021, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6400 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0023, (cst_val *)&val_6401},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0024, (cst_val *)&val_4458},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6403 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0027, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6405 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0030, (cst_val *)&val_0023},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0031, (cst_val *)&val_6406},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0032, (cst_val *)&val_0232},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0033, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6408 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0036, (cst_val *)&val_6409},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6411 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0039, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6413 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0042, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0043, (cst_val *)&val_6414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6416 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0046, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6418 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0049, (cst_val *)&val_6419},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0050, (cst_val *)&val_6420},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0051, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6421 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0053, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6423 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0056, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6424 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0058, (cst_val *)&val_6425},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6427 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0061, (cst_val *)&val_3696},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6428 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6429 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0064, (cst_val *)&val_6430},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0065, (cst_val *)&val_0228},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0066, (cst_val *)&val_6431},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6432 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0068, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6433 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0070, (cst_val *)&val_6434},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0071, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6436 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0074, (cst_val *)&val_6437},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6439 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0077, (cst_val *)&val_1406},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0078, (cst_val *)&val_0023},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0079, (cst_val *)&val_6440},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0080, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6441 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0082, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6442 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0084, (cst_val *)&val_6443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6444 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0086, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6447 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0090, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6448 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0092, (cst_val *)&val_6449},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0093, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6450 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6451 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0096, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6453 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0099, (cst_val *)&val_6454},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0100, (cst_val *)&val_1813},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0101, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6455 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6456 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0104, (cst_val *)&val_0989},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0105, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6457 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0107, (cst_val *)&val_6458},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0108, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6459 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0110, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6461 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0113, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6464 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0117, (cst_val *)&val_6465},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0118, (cst_val *)&val_0471},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0119, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6467 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0122, (cst_val *)&val_0395},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0123, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6468 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6469 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0126, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6470 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0128, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6471 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0130, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6472 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0132, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6473 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0134, (cst_val *)&val_0885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6475 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0137, (cst_val *)&val_6476},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0138, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6478 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0141, (cst_val *)&val_6479},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0142, (cst_val *)&val_0920},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0143, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6480 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0145, (cst_val *)&val_6481},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6484 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0149, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6486 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0152, (cst_val *)&val_0004},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0153, (cst_val *)&val_0550},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0154, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6487 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6488 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0157, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6489 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0159, (cst_val *)&val_6490},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0160, (cst_val *)&val_6491},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0161, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6493 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0164, (cst_val *)&val_6494},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0165, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6495 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0167, (cst_val *)&val_0108},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0168, (cst_val *)&val_3601},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6499 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6500 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0174, (cst_val *)&val_0140},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0175, (cst_val *)&val_0985},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0176, (cst_val *)&val_1009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6501 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0178, (cst_val *)&val_6502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6503 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0180, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6505 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0183, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6506 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0185, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6507 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0187, (cst_val *)&val_6508},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0188, (cst_val *)&val_6509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6511 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0191, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0192, (cst_val *)&val_0717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6514 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0196, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6515 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0198, (cst_val *)&val_6516},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6517 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0200, (cst_val *)&val_6518},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_67_NO_0201, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6521 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ey_67_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_index",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
NULL };

const cst_cart cmu_us_slt_single_mcep_ey_67_cart = {
  cmu_us_slt_single_mcep_ey_67_cart_nodes,
  cmu_us_slt_single_mcep_ey_67_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ey_68_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0000, (cst_val *)&val_0364},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0001, (cst_val *)&val_2511},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0002, (cst_val *)&val_6522},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6524 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0005, (cst_val *)&val_0363},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0006, (cst_val *)&val_0140},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0007, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6525 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0009, (cst_val *)&val_6526},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6527 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6529 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0013, (cst_val *)&val_6397},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0014, (cst_val *)&val_0775},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0015, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6530 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0017, (cst_val *)&val_1517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6532 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0020, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6535 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0024, (cst_val *)&val_0228},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0025, (cst_val *)&val_0042},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0026, (cst_val *)&val_1193},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0027, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6537 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0030, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6539 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0033, (cst_val *)&val_6540},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0034, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6541 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0036, (cst_val *)&val_4262},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6544 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0040, (cst_val *)&val_0363},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0041, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6545 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0043, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0044, (cst_val *)&val_0030},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0045, (cst_val *)&val_1395},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0046, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6546 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0048, (cst_val *)&val_6547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6549 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0051, (cst_val *)&val_0465},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0052, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6551 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0055, (cst_val *)&val_5841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6552 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0057, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6555 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0061, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6556 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0063, (cst_val *)&val_0395},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0064, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6558 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0067, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0068, (cst_val *)&val_4609},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6560 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0071, (cst_val *)&val_6561},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0072, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6562 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0074, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6564 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0077, (cst_val *)&val_6565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6567 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0080, (cst_val *)&val_0023},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0081, (cst_val *)&val_6568},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0082, (cst_val *)&val_0082},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0083, (cst_val *)&val_6569},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0084, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6571 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0087, (cst_val *)&val_2775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6573 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0090, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6575 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0093, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6577 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0096, (cst_val *)&val_5794},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0097, (cst_val *)&val_6578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6580 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0100, (cst_val *)&val_1463},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0101, (cst_val *)&val_3091},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0102, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6581 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0104, (cst_val *)&val_6547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6583 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0107, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6584 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0109, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6585 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0111, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6586 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0113, (cst_val *)&val_6587},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ey_68_NO_0114, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6591 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ey_68_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_place",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_ey_68_cart = {
  cmu_us_slt_single_mcep_ey_68_cart_nodes,
  cmu_us_slt_single_mcep_ey_68_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_f_71_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0001, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6592 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0003, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0004, (cst_val *)&val_0072},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0005, (cst_val *)&val_6593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6594 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0007, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6596 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0010, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6598 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0013, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6599 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0015, (cst_val *)&val_6600},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0016, (cst_val *)&val_1085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6602 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0019, (cst_val *)&val_0371},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0020, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6605 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0024, (cst_val *)&val_0287},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0025, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6606 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0027, (cst_val *)&val_0022},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0028, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0029, (cst_val *)&val_1887},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0030, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6607 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0032, (cst_val *)&val_5707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6610 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0036, (cst_val *)&val_3823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6612 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0039, (cst_val *)&val_4283},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0040, (cst_val *)&val_6613},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0041, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6615 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6616 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6617 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0046, (cst_val *)&val_6618},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0047, (cst_val *)&val_0449},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0048, (cst_val *)&val_0023},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0049, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6620 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0052, (cst_val *)&val_0004},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0053, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6623 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0057, (cst_val *)&val_0064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0058, (cst_val *)&val_6624},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0059, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6626 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0062, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6628 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0065, (cst_val *)&val_6629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6631 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0068, (cst_val *)&val_3486},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0069, (cst_val *)&val_4087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6632 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0071, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0072, (cst_val *)&val_6633},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6636 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0076, (cst_val *)&val_0018},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0077, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6638 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_71_NO_0080, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6640 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_f_71_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_f_71_cart = {
  cmu_us_slt_single_mcep_f_71_cart_nodes,
  cmu_us_slt_single_mcep_f_71_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_f_72_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0000, (cst_val *)&val_0073},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0001, (cst_val *)&val_0025},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0002, (cst_val *)&val_6641},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0003, (cst_val *)&val_0284},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0004, (cst_val *)&val_0478},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0005, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0006, (cst_val *)&val_0001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0007, (cst_val *)&val_6642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6644 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0010, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6646 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0013, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6649 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0017, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0018, (cst_val *)&val_0004},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0019, (cst_val *)&val_6650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6652 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0022, (cst_val *)&val_2479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6654 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0025, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6655 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0027, (cst_val *)&val_6656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6658 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0030, (cst_val *)&val_4907},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0031, (cst_val *)&val_0284},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0032, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6660 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0035, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6663 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0039, (cst_val *)&val_0001},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0040, (cst_val *)&val_6664},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0041, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6665 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6666 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0044, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6668 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0047, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6669 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0049, (cst_val *)&val_0287},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0050, (cst_val *)&val_1395},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0051, (cst_val *)&val_0108},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0052, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6670 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0054, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6673 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0058, (cst_val *)&val_6674},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6675 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0060, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6677 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0063, (cst_val *)&val_0064},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0064, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6680 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0068, (cst_val *)&val_0625},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0069, (cst_val *)&val_0004},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0070, (cst_val *)&val_0007},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0071, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6681 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0073, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6683 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0076, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6684 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0078, (cst_val *)&val_0850},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0079, (cst_val *)&val_6685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6687 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0082, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0083, (cst_val *)&val_6688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6690 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0086, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6692 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0089, (cst_val *)&val_2926},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0090, (cst_val *)&val_0088},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0091, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6694 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0094, (cst_val *)&val_1400},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0095, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6695 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0097, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6698 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0101, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6699 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0103, (cst_val *)&val_0064},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0104, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6701 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0107, (cst_val *)&val_6702},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6704 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0110, (cst_val *)&val_0001},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0111, (cst_val *)&val_6705},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0112, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6706 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0114, (cst_val *)&val_0001},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0115, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6707 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0117, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6709 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0120, (cst_val *)&val_1227},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6710 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0122, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6711 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0124, (cst_val *)&val_6712},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6713 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6714 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0127, (cst_val *)&val_0001},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0128, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6715 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0130, (cst_val *)&val_1791},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0131, (cst_val *)&val_6629},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6717 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0134, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6718 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6719 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0137, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6720 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0139, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6722 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0142, (cst_val *)&val_0061},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0143, (cst_val *)&val_0391},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0144, (cst_val *)&val_6723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6725 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0147, (cst_val *)&val_0239},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0148, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6726 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6728 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0152, (cst_val *)&val_2932},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0153, (cst_val *)&val_1044},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0154, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6729 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0156, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6730 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0158, (cst_val *)&val_6731},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6733 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0161, (cst_val *)&val_3253},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0162, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6734 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0164, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6735 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0166, (cst_val *)&val_4922},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0167, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6737 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0170, (cst_val *)&val_2845},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0171, (cst_val *)&val_6738},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6741 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0175, (cst_val *)&val_6742},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0176, (cst_val *)&val_0064},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0177, (cst_val *)&val_6743},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6745 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0180, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6747 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0183, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6749 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0186, (cst_val *)&val_0395},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0187, (cst_val *)&val_6750},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0188, (cst_val *)&val_6751},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0189, (cst_val *)&val_0064},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0190, (cst_val *)&val_6752},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6753 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0192, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6757 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0197, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6758 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6759 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0200, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6760 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0202, (cst_val *)&val_0004},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0203, (cst_val *)&val_6761},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0204, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6762 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0206, (cst_val *)&val_6763},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0207, (cst_val *)&val_6764},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0208, (cst_val *)&val_0993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6765 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0210, (cst_val *)&val_3851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6770 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0216, (cst_val *)&val_0395},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0217, (cst_val *)&val_6771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6772 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0219, (cst_val *)&val_6773},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0220, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6774 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6776 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0224, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6777 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0226, (cst_val *)&val_6778},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0227, (cst_val *)&val_6779},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0228, (cst_val *)&val_1606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6780 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6781 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0231, (cst_val *)&val_4922},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0232, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6783 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_72_NO_0235, (cst_val *)&val_6784},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6787 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_f_72_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_index",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_f_72_cart = {
  cmu_us_slt_single_mcep_f_72_cart_nodes,
  cmu_us_slt_single_mcep_f_72_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_f_73_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0000, (cst_val *)&val_0042},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0001, (cst_val *)&val_1406},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0002, (cst_val *)&val_0064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0003, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6789 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0006, (cst_val *)&val_0001},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0007, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6791 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0010, (cst_val *)&val_0237},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0011, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6793 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0014, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6794 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0016, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6796 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0019, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6797 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0021, (cst_val *)&val_1119},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0022, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6798 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0024, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6799 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0026, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6800 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6801 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0029, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6802 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0031, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6804 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0034, (cst_val *)&val_6805},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0035, (cst_val *)&val_1616},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0036, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6806 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0038, (cst_val *)&val_6807},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0039, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6809 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0042, (cst_val *)&val_0920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6811 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0045, (cst_val *)&val_0108},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0046, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6812 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6813 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_f_73_NO_0049, (cst_val *)&val_6814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6817 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_f_73_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_slt_single_mcep_f_73_cart = {
  cmu_us_slt_single_mcep_f_73_cart_nodes,
  cmu_us_slt_single_mcep_f_73_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ih_86_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0000, (cst_val *)&val_0217},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0001, (cst_val *)&val_2281},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0002, (cst_val *)&val_1390},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0003, (cst_val *)&val_0709},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6819 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0006, (cst_val *)&val_0284},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0007, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6821 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0010, (cst_val *)&val_1579},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0011, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6822 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0013, (cst_val *)&val_1114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6825 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0017, (cst_val *)&val_0018},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0018, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6826 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0020, (cst_val *)&val_0652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6828 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0023, (cst_val *)&val_5046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6830 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0026, (cst_val *)&val_1660},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0027, (cst_val *)&val_0237},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0028, (cst_val *)&val_6831},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0029, (cst_val *)&val_0524},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6834 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0033, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6835 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0035, (cst_val *)&val_6836},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0036, (cst_val *)&val_1071},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0037, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6837 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6839 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0041, (cst_val *)&val_0023},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0042, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6841 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0045, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6843 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0048, (cst_val *)&val_5995},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0049, (cst_val *)&val_0643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6845 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0052, (cst_val *)&val_0140},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0053, (cst_val *)&val_6846},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0054, (cst_val *)&val_0018},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0055, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6848 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0058, (cst_val *)&val_0467},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0059, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6850 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0062, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0063, (cst_val *)&val_1470},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6852 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0066, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6853 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0068, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6854 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0070, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6855 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0072, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6857 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0075, (cst_val *)&val_0026},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0076, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6858 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0078, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0079, (cst_val *)&val_6859},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6863 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0084, (cst_val *)&val_0237},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0085, (cst_val *)&val_0232},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0086, (cst_val *)&val_0140},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0087, (cst_val *)&val_1355},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0088, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6867 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0093, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6868 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0095, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6869 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0097, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6870 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0099, (cst_val *)&val_4301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6871 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0101, (cst_val *)&val_1358},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0102, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6873 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0105, (cst_val *)&val_0088},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0106, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6874 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0108, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6876 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0111, (cst_val *)&val_1485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6877 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0113, (cst_val *)&val_6878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6880 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0116, (cst_val *)&val_0232},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0117, (cst_val *)&val_0420},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0118, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6882 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0121, (cst_val *)&val_0042},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0122, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6884 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0125, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6886 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0128, (cst_val *)&val_0705},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0129, (cst_val *)&val_0590},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0130, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6888 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0133, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6889 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0135, (cst_val *)&val_0009},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0136, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6891 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0139, (cst_val *)&val_6892},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6894 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0142, (cst_val *)&val_0007},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0143, (cst_val *)&val_0105},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0144, (cst_val *)&val_1358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6895 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0146, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6896 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0148, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6898 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0151, (cst_val *)&val_6899},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0152, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6901 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0155, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6903 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0158, (cst_val *)&val_0088},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0159, (cst_val *)&val_0239},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0160, (cst_val *)&val_3356},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6906 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0164, (cst_val *)&val_0004},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_86_NO_0165, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6909 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ih_86_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_rindex",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_slt_single_mcep_ih_86_cart = {
  cmu_us_slt_single_mcep_ih_86_cart_nodes,
  cmu_us_slt_single_mcep_ih_86_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ih_87_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0001, (cst_val *)&val_0547},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0002, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6911 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0005, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0006, (cst_val *)&val_0643},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0007, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0008, (cst_val *)&val_6912},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0009, (cst_val *)&val_0994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6914 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0012, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6916 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0015, (cst_val *)&val_2775},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0016, (cst_val *)&val_6917},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0017, (cst_val *)&val_0994},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6918 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6919 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0020, (cst_val *)&val_6920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6923 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0024, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0025, (cst_val *)&val_6924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6925 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0027, (cst_val *)&val_0621},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0028, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6928 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0032, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6929 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0034, (cst_val *)&val_0001},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0035, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6931 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0038, (cst_val *)&val_6932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6933 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0040, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6935 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0043, (cst_val *)&val_1838},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0044, (cst_val *)&val_4573},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0045, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6936 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0047, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0048, (cst_val *)&val_1006},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0049, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6939 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0053, (cst_val *)&val_0985},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0054, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6942 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0058, (cst_val *)&val_6943},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0059, (cst_val *)&val_3647},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0060, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6944 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0062, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6945 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0064, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6947 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6949 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0069, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6951 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0072, (cst_val *)&val_0105},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0073, (cst_val *)&val_1071},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0074, (cst_val *)&val_1071},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0075, (cst_val *)&val_0105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0076, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6953 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0079, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6955 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0082, (cst_val *)&val_0004},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0083, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6957 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0086, (cst_val *)&val_1218},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0087, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6960 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0091, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0092, (cst_val *)&val_6961},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6962 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0094, (cst_val *)&val_0471},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0095, (cst_val *)&val_6963},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6964 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6965 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0098, (cst_val *)&val_0969},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0099, (cst_val *)&val_6966},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0100, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6967 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6970 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0105, (cst_val *)&val_0001},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0106, (cst_val *)&val_1407},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0107, (cst_val *)&val_6971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6972 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0109, (cst_val *)&val_0023},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0110, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6975 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6976 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0115, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0116, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6977 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6978 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0119, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6980 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0122, (cst_val *)&val_0137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0123, (cst_val *)&val_3147},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0124, (cst_val *)&val_0228},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0125, (cst_val *)&val_0280},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0126, (cst_val *)&val_2311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6982 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0129, (cst_val *)&val_0088},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0130, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6983 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0132, (cst_val *)&val_6984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6985 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6986 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0135, (cst_val *)&val_0061},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0136, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6988 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0139, (cst_val *)&val_0105},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0140, (cst_val *)&val_0032},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6990 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6991 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0144, (cst_val *)&val_2449},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0145, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6993 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0148, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6994 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0150, (cst_val *)&val_0023},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0151, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0152, (cst_val *)&val_0590},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0153, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6995 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0155, (cst_val *)&val_6996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6998 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0158, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_6999 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0160, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7000 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0162, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7001 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7003 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0166, (cst_val *)&val_0004},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0167, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7005 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0170, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7007 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0173, (cst_val *)&val_0652},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0174, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7009 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0177, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0178, (cst_val *)&val_5671},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0179, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7010 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0181, (cst_val *)&val_0642},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0182, (cst_val *)&val_7011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7014 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0186, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7016 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0189, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7018 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0192, (cst_val *)&val_0088},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0193, (cst_val *)&val_0399},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0194, (cst_val *)&val_7019},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0195, (cst_val *)&val_7020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7023 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0199, (cst_val *)&val_1006},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0200, (cst_val *)&val_0023},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0201, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0202, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7024 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7025 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0205, (cst_val *)&val_6996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7027 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0208, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7029 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0211, (cst_val *)&val_7030},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0212, (cst_val *)&val_6943},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7032 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0215, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7033 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0217, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7035 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0220, (cst_val *)&val_0061},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0221, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7037 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0224, (cst_val *)&val_0679},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0225, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7038 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0227, (cst_val *)&val_0228},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0228, (cst_val *)&val_7039},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0229, (cst_val *)&val_3950},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0230, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7040 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7042 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0234, (cst_val *)&val_7043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7045 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7046 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0238, (cst_val *)&val_0228},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0239, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7047 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0241, (cst_val *)&val_0471},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_87_NO_0242, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7048 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7051 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ih_87_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_phone_place",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_slt_single_mcep_ih_87_cart = {
  cmu_us_slt_single_mcep_ih_87_cart_nodes,
  cmu_us_slt_single_mcep_ih_87_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ih_88_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0001, (cst_val *)&val_7052},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0002, (cst_val *)&val_7053},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0003, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7054 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0005, (cst_val *)&val_7055},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0006, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7058 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0010, (cst_val *)&val_7059},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0011, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7060 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0013, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7062 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0016, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7063 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0018, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7065 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0021, (cst_val *)&val_0088},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0022, (cst_val *)&val_0186},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0023, (cst_val *)&val_0082},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0024, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7068 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0028, (cst_val *)&val_1119},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0029, (cst_val *)&val_0082},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0030, (cst_val *)&val_7069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7072 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0034, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7073 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7074 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0037, (cst_val *)&val_0395},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0038, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7076 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0041, (cst_val *)&val_0038},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0042, (cst_val *)&val_1377},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0043, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7077 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0045, (cst_val *)&val_4776},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0046, (cst_val *)&val_3851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7078 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7080 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0050, (cst_val *)&val_3920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7081 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0052, (cst_val *)&val_0217},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0053, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7083 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0056, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7084 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0058, (cst_val *)&val_0699},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0059, (cst_val *)&val_0727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7085 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7088 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0064, (cst_val *)&val_0228},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0065, (cst_val *)&val_0140},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0066, (cst_val *)&val_0018},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0067, (cst_val *)&val_0373},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7089 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0069, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7091 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0072, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0073, (cst_val *)&val_0365},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0074, (cst_val *)&val_5671},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0075, (cst_val *)&val_1000},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0076, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0077, (cst_val *)&val_7092},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7094 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0080, (cst_val *)&val_5346},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0081, (cst_val *)&val_5848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7095 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0083, (cst_val *)&val_0683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7097 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7098 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0087, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7099 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7101 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0091, (cst_val *)&val_0313},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0092, (cst_val *)&val_1887},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7102 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7104 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0096, (cst_val *)&val_0048},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0097, (cst_val *)&val_0178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7105 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7106 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7107 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0101, (cst_val *)&val_4439},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0102, (cst_val *)&val_7108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0103, (cst_val *)&val_7109},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7110 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0105, (cst_val *)&val_7111},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0106, (cst_val *)&val_0239},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0107, (cst_val *)&val_4313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7115 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0112, (cst_val *)&val_0105},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0113, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0114, (cst_val *)&val_7116},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7117 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7118 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0117, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7120 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0120, (cst_val *)&val_0200},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0121, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7121 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0123, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0124, (cst_val *)&val_3642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7122 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7123 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0127, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7126 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0131, (cst_val *)&val_0057},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0132, (cst_val *)&val_1193},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0133, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7127 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0135, (cst_val *)&val_5863},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7129 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0138, (cst_val *)&val_0105},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0139, (cst_val *)&val_2042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7132 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0143, (cst_val *)&val_0105},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0144, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7133 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0146, (cst_val *)&val_7134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7136 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0149, (cst_val *)&val_7137},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0150, (cst_val *)&val_6540},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0151, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7140 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0155, (cst_val *)&val_1193},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0156, (cst_val *)&val_0073},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0157, (cst_val *)&val_7141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7143 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0160, (cst_val *)&val_7144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7146 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0163, (cst_val *)&val_2845},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7147 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0165, (cst_val *)&val_7148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7150 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0168, (cst_val *)&val_1978},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0169, (cst_val *)&val_1310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7151 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0171, (cst_val *)&val_0019},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0172, (cst_val *)&val_7152},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0173, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7154 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7155 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0177, (cst_val *)&val_7156},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0178, (cst_val *)&val_3826},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7158 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0181, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7160 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0184, (cst_val *)&val_0828},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0185, (cst_val *)&val_1395},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0186, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7161 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0188, (cst_val *)&val_7162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7163 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0190, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7164 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0192, (cst_val *)&val_7165},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7167 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0195, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7168 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0197, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7169 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0199, (cst_val *)&val_7170},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7171 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7172 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0202, (cst_val *)&val_1466},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0203, (cst_val *)&val_0595},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0204, (cst_val *)&val_0186},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0205, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7174 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0208, (cst_val *)&val_7175},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0209, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7177 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0212, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7178 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0214, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7180 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0217, (cst_val *)&val_4010},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0218, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7182 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0221, (cst_val *)&val_1967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7183 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0223, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7184 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0225, (cst_val *)&val_0194},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0226, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7187 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0230, (cst_val *)&val_0018},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0231, (cst_val *)&val_1967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7188 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0233, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0234, (cst_val *)&val_7189},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0235, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0236, (cst_val *)&val_7190},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7192 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0239, (cst_val *)&val_0108},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0240, (cst_val *)&val_7193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7196 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0244, (cst_val *)&val_5511},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0245, (cst_val *)&val_3023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0246, (cst_val *)&val_7197},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7201 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0251, (cst_val *)&val_7202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7204 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ih_88_NO_0254, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7205 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7206 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ih_88_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_state_pos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_phone_index",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_ih_88_cart = {
  cmu_us_slt_single_mcep_ih_88_cart_nodes,
  cmu_us_slt_single_mcep_ih_88_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_p_136_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0000, (cst_val *)&val_0007},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0001, (cst_val *)&val_2064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0002, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0003, (cst_val *)&val_1061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7208 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0006, (cst_val *)&val_7209},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0007, (cst_val *)&val_0783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7211 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0010, (cst_val *)&val_0284},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0011, (cst_val *)&val_1143},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0012, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7214 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0016, (cst_val *)&val_1080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7215 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7216 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0019, (cst_val *)&val_0025},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0020, (cst_val *)&val_0395},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0021, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7218 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0024, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7219 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0026, (cst_val *)&val_0001},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0027, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7221 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0030, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7222 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0032, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7224 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0035, (cst_val *)&val_0461},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0036, (cst_val *)&val_7225},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7228 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0040, (cst_val *)&val_7229},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0041, (cst_val *)&val_0046},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0042, (cst_val *)&val_0239},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0043, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7231 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0046, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7232 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0048, (cst_val *)&val_0683},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0049, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7235 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0053, (cst_val *)&val_0014},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0054, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7237 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0057, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7238 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0059, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7239 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0061, (cst_val *)&val_0108},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0062, (cst_val *)&val_7240},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7242 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_136_NO_0065, (cst_val *)&val_3023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7245 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_p_136_feat_table[] = {
"lisp_cg_state_index",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_p_136_cart = {
  cmu_us_slt_single_mcep_p_136_cart_nodes,
  cmu_us_slt_single_mcep_p_136_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_p_137_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0000, (cst_val *)&val_0137},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0001, (cst_val *)&val_0295},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0003, (cst_val *)&val_7246},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0004, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7248 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0007, (cst_val *)&val_7249},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0008, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7250 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0010, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7251 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7252 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0013, (cst_val *)&val_0679},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0014, (cst_val *)&val_7253},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0015, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7254 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0017, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7257 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0021, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7258 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0023, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7259 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0025, (cst_val *)&val_7260},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7262 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0028, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0029, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7263 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0031, (cst_val *)&val_1006},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0032, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7265 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0035, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7266 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0037, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7268 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0040, (cst_val *)&val_7269},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0041, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7271 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0044, (cst_val *)&val_0942},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0045, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7272 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7273 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0048, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7274 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0050, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7276 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0053, (cst_val *)&val_7277},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0054, (cst_val *)&val_7278},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0055, (cst_val *)&val_0140},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0056, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7279 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0058, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7280 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0060, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7282 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0063, (cst_val *)&val_1227},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0064, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0065, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7283 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7284 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0068, (cst_val *)&val_7285},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7286 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0070, (cst_val *)&val_7287},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7290 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0074, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7292 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0077, (cst_val *)&val_0668},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0078, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7293 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0080, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7294 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0082, (cst_val *)&val_3486},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7296 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0085, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7298 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0088, (cst_val *)&val_4602},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0089, (cst_val *)&val_7209},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0090, (cst_val *)&val_1753},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0091, (cst_val *)&val_7299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7300 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0093, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7302 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0096, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7303 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7304 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0099, (cst_val *)&val_6629},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0100, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7305 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0102, (cst_val *)&val_5282},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7306 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0104, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7309 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0108, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7310 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0110, (cst_val *)&val_1080},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0111, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7312 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_137_NO_0114, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7313 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7314 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_p_137_feat_table[] = {
"lisp_cg_state_pos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_p_137_cart = {
  cmu_us_slt_single_mcep_p_137_cart_nodes,
  cmu_us_slt_single_mcep_p_137_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_p_138_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0000, (cst_val *)&val_0047},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0001, (cst_val *)&val_0237},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0002, (cst_val *)&val_7209},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0003, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7315 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0005, (cst_val *)&val_5944},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0006, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7318 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0010, (cst_val *)&val_0003},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0011, (cst_val *)&val_1617},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0012, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7320 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0015, (cst_val *)&val_1548},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7323 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0019, (cst_val *)&val_1978},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0020, (cst_val *)&val_0009},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0021, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7325 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0024, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7326 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0026, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7328 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0029, (cst_val *)&val_0550},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0030, (cst_val *)&val_1699},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0031, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7329 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0033, (cst_val *)&val_0001},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0034, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7330 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7331 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0037, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7333 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0040, (cst_val *)&val_0025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0041, (cst_val *)&val_7334},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0042, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7335 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7336 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0045, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7337 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7338 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0048, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7339 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0050, (cst_val *)&val_0232},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0051, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7341 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0054, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7342 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0056, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7343 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7344 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0059, (cst_val *)&val_7345},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0060, (cst_val *)&val_0001},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0061, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7346 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7347 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0064, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0065, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7348 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0067, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7349 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7350 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0070, (cst_val *)&val_7351},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0071, (cst_val *)&val_7352},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7353 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7354 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0074, (cst_val *)&val_1019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7356 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0077, (cst_val *)&val_0395},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0078, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7357 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7358 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0081, (cst_val *)&val_0018},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0082, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7360 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0085, (cst_val *)&val_7361},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7362 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7363 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0088, (cst_val *)&val_0668},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0089, (cst_val *)&val_0064},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0090, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7364 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7365 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0093, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0094, (cst_val *)&val_0137},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0095, (cst_val *)&val_7366},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7367 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7368 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0098, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7370 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0101, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7371 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0103, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7372 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0105, (cst_val *)&val_5430},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0106, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7374 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0109, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7376 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0112, (cst_val *)&val_0232},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0113, (cst_val *)&val_7377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7379 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0116, (cst_val *)&val_0004},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0117, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7380 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0119, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7381 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7382 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_p_138_NO_0122, (cst_val *)&val_7383},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7384 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7385 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_p_138_feat_table[] = {
"lisp_cg_state_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
NULL };

const cst_cart cmu_us_slt_single_mcep_p_138_cart = {
  cmu_us_slt_single_mcep_p_138_cart_nodes,
  cmu_us_slt_single_mcep_p_138_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_iy_91_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0001, (cst_val *)&val_0705},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0002, (cst_val *)&val_7386},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0003, (cst_val *)&val_0099},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0004, (cst_val *)&val_5434},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0005, (cst_val *)&val_7387},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0006, (cst_val *)&val_0171},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0007, (cst_val *)&val_7388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7390 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0010, (cst_val *)&val_0850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7394 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0015, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7395 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0017, (cst_val *)&val_7396},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7397 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7398 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0020, (cst_val *)&val_7399},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0021, (cst_val *)&val_0009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0022, (cst_val *)&val_7400},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0023, (cst_val *)&val_1221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7403 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0027, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7405 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0030, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7407 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0033, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0034, (cst_val *)&val_7408},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0035, (cst_val *)&val_1044},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0036, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7409 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0038, (cst_val *)&val_7410},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7412 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0041, (cst_val *)&val_7413},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0042, (cst_val *)&val_7414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7416 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0045, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7418 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0048, (cst_val *)&val_0299},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0049, (cst_val *)&val_7419},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7422 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0053, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7423 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0055, (cst_val *)&val_0023},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0056, (cst_val *)&val_6593},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0057, (cst_val *)&val_2882},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0058, (cst_val *)&val_5650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7425 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0061, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7426 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7427 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0064, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7428 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0066, (cst_val *)&val_7429},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0067, (cst_val *)&val_0223},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0068, (cst_val *)&val_1114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7433 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0073, (cst_val *)&val_0105},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0074, (cst_val *)&val_4873},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7434 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0076, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7437 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0080, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0081, (cst_val *)&val_0313},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0082, (cst_val *)&val_1355},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0083, (cst_val *)&val_0099},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0084, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7438 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7439 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0087, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7440 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0089, (cst_val *)&val_2683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7442 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0092, (cst_val *)&val_0042},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0093, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7443 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7444 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0096, (cst_val *)&val_0178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7445 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0098, (cst_val *)&val_7446},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7447 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7448 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0101, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7450 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0104, (cst_val *)&val_1660},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0105, (cst_val *)&val_0237},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0106, (cst_val *)&val_2492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7451 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0108, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7453 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0111, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0112, (cst_val *)&val_2081},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0113, (cst_val *)&val_0506},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0114, (cst_val *)&val_3135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7455 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0117, (cst_val *)&val_2281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7458 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0121, (cst_val *)&val_0453},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0122, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7459 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0124, (cst_val *)&val_0644},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0125, (cst_val *)&val_0108},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0126, (cst_val *)&val_7460},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7461 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7463 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0130, (cst_val *)&val_7464},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7465 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0132, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7467 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0135, (cst_val *)&val_7468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7470 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0138, (cst_val *)&val_2699},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0139, (cst_val *)&val_1347},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0140, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7472 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0143, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7474 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0146, (cst_val *)&val_0705},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0147, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7475 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0149, (cst_val *)&val_3580},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7477 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0152, (cst_val *)&val_7478},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0153, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7479 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0155, (cst_val *)&val_7480},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0156, (cst_val *)&val_2096},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0157, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7483 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0161, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7484 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0163, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7485 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7486 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0166, (cst_val *)&val_5863},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0167, (cst_val *)&val_0140},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0168, (cst_val *)&val_4447},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0169, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7487 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0171, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7488 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0173, (cst_val *)&val_3760},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7490 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0176, (cst_val *)&val_7491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7492 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7493 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0179, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7494 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0181, (cst_val *)&val_0343},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0182, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7495 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0184, (cst_val *)&val_0036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7498 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0188, (cst_val *)&val_0073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7499 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_91_NO_0190, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7500 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7501 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_iy_91_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_iy_91_cart = {
  cmu_us_slt_single_mcep_iy_91_cart_nodes,
  cmu_us_slt_single_mcep_iy_91_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_iy_92_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0000, (cst_val *)&val_7502},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0001, (cst_val *)&val_0228},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0002, (cst_val *)&val_0237},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0003, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7504 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0006, (cst_val *)&val_7505},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0007, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7506 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0009, (cst_val *)&val_4341},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0010, (cst_val *)&val_0023},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0011, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7508 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0014, (cst_val *)&val_7148},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7510 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0017, (cst_val *)&val_7511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7512 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7513 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0020, (cst_val *)&val_3074},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0021, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7514 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0023, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7515 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0025, (cst_val *)&val_0018},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0026, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7517 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0029, (cst_val *)&val_0023},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0030, (cst_val *)&val_7518},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7521 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0034, (cst_val *)&val_7522},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0035, (cst_val *)&val_1326},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0036, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7523 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7524 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7526 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0041, (cst_val *)&val_0228},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0042, (cst_val *)&val_0108},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0043, (cst_val *)&val_7527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7528 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0045, (cst_val *)&val_0023},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0046, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7529 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0048, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7530 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0050, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7531 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7532 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0053, (cst_val *)&val_7533},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0054, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7534 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7535 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0057, (cst_val *)&val_7536},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0058, (cst_val *)&val_0137},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0059, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7539 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0063, (cst_val *)&val_0024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7542 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0067, (cst_val *)&val_7543},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0068, (cst_val *)&val_0088},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0069, (cst_val *)&val_0023},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0070, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0071, (cst_val *)&val_0284},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0072, (cst_val *)&val_7544},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7546 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0075, (cst_val *)&val_7547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7549 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0078, (cst_val *)&val_7550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7552 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0081, (cst_val *)&val_0465},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0082, (cst_val *)&val_7553},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7555 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0085, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7556 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0087, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7557 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0089, (cst_val *)&val_7558},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0090, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7561 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0094, (cst_val *)&val_0023},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0095, (cst_val *)&val_0039},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0096, (cst_val *)&val_0018},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0097, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7562 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0099, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7563 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0101, (cst_val *)&val_7564},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7565 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7566 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0104, (cst_val *)&val_3783},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0105, (cst_val *)&val_0084},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0106, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7568 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0109, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7569 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7572 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0114, (cst_val *)&val_1878},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0115, (cst_val *)&val_0018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0116, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7573 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0118, (cst_val *)&val_5430},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7575 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0121, (cst_val *)&val_1406},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0122, (cst_val *)&val_1386},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7577 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0125, (cst_val *)&val_0232},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0126, (cst_val *)&val_7578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7580 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0129, (cst_val *)&val_0280},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0130, (cst_val *)&val_7581},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7583 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0133, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7584 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7585 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0136, (cst_val *)&val_7586},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0137, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7588 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7589 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0141, (cst_val *)&val_0105},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0142, (cst_val *)&val_4602},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0143, (cst_val *)&val_0061},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0144, (cst_val *)&val_7590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7591 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7592 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0147, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7594 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0150, (cst_val *)&val_0465},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0151, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7595 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7596 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0154, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0155, (cst_val *)&val_1626},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7597 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0157, (cst_val *)&val_7111},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0158, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7598 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0160, (cst_val *)&val_7599},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0161, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7602 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0165, (cst_val *)&val_7603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7605 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0168, (cst_val *)&val_3766},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0169, (cst_val *)&val_0018},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0170, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7607 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0173, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7609 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7610 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0177, (cst_val *)&val_0088},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0178, (cst_val *)&val_0009},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0179, (cst_val *)&val_7611},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7612 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0181, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7614 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0184, (cst_val *)&val_0018},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0185, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7615 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0187, (cst_val *)&val_7616},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7618 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0190, (cst_val *)&val_0023},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0191, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7620 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0194, (cst_val *)&val_7621},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0195, (cst_val *)&val_7622},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0196, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7623 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7626 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0201, (cst_val *)&val_2385},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0202, (cst_val *)&val_0232},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0203, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7627 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0205, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7629 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0208, (cst_val *)&val_0004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0209, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7631 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0212, (cst_val *)&val_2468},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0213, (cst_val *)&val_0048},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0214, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7633 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0217, (cst_val *)&val_4141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7635 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7636 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0221, (cst_val *)&val_0232},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0222, (cst_val *)&val_1080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7637 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7638 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0225, (cst_val *)&val_3102},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0226, (cst_val *)&val_0061},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0227, (cst_val *)&val_0064},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0228, (cst_val *)&val_0024},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0229, (cst_val *)&val_7639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7642 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0233, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7644 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0236, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7646 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0239, (cst_val *)&val_7647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7649 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0242, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0243, (cst_val *)&val_0228},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0244, (cst_val *)&val_7650},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0245, (cst_val *)&val_2858},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0246, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7652 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7653 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0250, (cst_val *)&val_7654},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0251, (cst_val *)&val_4332},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0252, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7658 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0257, (cst_val *)&val_0942},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0258, (cst_val *)&val_2644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7660 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0261, (cst_val *)&val_7661},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0262, (cst_val *)&val_0140},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0263, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7663 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0266, (cst_val *)&val_1544},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7665 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0269, (cst_val *)&val_1699},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0270, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7666 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0272, (cst_val *)&val_7667},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7670 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0276, (cst_val *)&val_0088},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0277, (cst_val *)&val_0506},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0278, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7672 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0281, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7673 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0283, (cst_val *)&val_3442},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7675 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0286, (cst_val *)&val_0014},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0287, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7677 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0290, (cst_val *)&val_7678},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0291, (cst_val *)&val_0140},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0292, (cst_val *)&val_0108},
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0293, (cst_val *)&val_0141},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0294, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7681 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0298, (cst_val *)&val_0239},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0299, (cst_val *)&val_7682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7684 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0302, (cst_val *)&val_7685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7687 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0305, (cst_val *)&val_7688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7689 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7690 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0308, (cst_val *)&val_0547},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0309, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7692 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0312, (cst_val *)&val_0105},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0313, (cst_val *)&val_0387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7694 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_92_NO_0316, (cst_val *)&val_7695},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7697 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_iy_92_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_rindex",
NULL };

const cst_cart cmu_us_slt_single_mcep_iy_92_cart = {
  cmu_us_slt_single_mcep_iy_92_cart_nodes,
  cmu_us_slt_single_mcep_iy_92_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_iy_93_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0001, (cst_val *)&val_7698},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0002, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0003, (cst_val *)&val_7699},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0004, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7700 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0006, (cst_val *)&val_7701},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0007, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7702 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0009, (cst_val *)&val_2644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7703 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0011, (cst_val *)&val_7704},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7705 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7706 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0014, (cst_val *)&val_7707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7708 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0016, (cst_val *)&val_6618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7710 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0019, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7711 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0021, (cst_val *)&val_7712},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0022, (cst_val *)&val_7713},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7714 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0024, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7716 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0027, (cst_val *)&val_7717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7718 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0029, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7719 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0031, (cst_val *)&val_7720},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7722 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0034, (cst_val *)&val_0093},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0035, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7724 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0038, (cst_val *)&val_7725},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0039, (cst_val *)&val_2707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7726 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0041, (cst_val *)&val_7727},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0042, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7728 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0044, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7729 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0046, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7732 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0050, (cst_val *)&val_0132},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0051, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7735 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0055, (cst_val *)&val_7736},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0056, (cst_val *)&val_0093},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0057, (cst_val *)&val_7737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7739 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0060, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7740 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0062, (cst_val *)&val_7741},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0063, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7742 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0065, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7743 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0067, (cst_val *)&val_7744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7745 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0069, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7747 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0072, (cst_val *)&val_0088},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0073, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7749 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0076, (cst_val *)&val_0105},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0077, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7752 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0081, (cst_val *)&val_1949},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0082, (cst_val *)&val_1287},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0083, (cst_val *)&val_0023},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0084, (cst_val *)&val_7753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7756 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0088, (cst_val *)&val_6618},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7758 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0091, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7759 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0093, (cst_val *)&val_7760},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0094, (cst_val *)&val_7761},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7762 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0096, (cst_val *)&val_7763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7765 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0099, (cst_val *)&val_0003},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0100, (cst_val *)&val_7766},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7769 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0104, (cst_val *)&val_0064},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0105, (cst_val *)&val_0018},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0106, (cst_val *)&val_2932},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0107, (cst_val *)&val_0099},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0108, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7770 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0110, (cst_val *)&val_2932},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0111, (cst_val *)&val_7771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7774 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0115, (cst_val *)&val_1699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7775 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0117, (cst_val *)&val_7776},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7777 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0119, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7780 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0123, (cst_val *)&val_0108},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0124, (cst_val *)&val_0064},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0125, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7782 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0128, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7783 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7784 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0131, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0132, (cst_val *)&val_7785},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7786 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7787 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0135, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7789 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0138, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0139, (cst_val *)&val_0668},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0140, (cst_val *)&val_0373},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0141, (cst_val *)&val_7790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7792 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7793 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0145, (cst_val *)&val_0605},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0146, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7796 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0150, (cst_val *)&val_0643},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0151, (cst_val *)&val_2301},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0152, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7797 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0154, (cst_val *)&val_7798},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7800 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0157, (cst_val *)&val_0088},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0158, (cst_val *)&val_0595},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0159, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7801 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7803 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0163, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7804 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0165, (cst_val *)&val_7805},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7806 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0167, (cst_val *)&val_0644},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7808 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0170, (cst_val *)&val_0232},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0171, (cst_val *)&val_0018},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0172, (cst_val *)&val_0828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7810 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0175, (cst_val *)&val_0280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7812 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0178, (cst_val *)&val_0088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0179, (cst_val *)&val_0132},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0180, (cst_val *)&val_0595},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7815 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0184, (cst_val *)&val_1978},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_iy_93_NO_0185, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7817 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7818 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_iy_93_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
NULL };

const cst_cart cmu_us_slt_single_mcep_iy_93_cart = {
  cmu_us_slt_single_mcep_iy_93_cart_nodes,
  cmu_us_slt_single_mcep_iy_93_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_l_106_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0001, (cst_val *)&val_7819},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0002, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0003, (cst_val *)&val_0001},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0004, (cst_val *)&val_0034},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0005, (cst_val *)&val_4879},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0006, (cst_val *)&val_3330},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0007, (cst_val *)&val_0683},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0008, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7821 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0011, (cst_val *)&val_7822},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0012, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7825 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0016, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7826 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0018, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7827 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0020, (cst_val *)&val_2612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7829 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0023, (cst_val *)&val_0927},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0024, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7831 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0027, (cst_val *)&val_1407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7833 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7834 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0031, (cst_val *)&val_1395},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0032, (cst_val *)&val_2095},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0033, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7836 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0036, (cst_val *)&val_3223},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0037, (cst_val *)&val_7837},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7838 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0039, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7840 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0042, (cst_val *)&val_7841},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0043, (cst_val *)&val_0036},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0044, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7844 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0048, (cst_val *)&val_0395},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0049, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7846 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0052, (cst_val *)&val_0237},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0053, (cst_val *)&val_3823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7848 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0056, (cst_val *)&val_7849},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7851 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0059, (cst_val *)&val_0900},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0060, (cst_val *)&val_3260},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0061, (cst_val *)&val_0237},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0062, (cst_val *)&val_0453},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7852 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7853 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0065, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7854 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0067, (cst_val *)&val_7855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7857 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0070, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7858 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0072, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7859 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7860 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0075, (cst_val *)&val_0004},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0076, (cst_val *)&val_7861},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7863 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0079, (cst_val *)&val_3260},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0080, (cst_val *)&val_0237},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0081, (cst_val *)&val_7864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7868 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0086, (cst_val *)&val_0004},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0087, (cst_val *)&val_0061},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0088, (cst_val *)&val_1154},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0089, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7869 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0091, (cst_val *)&val_7870},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0092, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7871 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7872 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0095, (cst_val *)&val_0284},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0096, (cst_val *)&val_6540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7873 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7876 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0101, (cst_val *)&val_0395},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0102, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0103, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7878 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0106, (cst_val *)&val_7879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7880 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0108, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7882 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0111, (cst_val *)&val_0025},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0112, (cst_val *)&val_0942},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0113, (cst_val *)&val_0920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7883 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0115, (cst_val *)&val_2019},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0116, (cst_val *)&val_7884},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7885 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7887 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0120, (cst_val *)&val_0023},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0121, (cst_val *)&val_2019},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0122, (cst_val *)&val_0141},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0123, (cst_val *)&val_4762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7891 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7892 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0129, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7894 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0132, (cst_val *)&val_7895},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0133, (cst_val *)&val_0105},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0134, (cst_val *)&val_0681},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0135, (cst_val *)&val_7896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7898 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0138, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7900 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0141, (cst_val *)&val_0547},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0142, (cst_val *)&val_0108},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0143, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7902 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0146, (cst_val *)&val_7903},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7905 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0149, (cst_val *)&val_0395},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0150, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7906 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0152, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7909 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0156, (cst_val *)&val_0395},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0157, (cst_val *)&val_7910},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0158, (cst_val *)&val_4034},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0159, (cst_val *)&val_0492},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0160, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7912 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0163, (cst_val *)&val_1167},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0164, (cst_val *)&val_7913},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7915 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0167, (cst_val *)&val_2105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7916 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7918 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0171, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7920 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0174, (cst_val *)&val_7921},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0175, (cst_val *)&val_0023},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0176, (cst_val *)&val_0108},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0177, (cst_val *)&val_7922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7924 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0180, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7926 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0183, (cst_val *)&val_4341},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0184, (cst_val *)&val_7927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7929 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0187, (cst_val *)&val_3590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7931 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0190, (cst_val *)&val_7932},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0191, (cst_val *)&val_2103},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0192, (cst_val *)&val_3359},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7934 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0195, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7935 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0197, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7936 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0199, (cst_val *)&val_0108},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0200, (cst_val *)&val_0141},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7940 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0205, (cst_val *)&val_0018},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0206, (cst_val *)&val_0395},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0207, (cst_val *)&val_1984},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0208, (cst_val *)&val_7941},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7942 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0210, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7945 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0214, (cst_val *)&val_0140},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0215, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7946 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0217, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7947 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0219, (cst_val *)&val_7948},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7950 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0222, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7951 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0224, (cst_val *)&val_7952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7953 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0226, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7955 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0229, (cst_val *)&val_7956},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0230, (cst_val *)&val_7957},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0231, (cst_val *)&val_0547},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0232, (cst_val *)&val_7958},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7960 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0235, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7961 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0237, (cst_val *)&val_0023},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0238, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7962 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7964 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0242, (cst_val *)&val_7965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7966 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0244, (cst_val *)&val_0023},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0245, (cst_val *)&val_7967},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0246, (cst_val *)&val_0039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7970 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0250, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7972 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0253, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7973 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0255, (cst_val *)&val_0140},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0256, (cst_val *)&val_0009},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0257, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7974 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0259, (cst_val *)&val_7975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7977 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0262, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7978 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0264, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7980 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0267, (cst_val *)&val_0284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7982 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0270, (cst_val *)&val_0142},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0271, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7983 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0273, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7984 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0275, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7985 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0277, (cst_val *)&val_0004},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0278, (cst_val *)&val_0099},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0279, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7988 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0283, (cst_val *)&val_0140},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0284, (cst_val *)&val_0982},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0285, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7990 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0288, (cst_val *)&val_3580},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0289, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7993 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0293, (cst_val *)&val_0237},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0294, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7995 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0297, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7997 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0300, (cst_val *)&val_0099},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0301, (cst_val *)&val_0004},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0302, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7998 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0304, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_7999 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0306, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8001 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0309, (cst_val *)&val_1060},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0310, (cst_val *)&val_2135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8003 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0313, (cst_val *)&val_8004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0314, (cst_val *)&val_4333},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8007 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0318, (cst_val *)&val_1143},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0319, (cst_val *)&val_8008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8010 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0322, (cst_val *)&val_0108},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_106_NO_0323, (cst_val *)&val_8011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8012 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8014 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_l_106_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_l_106_cart = {
  cmu_us_slt_single_mcep_l_106_cart_nodes,
  cmu_us_slt_single_mcep_l_106_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_l_107_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0000, (cst_val *)&val_0200},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0002, (cst_val *)&val_0395},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0003, (cst_val *)&val_0004},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0004, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8015 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0006, (cst_val *)&val_2688},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8017 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0009, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8018 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0011, (cst_val *)&val_1221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8019 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0013, (cst_val *)&val_0025},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0014, (cst_val *)&val_8020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8021 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0016, (cst_val *)&val_8022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8024 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0019, (cst_val *)&val_8025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8026 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0021, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8027 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0023, (cst_val *)&val_8028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8030 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0026, (cst_val *)&val_0061},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0027, (cst_val *)&val_0105},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0028, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8032 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0031, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8033 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0033, (cst_val *)&val_0169},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0034, (cst_val *)&val_2775},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8035 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0037, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0038, (cst_val *)&val_8036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8037 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0040, (cst_val *)&val_0625},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8039 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0043, (cst_val *)&val_8040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8042 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0046, (cst_val *)&val_0547},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0047, (cst_val *)&val_8043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8044 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0049, (cst_val *)&val_0125},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0050, (cst_val *)&val_8045},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8046 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0052, (cst_val *)&val_4610},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8048 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0055, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8049 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0057, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8050 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0059, (cst_val *)&val_8051},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8052 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8053 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0062, (cst_val *)&val_0001},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0063, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0064, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0065, (cst_val *)&val_7229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8054 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8055 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0068, (cst_val *)&val_8056},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8057 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8058 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8059 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0072, (cst_val *)&val_0638},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0073, (cst_val *)&val_0140},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0074, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8060 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0076, (cst_val *)&val_0313},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0077, (cst_val *)&val_8061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8063 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0080, (cst_val *)&val_8064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8065 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8066 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0083, (cst_val *)&val_5944},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8067 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8068 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0086, (cst_val *)&val_1406},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0087, (cst_val *)&val_8069},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8070 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8072 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0091, (cst_val *)&val_1407},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0092, (cst_val *)&val_0088},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0093, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8073 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0095, (cst_val *)&val_6080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8074 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0097, (cst_val *)&val_0237},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0098, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8076 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0101, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8078 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0104, (cst_val *)&val_0004},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0105, (cst_val *)&val_0105},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0106, (cst_val *)&val_0025},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0107, (cst_val *)&val_8079},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8080 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0109, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8081 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8082 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0112, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8084 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0115, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8085 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0117, (cst_val *)&val_6080},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8087 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0120, (cst_val *)&val_0308},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0121, (cst_val *)&val_8088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8090 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0124, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8091 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8092 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0127, (cst_val *)&val_1264},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0128, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8093 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8094 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0131, (cst_val *)&val_0012},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0132, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8096 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0135, (cst_val *)&val_8097},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8099 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0138, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0139, (cst_val *)&val_0023},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0140, (cst_val *)&val_8100},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0141, (cst_val *)&val_0140},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0142, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8101 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8102 },
{ 34, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0145, (cst_val *)&val_0833},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0146, (cst_val *)&val_0018},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0147, (cst_val *)&val_8103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8105 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0150, (cst_val *)&val_8106},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0151, (cst_val *)&val_8107},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8108 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8109 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8110 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0155, (cst_val *)&val_8111},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0156, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8112 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0158, (cst_val *)&val_8113},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8114 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8115 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0161, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8116 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0163, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8117 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0165, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8118 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8119 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0168, (cst_val *)&val_0018},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0169, (cst_val *)&val_0547},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0170, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8121 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0173, (cst_val *)&val_8122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8124 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0176, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0177, (cst_val *)&val_8125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8126 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8127 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0180, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8128 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0182, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8130 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0185, (cst_val *)&val_8131},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0186, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0187, (cst_val *)&val_4064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8132 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8133 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0190, (cst_val *)&val_8134},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8135 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8136 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0193, (cst_val *)&val_0018},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0194, (cst_val *)&val_0018},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0195, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8137 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0197, (cst_val *)&val_3647},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8139 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0200, (cst_val *)&val_8140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8141 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0202, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0203, (cst_val *)&val_0014},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0204, (cst_val *)&val_2081},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8142 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8144 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0208, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8146 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0211, (cst_val *)&val_0140},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0212, (cst_val *)&val_8147},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0213, (cst_val *)&val_0445},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0214, (cst_val *)&val_3129},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0215, (cst_val *)&val_4313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8148 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8149 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0218, (cst_val *)&val_0108},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0219, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8152 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0223, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8153 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8154 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0226, (cst_val *)&val_0011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8156 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0229, (cst_val *)&val_0105},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0230, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8157 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0232, (cst_val *)&val_8158},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8160 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0235, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8161 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0237, (cst_val *)&val_8162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8164 },
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0240, (cst_val *)&val_0287},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0241, (cst_val *)&val_8165},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0242, (cst_val *)&val_8166},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0243, (cst_val *)&val_0001},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0244, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8167 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0246, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0247, (cst_val *)&val_6540},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8169 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8170 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0251, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8171 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0253, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8173 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0256, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8174 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0258, (cst_val *)&val_8175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8177 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0261, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8178 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0263, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8179 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8180 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0266, (cst_val *)&val_8181},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0267, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8182 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0269, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8183 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0271, (cst_val *)&val_3542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8185 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_107_NO_0274, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8186 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8187 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_l_107_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"lisp_cg_phone_index",
"lisp_cg_phone_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_l_107_cart = {
  cmu_us_slt_single_mcep_l_107_cart_nodes,
  cmu_us_slt_single_mcep_l_107_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_l_108_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0001, (cst_val *)&val_0099},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0002, (cst_val *)&val_2845},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0003, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8188 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0005, (cst_val *)&val_0088},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0006, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8189 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8190 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0009, (cst_val *)&val_4204},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8192 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0012, (cst_val *)&val_8193},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0013, (cst_val *)&val_8194},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0014, (cst_val *)&val_8195},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0015, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8197 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0018, (cst_val *)&val_2193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8199 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0021, (cst_val *)&val_8195},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8201 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0024, (cst_val *)&val_8202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8204 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0027, (cst_val *)&val_0395},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0028, (cst_val *)&val_0047},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0029, (cst_val *)&val_8205},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0030, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8206 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8207 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0033, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8208 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0035, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8209 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0037, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8211 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0040, (cst_val *)&val_0108},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0041, (cst_val *)&val_3996},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8213 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0044, (cst_val *)&val_7957},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0045, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8214 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8215 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0048, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8216 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8217 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0051, (cst_val *)&val_0023},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0052, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8218 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0054, (cst_val *)&val_8219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8220 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8221 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0057, (cst_val *)&val_0048},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0058, (cst_val *)&val_0018},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0059, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8222 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8224 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0063, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8226 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0066, (cst_val *)&val_0140},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0067, (cst_val *)&val_0140},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0068, (cst_val *)&val_0004},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0069, (cst_val *)&val_3224},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0070, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8228 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8229 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0074, (cst_val *)&val_0529},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0075, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8232 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0079, (cst_val *)&val_0828},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0080, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8234 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0083, (cst_val *)&val_0061},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0084, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8235 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8236 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0087, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8237 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0089, (cst_val *)&val_1369},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8239 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0092, (cst_val *)&val_0001},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0093, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8240 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0095, (cst_val *)&val_2056},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0096, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8241 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0098, (cst_val *)&val_2511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8243 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0101, (cst_val *)&val_1044},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0102, (cst_val *)&val_1341},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0103, (cst_val *)&val_1952},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0104, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8245 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0107, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8247 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0110, (cst_val *)&val_0477},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0111, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8250 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0115, (cst_val *)&val_8251},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8252 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0117, (cst_val *)&val_1758},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0118, (cst_val *)&val_8253},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8254 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8256 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0122, (cst_val *)&val_0151},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0123, (cst_val *)&val_0137},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0124, (cst_val *)&val_0108},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0125, (cst_val *)&val_8257},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0126, (cst_val *)&val_0395},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0127, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8259 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0130, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8260 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0132, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8261 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0134, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8262 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8263 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0137, (cst_val *)&val_0140},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0138, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8264 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0140, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8265 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8266 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8267 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0144, (cst_val *)&val_0942},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0145, (cst_val *)&val_0018},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0146, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8269 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0149, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0150, (cst_val *)&val_6277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8272 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0154, (cst_val *)&val_6277},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8273 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0156, (cst_val *)&val_0018},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0157, (cst_val *)&val_8274},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8276 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0160, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8278 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0163, (cst_val *)&val_8279},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8280 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0165, (cst_val *)&val_0014},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0166, (cst_val *)&val_0014},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0167, (cst_val *)&val_8281},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8283 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0170, (cst_val *)&val_8284},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8285 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8286 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0173, (cst_val *)&val_0140},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0174, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8287 },
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0176, (cst_val *)&val_7240},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8290 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0180, (cst_val *)&val_1338},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0181, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8291 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0183, (cst_val *)&val_1137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8293 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0186, (cst_val *)&val_4907},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0187, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0188, (cst_val *)&val_6277},
{ 21, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0189, (cst_val *)&val_8294},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8296 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0192, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8297 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8298 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0195, (cst_val *)&val_0018},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0196, (cst_val *)&val_0014},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0197, (cst_val *)&val_3192},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8300 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0200, (cst_val *)&val_0982},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8302 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8303 },
{ 29, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0204, (cst_val *)&val_3824},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0205, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8305 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0208, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8306 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_l_108_NO_0210, (cst_val *)&val_8307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8309 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_l_108_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_phone_index",
NULL };

const cst_cart cmu_us_slt_single_mcep_l_108_cart = {
  cmu_us_slt_single_mcep_l_108_cart_nodes,
  cmu_us_slt_single_mcep_l_108_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_z_199_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0000, (cst_val *)&val_0942},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0001, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0002, (cst_val *)&val_0025},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0003, (cst_val *)&val_0004},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0004, (cst_val *)&val_0284},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0005, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0006, (cst_val *)&val_1577},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8310 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0008, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8311 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0010, (cst_val *)&val_4908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8312 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8313 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0013, (cst_val *)&val_1928},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8314 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8315 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0016, (cst_val *)&val_4543},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0017, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8317 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0020, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8318 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0022, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8320 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0025, (cst_val *)&val_1669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8321 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0027, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8322 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8323 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0030, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0031, (cst_val *)&val_0018},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0032, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8326 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8327 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0037, (cst_val *)&val_1489},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0038, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8328 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0040, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8330 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0043, (cst_val *)&val_1406},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0044, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0045, (cst_val *)&val_8331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8333 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0048, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8334 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0050, (cst_val *)&val_8335},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8336 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8337 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0053, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0054, (cst_val *)&val_8338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8340 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0057, (cst_val *)&val_0061},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0058, (cst_val *)&val_8341},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8342 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8343 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0061, (cst_val *)&val_0346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8345 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0064, (cst_val *)&val_0547},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0065, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8346 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0067, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8348 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0070, (cst_val *)&val_4602},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0071, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8349 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0073, (cst_val *)&val_2644},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0074, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8351 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0077, (cst_val *)&val_5942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8352 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0079, (cst_val *)&val_0105},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0080, (cst_val *)&val_8353},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8356 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0084, (cst_val *)&val_0030},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0085, (cst_val *)&val_8357},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8358 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0087, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8359 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8360 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0090, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8361 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0092, (cst_val *)&val_0001},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0093, (cst_val *)&val_8362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8364 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_199_NO_0096, (cst_val *)&val_2975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8366 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_z_199_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:HMMstate.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_z_199_cart = {
  cmu_us_slt_single_mcep_z_199_cart_nodes,
  cmu_us_slt_single_mcep_z_199_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_z_200_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0001, (cst_val *)&val_3224},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0002, (cst_val *)&val_0795},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0003, (cst_val *)&val_0018},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0004, (cst_val *)&val_8367},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0005, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8369 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0008, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8370 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8372 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0012, (cst_val *)&val_0009},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0013, (cst_val *)&val_1548},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0014, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8373 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8375 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0018, (cst_val *)&val_8376},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0019, (cst_val *)&val_3851},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8377 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8378 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0022, (cst_val *)&val_1391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8379 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0024, (cst_val *)&val_8380},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8381 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0026, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8383 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0029, (cst_val *)&val_0099},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0030, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8384 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0032, (cst_val *)&val_0018},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0033, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8385 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0035, (cst_val *)&val_8386},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0036, (cst_val *)&val_8387},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8388 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8390 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0040, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8391 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8392 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0043, (cst_val *)&val_0001},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0044, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8393 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0046, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8395 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0049, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8396 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0051, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8397 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0053, (cst_val *)&val_0108},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0054, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8398 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0056, (cst_val *)&val_8219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8400 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8401 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0060, (cst_val *)&val_0927},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0061, (cst_val *)&val_0025},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0062, (cst_val *)&val_0064},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0063, (cst_val *)&val_0025},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0064, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8403 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0067, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8404 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8405 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0070, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8406 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0072, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8407 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0074, (cst_val *)&val_8408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8409 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8410 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0077, (cst_val *)&val_0064},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0078, (cst_val *)&val_0942},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0079, (cst_val *)&val_6292},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8411 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8412 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0082, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8414 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0085, (cst_val *)&val_0228},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0086, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8416 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0089, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8418 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0092, (cst_val *)&val_0287},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0093, (cst_val *)&val_8419},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0094, (cst_val *)&val_2707},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8420 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0096, (cst_val *)&val_0001},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0097, (cst_val *)&val_1409},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0098, (cst_val *)&val_1732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8422 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0101, (cst_val *)&val_1732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8423 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8424 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0104, (cst_val *)&val_8425},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0105, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8426 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0107, (cst_val *)&val_0169},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8428 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0110, (cst_val *)&val_0064},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0111, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8429 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8431 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0115, (cst_val *)&val_0064},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0116, (cst_val *)&val_3265},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8432 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0118, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8434 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0121, (cst_val *)&val_1952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8436 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0124, (cst_val *)&val_8437},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0125, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8438 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0127, (cst_val *)&val_0449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8440 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0130, (cst_val *)&val_0232},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0131, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8442 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0134, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8443 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0136, (cst_val *)&val_8257},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0137, (cst_val *)&val_0064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0138, (cst_val *)&val_8444},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0139, (cst_val *)&val_1753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8447 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0143, (cst_val *)&val_4087},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8449 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0146, (cst_val *)&val_0108},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0147, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8450 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0149, (cst_val *)&val_8451},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8452 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0151, (cst_val *)&val_1384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8454 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0154, (cst_val *)&val_8455},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0155, (cst_val *)&val_8456},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_200_NO_0156, (cst_val *)&val_8457},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8458 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8461 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_z_200_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_pos",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_z_200_cart = {
  cmu_us_slt_single_mcep_z_200_cart_nodes,
  cmu_us_slt_single_mcep_z_200_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_z_201_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0000, (cst_val *)&val_0923},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0001, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0002, (cst_val *)&val_4034},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0003, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0004, (cst_val *)&val_0779},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8462 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0006, (cst_val *)&val_8463},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0007, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8464 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0009, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8466 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8467 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0013, (cst_val *)&val_8468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8470 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0016, (cst_val *)&val_8471},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0017, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8473 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0020, (cst_val *)&val_0019},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0021, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8474 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8475 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0024, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8477 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0027, (cst_val *)&val_4034},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0028, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0029, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0030, (cst_val *)&val_0140},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0031, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8478 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0033, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8479 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8480 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0036, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8482 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8483 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0040, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8484 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0042, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8485 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0044, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8487 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0047, (cst_val *)&val_0575},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0048, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8488 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0050, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8489 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8491 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0054, (cst_val *)&val_0064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0055, (cst_val *)&val_0018},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0056, (cst_val *)&val_8492},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0057, (cst_val *)&val_0057},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0058, (cst_val *)&val_0108},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0059, (cst_val *)&val_3023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8493 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8494 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0062, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8495 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0064, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8496 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0066, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8497 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0068, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8499 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0071, (cst_val *)&val_8500},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0072, (cst_val *)&val_0232},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0073, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8501 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0075, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8502 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0077, (cst_val *)&val_4332},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8503 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0079, (cst_val *)&val_2198},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0080, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8504 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0082, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8505 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8506 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8507 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0086, (cst_val *)&val_8508},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0087, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0088, (cst_val *)&val_8509},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0089, (cst_val *)&val_8510},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8512 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0092, (cst_val *)&val_3601},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0093, (cst_val *)&val_4029},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0094, (cst_val *)&val_8513},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8515 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8517 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0099, (cst_val *)&val_0942},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0100, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8518 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0102, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8519 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0104, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8521 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0107, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8522 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0109, (cst_val *)&val_0936},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0110, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8523 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0112, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8524 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0114, (cst_val *)&val_8525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8527 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0117, (cst_val *)&val_2131},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0118, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8529 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0121, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8531 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0124, (cst_val *)&val_0088},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0125, (cst_val *)&val_8532},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8534 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0128, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8535 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0130, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8536 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8537 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0133, (cst_val *)&val_1669},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0134, (cst_val *)&val_1878},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8538 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0136, (cst_val *)&val_8539},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8541 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0139, (cst_val *)&val_8542},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8543 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0141, (cst_val *)&val_8544},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0142, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8546 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8547 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0146, (cst_val *)&val_8548},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0147, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8549 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0149, (cst_val *)&val_8550},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0150, (cst_val *)&val_8551},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8554 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0154, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8555 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0156, (cst_val *)&val_8556},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8558 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0159, (cst_val *)&val_0042},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0160, (cst_val *)&val_0237},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0161, (cst_val *)&val_8559},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8560 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8561 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0164, (cst_val *)&val_4549},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0165, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8562 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8564 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0169, (cst_val *)&val_8565},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0170, (cst_val *)&val_3552},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0171, (cst_val *)&val_8566},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0172, (cst_val *)&val_8567},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8568 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8569 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0175, (cst_val *)&val_8570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8571 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8572 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0178, (cst_val *)&val_0364},
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0179, (cst_val *)&val_2905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8574 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0182, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8575 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0184, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8576 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0186, (cst_val *)&val_1840},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0187, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0188, (cst_val *)&val_1558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8578 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0191, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8581 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0195, (cst_val *)&val_0364},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8582 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0197, (cst_val *)&val_3552},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0198, (cst_val *)&val_0021},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8584 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0201, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8585 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0203, (cst_val *)&val_0194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8587 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0206, (cst_val *)&val_0105},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0207, (cst_val *)&val_8588},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8589 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0209, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8590 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8591 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0212, (cst_val *)&val_0986},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0213, (cst_val *)&val_0011},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0214, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8594 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0218, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8595 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_z_201_NO_0220, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8597 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_z_201_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_pos",
NULL };

const cst_cart cmu_us_slt_single_mcep_z_201_cart = {
  cmu_us_slt_single_mcep_z_201_cart_nodes,
  cmu_us_slt_single_mcep_z_201_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_pau_161_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0001, (cst_val *)&val_2377},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0002, (cst_val *)&val_0001},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0003, (cst_val *)&val_1406},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0004, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8598 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0006, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8599 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0008, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8600 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8601 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0011, (cst_val *)&val_8219},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0012, (cst_val *)&val_0001},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0013, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8602 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8603 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0016, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8604 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0018, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8605 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0020, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8607 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8608 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0024, (cst_val *)&val_0088},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0025, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8609 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0027, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8610 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0029, (cst_val *)&val_2593},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8611 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8612 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0032, (cst_val *)&val_0001},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0033, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8614 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0036, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8615 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0038, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8616 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0040, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8617 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0042, (cst_val *)&val_0681},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0043, (cst_val *)&val_2377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8619 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0046, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8620 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8621 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0049, (cst_val *)&val_8622},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0050, (cst_val *)&val_4081},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0051, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8623 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0053, (cst_val *)&val_0001},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0054, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8625 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0057, (cst_val *)&val_2775},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0058, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8626 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0060, (cst_val *)&val_1384},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8627 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8628 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8629 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0064, (cst_val *)&val_0054},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8631 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0067, (cst_val *)&val_8632},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8633 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0069, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8634 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8635 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0072, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0073, (cst_val *)&val_3436},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0074, (cst_val *)&val_0014},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0075, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8637 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0078, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8638 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0080, (cst_val *)&val_8639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8640 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0082, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8641 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8642 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0085, (cst_val *)&val_8643},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0086, (cst_val *)&val_0449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8644 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8645 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0089, (cst_val *)&val_8646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8648 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0092, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0093, (cst_val *)&val_1044},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0094, (cst_val *)&val_0004},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0095, (cst_val *)&val_0088},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0096, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8649 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8650 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0099, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8652 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0102, (cst_val *)&val_2643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8653 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0104, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8654 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8655 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0107, (cst_val *)&val_0137},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0108, (cst_val *)&val_0105},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0109, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8656 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8657 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0112, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8658 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0114, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8659 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0116, (cst_val *)&val_2643},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0117, (cst_val *)&val_8660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8661 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8664 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0122, (cst_val *)&val_1395},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0123, (cst_val *)&val_0088},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0124, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8665 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0126, (cst_val *)&val_0699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8666 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0128, (cst_val *)&val_0004},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0129, (cst_val *)&val_4010},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0130, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8667 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8669 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0134, (cst_val *)&val_8670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8672 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0137, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8673 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0139, (cst_val *)&val_1044},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0140, (cst_val *)&val_0228},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0141, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8674 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0143, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8675 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8676 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0146, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8677 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0148, (cst_val *)&val_2211},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0149, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8679 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0152, (cst_val *)&val_2970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8680 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8681 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0155, (cst_val *)&val_0228},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0156, (cst_val *)&val_8682},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8683 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8684 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0159, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8686 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0162, (cst_val *)&val_2688},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0163, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0164, (cst_val *)&val_4333},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0165, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8687 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0167, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8689 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0170, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8690 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0172, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8692 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0175, (cst_val *)&val_0414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8694 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0178, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0179, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8696 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_161_NO_0182, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8698 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_pau_161_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_pau_161_cart = {
  cmu_us_slt_single_mcep_pau_161_cart_nodes,
  cmu_us_slt_single_mcep_pau_161_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_s_151_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0000, (cst_val *)&val_0942},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0002, (cst_val *)&val_3034},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0003, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8699 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0005, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8700 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8701 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0008, (cst_val *)&val_0072},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0009, (cst_val *)&val_0105},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0010, (cst_val *)&val_0108},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0011, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8702 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0013, (cst_val *)&val_0954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8704 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8705 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0017, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8706 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0019, (cst_val *)&val_0025},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0020, (cst_val *)&val_8707},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0021, (cst_val *)&val_8708},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8709 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8711 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0025, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8713 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0028, (cst_val *)&val_0681},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0029, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8714 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0031, (cst_val *)&val_0865},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8716 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0034, (cst_val *)&val_0023},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0035, (cst_val *)&val_5064},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0036, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8717 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8718 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0039, (cst_val *)&val_0137},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0040, (cst_val *)&val_5951},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8721 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0044, (cst_val *)&val_8722},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0045, (cst_val *)&val_5346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8723 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0047, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8724 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0049, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8725 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0051, (cst_val *)&val_8726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8727 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8728 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0054, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8729 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8730 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0057, (cst_val *)&val_0004},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0058, (cst_val *)&val_8731},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0059, (cst_val *)&val_0228},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0060, (cst_val *)&val_0099},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0061, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8733 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0064, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8734 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8735 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0067, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8736 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0069, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8737 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0071, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8739 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0074, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8741 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0077, (cst_val *)&val_2005},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0078, (cst_val *)&val_5848},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8743 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0081, (cst_val *)&val_5995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8744 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0083, (cst_val *)&val_1060},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0084, (cst_val *)&val_0142},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0085, (cst_val *)&val_8745},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8746 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8747 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8748 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0089, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8749 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0091, (cst_val *)&val_0605},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0092, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8751 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8752 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0096, (cst_val *)&val_0004},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0097, (cst_val *)&val_4602},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0098, (cst_val *)&val_0550},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0099, (cst_val *)&val_8753},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0100, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8754 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0102, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8756 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0105, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8757 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8758 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0108, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8759 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0110, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8761 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0113, (cst_val *)&val_8762},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0114, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8764 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0117, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8765 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0119, (cst_val *)&val_5789},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0120, (cst_val *)&val_0395},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0121, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8769 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0126, (cst_val *)&val_4762},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0127, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8770 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0129, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8772 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0132, (cst_val *)&val_1167},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0133, (cst_val *)&val_3730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8773 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8774 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0136, (cst_val *)&val_0638},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0137, (cst_val *)&val_1492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8776 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_151_NO_0140, (cst_val *)&val_8777},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8779 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_s_151_feat_table[] = {
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_state_index",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_s_151_cart = {
  cmu_us_slt_single_mcep_s_151_cart_nodes,
  cmu_us_slt_single_mcep_s_151_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_s_152_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0000, (cst_val *)&val_1347},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0001, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0002, (cst_val *)&val_1347},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0003, (cst_val *)&val_2932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8780 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0005, (cst_val *)&val_3129},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0006, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8781 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8782 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0009, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8783 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0011, (cst_val *)&val_0237},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0012, (cst_val *)&val_8784},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0013, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8785 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0015, (cst_val *)&val_8786},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8788 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0018, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8789 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0020, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8790 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8791 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0023, (cst_val *)&val_1119},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0024, (cst_val *)&val_6414},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8792 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0026, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8794 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0029, (cst_val *)&val_8795},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8796 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8797 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0032, (cst_val *)&val_2198},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0033, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8798 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0035, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8800 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0038, (cst_val *)&val_0140},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0039, (cst_val *)&val_0025},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0040, (cst_val *)&val_0681},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0041, (cst_val *)&val_8801},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0042, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8804 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0046, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8805 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0048, (cst_val *)&val_0012},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0049, (cst_val *)&val_8806},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8808 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0052, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8809 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8810 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0055, (cst_val *)&val_2280},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0056, (cst_val *)&val_3129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8811 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0058, (cst_val *)&val_8812},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0059, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8813 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0061, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0062, (cst_val *)&val_8814},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8817 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0066, (cst_val *)&val_7480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8819 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0069, (cst_val *)&val_0681},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0070, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8821 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0073, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8822 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0075, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8824 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0078, (cst_val *)&val_0105},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0079, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0080, (cst_val *)&val_8825},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8827 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0083, (cst_val *)&val_0985},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0084, (cst_val *)&val_8828},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8829 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0086, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8831 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0089, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8832 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8833 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0092, (cst_val *)&val_8834},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0093, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8837 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0097, (cst_val *)&val_0471},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0098, (cst_val *)&val_0025},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0099, (cst_val *)&val_1804},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0100, (cst_val *)&val_8838},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8839 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8841 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0104, (cst_val *)&val_1804},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0105, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8842 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8844 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0109, (cst_val *)&val_0228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0110, (cst_val *)&val_2377},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0111, (cst_val *)&val_1347},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0112, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8845 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0114, (cst_val *)&val_8846},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8848 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0117, (cst_val *)&val_0018},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0118, (cst_val *)&val_0042},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8852 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0123, (cst_val *)&val_0004},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0124, (cst_val *)&val_0232},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0125, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8853 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8854 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0128, (cst_val *)&val_0061},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0129, (cst_val *)&val_8855},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8857 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0132, (cst_val *)&val_0023},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0133, (cst_val *)&val_8858},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0134, (cst_val *)&val_1422},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8859 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0136, (cst_val *)&val_8860},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8863 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0140, (cst_val *)&val_0137},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0141, (cst_val *)&val_8864},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8865 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8866 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8867 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0145, (cst_val *)&val_0023},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0146, (cst_val *)&val_6846},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0147, (cst_val *)&val_0669},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8869 },
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0150, (cst_val *)&val_0142},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0151, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8871 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0154, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8873 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0157, (cst_val *)&val_0064},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0158, (cst_val *)&val_1558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8874 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0160, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8876 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0163, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0164, (cst_val *)&val_8444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8879 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0168, (cst_val *)&val_8880},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0169, (cst_val *)&val_0018},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0170, (cst_val *)&val_0001},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0171, (cst_val *)&val_2468},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0172, (cst_val *)&val_1044},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0173, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8881 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0175, (cst_val *)&val_1347},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0176, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8882 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8883 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0179, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8884 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0181, (cst_val *)&val_8885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8886 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8887 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0184, (cst_val *)&val_0061},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0185, (cst_val *)&val_7698},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8888 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8889 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0188, (cst_val *)&val_0590},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0189, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8891 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0192, (cst_val *)&val_0018},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0193, (cst_val *)&val_0783},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8892 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0195, (cst_val *)&val_8893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8895 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0198, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8897 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0201, (cst_val *)&val_0232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0202, (cst_val *)&val_8898},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8899 },
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0204, (cst_val *)&val_8900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8901 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8902 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0207, (cst_val *)&val_3129},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0208, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8903 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0210, (cst_val *)&val_8904},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8906 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0213, (cst_val *)&val_0061},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0214, (cst_val *)&val_0717},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0215, (cst_val *)&val_8907},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0216, (cst_val *)&val_8908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8910 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8911 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0220, (cst_val *)&val_8912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8914 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0223, (cst_val *)&val_0064},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0224, (cst_val *)&val_0001},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0225, (cst_val *)&val_3259},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8916 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0228, (cst_val *)&val_8917},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0229, (cst_val *)&val_0014},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0230, (cst_val *)&val_8162},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8918 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0232, (cst_val *)&val_8919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8920 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8922 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8923 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0237, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8924 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0239, (cst_val *)&val_0064},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0240, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8925 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0242, (cst_val *)&val_1881},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0243, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8926 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8928 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0247, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8929 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0249, (cst_val *)&val_1878},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0250, (cst_val *)&val_8930},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8932 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0253, (cst_val *)&val_8933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8934 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8935 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0256, (cst_val *)&val_1685},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0257, (cst_val *)&val_2064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0258, (cst_val *)&val_0927},
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0259, (cst_val *)&val_0004},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0260, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0261, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8936 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8937 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0264, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8938 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0266, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8939 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0268, (cst_val *)&val_0023},
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0269, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8940 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8942 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0273, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8943 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0275, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8944 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0277, (cst_val *)&val_0023},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0278, (cst_val *)&val_0025},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0279, (cst_val *)&val_2932},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8946 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0282, (cst_val *)&val_2612},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0283, (cst_val *)&val_8947},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8948 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8951 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0288, (cst_val *)&val_0023},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0289, (cst_val *)&val_0061},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0290, (cst_val *)&val_0014},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0291, (cst_val *)&val_4762},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8952 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8954 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0295, (cst_val *)&val_3129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8955 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0297, (cst_val *)&val_8956},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8957 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0299, (cst_val *)&val_0709},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0300, (cst_val *)&val_8958},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0301, (cst_val *)&val_0717},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0302, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8959 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0304, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8961 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0307, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8962 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0309, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8964 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0312, (cst_val *)&val_8965},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8967 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0315, (cst_val *)&val_5841},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8968 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0317, (cst_val *)&val_3450},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8969 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8970 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0320, (cst_val *)&val_0471},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0321, (cst_val *)&val_0018},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0322, (cst_val *)&val_0223},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0323, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8971 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8972 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8974 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0328, (cst_val *)&val_0217},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0329, (cst_val *)&val_0016},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8975 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0331, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8977 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0334, (cst_val *)&val_0018},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0335, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0336, (cst_val *)&val_0018},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0337, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8978 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0339, (cst_val *)&val_1310},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0340, (cst_val *)&val_8979},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8980 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0342, (cst_val *)&val_8981},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8983 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8984 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0346, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8985 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0348, (cst_val *)&val_4962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8986 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8987 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0351, (cst_val *)&val_3129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8988 },
{ 36, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0353, (cst_val *)&val_0064},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0354, (cst_val *)&val_8989},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0355, (cst_val *)&val_8990},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8993 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0359, (cst_val *)&val_0014},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0360, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8994 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8996 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0364, (cst_val *)&val_0012},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0365, (cst_val *)&val_5652},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8997 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0367, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8998 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_8999 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0370, (cst_val *)&val_0232},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0371, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9001 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0374, (cst_val *)&val_0395},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0375, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9002 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9003 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0378, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9005 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0381, (cst_val *)&val_0017},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0382, (cst_val *)&val_0023},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0383, (cst_val *)&val_9006},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0384, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9007 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9009 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0388, (cst_val *)&val_0105},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0389, (cst_val *)&val_9010},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0390, (cst_val *)&val_9011},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0391, (cst_val *)&val_7011},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0392, (cst_val *)&val_9012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9014 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0395, (cst_val *)&val_0931},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9016 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9018 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0400, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9019 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0402, (cst_val *)&val_0023},
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0403, (cst_val *)&val_0643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9020 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0405, (cst_val *)&val_0900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9022 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0408, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9023 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0410, (cst_val *)&val_9024},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9025 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9026 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0413, (cst_val *)&val_9027},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0414, (cst_val *)&val_9028},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0415, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9031 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0419, (cst_val *)&val_0140},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0420, (cst_val *)&val_0675},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9032 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9034 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0424, (cst_val *)&val_0217},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0425, (cst_val *)&val_1928},
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0426, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9036 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0429, (cst_val *)&val_9037},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9038 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9039 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0432, (cst_val *)&val_0023},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0433, (cst_val *)&val_0108},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0434, (cst_val *)&val_9040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9042 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0437, (cst_val *)&val_9043},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0438, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9045 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0441, (cst_val *)&val_1648},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9047 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0444, (cst_val *)&val_9048},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0445, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9049 },
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0447, (cst_val *)&val_9050},
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0448, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9052 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0451, (cst_val *)&val_0014},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0452, (cst_val *)&val_9053},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0453, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9054 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0455, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9057 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0459, (cst_val *)&val_9058},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0460, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9060 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0463, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9061 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9062 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0466, (cst_val *)&val_0625},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0467, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9063 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9064 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0470, (cst_val *)&val_9065},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9066 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9067 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0473, (cst_val *)&val_0681},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0474, (cst_val *)&val_2563},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0475, (cst_val *)&val_9068},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9069 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0477, (cst_val *)&val_1232},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0478, (cst_val *)&val_9070},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9072 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9073 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0482, (cst_val *)&val_1232},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0483, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9074 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9075 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0486, (cst_val *)&val_9076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9078 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0489, (cst_val *)&val_9079},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0490, (cst_val *)&val_9080},
{ 31, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0491, (cst_val *)&val_9081},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0492, (cst_val *)&val_6702},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0493, (cst_val *)&val_9082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9083 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9084 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9085 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0497, (cst_val *)&val_9086},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9088 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0500, (cst_val *)&val_9089},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9090 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9091 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0503, (cst_val *)&val_9092},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0504, (cst_val *)&val_1908},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0505, (cst_val *)&val_9093},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0506, (cst_val *)&val_9094},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9095 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9096 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9097 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0510, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9098 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9099 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0513, (cst_val *)&val_9100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9101 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0515, (cst_val *)&val_0064},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0516, (cst_val *)&val_9102},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0517, (cst_val *)&val_4064},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0518, (cst_val *)&val_0592},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0519, (cst_val *)&val_3456},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9103 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9105 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0523, (cst_val *)&val_1577},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0524, (cst_val *)&val_9106},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9107 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9108 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0527, (cst_val *)&val_2905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9109 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0529, (cst_val *)&val_3570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9110 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0531, (cst_val *)&val_3717},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9111 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0533, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9113 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9114 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0537, (cst_val *)&val_9115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9116 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0539, (cst_val *)&val_8131},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9117 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0541, (cst_val *)&val_0985},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0542, (cst_val *)&val_9118},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0543, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9120 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9121 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0547, (cst_val *)&val_0228},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0548, (cst_val *)&val_9122},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0549, (cst_val *)&val_2949},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9124 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9125 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0553, (cst_val *)&val_9126},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0554, (cst_val *)&val_3760},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0555, (cst_val *)&val_9127},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9129 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9131 },
{ 35, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0560, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0561, (cst_val *)&val_0100},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0562, (cst_val *)&val_9132},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0563, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9134 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9135 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0567, (cst_val *)&val_1466},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0568, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9136 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0570, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9137 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0572, (cst_val *)&val_5303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9138 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9139 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0575, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9140 },
{ 28, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0577, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9142 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0580, (cst_val *)&val_9143},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0581, (cst_val *)&val_0105},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0582, (cst_val *)&val_0023},
{ 25, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0583, (cst_val *)&val_0025},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0584, (cst_val *)&val_9144},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9145 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9146 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9148 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0589, (cst_val *)&val_0137},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0590, (cst_val *)&val_7975},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9149 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9150 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_152_NO_0593, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9151 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9153 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_s_152_feat_table[] = {
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
NULL };

const cst_cart cmu_us_slt_single_mcep_s_152_cart = {
  cmu_us_slt_single_mcep_s_152_cart_nodes,
  cmu_us_slt_single_mcep_s_152_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_s_153_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0001, (cst_val *)&val_9154},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0002, (cst_val *)&val_0252},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0003, (cst_val *)&val_0942},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0004, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9155 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9156 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0007, (cst_val *)&val_9157},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0008, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9158 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9159 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9160 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0012, (cst_val *)&val_1061},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0013, (cst_val *)&val_0151},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0014, (cst_val *)&val_1606},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9161 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9162 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0017, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9163 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0019, (cst_val *)&val_0395},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0020, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9164 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9165 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9166 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0024, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9167 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9168 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0027, (cst_val *)&val_0099},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0028, (cst_val *)&val_0237},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0029, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9169 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0031, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9170 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9171 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0034, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9172 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0036, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9173 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0038, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9174 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0040, (cst_val *)&val_0001},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0041, (cst_val *)&val_9175},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9177 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9178 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0045, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9179 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0047, (cst_val *)&val_0850},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0048, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9180 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0050, (cst_val *)&val_0237},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0051, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9182 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0054, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9184 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9185 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0058, (cst_val *)&val_0364},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0059, (cst_val *)&val_0099},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0060, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9186 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0062, (cst_val *)&val_0003},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0063, (cst_val *)&val_0597},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0064, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9187 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9188 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0067, (cst_val *)&val_9189},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0068, (cst_val *)&val_0140},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0069, (cst_val *)&val_7701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9190 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9191 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9192 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0073, (cst_val *)&val_4204},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0074, (cst_val *)&val_9193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9194 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9197 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0079, (cst_val *)&val_0046},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0080, (cst_val *)&val_9198},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0081, (cst_val *)&val_4440},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0082, (cst_val *)&val_1489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9199 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9200 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0085, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9201 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9202 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0088, (cst_val *)&val_0850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9203 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0090, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9204 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9205 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0093, (cst_val *)&val_0529},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0094, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9206 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0096, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9207 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9208 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0099, (cst_val *)&val_9209},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0100, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9210 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9211 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0103, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9212 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0105, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9214 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0108, (cst_val *)&val_9215},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0109, (cst_val *)&val_9216},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0110, (cst_val *)&val_9217},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0111, (cst_val *)&val_0108},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0112, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9218 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0114, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9220 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0117, (cst_val *)&val_9221},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0118, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9222 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0120, (cst_val *)&val_0093},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9223 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9224 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0123, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9225 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0125, (cst_val *)&val_9226},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9227 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9228 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0128, (cst_val *)&val_0108},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0129, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0130, (cst_val *)&val_9229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9230 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9231 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0133, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9232 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0135, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9234 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0138, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0139, (cst_val *)&val_9235},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9237 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0142, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9238 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9239 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0145, (cst_val *)&val_9240},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0146, (cst_val *)&val_3920},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0147, (cst_val *)&val_9241},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9242 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9243 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0150, (cst_val *)&val_0072},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0151, (cst_val *)&val_1049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9244 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9245 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0154, (cst_val *)&val_0200},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0155, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9246 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9247 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0158, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9248 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9249 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0161, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9250 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9251 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0164, (cst_val *)&val_0004},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0165, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9252 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0167, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9253 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9254 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0170, (cst_val *)&val_0018},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0171, (cst_val *)&val_9255},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0172, (cst_val *)&val_0018},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0173, (cst_val *)&val_1600},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9256 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9257 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0176, (cst_val *)&val_0638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9259 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0179, (cst_val *)&val_0365},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0180, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9262 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0184, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9263 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_s_153_NO_0186, (cst_val *)&val_3920},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9265 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_s_153_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
NULL };

const cst_cart cmu_us_slt_single_mcep_s_153_cart = {
  cmu_us_slt_single_mcep_s_153_cart_nodes,
  cmu_us_slt_single_mcep_s_153_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_eh_56_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0000, (cst_val *)&val_0232},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0001, (cst_val *)&val_1355},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0002, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9266 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0004, (cst_val *)&val_9267},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9269 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0007, (cst_val *)&val_0189},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0008, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9270 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9271 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0011, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9272 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0013, (cst_val *)&val_0088},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0014, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9274 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0017, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9275 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9276 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0020, (cst_val *)&val_0140},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0021, (cst_val *)&val_0217},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0022, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9277 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9278 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0025, (cst_val *)&val_0592},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0026, (cst_val *)&val_2131},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0027, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9280 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9281 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9282 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0032, (cst_val *)&val_0795},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0033, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0034, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9283 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0036, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9284 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0038, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9285 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0040, (cst_val *)&val_0018},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0041, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9287 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0044, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0045, (cst_val *)&val_0986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9288 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9290 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0049, (cst_val *)&val_0459},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0050, (cst_val *)&val_0237},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0051, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9292 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9293 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0055, (cst_val *)&val_0105},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0056, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9294 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9296 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0060, (cst_val *)&val_1060},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9297 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0062, (cst_val *)&val_0459},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0063, (cst_val *)&val_0011},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0064, (cst_val *)&val_0942},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9298 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9300 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0068, (cst_val *)&val_0018},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0069, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9301 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9302 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0072, (cst_val *)&val_0471},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0073, (cst_val *)&val_9303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9305 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0076, (cst_val *)&val_0004},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0077, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9306 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0079, (cst_val *)&val_1681},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_56_NO_0080, (cst_val *)&val_9307},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9308 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9309 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9310 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9311 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_eh_56_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_eh_56_cart = {
  cmu_us_slt_single_mcep_eh_56_cart_nodes,
  cmu_us_slt_single_mcep_eh_56_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_eh_57_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0000, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0001, (cst_val *)&val_9312},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0002, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9313 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0004, (cst_val *)&val_9314},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9316 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0007, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0008, (cst_val *)&val_0237},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0009, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9317 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9318 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0012, (cst_val *)&val_3273},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0013, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9320 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0016, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9322 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0019, (cst_val *)&val_9323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9324 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9325 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0022, (cst_val *)&val_0105},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0023, (cst_val *)&val_1395},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0024, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9326 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0026, (cst_val *)&val_0004},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0027, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9328 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9329 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0031, (cst_val *)&val_0280},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0032, (cst_val *)&val_9330},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0033, (cst_val *)&val_9331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9332 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0035, (cst_val *)&val_0530},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9334 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9335 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0039, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0040, (cst_val *)&val_9336},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9337 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0042, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9338 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0044, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9340 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0047, (cst_val *)&val_9341},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0048, (cst_val *)&val_0004},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0049, (cst_val *)&val_9342},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0050, (cst_val *)&val_9343},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9344 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9346 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0054, (cst_val *)&val_0004},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0055, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9348 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9349 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0059, (cst_val *)&val_9350},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0060, (cst_val *)&val_9351},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9353 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0063, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9354 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0065, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9355 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9356 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0068, (cst_val *)&val_0550},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0069, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0070, (cst_val *)&val_6285},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0071, (cst_val *)&val_0232},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0072, (cst_val *)&val_9357},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9359 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0075, (cst_val *)&val_0232},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0076, (cst_val *)&val_2449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9361 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0079, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9362 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0081, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9363 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9364 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0084, (cst_val *)&val_9365},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0085, (cst_val *)&val_0228},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0086, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9366 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9367 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0089, (cst_val *)&val_1813},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0090, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9368 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9369 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0093, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9370 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0095, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9371 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0097, (cst_val *)&val_1085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9372 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9373 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0100, (cst_val *)&val_0023},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0101, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9374 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9376 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0105, (cst_val *)&val_0105},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0106, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9377 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0108, (cst_val *)&val_9378},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9379 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9380 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0111, (cst_val *)&val_1984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9381 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0113, (cst_val *)&val_0699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9382 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0115, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9383 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9384 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0118, (cst_val *)&val_9385},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0119, (cst_val *)&val_0232},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0120, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9386 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9387 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0123, (cst_val *)&val_0232},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0124, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9388 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0126, (cst_val *)&val_0076},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0127, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9390 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9391 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0131, (cst_val *)&val_9392},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0132, (cst_val *)&val_0228},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0133, (cst_val *)&val_4029},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0134, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0135, (cst_val *)&val_0976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9394 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9396 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0140, (cst_val *)&val_0228},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0141, (cst_val *)&val_9397},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0142, (cst_val *)&val_9398},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9399 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9400 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0145, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9401 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0147, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9403 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0150, (cst_val *)&val_9404},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9405 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9406 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0153, (cst_val *)&val_2356},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0154, (cst_val *)&val_4333},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9407 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9408 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0157, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9409 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0159, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9411 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0162, (cst_val *)&val_0018},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0163, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9412 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0165, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9413 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9414 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0168, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9415 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_57_NO_0170, (cst_val *)&val_9416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9417 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9418 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_eh_57_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_place",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
NULL };

const cst_cart cmu_us_slt_single_mcep_eh_57_cart = {
  cmu_us_slt_single_mcep_eh_57_cart_nodes,
  cmu_us_slt_single_mcep_eh_57_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_eh_58_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0000, (cst_val *)&val_6196},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0001, (cst_val *)&val_1978},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0002, (cst_val *)&val_9419},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0003, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9420 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9421 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0006, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0007, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9422 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9423 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0010, (cst_val *)&val_0105},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0011, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9425 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0014, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9426 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0016, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9428 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0019, (cst_val *)&val_0828},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0020, (cst_val *)&val_9429},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0021, (cst_val *)&val_1813},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0022, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9431 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0025, (cst_val *)&val_0189},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9432 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9434 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0029, (cst_val *)&val_9435},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0030, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0031, (cst_val *)&val_9436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9437 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0033, (cst_val *)&val_9438},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0034, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9439 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0036, (cst_val *)&val_3570},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9440 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9441 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0039, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9442 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9443 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0042, (cst_val *)&val_0061},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0043, (cst_val *)&val_9444},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9445 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0045, (cst_val *)&val_4658},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9446 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9447 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0048, (cst_val *)&val_2643},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0049, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9449 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0052, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9450 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0054, (cst_val *)&val_0228},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0055, (cst_val *)&val_9451},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0056, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9452 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9454 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0060, (cst_val *)&val_0177},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0061, (cst_val *)&val_0004},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0062, (cst_val *)&val_9455},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9456 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9458 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0066, (cst_val *)&val_9459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9461 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0069, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0070, (cst_val *)&val_0373},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0071, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9462 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0073, (cst_val *)&val_9463},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9464 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0075, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9466 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0078, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9467 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0080, (cst_val *)&val_1967},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9468 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0082, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9469 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9470 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0085, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0086, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9471 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0088, (cst_val *)&val_0012},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9473 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9474 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0092, (cst_val *)&val_0004},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0093, (cst_val *)&val_1978},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0094, (cst_val *)&val_1019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9475 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0096, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9476 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0098, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9477 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9478 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0101, (cst_val *)&val_0228},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0102, (cst_val *)&val_1193},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0103, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9479 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0105, (cst_val *)&val_9480},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9481 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9482 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0108, (cst_val *)&val_0100},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0109, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9483 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0111, (cst_val *)&val_0186},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0112, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9484 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9485 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0115, (cst_val *)&val_3273},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9486 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9487 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0118, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9488 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0120, (cst_val *)&val_9489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9490 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0122, (cst_val *)&val_0026},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9491 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9492 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0125, (cst_val *)&val_0828},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0126, (cst_val *)&val_9493},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0127, (cst_val *)&val_1813},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0128, (cst_val *)&val_9494},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0129, (cst_val *)&val_9495},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9497 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9498 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0133, (cst_val *)&val_9499},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9500 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0135, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9501 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9502 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9503 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0139, (cst_val *)&val_1967},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0140, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9505 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0143, (cst_val *)&val_0042},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0144, (cst_val *)&val_9506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9507 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0146, (cst_val *)&val_1406},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0147, (cst_val *)&val_0074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9508 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9509 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0150, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9511 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9512 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0154, (cst_val *)&val_0082},
{ 22, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0155, (cst_val *)&val_0194},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0156, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9515 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0160, (cst_val *)&val_0088},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0161, (cst_val *)&val_0100},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9517 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0164, (cst_val *)&val_1377},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9518 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_eh_58_NO_0166, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9519 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9520 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_eh_58_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_pos",
"lisp_cg_state_place",
NULL };

const cst_cart cmu_us_slt_single_mcep_eh_58_cart = {
  cmu_us_slt_single_mcep_eh_58_cart_nodes,
  cmu_us_slt_single_mcep_eh_58_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_t_164_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0001, (cst_val *)&val_0459},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0002, (cst_val *)&val_0287},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0003, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9521 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0005, (cst_val *)&val_0232},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0006, (cst_val *)&val_0095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9523 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0009, (cst_val *)&val_9524},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0010, (cst_val *)&val_0638},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0011, (cst_val *)&val_0004},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0012, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9527 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0016, (cst_val *)&val_2096},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9528 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9529 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0019, (cst_val *)&val_9530},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0020, (cst_val *)&val_9531},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9532 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9534 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0024, (cst_val *)&val_0137},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0025, (cst_val *)&val_0232},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0026, (cst_val *)&val_0076},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0027, (cst_val *)&val_0730},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9536 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0030, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9537 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9538 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0033, (cst_val *)&val_9539},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0034, (cst_val *)&val_1009},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0035, (cst_val *)&val_0099},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0036, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9540 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9542 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0040, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9543 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9544 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0043, (cst_val *)&val_0414},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0044, (cst_val *)&val_9545},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0045, (cst_val *)&val_9546},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9547 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9549 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0049, (cst_val *)&val_6674},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0050, (cst_val *)&val_9550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9551 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9552 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0053, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9553 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9554 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0056, (cst_val *)&val_9555},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9556 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0058, (cst_val *)&val_0004},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0059, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9557 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9558 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9559 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0063, (cst_val *)&val_3273},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0064, (cst_val *)&val_0529},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9560 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0066, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9561 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0068, (cst_val *)&val_9562},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9564 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0071, (cst_val *)&val_1060},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0072, (cst_val *)&val_9565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9566 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9567 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0075, (cst_val *)&val_9568},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0076, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9569 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0078, (cst_val *)&val_0850},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0079, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9571 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0082, (cst_val *)&val_0108},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0083, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0084, (cst_val *)&val_1155},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9572 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9574 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9575 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0089, (cst_val *)&val_9576},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9577 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9578 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0092, (cst_val *)&val_0046},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0093, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0094, (cst_val *)&val_0025},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0095, (cst_val *)&val_0064},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0096, (cst_val *)&val_0218},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0097, (cst_val *)&val_0681},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0098, (cst_val *)&val_2095},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9580 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0101, (cst_val *)&val_0284},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0102, (cst_val *)&val_0105},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0103, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9581 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9583 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9584 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0108, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9585 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0110, (cst_val *)&val_0043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9587 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0113, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0114, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9588 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0116, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9589 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9590 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0119, (cst_val *)&val_8639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9591 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0121, (cst_val *)&val_0395},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0122, (cst_val *)&val_9592},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9594 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0125, (cst_val *)&val_0105},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0126, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9595 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0128, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9596 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0130, (cst_val *)&val_0025},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0131, (cst_val *)&val_9597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9598 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9599 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0134, (cst_val *)&val_0123},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9600 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0136, (cst_val *)&val_1485},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9602 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0139, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9603 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0141, (cst_val *)&val_5046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9604 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9605 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0144, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0145, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9606 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0147, (cst_val *)&val_0942},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0148, (cst_val *)&val_2019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9607 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0150, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9609 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0153, (cst_val *)&val_0023},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0154, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9611 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0157, (cst_val *)&val_3823},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0158, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9612 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9614 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0162, (cst_val *)&val_0942},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0163, (cst_val *)&val_9615},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0164, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9616 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0166, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9619 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0170, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9620 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0172, (cst_val *)&val_0001},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0173, (cst_val *)&val_0105},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0174, (cst_val *)&val_4879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9621 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9622 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9623 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0178, (cst_val *)&val_0395},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0179, (cst_val *)&val_9624},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9625 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9627 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0183, (cst_val *)&val_0669},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0184, (cst_val *)&val_0900},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0185, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9628 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0187, (cst_val *)&val_0675},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0188, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9629 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9631 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0192, (cst_val *)&val_0140},
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0193, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9634 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0197, (cst_val *)&val_0942},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0198, (cst_val *)&val_0478},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0199, (cst_val *)&val_9635},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9637 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0202, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9638 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9639 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0205, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9640 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0207, (cst_val *)&val_0420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9641 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0209, (cst_val *)&val_0705},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9642 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9643 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0212, (cst_val *)&val_4214},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0213, (cst_val *)&val_0018},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0214, (cst_val *)&val_9644},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0215, (cst_val *)&val_0137},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0216, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9645 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0218, (cst_val *)&val_9646},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9647 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9648 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9649 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0222, (cst_val *)&val_0137},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0223, (cst_val *)&val_0014},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0224, (cst_val *)&val_1616},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0225, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9650 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9652 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0229, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9653 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0231, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9654 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0233, (cst_val *)&val_1019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9655 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9656 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0236, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9658 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0239, (cst_val *)&val_0681},
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0240, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9659 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9660 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0243, (cst_val *)&val_0001},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0244, (cst_val *)&val_0108},
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0245, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9661 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0247, (cst_val *)&val_5665},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0248, (cst_val *)&val_9662},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9663 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9664 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9665 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0252, (cst_val *)&val_0850},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9666 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0254, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9667 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0256, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9669 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0259, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9670 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0261, (cst_val *)&val_4658},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9671 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9672 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0264, (cst_val *)&val_0137},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0265, (cst_val *)&val_0030},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0266, (cst_val *)&val_0001},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0267, (cst_val *)&val_9673},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0268, (cst_val *)&val_6073},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9675 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0271, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9677 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0274, (cst_val *)&val_0018},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0275, (cst_val *)&val_9678},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9680 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0278, (cst_val *)&val_1019},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0279, (cst_val *)&val_1028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9682 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9683 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0283, (cst_val *)&val_3224},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0284, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9685 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9686 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_164_NO_0288, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9687 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9688 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_t_164_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_phone_place",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.syl_final",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
NULL };

const cst_cart cmu_us_slt_single_mcep_t_164_cart = {
  cmu_us_slt_single_mcep_t_164_cart_nodes,
  cmu_us_slt_single_mcep_t_164_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_t_165_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0000, (cst_val *)&val_9689},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0001, (cst_val *)&val_0064},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0002, (cst_val *)&val_2064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0003, (cst_val *)&val_0004},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0004, (cst_val *)&val_0284},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0005, (cst_val *)&val_8726},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9690 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0007, (cst_val *)&val_9691},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0008, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9692 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9693 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9694 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0012, (cst_val *)&val_0001},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0013, (cst_val *)&val_9695},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9696 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9698 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0017, (cst_val *)&val_6641},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0018, (cst_val *)&val_2064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9700 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0021, (cst_val *)&val_9701},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9703 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0024, (cst_val *)&val_0237},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0025, (cst_val *)&val_1071},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9704 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0027, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9705 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0029, (cst_val *)&val_9706},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9707 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9708 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0032, (cst_val *)&val_9709},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0033, (cst_val *)&val_0218},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9710 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0035, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9712 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0038, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0039, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9713 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0041, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9715 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9716 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0045, (cst_val *)&val_2377},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0046, (cst_val *)&val_0064},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0047, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9717 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0049, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9718 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0051, (cst_val *)&val_1006},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0052, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9719 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0054, (cst_val *)&val_0105},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0055, (cst_val *)&val_1753},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9720 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9721 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0058, (cst_val *)&val_9722},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9723 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9725 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0062, (cst_val *)&val_0004},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0063, (cst_val *)&val_0140},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0064, (cst_val *)&val_1232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9726 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0066, (cst_val *)&val_1006},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0067, (cst_val *)&val_2064},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0068, (cst_val *)&val_0850},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0069, (cst_val *)&val_9727},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9729 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0072, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9731 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9732 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9733 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0077, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9734 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0079, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9735 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9736 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0082, (cst_val *)&val_1753},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0083, (cst_val *)&val_9737},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9738 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9739 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0086, (cst_val *)&val_0142},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9740 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9741 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0089, (cst_val *)&val_0140},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0090, (cst_val *)&val_0064},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0091, (cst_val *)&val_0538},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0092, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9743 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0095, (cst_val *)&val_9744},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9746 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0098, (cst_val *)&val_9747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9749 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0101, (cst_val *)&val_0020},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9750 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9751 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0104, (cst_val *)&val_1071},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0105, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0106, (cst_val *)&val_2468},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9752 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0108, (cst_val *)&val_0025},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0109, (cst_val *)&val_0064},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0110, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9753 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9755 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0114, (cst_val *)&val_0986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9756 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9757 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0117, (cst_val *)&val_0237},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0118, (cst_val *)&val_9758},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0119, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9759 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0121, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9760 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9761 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0124, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9762 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0126, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9763 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9764 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0129, (cst_val *)&val_1119},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0130, (cst_val *)&val_9765},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0131, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9766 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0133, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9767 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9768 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0136, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9769 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9770 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0139, (cst_val *)&val_0228},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0140, (cst_val *)&val_9771},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9773 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0143, (cst_val *)&val_9774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9775 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0145, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9776 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0147, (cst_val *)&val_9777},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9778 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9779 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0150, (cst_val *)&val_0137},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0151, (cst_val *)&val_0019},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0152, (cst_val *)&val_9780},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0153, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9781 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0155, (cst_val *)&val_0027},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0156, (cst_val *)&val_0363},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0157, (cst_val *)&val_0012},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0158, (cst_val *)&val_0550},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0159, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9783 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0162, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9784 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0164, (cst_val *)&val_2311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9785 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9786 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0167, (cst_val *)&val_0391},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0168, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9787 },
{ 29, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0170, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9789 },
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0173, (cst_val *)&val_9790},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9792 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0176, (cst_val *)&val_0313},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0177, (cst_val *)&val_0001},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0178, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9793 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9794 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0181, (cst_val *)&val_0108},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0182, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9795 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9796 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0185, (cst_val *)&val_9797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9798 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9799 },
{ 31, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0188, (cst_val *)&val_0061},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0189, (cst_val *)&val_9800},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9801 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0191, (cst_val *)&val_7399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9804 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0195, (cst_val *)&val_9805},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0196, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9807 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9808 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0200, (cst_val *)&val_4873},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0201, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9809 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0203, (cst_val *)&val_0001},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0204, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9810 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9811 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0207, (cst_val *)&val_9812},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0208, (cst_val *)&val_1149},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9813 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9814 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9815 },
{ 32, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0212, (cst_val *)&val_0018},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0213, (cst_val *)&val_9816},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0214, (cst_val *)&val_0001},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0215, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9817 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0217, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9819 },
{ 30, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0220, (cst_val *)&val_0108},
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0221, (cst_val *)&val_0125},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9821 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0224, (cst_val *)&val_4610},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0225, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9822 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9823 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9824 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0229, (cst_val *)&val_0218},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0230, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9825 },
{ 33, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0232, (cst_val *)&val_0239},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9826 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9827 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0235, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9828 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0237, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9830 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9831 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0241, (cst_val *)&val_8386},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0242, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9832 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0244, (cst_val *)&val_0001},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0245, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0246, (cst_val *)&val_9833},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9834 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9835 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9837 },
{ 34, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0251, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9838 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0253, (cst_val *)&val_3129},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9839 },
{ 7, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0255, (cst_val *)&val_2905},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9840 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9841 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0258, (cst_val *)&val_9812},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0259, (cst_val *)&val_9842},
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0260, (cst_val *)&val_0019},
{ 20, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0261, (cst_val *)&val_9843},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9844 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9845 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9846 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0265, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9848 },
{ 35, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0268, (cst_val *)&val_9849},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_165_NO_0269, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9850 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9852 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_t_165_feat_table[] = {
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_state_index",
"lisp_cg_state_pos",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_position_in_phrasep",
NULL };

const cst_cart cmu_us_slt_single_mcep_t_165_cart = {
  cmu_us_slt_single_mcep_t_165_cart_nodes,
  cmu_us_slt_single_mcep_t_165_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_t_166_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0001, (cst_val *)&val_3580},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0003, (cst_val *)&val_3160},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0004, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9853 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0006, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9855 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0009, (cst_val *)&val_0313},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0010, (cst_val *)&val_0001},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0011, (cst_val *)&val_0237},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0012, (cst_val *)&val_9797},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9856 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9857 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0015, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9859 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0018, (cst_val *)&val_0140},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0019, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9860 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9861 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0022, (cst_val *)&val_9862},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9863 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9865 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0026, (cst_val *)&val_0003},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0027, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9866 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0029, (cst_val *)&val_0073},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0030, (cst_val *)&val_0025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9867 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0032, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9868 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9869 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0035, (cst_val *)&val_2311},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9871 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0038, (cst_val *)&val_0004},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0039, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9873 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0042, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9874 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0044, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9875 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9876 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0047, (cst_val *)&val_0850},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0048, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9877 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0050, (cst_val *)&val_0284},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0051, (cst_val *)&val_7849},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0052, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9878 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0054, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9879 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0056, (cst_val *)&val_9880},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9882 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0059, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9884 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0062, (cst_val *)&val_9885},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9886 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0064, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9888 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0067, (cst_val *)&val_0189},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0068, (cst_val *)&val_0942},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0069, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9889 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9891 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0073, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9892 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0075, (cst_val *)&val_9893},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9894 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9895 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0078, (cst_val *)&val_0140},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0079, (cst_val *)&val_0061},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0080, (cst_val *)&val_2301},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0081, (cst_val *)&val_5886},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0082, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9898 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0086, (cst_val *)&val_3500},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9899 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9900 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0089, (cst_val *)&val_0082},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0090, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9901 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0092, (cst_val *)&val_9902},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0093, (cst_val *)&val_1492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9903 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9904 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9905 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0097, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0098, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9906 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0100, (cst_val *)&val_4982},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0101, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9907 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9908 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0104, (cst_val *)&val_1669},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0105, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9909 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9910 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0108, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9911 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9912 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0111, (cst_val *)&val_0395},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0112, (cst_val *)&val_9913},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0113, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9915 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9916 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0117, (cst_val *)&val_5046},
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0118, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0119, (cst_val *)&val_0478},
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0120, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9917 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9918 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0123, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9920 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0126, (cst_val *)&val_0088},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0127, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9922 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0130, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9923 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9924 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0133, (cst_val *)&val_0088},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0134, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9926 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0137, (cst_val *)&val_0018},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0138, (cst_val *)&val_9927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9929 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9930 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0142, (cst_val *)&val_0942},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0143, (cst_val *)&val_0137},
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0144, (cst_val *)&val_0140},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0145, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9931 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9932 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0148, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9933 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9934 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0151, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9936 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0154, (cst_val *)&val_8753},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0155, (cst_val *)&val_0668},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0156, (cst_val *)&val_4831},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0157, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9937 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9938 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0160, (cst_val *)&val_0027},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9939 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9940 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0163, (cst_val *)&val_0828},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0164, (cst_val *)&val_1218},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0165, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9941 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0167, (cst_val *)&val_9942},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0168, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9943 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9945 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9947 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0174, (cst_val *)&val_0828},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0175, (cst_val *)&val_9948},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0176, (cst_val *)&val_2905},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0177, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9950 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9951 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_t_166_NO_0181, (cst_val *)&val_9952},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9953 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9954 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9955 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_t_166_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_index",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"lisp_cg_state_pos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"lisp_cg_position_in_phrasep",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.pos_in_syl",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_t_166_cart = {
  cmu_us_slt_single_mcep_t_166_cart_nodes,
  cmu_us_slt_single_mcep_t_166_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_er_61_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0000, (cst_val *)&val_9956},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0001, (cst_val *)&val_0064},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0002, (cst_val *)&val_0217},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9957 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0004, (cst_val *)&val_0137},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0005, (cst_val *)&val_0023},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0006, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9958 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0008, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9960 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0011, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9961 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0013, (cst_val *)&val_4301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9962 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0015, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9964 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0018, (cst_val *)&val_1060},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0019, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9966 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0022, (cst_val *)&val_1660},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9967 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0024, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9969 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0027, (cst_val *)&val_1355},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0028, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9970 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9971 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0031, (cst_val *)&val_0018},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0032, (cst_val *)&val_1441},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0033, (cst_val *)&val_9972},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9973 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0035, (cst_val *)&val_3436},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9974 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9975 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0038, (cst_val *)&val_0004},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0039, (cst_val *)&val_8639},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9976 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9977 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0042, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9978 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0044, (cst_val *)&val_1681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9979 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0046, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9980 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0048, (cst_val *)&val_0023},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0049, (cst_val *)&val_4603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9981 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9983 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0053, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9985 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0056, (cst_val *)&val_9986},
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0057, (cst_val *)&val_0140},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0058, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0059, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0060, (cst_val *)&val_0989},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9987 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9988 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0063, (cst_val *)&val_2700},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9990 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0066, (cst_val *)&val_0301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9991 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9992 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0069, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0070, (cst_val *)&val_0061},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0071, (cst_val *)&val_9993},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9994 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0073, (cst_val *)&val_1355},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0074, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9995 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9997 },
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0078, (cst_val *)&val_9998},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0079, (cst_val *)&val_0237},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0080, (cst_val *)&val_0363},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0081, (cst_val *)&val_2135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_9999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10001 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0085, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10002 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0087, (cst_val *)&val_1660},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0088, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10004 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0091, (cst_val *)&val_0151},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0092, (cst_val *)&val_0023},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0093, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10005 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10007 },
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0097, (cst_val *)&val_0018},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0098, (cst_val *)&val_10008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10010 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10011 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0102, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10012 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0104, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10013 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10014 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0107, (cst_val *)&val_0023},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0108, (cst_val *)&val_1577},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0109, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10015 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0111, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10016 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0113, (cst_val *)&val_0492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10017 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10018 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0116, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10019 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10020 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0119, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10021 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0121, (cst_val *)&val_1660},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0122, (cst_val *)&val_10022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10023 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10024 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0125, (cst_val *)&val_1355},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0126, (cst_val *)&val_10025},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10027 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0129, (cst_val *)&val_4301},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0130, (cst_val *)&val_10028},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10029 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10030 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0133, (cst_val *)&val_0018},
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0134, (cst_val *)&val_0590},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0135, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10032 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0138, (cst_val *)&val_4064},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0139, (cst_val *)&val_0976},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10033 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10034 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10035 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0143, (cst_val *)&val_5995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10036 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10037 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0146, (cst_val *)&val_0004},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0147, (cst_val *)&val_4301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10038 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0149, (cst_val *)&val_0228},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0150, (cst_val *)&val_10039},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10040 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0152, (cst_val *)&val_1984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10042 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0155, (cst_val *)&val_0061},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0156, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10043 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10044 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0159, (cst_val *)&val_0395},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0160, (cst_val *)&val_1355},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10045 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0162, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10046 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10047 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0165, (cst_val *)&val_0140},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0166, (cst_val *)&val_10048},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0167, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10049 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10050 },
{ 26, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0170, (cst_val *)&val_0547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10052 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0173, (cst_val *)&val_10053},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0174, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10054 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0176, (cst_val *)&val_1685},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10055 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10056 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10057 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0180, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0181, (cst_val *)&val_1071},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0182, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10058 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0184, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10059 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10060 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0187, (cst_val *)&val_0023},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0188, (cst_val *)&val_10061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10062 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10063 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0191, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10064 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10065 },
{ 27, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0194, (cst_val *)&val_10066},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0195, (cst_val *)&val_0301},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0196, (cst_val *)&val_0108},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0197, (cst_val *)&val_0018},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0198, (cst_val *)&val_10067},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10068 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0200, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10069 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10070 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0203, (cst_val *)&val_0171},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10071 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10072 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0206, (cst_val *)&val_0200},
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0207, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10073 },
{ 17, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0209, (cst_val *)&val_10074},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0210, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10075 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10076 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10077 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10078 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0215, (cst_val *)&val_0108},
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0216, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10079 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10080 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0219, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10081 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0221, (cst_val *)&val_3767},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10082 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10083 },
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0224, (cst_val *)&val_10084},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0225, (cst_val *)&val_4392},
{ 19, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0226, (cst_val *)&val_10085},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10086 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10087 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10088 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_61_NO_0230, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10089 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10090 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_er_61_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_slt_single_mcep_er_61_cart = {
  cmu_us_slt_single_mcep_er_61_cart_nodes,
  cmu_us_slt_single_mcep_er_61_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_er_62_cart_nodes[] = {
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0000, (cst_val *)&val_10091},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0001, (cst_val *)&val_0465},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0002, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10092 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10093 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0005, (cst_val *)&val_0088},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0006, (cst_val *)&val_1227},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0007, (cst_val *)&val_0237},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0008, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10094 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10095 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0011, (cst_val *)&val_2449},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10096 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0013, (cst_val *)&val_0910},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0014, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10097 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0016, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10098 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0018, (cst_val *)&val_10099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10100 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10101 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0021, (cst_val *)&val_0780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10102 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0023, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10103 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0025, (cst_val *)&val_0836},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10104 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10105 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0028, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10106 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0030, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10107 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0032, (cst_val *)&val_10108},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0033, (cst_val *)&val_10109},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0034, (cst_val *)&val_4924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10110 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10111 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10112 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10113 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0039, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0040, (cst_val *)&val_10114},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0041, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0042, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10115 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0044, (cst_val *)&val_0140},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0045, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10116 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10117 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0048, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10118 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0050, (cst_val *)&val_3023},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0051, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10119 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10120 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0054, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10121 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0056, (cst_val *)&val_10122},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10123 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10124 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0059, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0060, (cst_val *)&val_0232},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0061, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10125 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10126 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0064, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10127 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0066, (cst_val *)&val_0105},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0067, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0068, (cst_val *)&val_0119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10128 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10129 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0071, (cst_val *)&val_2074},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10130 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10131 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10132 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0075, (cst_val *)&val_1626},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0076, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10133 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10134 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0079, (cst_val *)&val_0140},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0080, (cst_val *)&val_0014},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0081, (cst_val *)&val_10135},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10136 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10137 },
{ 23, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0084, (cst_val *)&val_0141},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0085, (cst_val *)&val_10138},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10139 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10140 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0088, (cst_val *)&val_1752},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10141 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10142 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0091, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10143 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10144 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0094, (cst_val *)&val_10145},
{ 0, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0095, (cst_val *)&val_10146},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10147 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10148 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0098, (cst_val *)&val_1407},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0099, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10149 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0101, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10150 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10151 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0104, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10152 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10153 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0107, (cst_val *)&val_0023},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0108, (cst_val *)&val_0228},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0109, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10154 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0111, (cst_val *)&val_10155},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0112, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10156 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10157 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10158 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0116, (cst_val *)&val_10159},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10160 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10161 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0119, (cst_val *)&val_10162},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0120, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10163 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10164 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0123, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10165 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0125, (cst_val *)&val_0030},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10166 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10167 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0128, (cst_val *)&val_0064},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0129, (cst_val *)&val_0088},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0130, (cst_val *)&val_1746},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10168 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10169 },
{ 26, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0133, (cst_val *)&val_5430},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0134, (cst_val *)&val_0140},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0135, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10170 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0137, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10171 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0139, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10172 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10173 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10174 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10175 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0144, (cst_val *)&val_0001},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0145, (cst_val *)&val_0232},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0146, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10176 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10177 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0149, (cst_val *)&val_0088},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0150, (cst_val *)&val_9416},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10178 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10179 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0153, (cst_val *)&val_0399},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0154, (cst_val *)&val_10180},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10181 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10182 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0157, (cst_val *)&val_0023},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0158, (cst_val *)&val_0495},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10183 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10184 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0161, (cst_val *)&val_1617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10185 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10186 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0164, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10187 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0166, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10188 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0168, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10189 },
{ 28, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0170, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10190 },
{ 27, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0172, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10191 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_62_NO_0174, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10192 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10193 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_er_62_feat_table[] = {
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.stress",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.syl_final",
NULL };

const cst_cart cmu_us_slt_single_mcep_er_62_cart = {
  cmu_us_slt_single_mcep_er_62_cart_nodes,
  cmu_us_slt_single_mcep_er_62_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_er_63_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0001, (cst_val *)&val_0072},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0002, (cst_val *)&val_0115},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0003, (cst_val *)&val_0088},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0004, (cst_val *)&val_2064},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0005, (cst_val *)&val_0082},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0006, (cst_val *)&val_10194},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10195 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10196 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10197 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0010, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10198 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10199 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0013, (cst_val *)&val_0140},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0014, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10200 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10201 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0017, (cst_val *)&val_10202},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10203 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10204 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0020, (cst_val *)&val_10205},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0021, (cst_val *)&val_10206},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0022, (cst_val *)&val_0018},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0023, (cst_val *)&val_1061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10207 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0025, (cst_val *)&val_10208},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10209 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0027, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10210 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0029, (cst_val *)&val_10211},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10212 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10213 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10214 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0033, (cst_val *)&val_0048},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10215 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0035, (cst_val *)&val_10216},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0036, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10217 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10218 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0039, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10219 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10220 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0042, (cst_val *)&val_10221},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10222 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0044, (cst_val *)&val_0516},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0045, (cst_val *)&val_10223},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10224 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0047, (cst_val *)&val_7399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10225 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10226 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10227 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0051, (cst_val *)&val_0018},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0052, (cst_val *)&val_10228},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0053, (cst_val *)&val_10229},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10230 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0055, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10231 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10232 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0058, (cst_val *)&val_7822},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0059, (cst_val *)&val_0194},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0060, (cst_val *)&val_8492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10233 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10234 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10235 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0064, (cst_val *)&val_0052},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0065, (cst_val *)&val_4283},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0066, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0067, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10236 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10237 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0070, (cst_val *)&val_10238},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10239 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10240 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10241 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10242 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0075, (cst_val *)&val_0082},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0076, (cst_val *)&val_0025},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0077, (cst_val *)&val_0137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10243 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10244 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0080, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10245 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10246 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0083, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0084, (cst_val *)&val_2970},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10247 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10248 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0087, (cst_val *)&val_1061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10249 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10250 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0090, (cst_val *)&val_0064},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0091, (cst_val *)&val_0018},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0092, (cst_val *)&val_0001},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0093, (cst_val *)&val_0769},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10251 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0095, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10252 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10253 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0098, (cst_val *)&val_0896},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10254 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0100, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10255 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10256 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0103, (cst_val *)&val_0982},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0104, (cst_val *)&val_10257},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10258 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10259 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0107, (cst_val *)&val_0108},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0108, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10260 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10261 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10262 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0112, (cst_val *)&val_2643},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0113, (cst_val *)&val_1949},
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0114, (cst_val *)&val_0780},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10263 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0116, (cst_val *)&val_0986},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10264 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10265 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0119, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10266 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0121, (cst_val *)&val_4313},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0122, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10267 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10268 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10269 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0126, (cst_val *)&val_0218},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0127, (cst_val *)&val_0595},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0128, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10270 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0130, (cst_val *)&val_0395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10271 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10272 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0133, (cst_val *)&val_0373},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0134, (cst_val *)&val_0007},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10273 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10274 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0137, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10275 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0139, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0140, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10276 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10277 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0143, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10278 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0145, (cst_val *)&val_4010},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10279 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10280 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0148, (cst_val *)&val_0088},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0149, (cst_val *)&val_0018},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0150, (cst_val *)&val_0900},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10281 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0152, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10282 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10283 },
{ 2, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0155, (cst_val *)&val_3147},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10284 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10285 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0158, (cst_val *)&val_0373},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0159, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10286 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10287 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0162, (cst_val *)&val_1978},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10288 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_er_63_NO_0164, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10289 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10290 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_er_63_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_state_place",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_phone_place",
"lisp_cg_phone_index",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.parent.n.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_er_63_cart = {
  cmu_us_slt_single_mcep_er_63_cart_nodes,
  cmu_us_slt_single_mcep_er_63_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ax_26_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0001, (cst_val *)&val_0006},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0002, (cst_val *)&val_0217},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0003, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10291 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10292 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0006, (cst_val *)&val_0137},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0007, (cst_val *)&val_10293},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10294 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0009, (cst_val *)&val_0216},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10295 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10296 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0012, (cst_val *)&val_1060},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0013, (cst_val *)&val_10297},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0014, (cst_val *)&val_10298},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0015, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10299 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10300 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10301 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0019, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10302 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0021, (cst_val *)&val_10303},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10304 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10305 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0024, (cst_val *)&val_0459},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10306 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0026, (cst_val *)&val_0465},
{ 10, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0027, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10307 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10308 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0030, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10309 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0032, (cst_val *)&val_10310},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10311 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10312 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0035, (cst_val *)&val_0217},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0036, (cst_val *)&val_10313},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0037, (cst_val *)&val_10314},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10315 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10316 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10317 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0041, (cst_val *)&val_0064},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0042, (cst_val *)&val_0023},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0043, (cst_val *)&val_10318},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10319 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10320 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0046, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10321 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10322 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0049, (cst_val *)&val_1009},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0050, (cst_val *)&val_10323},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10324 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0052, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10325 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10326 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0055, (cst_val *)&val_3450},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0056, (cst_val *)&val_0228},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0057, (cst_val *)&val_0465},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0058, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10327 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10328 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0061, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10329 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10330 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0064, (cst_val *)&val_10331},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10332 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10333 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10334 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0068, (cst_val *)&val_0683},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0069, (cst_val *)&val_0088},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0070, (cst_val *)&val_0011},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0071, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10335 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0073, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10336 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0075, (cst_val *)&val_10337},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0076, (cst_val *)&val_10338},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10339 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10340 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10341 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0080, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10342 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0082, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0083, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10343 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0085, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10344 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0087, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10345 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10346 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0090, (cst_val *)&val_0008},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0091, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10347 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10348 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0094, (cst_val *)&val_0399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10349 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0096, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10350 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10351 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0099, (cst_val *)&val_0705},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0100, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10352 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10353 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0103, (cst_val *)&val_0061},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0104, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10354 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10355 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0107, (cst_val *)&val_0467},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0108, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10356 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10357 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0111, (cst_val *)&val_0105},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0112, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10358 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10359 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0115, (cst_val *)&val_0023},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0116, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10360 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10361 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0119, (cst_val *)&val_10362},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10363 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0121, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10364 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0123, (cst_val *)&val_0478},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10365 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10366 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0126, (cst_val *)&val_0061},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0127, (cst_val *)&val_0668},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10367 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0129, (cst_val *)&val_10368},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0130, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10369 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10370 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0133, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10371 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10372 },
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0136, (cst_val *)&val_10373},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0137, (cst_val *)&val_0018},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0138, (cst_val *)&val_0088},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0139, (cst_val *)&val_0018},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0140, (cst_val *)&val_5346},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10374 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0142, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10375 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10376 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0145, (cst_val *)&val_10377},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0146, (cst_val *)&val_0358},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10378 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10379 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0149, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10380 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10381 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0152, (cst_val *)&val_0228},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0153, (cst_val *)&val_0023},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0154, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10382 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10383 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0157, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10384 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0159, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10385 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10386 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0162, (cst_val *)&val_0001},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0163, (cst_val *)&val_3625},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0164, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10387 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0166, (cst_val *)&val_0467},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0167, (cst_val *)&val_10388},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10389 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10390 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0170, (cst_val *)&val_10391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10392 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10393 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10394 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0174, (cst_val *)&val_2700},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0175, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10395 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10396 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10397 },
{ 24, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0179, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10398 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10399 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0182, (cst_val *)&val_2612},
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0183, (cst_val *)&val_0140},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0184, (cst_val *)&val_0643},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10400 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_26_NO_0186, (cst_val *)&val_8509},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10401 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10402 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10403 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10404 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ax_26_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:HMMstate.p.name",
"lisp_cg_state_pos",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
NULL };

const cst_cart cmu_us_slt_single_mcep_ax_26_cart = {
  cmu_us_slt_single_mcep_ax_26_cart_nodes,
  cmu_us_slt_single_mcep_ax_26_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ax_27_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0000, (cst_val *)&val_0105},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0001, (cst_val *)&val_0073},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0002, (cst_val *)&val_0004},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0003, (cst_val *)&val_0023},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0004, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10405 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0006, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10406 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10407 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0009, (cst_val *)&val_0597},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10408 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10409 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0012, (cst_val *)&val_0061},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0013, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10410 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10411 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0016, (cst_val *)&val_0018},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0017, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10412 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10413 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0020, (cst_val *)&val_0006},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0021, (cst_val *)&val_0365},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10414 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10415 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10416 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0025, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10417 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0027, (cst_val *)&val_0642},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0028, (cst_val *)&val_10418},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0029, (cst_val *)&val_1489},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10419 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0031, (cst_val *)&val_0108},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0032, (cst_val *)&val_10420},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10421 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10422 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0035, (cst_val *)&val_10423},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10424 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10425 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10426 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0039, (cst_val *)&val_1600},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0040, (cst_val *)&val_0088},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0041, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10427 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10428 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0044, (cst_val *)&val_10429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10430 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10431 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10432 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0048, (cst_val *)&val_0004},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0049, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0050, (cst_val *)&val_6664},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0051, (cst_val *)&val_0061},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0052, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10433 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10434 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0055, (cst_val *)&val_0228},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0056, (cst_val *)&val_0009},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0057, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0058, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10435 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10436 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10437 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10438 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0063, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10439 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10440 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0066, (cst_val *)&val_0023},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0067, (cst_val *)&val_0228},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0068, (cst_val *)&val_0018},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0069, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10441 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10442 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0072, (cst_val *)&val_10443},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10444 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10445 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10446 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0076, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10447 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0078, (cst_val *)&val_0018},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0079, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10448 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10449 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10450 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0083, (cst_val *)&val_0004},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0084, (cst_val *)&val_0683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10451 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10452 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0087, (cst_val *)&val_0228},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0088, (cst_val *)&val_0018},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0089, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10453 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10454 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10455 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0093, (cst_val *)&val_0506},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10456 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0095, (cst_val *)&val_0232},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0096, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10457 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10458 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0099, (cst_val *)&val_0088},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0100, (cst_val *)&val_0982},
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0101, (cst_val *)&val_0073},
{ 18, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0102, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10459 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10460 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10461 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0106, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10462 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10463 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10464 },
{ 16, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0110, (cst_val *)&val_1347},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0111, (cst_val *)&val_0061},
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0112, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10465 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10466 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0115, (cst_val *)&val_10467},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0116, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10468 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0118, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10469 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0120, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10470 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0122, (cst_val *)&val_10297},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0123, (cst_val *)&val_0679},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10471 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10472 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10473 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0127, (cst_val *)&val_10474},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0128, (cst_val *)&val_1369},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0129, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10475 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10476 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10477 },
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0133, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10478 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10479 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0136, (cst_val *)&val_0018},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0137, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10480 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0139, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10481 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0141, (cst_val *)&val_10482},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10483 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10484 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0144, (cst_val *)&val_10485},
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0145, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10486 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0147, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10487 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0149, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10488 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10489 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0152, (cst_val *)&val_0023},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0153, (cst_val *)&val_1700},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0154, (cst_val *)&val_0699},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10490 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10491 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0157, (cst_val *)&val_10492},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10493 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0159, (cst_val *)&val_0132},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10494 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10495 },
{ 3, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0162, (cst_val *)&val_0465},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0163, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10496 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10497 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_27_NO_0166, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10498 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10499 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ax_27_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"lisp_cg_position_in_phrasep",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.gpos",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"lisp_cg_state_rindex",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.p.ph_vc",
"R:mcep_link.parent.R:segstate.parent.p.name",
NULL };

const cst_cart cmu_us_slt_single_mcep_ax_27_cart = {
  cmu_us_slt_single_mcep_ax_27_cart_nodes,
  cmu_us_slt_single_mcep_ax_27_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_ax_28_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0000, (cst_val *)&val_0064},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0001, (cst_val *)&val_10500},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0002, (cst_val *)&val_0088},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0003, (cst_val *)&val_0132},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0004, (cst_val *)&val_0643},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0005, (cst_val *)&val_10501},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0006, (cst_val *)&val_10502},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10503 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10504 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10505 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0010, (cst_val *)&val_0108},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0011, (cst_val *)&val_4034},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10506 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0013, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10507 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10508 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0016, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10509 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10510 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10511 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0020, (cst_val *)&val_1813},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0021, (cst_val *)&val_2775},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0022, (cst_val *)&val_0114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10512 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0024, (cst_val *)&val_0017},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10513 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10514 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10515 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0028, (cst_val *)&val_0009},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10516 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10517 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0031, (cst_val *)&val_0082},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0032, (cst_val *)&val_0194},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0033, (cst_val *)&val_0025},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0034, (cst_val *)&val_10518},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0035, (cst_val *)&val_10519},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10520 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10521 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10522 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10523 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0040, (cst_val *)&val_10524},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0041, (cst_val *)&val_0538},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10525 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10526 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10527 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0045, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10528 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0047, (cst_val *)&val_0088},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0048, (cst_val *)&val_1962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10529 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0050, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10530 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10531 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0053, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10532 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0055, (cst_val *)&val_3920},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0056, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10533 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10534 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0059, (cst_val *)&val_0371},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0060, (cst_val *)&val_1377},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0061, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10535 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10536 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0064, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10537 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0066, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10538 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10539 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10540 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0070, (cst_val *)&val_1978},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0071, (cst_val *)&val_0140},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0072, (cst_val *)&val_0740},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0073, (cst_val *)&val_0625},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0074, (cst_val *)&val_3640},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10541 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10542 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10543 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0078, (cst_val *)&val_0061},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0079, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10544 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0081, (cst_val *)&val_4603},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10545 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10546 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0084, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10547 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0086, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10548 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10549 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0089, (cst_val *)&val_0140},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0090, (cst_val *)&val_1167},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10550 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10551 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0093, (cst_val *)&val_1813},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0094, (cst_val *)&val_0099},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10552 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10553 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0097, (cst_val *)&val_4419},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10554 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10555 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0100, (cst_val *)&val_0061},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0101, (cst_val *)&val_0042},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0102, (cst_val *)&val_3500},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0103, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10556 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10557 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0106, (cst_val *)&val_10558},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0107, (cst_val *)&val_1193},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0108, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10559 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10560 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0111, (cst_val *)&val_1813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10561 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10562 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0114, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10563 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10564 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0117, (cst_val *)&val_10565},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10566 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0119, (cst_val *)&val_1193},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10567 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10568 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0122, (cst_val *)&val_0373},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0123, (cst_val *)&val_10569},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0124, (cst_val *)&val_4907},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0125, (cst_val *)&val_0471},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0126, (cst_val *)&val_0006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10570 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10571 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0129, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10572 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0131, (cst_val *)&val_0363},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0132, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10573 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10574 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0135, (cst_val *)&val_0142},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0136, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10575 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10576 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10577 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0140, (cst_val *)&val_0022},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0141, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0142, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10578 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10579 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10580 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10581 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0147, (cst_val *)&val_7611},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0148, (cst_val *)&val_2280},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10582 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10583 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0151, (cst_val *)&val_5841},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0152, (cst_val *)&val_0395},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0153, (cst_val *)&val_0008},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10584 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0155, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10585 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10586 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10587 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10588 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0160, (cst_val *)&val_1813},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0161, (cst_val *)&val_10589},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0162, (cst_val *)&val_10590},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0163, (cst_val *)&val_10591},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10592 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10593 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10594 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0167, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10595 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0169, (cst_val *)&val_0105},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0170, (cst_val *)&val_3273},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0171, (cst_val *)&val_2612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10596 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10597 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10598 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0175, (cst_val *)&val_10599},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10600 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0177, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10601 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10602 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0180, (cst_val *)&val_10229},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0181, (cst_val *)&val_9506},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0182, (cst_val *)&val_0740},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10603 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10604 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0185, (cst_val *)&val_0114},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0186, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10605 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0188, (cst_val *)&val_0478},
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0189, (cst_val *)&val_0108},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10606 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10607 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0192, (cst_val *)&val_0140},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10608 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10609 },
{ 24, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0195, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10610 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10611 },
{ 23, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0198, (cst_val *)&val_0004},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0199, (cst_val *)&val_0200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10612 },
{ 25, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_ax_28_NO_0201, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10613 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10614 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10615 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_ax_28_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_state_rindex",
"lisp_cg_position_in_phrasep",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.p.gpos",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.seg_onsetcoda",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.seg_onsetcoda",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.position_type",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.parent.R:Word.n.gpos",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.accented",
"R:mcep_link.parent.R:segstate.parent.n.ph_vlng",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
NULL };

const cst_cart cmu_us_slt_single_mcep_ax_28_cart = {
  cmu_us_slt_single_mcep_ax_28_cart_nodes,
  cmu_us_slt_single_mcep_ax_28_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_pau_141_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0000, (cst_val *)&val_0018},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0001, (cst_val *)&val_1390},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0003, (cst_val *)&val_4924},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10616 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0005, (cst_val *)&val_4634},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0006, (cst_val *)&val_0575},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10617 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10618 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10619 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10620 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0011, (cst_val *)&val_2707},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0012, (cst_val *)&val_0237},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0013, (cst_val *)&val_10621},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0014, (cst_val *)&val_0177},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10622 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0016, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10623 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0018, (cst_val *)&val_4204},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0019, (cst_val *)&val_1908},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10624 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10625 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0022, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10626 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10627 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0025, (cst_val *)&val_5064},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0026, (cst_val *)&val_10628},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10629 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0028, (cst_val *)&val_0717},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0029, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10630 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10631 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0032, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10632 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10633 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10634 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0036, (cst_val *)&val_0100},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0037, (cst_val *)&val_10621},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0038, (cst_val *)&val_4114},
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0039, (cst_val *)&val_0018},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0040, (cst_val *)&val_3985},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10635 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0042, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10636 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10637 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0045, (cst_val *)&val_10638},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10639 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10640 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10641 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0049, (cst_val *)&val_5064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0050, (cst_val *)&val_1558},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10642 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0052, (cst_val *)&val_0717},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0053, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10643 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10644 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0056, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10645 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10646 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10647 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0060, (cst_val *)&val_0879},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10648 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0062, (cst_val *)&val_5064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0063, (cst_val *)&val_1753},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0064, (cst_val *)&val_2525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10649 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0066, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0067, (cst_val *)&val_10650},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10651 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10652 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0070, (cst_val *)&val_3634},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10653 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10654 },
{ 8, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0073, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10655 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0075, (cst_val *)&val_10656},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10657 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10658 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0078, (cst_val *)&val_0040},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10659 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0080, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10660 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10661 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0083, (cst_val *)&val_0444},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0084, (cst_val *)&val_0252},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10662 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10663 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0087, (cst_val *)&val_10664},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0088, (cst_val *)&val_1403},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0089, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10665 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0091, (cst_val *)&val_10666},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0092, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10667 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0094, (cst_val *)&val_1517},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10668 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10669 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10670 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0098, (cst_val *)&val_0132},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0099, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10671 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0101, (cst_val *)&val_0969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10672 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10673 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0104, (cst_val *)&val_2525},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10674 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10675 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0107, (cst_val *)&val_0414},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0108, (cst_val *)&val_2395},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10676 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10677 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0111, (cst_val *)&val_4029},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0112, (cst_val *)&val_0440},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10678 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10679 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10680 },
{ 15, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0116, (cst_val *)&val_0217},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0117, (cst_val *)&val_0652},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0118, (cst_val *)&val_0004},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0119, (cst_val *)&val_1044},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0120, (cst_val *)&val_0007},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0121, (cst_val *)&val_1406},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10681 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10682 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0124, (cst_val *)&val_10683},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0125, (cst_val *)&val_0228},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0126, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10684 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10685 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0129, (cst_val *)&val_1819},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10686 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10687 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0132, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10688 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10689 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0135, (cst_val *)&val_0061},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0136, (cst_val *)&val_0550},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10690 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10691 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10692 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0140, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0141, (cst_val *)&val_10693},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10694 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0143, (cst_val *)&val_10621},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10695 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10696 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0146, (cst_val *)&val_0506},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0147, (cst_val *)&val_3922},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10697 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10698 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0150, (cst_val *)&val_0186},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10699 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10700 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0153, (cst_val *)&val_0004},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0154, (cst_val *)&val_0308},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0155, (cst_val *)&val_0433},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0156, (cst_val *)&val_2707},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0157, (cst_val *)&val_1006},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10701 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0159, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10702 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10703 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10704 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0163, (cst_val *)&val_0681},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10705 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0165, (cst_val *)&val_0228},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0166, (cst_val *)&val_0023},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0167, (cst_val *)&val_0084},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10706 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10707 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0170, (cst_val *)&val_7399},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10708 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10709 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0173, (cst_val *)&val_0969},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0174, (cst_val *)&val_0061},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0175, (cst_val *)&val_5511},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10710 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10711 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10712 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10713 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0180, (cst_val *)&val_1390},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0181, (cst_val *)&val_0088},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0182, (cst_val *)&val_0072},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10714 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10715 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0185, (cst_val *)&val_1044},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10716 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10717 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0188, (cst_val *)&val_0076},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10718 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0190, (cst_val *)&val_3955},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0191, (cst_val *)&val_0228},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0192, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10719 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10720 },
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0195, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10721 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10722 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0198, (cst_val *)&val_10723},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10724 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10725 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0201, (cst_val *)&val_0088},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0202, (cst_val *)&val_2468},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0203, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10726 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0205, (cst_val *)&val_1347},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10727 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0207, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10728 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10729 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0210, (cst_val *)&val_1928},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0211, (cst_val *)&val_0309},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10730 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10731 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0214, (cst_val *)&val_10732},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10733 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10734 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0217, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10735 },
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0219, (cst_val *)&val_0237},
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0220, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10736 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10737 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0223, (cst_val *)&val_10738},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10739 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10740 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0226, (cst_val *)&val_0018},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0227, (cst_val *)&val_0099},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0228, (cst_val *)&val_0018},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0229, (cst_val *)&val_3044},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0230, (cst_val *)&val_0095},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0231, (cst_val *)&val_3670},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0232, (cst_val *)&val_10741},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10742 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10743 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0235, (cst_val *)&val_3933},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10744 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10745 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10746 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0239, (cst_val *)&val_2095},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0240, (cst_val *)&val_10747},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10748 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10749 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0243, (cst_val *)&val_10750},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0244, (cst_val *)&val_2103},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10751 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0246, (cst_val *)&val_3036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10752 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10753 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0249, (cst_val *)&val_2949},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0250, (cst_val *)&val_3036},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10754 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10755 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10756 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0254, (cst_val *)&val_0228},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0255, (cst_val *)&val_2699},
{ 5, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0256, (cst_val *)&val_0237},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10757 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0258, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10758 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0260, (cst_val *)&val_4658},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10759 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10760 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0263, (cst_val *)&val_0073},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0264, (cst_val *)&val_0363},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10761 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0266, (cst_val *)&val_0264},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0267, (cst_val *)&val_10762},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0268, (cst_val *)&val_10763},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10764 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10765 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10766 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10767 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0273, (cst_val *)&val_0264},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0274, (cst_val *)&val_0141},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0275, (cst_val *)&val_6104},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10768 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10769 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0278, (cst_val *)&val_10770},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10771 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10772 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10773 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0282, (cst_val *)&val_0088},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0283, (cst_val *)&val_0023},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0284, (cst_val *)&val_3666},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0285, (cst_val *)&val_10774},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10775 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10776 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10777 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10778 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0290, (cst_val *)&val_0705},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0291, (cst_val *)&val_7408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10779 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10780 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0294, (cst_val *)&val_0064},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0295, (cst_val *)&val_2005},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10781 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0297, (cst_val *)&val_1390},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10782 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10783 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0300, (cst_val *)&val_0232},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0301, (cst_val *)&val_4313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10784 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10785 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0304, (cst_val *)&val_10786},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0305, (cst_val *)&val_5886},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10787 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10788 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10789 },
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0309, (cst_val *)&val_1390},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0310, (cst_val *)&val_4458},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0311, (cst_val *)&val_10790},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0312, (cst_val *)&val_0088},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0313, (cst_val *)&val_3200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10791 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10792 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0316, (cst_val *)&val_0228},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0317, (cst_val *)&val_10793},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10794 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10795 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0320, (cst_val *)&val_10796},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10797 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10798 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0323, (cst_val *)&val_3044},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0324, (cst_val *)&val_8219},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10799 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10800 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0327, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10801 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0329, (cst_val *)&val_0095},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0330, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10802 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10803 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10804 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0334, (cst_val *)&val_0264},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10805 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0336, (cst_val *)&val_0232},
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0337, (cst_val *)&val_3823},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10806 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10807 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0340, (cst_val *)&val_0064},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0341, (cst_val *)&val_0919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10808 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10809 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0344, (cst_val *)&val_0001},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10810 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0346, (cst_val *)&val_2095},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0347, (cst_val *)&val_1429},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10811 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10812 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0350, (cst_val *)&val_10813},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10814 },
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0352, (cst_val *)&val_0023},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0353, (cst_val *)&val_2612},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10815 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10816 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10817 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0357, (cst_val *)&val_0004},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0358, (cst_val *)&val_0337},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0359, (cst_val *)&val_0228},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0360, (cst_val *)&val_2699},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0361, (cst_val *)&val_2858},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0362, (cst_val *)&val_4141},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0363, (cst_val *)&val_5520},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10818 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10819 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0366, (cst_val *)&val_0029},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10820 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10821 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10822 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0370, (cst_val *)&val_0264},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0371, (cst_val *)&val_2775},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0372, (cst_val *)&val_3670},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10823 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0374, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10824 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10825 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0377, (cst_val *)&val_10826},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0378, (cst_val *)&val_3765},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0379, (cst_val *)&val_1178},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10827 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10828 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10829 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10830 },
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0384, (cst_val *)&val_0047},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10831 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10832 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0387, (cst_val *)&val_3061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10833 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0389, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10834 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0391, (cst_val *)&val_10835},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10836 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10837 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0394, (cst_val *)&val_3923},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0395, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10838 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10839 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0398, (cst_val *)&val_10840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10841 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10842 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0401, (cst_val *)&val_4634},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0402, (cst_val *)&val_0395},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0403, (cst_val *)&val_1984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10843 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10844 },
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0406, (cst_val *)&val_0001},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0407, (cst_val *)&val_10845},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0408, (cst_val *)&val_0125},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0409, (cst_val *)&val_0015},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10846 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0411, (cst_val *)&val_7011},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10847 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10848 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10849 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10850 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0416, (cst_val *)&val_0578},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10851 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10852 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0419, (cst_val *)&val_0055},
{ 21, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0420, (cst_val *)&val_0395},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0421, (cst_val *)&val_10853},
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0422, (cst_val *)&val_1984},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10854 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10855 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10856 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0426, (cst_val *)&val_7408},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10857 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10858 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10859 },
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0430, (cst_val *)&val_0064},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0431, (cst_val *)&val_1390},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0432, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10860 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0434, (cst_val *)&val_0018},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0435, (cst_val *)&val_0683},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10861 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10862 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10863 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0439, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10864 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10865 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0442, (cst_val *)&val_5330},
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0443, (cst_val *)&val_3061},
{ 14, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0444, (cst_val *)&val_0061},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10866 },
{ 4, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0446, (cst_val *)&val_0391},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10867 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10868 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0449, (cst_val *)&val_0232},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0450, (cst_val *)&val_0232},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10869 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0452, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10870 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10871 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0455, (cst_val *)&val_0232},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0456, (cst_val *)&val_0004},
{ 13, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0457, (cst_val *)&val_0019},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10872 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10873 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0460, (cst_val *)&val_4313},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10874 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10875 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0463, (cst_val *)&val_0004},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0464, (cst_val *)&val_3368},
{ 1, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0465, (cst_val *)&val_1390},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0466, (cst_val *)&val_0299},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10876 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0468, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10877 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10878 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10879 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10880 },
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0473, (cst_val *)&val_0105},
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0474, (cst_val *)&val_1119},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10881 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10882 },
{ 22, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0477, (cst_val *)&val_0681},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0478, (cst_val *)&val_4283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10883 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10884 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0481, (cst_val *)&val_10885},
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0482, (cst_val *)&val_0200},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0483, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10886 },
{ 12, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0485, (cst_val *)&val_0099},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0486, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10887 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10888 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0489, (cst_val *)&val_2118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10889 },
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0491, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10890 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10891 },
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0494, (cst_val *)&val_0467},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10892 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10893 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10894 },
{ 6, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0498, (cst_val *)&val_0638},
{ 11, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0499, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10895 },
{ 9, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_141_NO_0501, (cst_val *)&val_2926},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10896 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10897 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10898 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_pau_141_feat_table[] = {
"R:mcep_link.parent.R:HMMstate.p.name",
"R:mcep_link.parent.R:HMMstate.n.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"R:mcep_link.parent.lisp_cg_duration",
"lisp_cg_phone_rindex",
"lisp_cg_state_pos",
"R:mcep_link.parent.R:segstate.n.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"lisp_cg_state_index",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"lisp_cg_state_rindex",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.name",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.p.ph_vlng",
NULL };

const cst_cart cmu_us_slt_single_mcep_pau_141_cart = {
  cmu_us_slt_single_mcep_pau_141_cart_nodes,
  cmu_us_slt_single_mcep_pau_141_feat_table
};

static const cst_cart_node cmu_us_slt_single_mcep_pau_142_cart_nodes[] = {
{ 0, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0000, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0001, (cst_val *)&val_1221},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0002, (cst_val *)&val_0064},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0003, (cst_val *)&val_2468},
{ 4, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0004, (cst_val *)&val_0023},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10899 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0006, (cst_val *)&val_0642},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10900 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10901 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0009, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10902 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10903 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0012, (cst_val *)&val_0313},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0013, (cst_val *)&val_2301},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10904 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0015, (cst_val *)&val_0088},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10905 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10906 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10907 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0019, (cst_val *)&val_0064},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10908 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10909 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0022, (cst_val *)&val_0287},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0023, (cst_val *)&val_0064},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0024, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0025, (cst_val *)&val_0301},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0026, (cst_val *)&val_10910},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10911 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0028, (cst_val *)&val_10912},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10913 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10914 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10915 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0032, (cst_val *)&val_0105},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0033, (cst_val *)&val_0465},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10916 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0035, (cst_val *)&val_10917},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0036, (cst_val *)&val_10918},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10919 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10920 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0039, (cst_val *)&val_0927},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10921 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10922 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0042, (cst_val *)&val_10923},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0043, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10924 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10925 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10926 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0047, (cst_val *)&val_0232},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0048, (cst_val *)&val_0018},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0049, (cst_val *)&val_2198},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0050, (cst_val *)&val_4283},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10927 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10928 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10929 },
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0054, (cst_val *)&val_1407},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10930 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10931 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0057, (cst_val *)&val_0228},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0058, (cst_val *)&val_1407},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0059, (cst_val *)&val_0018},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0060, (cst_val *)&val_0919},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10932 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10933 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0063, (cst_val *)&val_10934},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10935 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10936 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0066, (cst_val *)&val_10937},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0067, (cst_val *)&val_0445},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10938 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10939 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0070, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10940 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0072, (cst_val *)&val_1137},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0073, (cst_val *)&val_1614},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10941 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10942 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10943 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0077, (cst_val *)&val_0824},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0078, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10944 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10945 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0081, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0082, (cst_val *)&val_3200},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10946 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10947 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0085, (cst_val *)&val_0018},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10948 },
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0087, (cst_val *)&val_0088},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0088, (cst_val *)&val_2118},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10949 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10950 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0091, (cst_val *)&val_10951},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0092, (cst_val *)&val_6401},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0093, (cst_val *)&val_3674},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0094, (cst_val *)&val_0295},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10952 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0096, (cst_val *)&val_0105},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0097, (cst_val *)&val_10953},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0098, (cst_val *)&val_10954},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10955 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0100, (cst_val *)&val_0022},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10956 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10957 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10958 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10959 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10960 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10961 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0107, (cst_val *)&val_10962},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10963 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10964 },
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0110, (cst_val *)&val_0018},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0111, (cst_val *)&val_6431},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0112, (cst_val *)&val_0232},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0113, (cst_val *)&val_2198},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0114, (cst_val *)&val_0115},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10965 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10966 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10967 },
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0118, (cst_val *)&val_0064},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0119, (cst_val *)&val_1804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10968 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10969 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0122, (cst_val *)&val_0026},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0123, (cst_val *)&val_0313},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0124, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10970 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0126, (cst_val *)&val_10971},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10972 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0128, (cst_val *)&val_0046},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10973 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10974 },
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0131, (cst_val *)&val_10975},
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0132, (cst_val *)&val_0228},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10976 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0134, (cst_val *)&val_7975},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0135, (cst_val *)&val_10977},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10978 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10979 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10980 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10981 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0140, (cst_val *)&val_1840},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10982 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10983 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0143, (cst_val *)&val_0105},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0144, (cst_val *)&val_2081},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0145, (cst_val *)&val_0004},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0146, (cst_val *)&val_8097},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0147, (cst_val *)&val_4137},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10984 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10985 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0150, (cst_val *)&val_10986},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0151, (cst_val *)&val_10987},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10988 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10989 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10990 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0155, (cst_val *)&val_1804},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10991 },
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0157, (cst_val *)&val_0013},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10992 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10993 },
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0160, (cst_val *)&val_10994},
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0161, (cst_val *)&val_0681},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0162, (cst_val *)&val_10995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10996 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10997 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10998 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0166, (cst_val *)&val_0681},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0167, (cst_val *)&val_10995},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_10999 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11000 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11001 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0171, (cst_val *)&val_0232},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0172, (cst_val *)&val_0016},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0173, (cst_val *)&val_0986},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0174, (cst_val *)&val_11002},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11003 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11004 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11005 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0178, (cst_val *)&val_2198},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11006 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11007 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0181, (cst_val *)&val_0228},
{ 8, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0182, (cst_val *)&val_1949},
{ 15, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0183, (cst_val *)&val_10953},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0184, (cst_val *)&val_6491},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11008 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11009 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11010 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0188, (cst_val *)&val_6751},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11011 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11012 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0191, (cst_val *)&val_0824},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11013 },
{ 16, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0193, (cst_val *)&val_0064},
{ 10, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0194, (cst_val *)&val_11014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11015 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11016 },
{ 13, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0197, (cst_val *)&val_7527},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11017 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0199, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11018 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11019 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0202, (cst_val *)&val_10732},
{ 2, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0203, (cst_val *)&val_0064},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0204, (cst_val *)&val_0004},
{ 1, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0205, (cst_val *)&val_0679},
{ 17, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0206, (cst_val *)&val_0001},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0207, (cst_val *)&val_1114},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11020 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11021 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11022 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11023 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0212, (cst_val *)&val_6547},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11024 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0214, (cst_val *)&val_0082},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11025 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0216, (cst_val *)&val_3552},
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0217, (cst_val *)&val_0590},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11026 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11027 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0220, (cst_val *)&val_0105},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11028 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11029 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0223, (cst_val *)&val_0590},
{ 18, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0224, (cst_val *)&val_0018},
{ 9, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0225, (cst_val *)&val_0004},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11030 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11031 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11032 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0229, (cst_val *)&val_1571},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11033 },
{ 12, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0231, (cst_val *)&val_0228},
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0232, (cst_val *)&val_1466},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11034 },
{ 3, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0234, (cst_val *)&val_5969},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11035 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11036 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0237, (cst_val *)&val_11037},
{ 19, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0238, (cst_val *)&val_0014},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11038 },
{ 14, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0240, (cst_val *)&val_0057},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11039 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11040 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0243, (cst_val *)&val_0617},
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0244, (cst_val *)&val_0479},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11041 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11042 },
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0247, (cst_val *)&val_11043},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11044 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11045 },
{ 20, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0250, (cst_val *)&val_0471},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11046 },
{ 5, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0252, (cst_val *)&val_3508},
{ 6, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0253, (cst_val *)&val_0088},
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0254, (cst_val *)&val_3552},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11047 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11048 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0257, (cst_val *)&val_0617},
{ 11, CST_CART_OP_LESS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0258, (cst_val *)&val_11049},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11050 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11051 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11052 },
{ 7, CST_CART_OP_IS, CTNODE_cmu_us_slt_single_mcep_pau_142_NO_0262, (cst_val *)&val_0617},
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11053 },
{ 255, CST_CART_OP_NONE, 0, (cst_val *)&val_11054 },
{ 255, CST_CART_OP_NONE, 0, 0}};


static const char * const cmu_us_slt_single_mcep_pau_142_feat_table[] = {
"R:mcep_link.parent.R:segstate.parent.n.ph_cvox",
"lisp_cg_phone_rindex",
"R:mcep_link.parent.R:segstate.parent.p.ph_cvox",
"lisp_cg_phone_index",
"R:mcep_link.parent.R:segstate.parent.n.ph_cplace",
"R:mcep_link.parent.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.n.ph_ctype",
"R:mcep_link.parent.R:HMMstate.n.name",
"lisp_cg_state_place",
"R:mcep_link.parent.R:segstate.parent.n.ph_vc",
"lisp_cg_phone_place",
"R:mcep_link.parent.R:segstate.p.lisp_cg_duration",
"R:mcep_link.parent.R:segstate.parent.p.ph_ctype",
"R:mcep_link.parent.R:segstate.parent.p.name",
"lisp_cg_state_rindex",
"lisp_cg_state_index",
"R:mcep_link.parent.R:segstate.parent.p.ph_vrnd",
"R:mcep_link.parent.R:segstate.parent.n.ph_vfront",
"R:mcep_link.parent.R:segstate.parent.n.lisp_is_pau",
"R:mcep_link.parent.R:segstate.parent.p.ph_vheight",
"R:mcep_link.parent.R:segstate.parent.p.ph_cplace",
NULL };

const cst_cart cmu_us_slt_single_mcep_pau_142_cart = {
  cmu_us_slt_single_mcep_pau_142_cart_nodes,
  cmu_us_slt_single_mcep_pau_142_feat_table
};


const cst_cart * const cmu_us_slt_single_mcep_carts[] = {
 &cmu_us_slt_single_mcep_zh_204_cart,
 &cmu_us_slt_single_mcep_zh_205_cart,
 &cmu_us_slt_single_mcep_zh_206_cart,
 &cmu_us_slt_single_mcep_oy_131_cart,
 &cmu_us_slt_single_mcep_oy_132_cart,
 &cmu_us_slt_single_mcep_oy_133_cart,
 &cmu_us_slt_single_mcep_ch_41_cart,
 &cmu_us_slt_single_mcep_ch_42_cart,
 &cmu_us_slt_single_mcep_ch_43_cart,
 &cmu_us_slt_single_mcep_aw_21_cart,
 &cmu_us_slt_single_mcep_aw_22_cart,
 &cmu_us_slt_single_mcep_aw_23_cart,
 &cmu_us_slt_single_mcep_ow_126_cart,
 &cmu_us_slt_single_mcep_ow_127_cart,
 &cmu_us_slt_single_mcep_ow_128_cart,
 &cmu_us_slt_single_mcep_b_36_cart,
 &cmu_us_slt_single_mcep_b_37_cart,
 &cmu_us_slt_single_mcep_b_38_cart,
 &cmu_us_slt_single_mcep_g_76_cart,
 &cmu_us_slt_single_mcep_g_77_cart,
 &cmu_us_slt_single_mcep_g_78_cart,
 &cmu_us_slt_single_mcep_ng_121_cart,
 &cmu_us_slt_single_mcep_ng_122_cart,
 &cmu_us_slt_single_mcep_ng_123_cart,
 &cmu_us_slt_single_mcep_uw_179_cart,
 &cmu_us_slt_single_mcep_uw_180_cart,
 &cmu_us_slt_single_mcep_uw_181_cart,
 &cmu_us_slt_single_mcep_sh_156_cart,
 &cmu_us_slt_single_mcep_sh_157_cart,
 &cmu_us_slt_single_mcep_sh_158_cart,
 &cmu_us_slt_single_mcep_uh_174_cart,
 &cmu_us_slt_single_mcep_uh_175_cart,
 &cmu_us_slt_single_mcep_uh_176_cart,
 &cmu_us_slt_single_mcep_hh_81_cart,
 &cmu_us_slt_single_mcep_hh_82_cart,
 &cmu_us_slt_single_mcep_hh_83_cart,
 &cmu_us_slt_single_mcep_ae_6_cart,
 &cmu_us_slt_single_mcep_ae_7_cart,
 &cmu_us_slt_single_mcep_ae_8_cart,
 &cmu_us_slt_single_mcep_y_194_cart,
 &cmu_us_slt_single_mcep_y_195_cart,
 &cmu_us_slt_single_mcep_y_196_cart,
 &cmu_us_slt_single_mcep_k_101_cart,
 &cmu_us_slt_single_mcep_k_102_cart,
 &cmu_us_slt_single_mcep_k_103_cart,
 &cmu_us_slt_single_mcep_aa_1_cart,
 &cmu_us_slt_single_mcep_aa_2_cart,
 &cmu_us_slt_single_mcep_aa_3_cart,
 &cmu_us_slt_single_mcep_ay_31_cart,
 &cmu_us_slt_single_mcep_ay_32_cart,
 &cmu_us_slt_single_mcep_ay_33_cart,
 &cmu_us_slt_single_mcep_w_189_cart,
 &cmu_us_slt_single_mcep_w_190_cart,
 &cmu_us_slt_single_mcep_w_191_cart,
 &cmu_us_slt_single_mcep_m_111_cart,
 &cmu_us_slt_single_mcep_m_112_cart,
 &cmu_us_slt_single_mcep_m_113_cart,
 &cmu_us_slt_single_mcep_pau_143_cart,
 &cmu_us_slt_single_mcep_ao_16_cart,
 &cmu_us_slt_single_mcep_ao_17_cart,
 &cmu_us_slt_single_mcep_ao_18_cart,
 &cmu_us_slt_single_mcep_th_169_cart,
 &cmu_us_slt_single_mcep_th_170_cart,
 &cmu_us_slt_single_mcep_th_171_cart,
 &cmu_us_slt_single_mcep_ah_11_cart,
 &cmu_us_slt_single_mcep_ah_12_cart,
 &cmu_us_slt_single_mcep_ah_13_cart,
 &cmu_us_slt_single_mcep_v_184_cart,
 &cmu_us_slt_single_mcep_v_185_cart,
 &cmu_us_slt_single_mcep_v_186_cart,
 &cmu_us_slt_single_mcep_dh_51_cart,
 &cmu_us_slt_single_mcep_dh_52_cart,
 &cmu_us_slt_single_mcep_dh_53_cart,
 &cmu_us_slt_single_mcep_d_46_cart,
 &cmu_us_slt_single_mcep_d_47_cart,
 &cmu_us_slt_single_mcep_d_48_cart,
 &cmu_us_slt_single_mcep_n_116_cart,
 &cmu_us_slt_single_mcep_n_117_cart,
 &cmu_us_slt_single_mcep_n_118_cart,
 &cmu_us_slt_single_mcep_jh_96_cart,
 &cmu_us_slt_single_mcep_jh_97_cart,
 &cmu_us_slt_single_mcep_jh_98_cart,
 &cmu_us_slt_single_mcep_r_146_cart,
 &cmu_us_slt_single_mcep_r_147_cart,
 &cmu_us_slt_single_mcep_r_148_cart,
 &cmu_us_slt_single_mcep_ey_66_cart,
 &cmu_us_slt_single_mcep_ey_67_cart,
 &cmu_us_slt_single_mcep_ey_68_cart,
 &cmu_us_slt_single_mcep_f_71_cart,
 &cmu_us_slt_single_mcep_f_72_cart,
 &cmu_us_slt_single_mcep_f_73_cart,
 &cmu_us_slt_single_mcep_ih_86_cart,
 &cmu_us_slt_single_mcep_ih_87_cart,
 &cmu_us_slt_single_mcep_ih_88_cart,
 &cmu_us_slt_single_mcep_p_136_cart,
 &cmu_us_slt_single_mcep_p_137_cart,
 &cmu_us_slt_single_mcep_p_138_cart,
 &cmu_us_slt_single_mcep_iy_91_cart,
 &cmu_us_slt_single_mcep_iy_92_cart,
 &cmu_us_slt_single_mcep_iy_93_cart,
 &cmu_us_slt_single_mcep_l_106_cart,
 &cmu_us_slt_single_mcep_l_107_cart,
 &cmu_us_slt_single_mcep_l_108_cart,
 &cmu_us_slt_single_mcep_z_199_cart,
 &cmu_us_slt_single_mcep_z_200_cart,
 &cmu_us_slt_single_mcep_z_201_cart,
 &cmu_us_slt_single_mcep_pau_161_cart,
 &cmu_us_slt_single_mcep_s_151_cart,
 &cmu_us_slt_single_mcep_s_152_cart,
 &cmu_us_slt_single_mcep_s_153_cart,
 &cmu_us_slt_single_mcep_eh_56_cart,
 &cmu_us_slt_single_mcep_eh_57_cart,
 &cmu_us_slt_single_mcep_eh_58_cart,
 &cmu_us_slt_single_mcep_t_164_cart,
 &cmu_us_slt_single_mcep_t_165_cart,
 &cmu_us_slt_single_mcep_t_166_cart,
 &cmu_us_slt_single_mcep_er_61_cart,
 &cmu_us_slt_single_mcep_er_62_cart,
 &cmu_us_slt_single_mcep_er_63_cart,
 &cmu_us_slt_single_mcep_ax_26_cart,
 &cmu_us_slt_single_mcep_ax_27_cart,
 &cmu_us_slt_single_mcep_ax_28_cart,
 &cmu_us_slt_single_mcep_pau_141_cart,
 &cmu_us_slt_single_mcep_pau_142_cart,
 0 };
